<?php
namespace Folha\Logic\ControlePonto;
use Folha\Entities\GpeParamorg;
use Folha\Logic\ControlePonto\DateUtil;
/**
 * Description of RegistroPonto
 *
 * @author ingridmoreira
 */
class RegistroPonto {
    
    private $marcacao;
    private $idEntradaSaida;
    private $idDentroHoraBase;
    private $idMarcacao;
    private $horarioCorrente;
    private $intervaloBaseIni;
    private $intervaloBaseFim;
    private $dsIntervaloProjetado;

    const BALIZA     = 'b';
    const REGISTRO   = 'r';
    const VIRADA     = 'v';
    const AUTOMATICA = 'a';
    const DIGITADA   = 'd';
    const PROJETADA  = 'p';
    
    
    public function __construct($data, $marcacao, $idEntradaSaida, $nrorg, $dsIntervaloProjetado = null){
        /** @var $marcacao \Folha\Entities\GpeMarcacaoponto */
        $this->marcacao = $marcacao;
        $dataPonto = DateUtil::getDataDeString($data, DateUtil::FORMATO_BRASILEIRO, true);

        $dtHrAjustada = DateUtil::getDataDeString($this->marcacao->getDthrajustada()->format('d/m/Y H:i'),'d/m/Y H:i');
        $this->getMarcacao()->setDthrajustada($dtHrAjustada);

        $dataMarcacao = $this->marcacao->getDthrajustada()->format(DateUtil::FORMATO_BRASILEIRO);
        $dataMarcacao = DateUtil::getDataDeString($dataMarcacao, DateUtil::FORMATO_BRASILEIRO, true);

        $this->idEntradaSaida       = $idEntradaSaida;
        $this->idDentroHoraBase     = 'N';
        $this->dsIntervaloProjetado = null;

        /** @var $paramOrg \Folha\Entities\GpeParamorg */
        $paramOrg = GpeParamorg::findOneByNrorg($nrorg);
        $coletoresEspeciais = array($paramOrg->getNrcoletormarcautom(), $paramOrg->getNrcoletormarcdigit(),
                                    $paramOrg->getNrcoletormarcgersist(), $paramOrg->getNrcoletormarcviradia(),
                                    $paramOrg->getNrcoletormarcprojetada());

        if(!in_array($this->marcacao->getNrcoletor(),$coletoresEspeciais)){
            $this->idMarcacao = self::REGISTRO;
        }
        else{
            if($this->marcacao->getNrcoletor() == $paramOrg->getNrcoletormarcgersist()){
                $this->idMarcacao = self::BALIZA;
            }
            elseif($this->marcacao->getNrcoletor() == $paramOrg->getNrcoletormarcviradia()){
                $this->idMarcacao = self::VIRADA;
            }
            elseif($this->marcacao->getNrcoletor() == $paramOrg->getNrcoletormarcdigit()){
                $this->idMarcacao = self::DIGITADA;
            }
            elseif($this->marcacao->getNrcoletor() == $paramOrg->getNrcoletormarcprojetada()){
                $this->idMarcacao = self::PROJETADA;
            }
            else{
                $this->idMarcacao = self::AUTOMATICA;
            }
        }

        if(is_null($this->marcacao->getIddiaocorrencia())){
            if(DateUtil::comparaDatas($dataMarcacao, $dataPonto, DateUtil::ANTES)){
                $this->marcacao->setIddiaocorrencia('DS');
            }
            elseif(DateUtil::comparaDatas($dataMarcacao, $dataPonto, DateUtil::DEPOIS)){
                $this->marcacao->setIddiaocorrencia('DA');
            }
            else{
                $this->marcacao->setIddiaocorrencia('DC');
            }
        }
    }

    public function getMarcacao(){
        return $this->marcacao;
    }
    
    public function setMarcacao($marcacao){
        $this->marcacao = $marcacao;
    }

    /**
     * @return mixed
     */
    public function getIdEntradaSaida()
    {
        return $this->idEntradaSaida;
    }

    /**
     * @param mixed $idEntradaSaida
     */
    public function setIdEntradaSaida($idEntradaSaida)
    {
        $this->idEntradaSaida = $idEntradaSaida;
    }

    /**
     * @return mixed
     */
    public function getIdDentroHoraBase()
    {
        return $this->idDentroHoraBase;
    }

    /**
     * @param mixed $idDentroHoraBase
     */
    public function setIdDentroHoraBase($idDentroHoraBase)
    {
        $this->idDentroHoraBase = $idDentroHoraBase;
    }

    /**
     * @return mixed
     */
    public function getIdMarcacao()
    {
        return $this->idMarcacao;
    }

    /**
     * @param mixed $idMarcacao
     */
    public function setIdMarcacao($idMarcacao)
    {
        $this->idMarcacao = $idMarcacao;
    }

    /**
     * @return mixed
     */
    public function getHorarioCorrente()
    {
        $horarioCorrente = $this->horarioCorrente;
        return $horarioCorrente;
    }

    /**
     * @param mixed $horarioCorrente
     */
    public function setHorarioCorrente($horarioCorrente)
    {
        $this->horarioCorrente = $horarioCorrente;
    }

    /**
     * @return mixed
     */
    public function getIntervaloBaseIni()
    {
        return $this->intervaloBaseIni;
    }

    /**
     * @param mixed $intervaloBaseIni
     */
    public function setIntervaloBaseIni($intervaloBaseIni)
    {
        $this->intervaloBaseIni = $intervaloBaseIni;
    }

    /**
     * @return mixed
     */
    public function getIntervaloBaseFim()
    {
        return $this->intervaloBaseFim;
    }

    /**
     * @param mixed $intervaloBaseFim
     */
    public function setIntervaloBaseFim($intervaloBaseFim)
    {
        $this->intervaloBaseFim = $intervaloBaseFim;
    }

    /**
     * @return mixed
     */
    public function getDsIntervaloProjetado()
    {
        return $this->dsIntervaloProjetado;
    }

    /**
     * @param mixed $dsIntervaloProjetado
     */
    public function setDsIntervaloProjetado($dsIntervaloProjetado)
    {
        $this->dsIntervaloProjetado = $dsIntervaloProjetado;
    }
}
