/*
 @C:\Web_625\Sql\End_Conv\SQLServer\5102_DFSSTPO_Imposto_Saida.SQL

 Descrio:
 Procedure para gerao dos impostos e valor final das notas de sada e dos valores contabis

  Parmetros

 P_EMPRESA     - Cddigo da empresa
 P_PRODUTO     - Cdigo de rvore do produto(CDARVPROD)
 P_INSCESTA    - Inscrio estadual do lanamento
 P_TIPOOPER    - Tipo de operao do lanamento
 P_CLIENTE     - Cdigo do destinatrio da nota (CDCLIENTE, CDFORNECED ou CDFILIAL)
 P_FILIAL      - Cdigo da filial do lanamento (CDFILIAL)
 P_LANCTONF    - Nmero do lanamento (NRLANCTONF)
 P_INIVALID    - Data de sada do lanamento
 P_VRNOTAFISC  - Valor final da nota
 P_LANCESTQ    - Nmero do lanamento de estoque
 P_CDOPERADOR  - Operador gravado na LANCTOESTOQ

 RAISERROR('', 16,1);
*/

IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
                    WHERE
	        O.NAME = 'IMPOSTO_SAIDA' AND
	        TYPE = 'P' 			      AND
	        U.UID = O.UID            AND
	        U.NAME = USER)
DROP PROCEDURE IMPOSTO_SAIDA
GO

CREATE PROCEDURE IMPOSTO_SAIDA @P_EMPRESA    VARCHAR(02),
                               @P_INSCESTA   VARCHAR(16),
                               @P_TIPOOPER   VARCHAR(02),
                               @P_CLIENTE    VARCHAR(21),
                               @P_FILIAL     VARCHAR(04),
                               @P_LANCTONF   VARCHAR(10),
                               @P_INIVALID   DATETIME,
                               @P_LANCESTQ   VARCHAR(10) = NULL,
                               @P_CDOPERADOR VARCHAR(12) = NULL,
                               @P_VRNOTAFISC NUMERIC(15,5) OUTPUT
AS
   DECLARE @V_PAISORIG     VARCHAR(04);
   DECLARE @V_ESTAORIG     VARCHAR(02);
   DECLARE @V_MUNIORIG     VARCHAR(04);
   DECLARE @V_PAISDEST     VARCHAR(04);
   DECLARE @V_ESTADEST     VARCHAR(02);
   DECLARE @V_MUNIDEST     VARCHAR(04);
   DECLARE @V_IDUTMUNIORIG VARCHAR(01);
   DECLARE @V_PAISCFOP     VARCHAR(04);
   DECLARE @V_ESTACFOP     VARCHAR(02);
   DECLARE @V_CDPAISST     VARCHAR(04);
   DECLARE @V_SGESTADOST   VARCHAR(02);
   DECLARE @V_CDMUNICIPIOST VARCHAR(04);
   DECLARE @V_CDINSCESTAST VARCHAR(16);
   DECLARE @V_ALIQTEMP     VARCHAR(14);
   DECLARE @V_NRALIQTEMP   VARCHAR(14);
   DECLARE @V_DADOADIC     VARCHAR(03);
   DECLARE @V_INCITEMP     VARCHAR(14);
   DECLARE @V_CST1DIGT     VARCHAR(1);
   DECLARE @V_CSTTEMP      VARCHAR(14);
   DECLARE @V_FISCALIT     VARCHAR(20);
   DECLARE @V_CFOPTEMP     VARCHAR(14);
   DECLARE @V_FISOPEITEM   VARCHAR(10);
   DECLARE @V_FISOPEITEMAUX VARCHAR(10);
   DECLARE @V_SUFXCFOPPR   VARCHAR(03);
   DECLARE @V_SITUTRIBPR   VARCHAR(03);
   DECLARE @V_NRINSJURNF   VARCHAR(20);
   DECLARE @V_SERIE        VARCHAR(05);
   DECLARE @V_TIPOMOVI     VARCHAR(01);
   DECLARE @V_CDFISCOPER   VARCHAR(10);
   DECLARE @V_CDFILIEMIT   VARCHAR(04);
   DECLARE @V_CDFILIRECE   VARCHAR(04);
   DECLARE @V_ORIGDESTOP   VARCHAR(01);
   DECLARE @V_CDFISOPENTF  VARCHAR(10);
   DECLARE @V_IDENDCFOP    VARCHAR(01);
   DECLARE @V_IDENDEMIS    VARCHAR(01);
   DECLARE @V_CDEMPRESA    VARCHAR(02);
   DECLARE @V_CDINSCESTA   VARCHAR(16);
   DECLARE @V_CDINTEGRACAO VARCHAR(16);
   DECLARE @V_IDORIGDESTNF VARCHAR(01);
   DECLARE @V_NRLANBOLREC  VARCHAR(10);
   DECLARE @V_IDDOCFINANC  VARCHAR(01);
   DECLARE @V_IDERROAVISO  VARCHAR(01);
   DECLARE @V_IDDOCREPLIC  VARCHAR(14);
   DECLARE @V_IDDOCESTOQ   VARCHAR(14);
   DECLARE @V_IDSISTEMA    VARCHAR(03);
   DECLARE @V_IDRETPROEXP  VARCHAR(01);
   DECLARE @V_IDATUEST     VARCHAR(01);
   DECLARE @V_NMTIPOOPER   VARCHAR(30);
   DECLARE @V_NMFILIRECE   VARCHAR(30);
   DECLARE @V_DESCLANC     VARCHAR(60);
   DECLARE @V_CDFISCTEMP   VARCHAR(01);
   DECLARE @V_CDDETALHEPRODTEMP VARCHAR(05);
   DECLARE @V_IDTRIMPSTII  VARCHAR(01);
   DECLARE @V_CDIMPOSTRIB  VARCHAR(250);
   DECLARE @V_CDIMPOSICMS  VARCHAR(250);
   DECLARE @V_IDVRIMPSTRIB VARCHAR(01);
   DECLARE @V_IDDEVOLIST   VARCHAR(01);
   DECLARE @V_IDINTEREST   VARCHAR(01);
   DECLARE @V_NRINSCSUFRAMA VARCHAR(09);
   DECLARE @V_IDINTERNA    VARCHAR(01);
   DECLARE @V_PARDEDTMP    NUMERIC(15,5);
   DECLARE @V_PREDBCTMP    NUMERIC(15,5);
   DECLARE @V_ALIQUTMP     NUMERIC(15,5);
   DECLARE @V_COUNT        NUMERIC;
   DECLARE @V_ERROAVISO    NUMERIC;
   DECLARE @V_LIQUIITEM    NUMERIC(15,5);
   DECLARE @V_TOTALNOTA    NUMERIC(15,5);
   DECLARE @V_LIQUIDO      NUMERIC(15,5);
   DECLARE @V_SOMAENCA     NUMERIC(15,5);
   DECLARE @V_MENOENCA     NUMERIC(15,5);
   DECLARE @V_SOMAIMPO     NUMERIC(15,5);
   DECLARE @V_MENOIMPO     NUMERIC(15,5);
   DECLARE @V_TOTAPRODENCA NUMERIC(15,5);
   DECLARE @V_TOTAPRENIMPO NUMERIC(15,5);
   DECLARE @V_TOTAIMPBCALC NUMERIC(15,5);
   DECLARE @V_TOTAIMPBCDES DOUBLE PRECISION;
   DECLARE @V_TAXABASECALC NUMERIC(15,5);
   DECLARE @V_TAXAALIQUOTA NUMERIC(15,5);
   DECLARE @V_TAXAALIQINFO NUMERIC(15,5);
   DECLARE @V_PRODUENCARGO NUMERIC(15,5);
   DECLARE @V_SEQUIMPOSTNF NUMERIC;
   DECLARE @V_SOMAITEM     NUMERIC(15,5);
   DECLARE @V_DESCITEM     NUMERIC(15,5);
   DECLARE @V_BASECALCIT   NUMERIC(15,5);
   DECLARE @V_BASECALCTO   NUMERIC(15,5);
   DECLARE @V_BASECALCIRRF NUMERIC(15,5);
   DECLARE @V_IMPOSTOIT    NUMERIC(15,5);
   DECLARE @V_VRIMPOSTO    NUMERIC(15,5);
   DECLARE @V_FATOCONV     NUMERIC(15,5);
   DECLARE @V_TOTABRUT     NUMERIC(15,5);
   DECLARE @V_SOMAIMPONF   NUMERIC(15,5);
   DECLARE @V_DESCIMPONF   NUMERIC(15,5);
   DECLARE @V_QTDELANCTO   NUMERIC(15,5);
   DECLARE @V_VRUNITLANCTO NUMERIC(15,5);
   DECLARE @V_VRTOTALANCTO NUMERIC(15,5);
   DECLARE @V_TOTACONTAB   NUMERIC(15,5);
   DECLARE @V_VRBRUTO      NUMERIC(15,5);
   DECLARE @V_VRCONTAB     NUMERIC(15,5);
   DECLARE @V_IMPOCONTAB   NUMERIC(15,5);
   DECLARE @V_TOTIMPOCONT  NUMERIC(15,5);
   DECLARE @V_TOTIMPOBRUT  NUMERIC(15,5);
   DECLARE @V_CONTIMPO     NUMERIC(15,5);
   DECLARE @V_IMPOSRETI    NUMERIC(15,5);
   DECLARE @V_CONTABCALC   NUMERIC(15,5);
   DECLARE @V_PERDBCALC    NUMERIC(15,5);
   DECLARE @V_FAIXATOLER   NUMERIC(15,5);
   DECLARE @V_NRDECITOTANF NUMERIC(15,5);
   DECLARE @V_IMPOSINFUSU  NUMERIC(15,5);
   DECLARE @V_VRCONTAREC   NUMERIC(15,5);
   DECLARE @V_VRDIFERENCA  NUMERIC(15,5);
   DECLARE @V_VALRDESCITEM NUMERIC(15,5);
   DECLARE @V_EXISTE_ROT   NUMERIC;
   DECLARE @V_NRSEQITPROD  NUMERIC;
   DECLARE @V_VRFATOCONV   DOUBLE PRECISION;
   DECLARE @V_VRLIQUORIG   DOUBLE PRECISION;
   DECLARE @V_VRPESOBRUTO  DOUBLE PRECISION;
   DECLARE @V_VRREDUCAO    DOUBLE PRECISION;
   DECLARE @V_TAXABCSUBSTR DOUBLE PRECISION;
   DECLARE @V_PBCSUBTRIB   DOUBLE PRECISION;
   DECLARE @V_VRIMPOSTOST  DOUBLE PRECISION;
   DECLARE @V_BASEVLRMAX   DOUBLE PRECISION;
   DECLARE @V_VRPEMAXVENDA DOUBLE PRECISION;
   DECLARE @V_CALCVLRMAX   DOUBLE PRECISION;
   DECLARE @V_VRMAXVENDA   DOUBLE PRECISION;
   DECLARE @V_QTITEMORIG   DOUBLE PRECISION;
   DECLARE @V_QTITEMPROD   DOUBLE PRECISION;

   DECLARE @V_CDGRUPOFISC  VARCHAR(03);
   DECLARE @V_CDGRPFISCSV  VARCHAR(03);
   DECLARE @V_UTGRUPFISCS  VARCHAR(01);
   DECLARE @V_CDORIGDESTNF VARCHAR(21);
   DECLARE @V_IDCTRLESTQ   VARCHAR(01);
   DECLARE @V_IDTPCOMPPROD VARCHAR(01);

   DECLARE @V_IDOPERDEVONF VARCHAR(01);
   DECLARE @V_IDCONSPARFIS VARCHAR(01);
   DECLARE @V_CHAVE        VARCHAR(21);
   DECLARE @V_CDFILIALIT   VARCHAR(04);
   DECLARE @V_NRLANCTONFIT VARCHAR(10);
   DECLARE @V_IMPOSTO      VARCHAR(02);
   DECLARE @V_IDUTILALMOX  VARCHAR(01);
   DECLARE @V_IDUTILLCESTQ VARCHAR(01);
   DECLARE @V_IDUTILLOTE   VARCHAR(01);
   DECLARE @V_IDRECALCULO  VARCHAR(01);
   DECLARE @V_TRATIMPST    VARCHAR(01);
   DECLARE @V_CDIMPOBCALC  VARCHAR(02);
   DECLARE @V_IDITEMISSAO  VARCHAR(01);
   DECLARE @V_CDFILIAPFATU VARCHAR(04);
   DECLARE @V_NRAPFATUTNF  VARCHAR(10);
   DECLARE @V_CDFILIMOVI   VARCHAR(04);
   DECLARE @V_IDPMCBASECAL VARCHAR(01);
   DECLARE @V_CDTIPOOPER   VARCHAR(02);

   DECLARE @V_CDENCDESCBONDEV VARCHAR(02);
   DECLARE @V_CDAJUCTPAG      VARCHAR(04);
   DECLARE @V_VRPEDESCFORN    DOUBLE PRECISION;
   DECLARE @V_VRENCARBONI     DOUBLE PRECISION;
   DECLARE @V_IDCONDESBONFORN VARCHAR(01);
   DECLARE @V_DTINIVRPDESC    DATETIME;

   DECLARE @V_DSCDFISOPEIT VARCHAR(50);
   DECLARE @V_ICMS         VARCHAR(01);

   DECLARE @V_VRTOTAITEM   NUMERIC(16,2);
   DECLARE @V_SOMATOTAITEM NUMERIC(16,2);
   DECLARE @V_PERCENTITEM  NUMERIC;

   /*VARIVEIS DO CST DE NFE*/
   DECLARE @V_CDSITTRIBTMP VARCHAR(02);
   DECLARE @V_IDMODBCNFE   VARCHAR(01);
   DECLARE @V_IDMODBCSTNFE VARCHAR(01);
   DECLARE @V_CDTPCRPICOSTNFE   VARCHAR(03);
   DECLARE @V_CDNATUBCPCSTNFE   VARCHAR(02);

   DECLARE @V_CDSITUTRIBNFE VARCHAR(02);
   DECLARE @V_IDMODBCNFEIT   VARCHAR(01);
   DECLARE @V_IDMODBCSTNFEIT VARCHAR(01);
   DECLARE @V_CDTPCRPICOSTNFEIT VARCHAR(03);
   DECLARE @V_CDNATUBCPCSTNFEIT VARCHAR(02);

   /*VARIVEIS DO CURSOR C_IMPOSTORETI*/
   DECLARE @V_IMPRETI_CDEMPRESA   VARCHAR(02);
   DECLARE @V_IMPRETI_CDIMPOSTO   VARCHAR(02);
   DECLARE @V_IMPRETI_IDTPIJURNF  VARCHAR(01);
   DECLARE @V_IMPRETI_NRINSJURNF  VARCHAR(20);
   DECLARE @V_IMPRETI_DTENTRSAID  DATETIME;

   /*VARIVEIS DO CURSOR C_ITEMPRODUTO*/
   DECLARE @V_ITEMPROD_VRTOTAITEM   NUMERIC(16,2);
   DECLARE @V_ITEMPROD_VRDESCITEM   NUMERIC(16,2);
   DECLARE @V_ITEMPROD_CDPRODUTO    VARCHAR(10);
   DECLARE @V_ITEMPROD_NRSEQITPROD  VARCHAR(04);
   DECLARE @V_ITEMPROD_CDCSTINFUSU  VARCHAR(02);
   DECLARE @V_ITEMPROD_CDCFOPINFUSU VARCHAR(10);
   DECLARE @V_ITEMPROD_CDSUFXINFUSU VARCHAR(03);
   DECLARE @V_ITEMPROD_CDARVPROD    VARCHAR(20);
   DECLARE @V_ITEMPROD_QTITEMPROD   NUMERIC(10,3);
   DECLARE @V_ITEMPROD_IDORIGEMPROD VARCHAR(01);

   /*VARIVEIS DO CURSOR C_CSTTEMP*/
   DECLARE @V_CSTTMP_DSMENSCSTTMP   VARCHAR(120);

   /*VARIVEIS DO CURSOR C_CFOPTEMP*/
   DECLARE @V_CFOPTMP_DSMENSCFOTMP  VARCHAR(120);

   /*VARIVEIS DO CURSORC_INCITEMP*/
   DECLARE @V_INCITMP_DSMENSINCTMP  VARCHAR(120);

   /*VARIVEIS DO CURSOR C_INCIDENCIA*/
   DECLARE @V_INCIDEN_CDIMPOTEMP    VARCHAR(02);
   DECLARE @V_INCIDEN_CDFISCTEMP    VARCHAR(01);
   DECLARE @V_INCIDEN_IDTRATIMPTMP  VARCHAR(01);
   DECLARE @V_INCIDEN_IDCONSISTENT  VARCHAR(01);
   DECLARE @V_INCIDEN_IDIMPORECUP   VARCHAR(01);
   DECLARE @V_INCIDEN_IDUTMUNIORIG  VARCHAR(01);
   DECLARE @V_INCIDEN_IDUTVLRQTDEIMPO  VARCHAR(01);
   DECLARE @V_INCIDEN_CDDETALHEPROD VARCHAR(05);
   DECLARE @V_INCIDEN_CDREGRATMP    VARCHAR(10);
   DECLARE @V_INCIDEN_CDIMPOSTONFE  VARCHAR(02);
   DECLARE @V_INCIDEN_CDENQLEGALIPI VARCHAR(03);
   DECLARE @V_INCIDEN_CDCEST        VARCHAR(09);
   DECLARE @V_INCIDEN_VRADICALIQFECP DOUBLE PRECISION;

   /*VARIVEIS DO CURSOR C_ALIQTEMP*/
   DECLARE @V_ALIQTMP_DSMENSALITMP  VARCHAR(120);

   /*VARIVEIS DO CURSOR C_IMPOSINFUSU*/
   DECLARE @V_IMPOSINFUSU_CDIMPOSTO    VARCHAR(02);
   DECLARE @V_IMPOSINFUSU_CDFISCINFUSU VARCHAR(01);
   DECLARE @V_IMPOSINFUSU_VRALIQINFUSU NUMERIC(10,2);
   DECLARE @V_IMPOSINFUSU_VRRDBCINFUSU NUMERIC(10,2);
   DECLARE @V_IMPOSINFUSU_VRPDEDINFUSU NUMERIC(16,2);
   DECLARE @V_IMPOSINFUSU_IDTRATIMPO   VARCHAR(01);
   DECLARE @V_IMPOSINFUSU_IDCONSISTENT VARCHAR(01);
   DECLARE @V_IMPOSINFUSU_IDIMPORECUP  VARCHAR(01);

   /*VARIVEIS DO CURSOR C_ITEMENCARGO*/
   DECLARE @V_ITEMENC_CDENCARGO        VARCHAR(02);
   DECLARE @V_ITEMENC_VRITEMENCA       NUMERIC(16,2);
   DECLARE @V_ITEMENC_IDENCARGO        VARCHAR(01);
   DECLARE @V_ITEMENC_CDCTBLENTREN     VARCHAR(20);
   DECLARE @V_ITEMENC_CDCTBLSAIDEN     VARCHAR(20);

   /*VARIVEIS DO CURSOR C_VRLIQRATEIO*/
   DECLARE @V_VRLIQ_NRSEQITPROD        VARCHAR(04);
   DECLARE @V_VRLIQRAT_VRLIQUIDO       NUMERIC(15,6);
   DECLARE @V_VRLIQRAT_NRSEQITPROD     NUMERIC(15,6);

   DECLARE @V_VRLIQ_VRLIQUIDO          NUMERIC(16,2);

   /*VARIVEIS DO CURSOR C_ATUAVRCONT*/
   DECLARE @V_ATUAVR_NRSEQITPROD       VARCHAR(04);
   DECLARE @V_ATUAVR_VRLIQUIDO         NUMERIC(15,6);
   DECLARE @V_ATUAVR_CDIMPOSTO         VARCHAR(02);
   DECLARE @V_ATUAVR_VRIMPOSTOIT       NUMERIC(18,5);
   DECLARE @V_ATUAVR_CDFISCALIT        VARCHAR(01);
   DECLARE @V_ATUAVR_IDIMPORECUP       VARCHAR(01);
   DECLARE @V_ATUAVR_CDCCTBLATIV       VARCHAR(20);
   DECLARE @V_ATUAVR_CDCCTBLPASS       VARCHAR(20);
   DECLARE @V_ATUAVR_IDTRATIMPO        VARCHAR(01);
   DECLARE @V_ATUAVR_IDTIPCONTAB       VARCHAR(20);
   DECLARE @V_ATUAVR_NRITPROIMPOS      VARCHAR(01);

   /*VARIVEIS DO CURSOR C_ITEMPROIMPOS*/
   DECLARE @V_ITEMPROI_NRSEQITPROD     VARCHAR(04);
   DECLARE @V_ITEMPROI_NRITPROIMPOS    VARCHAR(01);
   DECLARE @V_ITEMPROI_CDIMPOSTO       VARCHAR(02);
   DECLARE @V_ITEMPROI_VRPERREDBCIT    NUMERIC(10,2);
   DECLARE @V_ITEMPROI_VRALIQITEM      NUMERIC(10,2);
   DECLARE @V_ITEMPROI_VRPARDEDIT      NUMERIC(16,2);
   DECLARE @V_ITEMPROI_VRLIQUIDO       NUMERIC(15,6);
   DECLARE @V_ITEMPROI_VRALIQINTEDEST  DOUBLE PRECISION;
   DECLARE @V_ITEMPROI_VRALIQFCP       DOUBLE PRECISION;
   DECLARE @V_ITEMPROI_VRALIQIMPOIT    NUMERIC(10,2);
   DECLARE @C_ITEMPROIMPOS_CDSITUTRIBNFE VARCHAR(02);
   DECLARE @C_ITEMPROIMPOS_IDMODBCNFE    VARCHAR(01);
   DECLARE @C_ITEMPROIMPOS_IDMODBCSTNFE  VARCHAR(01);
   DECLARE @C_ITEMPROIMPOS_IDMOTDESONERAIT VARCHAR(01);
   DECLARE @V_ITEMPROI_IDVALORINFO       VARCHAR(01);
   DECLARE @V_ITEMPROI_IDTRIMPSTII       VARCHAR(01);

   /*VARIVEIS DO CURSOR C_PRODUTO*/
   DECLARE @V_PRODUTO_NRSEQITPROD      VARCHAR(04);
   DECLARE @V_PRODUTO_CDIMPOSTO        VARCHAR(02);
   DECLARE @V_PRODUTO_VRPERREDBCIT     NUMERIC(10,2);
   DECLARE @V_PRODUTO_VRALIQITEM       NUMERIC(10,2);
   DECLARE @V_PRODUTO_VRPARDEDIT       NUMERIC(16,2);
   DECLARE @V_PRODUTO_CDFISCALIT       VARCHAR(01);
   DECLARE @V_PRODUTO_VRIMPOSTOIT      NUMERIC(16,2);
   DECLARE @V_PRODUTO_IDTRATIMPO       VARCHAR(01);
   DECLARE @V_PRODUTO_IDIMPORECUP      VARCHAR(01);
   DECLARE @V_PRODUTO_CDCCTBLPASS      VARCHAR(20);
   DECLARE @V_PRODUTO_CDCCTBLATIV      VARCHAR(20);
   DECLARE @V_PRODUTO_NRITPROIMPOS     VARCHAR(01);
   DECLARE @V_PRODUTO_IDTIPCONTAB      VARCHAR(20);
   DECLARE @V_PRODUTO_VRBASECALCIT     DOUBLE PRECISION;

   /*VARIVEIS DO CURSOR C_IMPOSNFTOT*/
   DECLARE @V_IMPOSNF_CDIMPOSTO        VARCHAR(02);
   DECLARE @V_IMPOSNF_VRIMPOSTOIT      NUMERIC(16,2);
   DECLARE @V_IMPOSNF_VRBASECALCIT     NUMERIC(16,2);

   /*VARIVEIS DO CURSOR C_IMPOSCONTAB*/
   DECLARE @V_IMPOSCNTTAB_VRTOTIMPONF  NUMERIC(15,2);
   DECLARE @V_IMPOSCNTTAB_IDIMPORECUP  VARCHAR(01);
   DECLARE @V_IMPOSCNTTAB_CDCCTBLPASS  VARCHAR(20);
   DECLARE @V_IMPOSCNTTAB_CDCCTBLATIV  VARCHAR(20);
   DECLARE @V_IMPOSCNTTAB_IDTRATIMPO   VARCHAR(01);
   DECLARE @V_IMPOSCNTTAB_CDFISCTEMP   VARCHAR(01);
   DECLARE @V_IMPOSCNTTAB_IDTIPCONTAB  VARCHAR(20);

   /*VARIVEIS DO CURSOR C_ITPRODUTO*/
   DECLARE @V_ITPROD_NRSEQITPROD       VARCHAR(04);
   DECLARE @V_ITPROD_VRLIQUIDO         NUMERIC(15,6);

   /*VARIVEIS DO CURSOR C_IMPOSTONF*/
   DECLARE @V_IMPOSTONF_CDIMPOSTO        VARCHAR(02);
   DECLARE @V_IMPOSTONF_NRIMPOSNF        VARCHAR(02);
   DECLARE @V_IMPOSTONF_VRCONTABILNF     NUMERIC(18,5);
   DECLARE @V_IMPOSTONF_VRPERREDBCNF     NUMERIC(10,2);
   DECLARE @V_IMPOSTONF_VRBASECALCNF     NUMERIC(15,2);
   DECLARE @V_IMPOSTONF_VRALIQNF         NUMERIC(10,2);
   DECLARE @V_IMPOSTONF_VRPARDEDNF       NUMERIC(15,2);
   DECLARE @V_IMPOSTONF_VRIMPOSTONF      NUMERIC(15,2);
   DECLARE @V_IMPOSTONF_CDFISCALNF       VARCHAR(01);
   DECLARE @V_IMPOSTONF_CDSITUTRIBNF     VARCHAR(03);
   DECLARE @V_IMPOSTONF_CDFISCOPERNF     VARCHAR(10);
   DECLARE @V_IMPOSTONF_CDSUFXCFOPNF     VARCHAR(03);
   DECLARE @V_IMPOSTONF_VRALIQITEM       NUMERIC(10,2);
   DECLARE @V_IMPOSTONF_VRPERREDBCIT     NUMERIC(10,2);
   DECLARE @V_IMPOSTONF_VRPARDEDIT       NUMERIC(16,2);
   DECLARE @V_IMPOSTONF_CDFISCALIT       VARCHAR(01);
   DECLARE @V_IMPOSTONF_CDSITUTRIBIT     VARCHAR(02);
   DECLARE @V_IMPOSTONF_CDFISCOPERIT     VARCHAR(10);
   DECLARE @V_IMPOSTONF_CDSUFXCFOPIT     VARCHAR(03);
   DECLARE @V_IMPOSTONF_VRCONTITIMP      NUMERIC(16,2);
   DECLARE @V_IMPOSTONF_VRBASECALCIT     NUMERIC(16,2);
   DECLARE @V_IMPOSTONF_VRIMPOSTOIT      NUMERIC(16,2);
   DECLARE @V_IMPOSTONF_NRITPROIMPOS     VARCHAR(01);
   DECLARE @V_IMPOSTONF_IDTRIMPSTII      VARCHAR(01);
   DECLARE @V_IMPOSTONF_IDTRIMPOSTNF     VARCHAR(01);
   DECLARE @V_IMPOSTONF_CDSITUTRIBIMNFE  VARCHAR(02);
   DECLARE @V_IMPOSTONF_VRCARGTRIB       NUMERIC(16,2);
   DECLARE @V_IMPOSTONF_IDIMPORECUP      VARCHAR(02);
   DECLARE @V_IMPOSTONF_CDTPCREDPICONF   VARCHAR(03);
   DECLARE @V_IMPOSTONF_CDNATUBCALPCNF   VARCHAR(02);
   DECLARE @V_IMPOSTONF_IDMOTDESONERANF  VARCHAR(01);
   DECLARE @V_IMPOSTONF_VRBCICMSSTRETIDO DOUBLE PRECISION;
   DECLARE @V_IMPOSTONF_VRICMSSTRETIDO   DOUBLE PRECISION;
   DECLARE @V_IMPOSTONF_IDDIFALIQCUSPRI  VARCHAR(01);

   /*VARIVEIS DO CURSOR C_ITEMPROD*/
   DECLARE @V_ITEMPRODU_CDFILIAL       VARCHAR(04);
   DECLARE @V_ITEMPRODU_NRLANCTONF     VARCHAR(10);
   DECLARE @V_ITEMPRODU_NRSEQITPROD    VARCHAR(04);
   DECLARE @V_ITEMPRODU_CDPRODUTO      VARCHAR(10);
   DECLARE @V_ITEMPRODU_CDPRODEMIS     VARCHAR(20);
   DECLARE @V_ITEMPRODU_DSPRODEMIS     VARCHAR(200);
   DECLARE @V_ITEMPRODU_IDATUVRESTOQ   VARCHAR(01);
   DECLARE @V_ITEMPRODU_QTITEMPROD     NUMERIC(10,3);
   DECLARE @V_ITEMPRODU_VRUNITITEM     NUMERIC(16,2);
   DECLARE @V_ITEMPRODU_VRDESCITEM     NUMERIC(16,2);
   DECLARE @V_ITEMPRODU_VRTOTAITEM     NUMERIC(16,2);
   DECLARE @V_ITEMPRODU_VRCONTITEM     NUMERIC(16,2);
   DECLARE @V_ITEMPRODU_IDCONFORITEM   VARCHAR(01);
   DECLARE @V_ITEMPRODU_CDFISOPEITEM   VARCHAR(10);
   DECLARE @V_ITEMPRODU_CDSUFXCFOPPR   VARCHAR(03);
   DECLARE @V_ITEMPRODU_CDSITUTRIBPR   VARCHAR(02);
   DECLARE @V_ITEMPRODU_IDERROSITEM    VARCHAR(05);
   DECLARE @V_ITEMPRODU_IDAVISOSITEM   VARCHAR(05);
   DECLARE @V_ITEMPRODU_VRBRUTITEM     NUMERIC(16,2);
   DECLARE @V_ITEMPRODU_CDARVPROD      VARCHAR(20);
   DECLARE @V_ITEMPRODU_NRLOTEESTQ     VARCHAR(20);
   DECLARE @V_ITEMPRODU_NRSUBLOTE      VARCHAR(04);
   DECLARE @V_ITEMPRODU_IDORIGEMPROD   VARCHAR(01);

   /*VARIVEIS DO CURSOR C_ITLANCTOEST*/
   DECLARE @V_ITLANCT_NRSEQITPROD      VARCHAR(04);
   DECLARE @V_ITLANCT_CDPRODUTO        VARCHAR(10);
   DECLARE @V_ITLANCT_VRUNITITEM       NUMERIC(16,2);
   DECLARE @V_ITLANCT_VRTOTAITEM       NUMERIC(16,2);
   DECLARE @V_ITLANCT_CDFILIMOVI       VARCHAR(04);
   DECLARE @V_ITLANCT_QTITEMPROD       NUMERIC(10,3);
   DECLARE @V_ITLANCT_CDPRODESTO       VARCHAR(10);
   DECLARE @V_ITLANCT_VRBRUTITEM       NUMERIC(16,2);
   DECLARE @V_ITLANCT_VRDESCITEM       NUMERIC(16,2);
   DECLARE @V_ITLANCT_VRCONTITEM       NUMERIC(16,2);
   DECLARE @V_ITLANCT_CDALMOXARIFE     VARCHAR(06);
   DECLARE @V_ITLANCT_CDLOCALESTOQ     VARCHAR(06);
   DECLARE @V_ITLANCT_NRLOTEESTQ       VARCHAR(20);
   DECLARE @V_ITLANCT_NRSUBLOTE        VARCHAR(04);
   DECLARE @V_ITLANCT_NRPEDIDO         VARCHAR(10);
   DECLARE @V_ITLANCT_NRITEMPED        VARCHAR(10);
   DECLARE @V_ITLANCT_VRCONTITEMORIG   NUMERIC(16,2);
   DECLARE @V_ITLANCT_VRBRUTITEMORIG   NUMERIC(16,2);
   DECLARE @V_ITLANCT_CDARVPROD        VARCHAR(20);
   DECLARE @V_ITLANCT_NMPRODUTO        VARCHAR(50);
   DECLARE @V_ITLANCT_IDORIGEMPROD     VARCHAR(01);

   /*VARIVEIS DO CURSOR C_IMPOSNFTOT*/
   DECLARE @V_IMPOSNFTOT_CDIMPOSTO     VARCHAR(02);
   DECLARE @V_IMPOSNFTOT_VRIMPOSTOIT   NUMERIC(16,2);
   DECLARE @V_IMPOSNFTOT_VRBASECALCIT  NUMERIC(16,2);
   DECLARE @V_IMPOSNFTOT_VRTOTIMPONF   NUMERIC(16,2);
   DECLARE @V_IMPOSNFTOT_VRTOTBCALCNF  NUMERIC(16,2);

   /*VARIVEIS DO CURSOR C_NOTABEBICRED*/
   DECLARE @V_NOTABEBICRED_VRTOTAITEM    NUMERIC(16,2);
   DECLARE @V_NOTABEBICRED_IDITEMISSAO   VARCHAR(01);
   DECLARE @V_NOTABEBICRED_CDPRODUTO     VARCHAR(10);
   DECLARE @V_NOTABEBICRED_IDTPNFCREDEB  VARCHAR(01);

   /*VARIVEIS DO CURSOR C_ITEMPRODUIMPOS*/
   DECLARE @C_ITEMPROIMPOS_CDIMPOSTO VARCHAR(02);
   DECLARE @C_ITEMPROIMPOS_CDFISCALIT VARCHAR(02);
   DECLARE @C_ITEMPROIMPOS_NRITPROIMPOS VARCHAR(01);
   DECLARE @C_ITEMPROIMPOS_VRALIQITEM NUMERIC(15,5);
   DECLARE @C_ITEMPROIMPOS_VRPERREDBCIT NUMERIC(10,2);
   DECLARE @C_ITEMPROIMPOS_VRPARDEDIT NUMERIC(16,2);
   DECLARE @C_ITEMPROIMPOS_VRCONTITIMP NUMERIC(18,5);
   DECLARE @C_ITEMPROIMPOS_VRBASECALCIT NUMERIC(16,2);
   DECLARE @C_ITEMPROIMPOS_VRIMPOSTOIT NUMERIC(18,5);
   DECLARE @C_ITEMPROIMPOS_CDTPCREDPICOITE VARCHAR(03);
   DECLARE @C_ITEMPROIMPOS_CDNATUBCALPCIT VARCHAR(02);
   DECLARE @C_ITEMPROIMPOS_IDTRIMPSTII VARCHAR(01);
   DECLARE @C_ITEMPROIMPOS_IDDIFALIQCUSPRI VARCHAR(01);
   DECLARE @C_ITEMPROIMPOS_CDIMPOSTONFE VARCHAR(02);
   DECLARE @C_ITEMPROIMPOS_CDENQLEGALIPI VARCHAR(03);
   DECLARE @C_ITEMPROIMPOS_CDCEST VARCHAR(09);
   DECLARE @C_ITEMPROIMPOS_IDUTVRPAUTAPROD VARCHAR(09);
   DECLARE @C_ITEMPROIMPOS_VRPAUTAMINPROD VARCHAR(09);
   DECLARE @C_ITEMPROIMPOS_QTITEMPROD VARCHAR(09);
   DECLARE @C_ITEMPROIMPOS_IDUTVRPAUTA VARCHAR(09);


   /*VARIVEIS DO CURSOR C_ITPROD*/
   DECLARE @V_ITPROD_CDPRODUTO    VARCHAR(10);
   DECLARE @V_ITPROD_CDCFOPINFUSU VARCHAR(05);
   DECLARE @V_ITPROD_CDSUFXINFUSU VARCHAR(03);
   DECLARE @V_ITPROD_CDCSTINFUSU  VARCHAR(03);
   DECLARE @V_ITPROD_NRSEQIT      VARCHAR(04);
   DECLARE @V_ITPROD_CDARVPROD    VARCHAR(20);
   DECLARE @V_ITPROD_IDORIGEMPROD VARCHAR(01);

   /*VARIAVEIS DO CURSOR C_ITEM*/
   DECLARE @C_ITEM_VRBRUTITEM   FLOAT;
   DECLARE @C_ITEM_VRCONTITEM   FLOAT;
   DECLARE @C_ITEM_NRSEQITPROD  VARCHAR(04);
   DECLARE @C_ITEM_CDIMPOSTO    VARCHAR(02);

   /*VARIVEIS DO CURSOR C_INCBCALC*/
   DECLARE @V_INCBCALC_CDFILIAL     VARCHAR(04);
   DECLARE @V_INCBCALC_NRLANCTONF   VARCHAR(10);
   DECLARE @V_INCBCALC_CDIMPOBCALC  VARCHAR(02);
   DECLARE @V_IDCNTRESTOQ           VARCHAR(01);

   DECLARE @V_IMPOSNFCOMP_CDFILIAL  VARCHAR(04);
   DECLARE @V_IMPOSNFCOMP_NRLANCTONF VARCHAR(10);
   DECLARE @V_IMPOSNFCOMP_CDIMPOSTO  VARCHAR(02);

   /*VARIVEIS DO CURSOR C_ITPROI*/
   DECLARE @V_ITPROI_CDIMPOSTO VARCHAR(02);
   DECLARE @V_ITPROI_NRITPROIMPOS VARCHAR(01);

   /*VARIVEIS DO CURSOR C_MENSINSC*/
   DECLARE @V_MENSINSC_CDMENSAGEM VARCHAR(03);
   DECLARE @V_MENSINSC_DSMENSINSCRESTA VARCHAR(120);

   /*VARIVEIS DO CURSOR C_MENSCLIENTE*/
   DECLARE @V_MENSCLIENTE_CDMENSAGEM VARCHAR(03);
   DECLARE @V_MENSCLIENTE_DSMENSCLIENTE VARCHAR(250);


   /*VARIVEIS DO CURSOR ICMSST*/
   DECLARE @V_ICMSST_CDIMPOSTRIB VARCHAR(02);

   /*VARIVEIS DO CURSOR C_ICMS*/
   DECLARE @C_ICMS VARCHAR(01);
   DECLARE @V_IMPOSTOTMP VARCHAR(02);

   /*VARIVEIR DO CURSOR C_ITEMENCARGO*/
   DECLARE @V_ITEMENCARGO_CDENCARGONFE VARCHAR(02);
   DECLARE @V_ITEMENCARGO_VRITEMENCA   NUMERIC(16,2);

   /*VARIVEIS DO CURSOR C_ITEMPRODUTO*/
   DECLARE @V_ITEMPRODUTO_NRSEQITPROD VARCHAR(04);
   DECLARE @V_ITEMPRODUTO_VRTOTAITEM  NUMERIC(16,2);

   DECLARE @V_CDFISCOPERSN VARCHAR(04);
   DECLARE @V_IMPOICMS     VARCHAR(02);

   DECLARE @V_IDIMPOBCALTPOP  VARCHAR(01);
   DECLARE @V_IDIMBCALTPOPDE  VARCHAR(01);

  /*VARIVEIS DO CURSOR C_IMPFISC*/
   DECLARE @V_IMPFISC_CDFILIAL     VARCHAR(04);
   DECLARE @V_IMPFISC_NRLANCTONF   VARCHAR(10);
   DECLARE @V_IMPFISC_CDIMPOSTO    VARCHAR(02);
   DECLARE @V_IMPFISC_CDSITUTRIBNF VARCHAR(03);
   DECLARE @V_IMPFISC_CDFISCOPERNF VARCHAR(11);
   DECLARE @V_IMPFISC_CDFISCALNF   VARCHAR(01);
   DECLARE @V_VRFRETEITEM   DOUBLE PRECISION;
   DECLARE @V_VRSEGURITEM   DOUBLE PRECISION;
   DECLARE @V_VRENCARGODESC DOUBLE PRECISION;
   DECLARE @V_DIFERENCA     DOUBLE PRECISION;
   DECLARE @V_SUMVRDESCITEM DOUBLE PRECISION;
   DECLARE @V_VROUTRASDESPITEM DOUBLE PRECISION;
   DECLARE @V_VRDESPADUANEIRA  DOUBLE PRECISION;
   DECLARE @V_IMPOSDESONERA    DOUBLE PRECISION;
   DECLARE @V_IDMOTIDESSTNFE VARCHAR(01);

   /*VARIVEIS DO CURSOR C_IMPOSITEMCOM*/
   DECLARE @V_IMPOSITEMCOM_NRSEQITPROD VARCHAR(04);
   DECLARE @V_IMPOSITEMCOM_CDIMPOSTO VARCHAR(02);
   DECLARE @V_IMPOSITEMCOM_NRITPROIMPOS VARCHAR(01);
   DECLARE @V_IMPOSITEMCOM_VRCONTITIMP DOUBLE PRECISION;
   DECLARE @V_IMPOSITEMCOM_VRPERREDBCIT DOUBLE PRECISION;
   DECLARE @V_IMPOSITEMCOM_VRBASECALCIT DOUBLE PRECISION;
   DECLARE @V_IMPOSITEMCOM_VRALIQITEM DOUBLE PRECISION;
   DECLARE @V_IMPOSITEMCOM_VRPARDEDIT DOUBLE PRECISION;
   DECLARE @V_IMPOSITEMCOM_VRIMPOSTOIT DOUBLE PRECISION;
   DECLARE @V_IMPOSITEMCOM_CDFISCALIT VARCHAR(01);
   DECLARE @V_IMPOSITEMCOM_IDUTVLRQTEIMPO VARCHAR(01);
   DECLARE @V_IMPOSITEMCOM_CDSITUTRIBIT VARCHAR(03);
   DECLARE @V_IMPOSITEMCOM_CDFISCOPERIT VARCHAR(04);
   DECLARE @V_IMPOSITEMCOM_VRPERMAJBCIT DOUBLE PRECISION;
   DECLARE @V_IMPOSITEMCOM_CDARVPROD    VARCHAR(20);
   DECLARE @V_IMPOSITEMCOM_CDENQLEGALIPI VARCHAR(03);
   DECLARE @V_IMPOSITEMCOM_CDCEST VARCHAR(09);

   /*VARIVEIS DO CURSOR C_MENSINSCESTAST*/
   DECLARE @C_MENSINSCESTAST_CDMENSAGEM VARCHAR(03);
   DECLARE @C_MENSINSCESTAST_DSMENSINSCESTAST VARCHAR(250);

   DECLARE @V_CDIMPOSTO VARCHAR(02);

   DECLARE @V_CDSITUCRT         VARCHAR(01);
   DECLARE @V_CDSIMPLESNACIONAL VARCHAR(5);
   DECLARE @V_RBT12             DOUBLE PRECISION; --RECEITA BRUTA TOTAL DOS LTIMOS 12 MESES
   DECLARE @V_RBA               DOUBLE PRECISION; --RECEITA BRUTA ACUMULADA
   DECLARE @V_VRSUBLIMITESN     DOUBLE PRECISION;
   DECLARE @V_VRALIQSIMPLES     DOUBLE PRECISION;
   DECLARE @V_APROVICMS         DOUBLE PRECISION;
   DECLARE @V_ALIQAPROVICMS     DOUBLE PRECISION;
   DECLARE @V_SIMPLES           VARCHAR(01);
   DECLARE @V_CDFAIXA           VARCHAR(5)
   DECLARE @V_IDUTCTRLLOTE      VARCHAR(01);
   DECLARE @V_NRLOTEESTQ        VARCHAR(20);
   DECLARE @V_MEDIA             INTEGER;
   DECLARE @V_BCICMSSTRETIDO    DOUBLE PRECISION;
   DECLARE @V_VRICMSSTRETIDO    DOUBLE PRECISION;
   DECLARE @V_ESTORNOCANC       VARCHAR(01);

    /*Alquota do imposto que possui diferencial de alquota*/
   DECLARE @V_DIFALIQ           DOUBLE PRECISION;

   DECLARE @V_CDFISCOPERREGRA     VARCHAR(10);
   DECLARE @V_DSCDFISOPEITREGRA   VARCHAR(50);
   DECLARE @V_IDDIFEALIQREGRA     VARCHAR(10);
   DECLARE @V_IDDIFALIQCUSPRREGRA VARCHAR(10);
   DECLARE @V_CFOPINFUSU          VARCHAR(01);
   DECLARE @V_CFOP1DIGT           VARCHAR(01);

   /*VARIVEIS DO CURSOR C_ICMSSTRETIDO*/
   DECLARE @V_ICMSSTRETIDO_CDFILIAL    VARCHAR(04);
   DECLARE @V_ICMSSTRETIDO_NRLANCTONF  VARCHAR(10);
   DECLARE @V_ICMSSTRETIDO_NRSEQITPROD VARCHAR(04);
   DECLARE @V_ICMSSTRETIDO_CDIMPOSTO   VARCHAR(02);
   DECLARE @V_ICMSSTRETIDO_VRBASE      DOUBLE PRECISION;
   DECLARE @V_ICMSSTRETIDO_VRIMPOSTO   DOUBLE PRECISION;
   DECLARE @V_TESTE VARCHAR(250);
   DECLARE @V_EXISTDSDADOSADIC  INTEGER;
   DECLARE @V_BCICMSRET       DOUBLE PRECISION;
   DECLARE @V_ICMSRET         DOUBLE PRECISION;

   /*VARIVEIS DO CURSOR C_ITEMIMPOS*/
   DECLARE @V_ITEMIMPOS_CDIMPOSTO VARCHAR(02);
   DECLARE @V_ITEMIMPOS_NRSEQITPROD VARCHAR(04);
   DECLARE @V_ITEMIMPOS_NRITPROIMPOS VARCHAR(01);
   DECLARE @V_IDCALCPESONF VARCHAR(01);
   DECLARE @V_IDUTDESCICMS VARCHAR(01);

   DECLARE @V_CDREGRAITALIQ VARCHAR(10);

   /*VARIVEIS DO CURSOR C_IMPOSNOTA */
   DECLARE @V_IMPOSNOTA_CDIMPOSTO VARCHAR(02);
   DECLARE @V_IMPOSNOTA_CDREGRAIT VARCHAR(10);
   /*VARIVEIS DO CURSOR C_REGRAMSG */
   DECLARE @V_REGRAMSG_CDREGRAFISC     VARCHAR(10);
   DECLARE @V_REGRAMSG_DSMENSREGRAFISC VARCHAR(150);

   /*VARIVEIS DO CURSOR C_CARGA */
   DECLARE @V_CARGA_CDIMPOSTO     VARCHAR(02);

   /*VARIVEIS DO CURSOR C_VRADICALIQFECP*/
   DECLARE @V_VRADICALIQFECP_VRADICALIQFECP DOUBLE PRECISION;
   DECLARE @V_VRADICALIQFECP_VRADICFECP DOUBLE PRECISION;
   DECLARE @V_VRADICALIQFECP_CDIMPOSTONFE VARCHAR(02);

   DECLARE @V_CARGA               FLOAT;
   DECLARE @V_CDIMPOSRECALC       VARCHAR(200);
   DECLARE @V_CDCFOPINFUSU     VARCHAR(11);
   DECLARE @V_DSCFOPINFUSU     VARCHAR(50);
   DECLARE @V_VRFATOCONVES     FLOAT;
   DECLARE @V_IDUTVLRQTDEIMPO  VARCHAR(01);
   DECLARE @V_CDPRODUTO        VARCHAR(10);
   DECLARE @V_DTENTRSAID       DATETIME;
   DECLARE @V_CDIMPOSTOI       VARCHAR(02);
   DECLARE @V_IDUTILVRMAX      VARCHAR(01);
   DECLARE @V_VRDESCMAXVENDA   FLOAT;
   DECLARE @V_FINALVRMAXVENDA  FLOAT;
   DECLARE @V_VRIMPOSTOVISUIT  FLOAT;
   DECLARE @V_CDGRUPOFISCAUX   VARCHAR(03);
   DECLARE @V_IDALTERADO_ENCA  VARCHAR(01);

   DECLARE @V_CDIMPOSIPI        VARCHAR(02);
   DECLARE @V_IDGERIPIDESPA     VARCHAR(01);
   DECLARE @V_IDGERICMSTDESPA   VARCHAR(01);
   DECLARE @V_VRTOTALIPI        FLOAT;
   DECLARE @V_CDENCARGOOD       VARCHAR(02);
   DECLARE @V_VRTOTALICMSST     FLOAT;
   DECLARE @V_CDENCARGOICMST    VARCHAR(02);
   DECLARE @V_IDPEINFICMSTDEME  VARCHAR(01);
   DECLARE @V_VRENCAICMSSTIT    FLOAT;
   DECLARE @V_VRICMSST          FLOAT;
   DECLARE @V_VRBASECALC        FLOAT;
   DECLARE @V_SOMAVRNOTAFISC    FLOAT;
   DECLARE @V_IDUTCTRLFISSAID   VARCHAR(01);
   DECLARE @V_IDUTCTRLFISFIL    VARCHAR(01);
   DECLARE @V_IDUTCTRLFIS       VARCHAR(01);
   DECLARE @V_IDPERVISIMPSCRE   VARCHAR(01);

   DECLARE @V_VRIMPOSST         FLOAT;
   DECLARE @V_VRADICFECPST      FLOAT;
   DECLARE @V_VRADICFECPSTAUX   FLOAT;
   DECLARE @V_SUBSTRIB_IDVRIMPSTRIB VARCHAR(01);
   DECLARE @V_SUBSTRIB_CDIMPOSTO    VARCHAR(02);

   DECLARE @V_DIFEVRBRUTO       DOUBLE PRECISION;

   DECLARE @V_DSDADOADIC        VARCHAR(255);

   DECLARE @V_VRPERDIFERE  FLOAT;
   DECLARE @V_PERDIFERE    FLOAT;
   DECLARE @V_IMPOSTOOPERA FLOAT;
   DECLARE @V_IMPOSTODIFER FLOAT;

   DECLARE @V_IDATUESTTPOP      VARCHAR(01);
   DECLARE @V_IDREMESSAINDU     VARCHAR(01);
   DECLARE @V_CDALMOXINFO       VARCHAR(06);
   DECLARE @V_CDLOCALINFO       VARCHAR(06);
   DECLARE @V_CDFILIALENTR      VARCHAR(04);
   DECLARE @V_NRLANESTENTR      VARCHAR(20);
   DECLARE @V_NRCTRLMOVEST      VARCHAR(20);
   DECLARE @V_BOLANESTENTR      BIT = 1;
   DECLARE @V_TEXT              VARCHAR(50);
   DECLARE @V_DSENDEDEVOEMBA    VARCHAR(255);
   DECLARE @V_CDENQLEGALIPI     VARCHAR(03);
   DECLARE @V_CDCEST            VARCHAR(09);

   /* variveis para gerao de entrada no estoque (filial agente de terceirao */
   DECLARE @V_CDFILIAGENT       VARCHAR(04);
   DECLARE @V_BOLANESTENTRAG    BIT = 1;
   DECLARE @V_NRLANESTENTRAG    VARCHAR(20);
   DECLARE @V_CDALMOXARIFEAG    VARCHAR(06);
   DECLARE @V_CDLOCALESTOQAG    VARCHAR(06);
   DECLARE @V_IDUTILLOTEAG      VARCHAR(01);
   DECLARE @V_NRLOTEESTQAG      VARCHAR(20);
   DECLARE @V_NRSUBLOTEAG       VARCHAR(04);
   DECLARE @V_NRLANCTONFAG      VARCHAR(20);
   DECLARE @V_IDTPIJURNF        VARCHAR(01);
   DECLARE @V_CDEMPRESAAG       VARCHAR(02);
   DECLARE @V_CDINSCESTAAG      VARCHAR(16);
   DECLARE @V_CDINSCMUNIAG      VARCHAR(16);
   DECLARE @V_CDFILIORIG        VARCHAR(04);
   DECLARE @V_TPOPERRETORNO     VARCHAR(02);

   DECLARE @V_IDUTILPVRIMPBC    VARCHAR(01);
   DECLARE @V_VRADICALIQFECP    DOUBLE PRECISION;
   DECLARE @V_VRADICFECP        DOUBLE PRECISION;
   DECLARE @V_IDCONSFINAL       VARCHAR(01);
   DECLARE @V_STRVRADICALIQFECP VARCHAR(15);
   DECLARE @V_STRVRADICFECP     VARCHAR(15);

   DECLARE @V_NOVO_CODIGO       VARCHAR(18);
   DECLARE @V_NOVO_CODIGO_NT    VARCHAR(18);

   DECLARE @V_VRIMPOSTOOPERAIT  DOUBLE PRECISION;
   DECLARE @V_VRPERDIFEREIT     DOUBLE PRECISION;
   DECLARE @V_VRIMPOSTODIFERIT  DOUBLE PRECISION;

   DECLARE @V_IDPRESENCIAL      VARCHAR(01);

   /*VARIVEIS DO CURSOR C_ITEMPRODUTO_DIFAL*/
   DECLARE @V_ITEMPRODUTO_DIFAL_NRSEQITPROD VARCHAR(04);

   DECLARE @V_NRINSESTDESNF     VARCHAR(20);
   DECLARE @V_IDCONTRIBICMS     VARCHAR(01);
   DECLARE @V_IDCONTRIBICMSAUX  VARCHAR(01);

   DECLARE @V_ALIQICMSDEST      DOUBLE PRECISION;
   DECLARE @V_ALIQFECPDEST      DOUBLE PRECISION;
   DECLARE @V_CDIMPOSTOFECP     VARCHAR(02);

   DECLARE @V_IDDIFECLI         VARCHAR(01);
   DECLARE @V_CDFILIALPED       VARCHAR(04);
   DECLARE @V_NRPEDIDO          VARCHAR(10);
   DECLARE @V_DADOSADICENDPED   VARCHAR(400);
   DECLARE @V_IDPRODPERIG       VARCHAR(01);
   DECLARE @V_MSGPRODPERIG      VARCHAR(500);
   DECLARE @V_GRAVAMSGPRODPERIG INTEGER;

   /*VARIVEIS DO CURSOR C_ITEMPRODINF*/
   DECLARE @V_ITEMPRODINF_NRSEQITPROD VARCHAR(04);
   DECLARE @V_ITEMPRODINF_IDPRODPERIG VARCHAR(01);
   DECLARE @V_ITEMPRODINF_DSINFADICPROD VARCHAR(500);
   DECLARE @V_ITEMPRODINF_CDPRODUTO VARCHAR(10);

   DECLARE @V_IDCALCDIFALDENT VARCHAR(01);

   /*VARIVEIS DO CURSOR C_AJUSTA_DIFERIMENTO*/
   DECLARE @C_AJUSTA_DIFERIMENTO_NRSEQITPROD VARCHAR(04);
   DECLARE @C_AJUSTA_DIFERIMENTO_VRIMPOSTOIT DOUBLE PRECISION;
   DECLARE @C_AJUSTA_DIFERIMENTO_VRIMPOSTOOPERAIT DOUBLE PRECISION;
   DECLARE @C_AJUSTA_DIFERIMENTO_VRIMPOSTODIFERIT DOUBLE PRECISION;
   DECLARE @C_AJUSTA_DIFERIMENTO_VRPERDIFEREIT DOUBLE PRECISION;

   DECLARE @V_NRREGISTROANP VARCHAR(10);
   DECLARE @V_DSREGISTROANP VARCHAR(255);
   DECLARE @V_IDUTILVENC VARCHAR(01);
   DECLARE @V_IDNOTADEVO VARCHAR(01);
   DECLARE @V_IDNFAJUSTE VARCHAR(01);
   DECLARE @V_IDVERLEIAUTENFE VARCHAR(04);

   /*VARIVEIS DO CURSOR C_ITEM*/
   DECLARE @V_ITEM_CDFILIAL     VARCHAR(04);
   DECLARE @V_ITEM_NRLANCTONF   VARCHAR(10);
   DECLARE @V_ITEM_NRSEQITPROD  VARCHAR(04);
   DECLARE @V_ITEM_CDCLASFISC   VARCHAR(10);
BEGIN
   SET @V_NRINSJURNF    = NULL;
   SET @V_SERIE         = NULL;
   SET @V_CDFILIEMIT    = NULL;
   SET @V_CDFILIRECE    = NULL;
   SET @V_IDUTILALMOX   = NULL;
   SET @V_IDUTILLCESTQ  = NULL;
   SET @V_IDUTILLOTE    = NULL;
   SET @V_CDINTEGRACAO  = NULL;
   SET @V_IDORIGDESTNF  = NULL;
   SET @V_IDDOCFINANC   = NULL;
   SET @V_IDDOCREPLIC   = NULL;
   SET @V_IDSISTEMA     = NULL;
   SET @V_IDCTRLESTQ    = NULL;
   SET @V_IDDOCESTOQ    = NULL;
   SET @V_NRDECITOTANF  = NULL;
   SET @V_DADOADIC      = NULL;
   SET @V_IDENDCFOP     = NULL;
   SET @V_CDEMPRESA     = NULL;
   SET @V_CDINSCESTA    = NULL;
   SET @V_PAISORIG      = NULL;
   SET @V_ESTAORIG      = NULL;
   SET @V_MUNIORIG      = NULL;
   SET @V_ORIGDESTOP    = NULL;
   SET @V_IDENDEMIS     = NULL;
   SET @V_PAISDEST      = NULL;
   SET @V_ESTADEST      = NULL;
   SET @V_MUNIDEST      = NULL;
   SET @V_PAISCFOP      = NULL;
   SET @V_ESTACFOP      = NULL;
   SET @V_LIQUIDO       = 0;
   SET @V_IDOPERDEVONF  = NULL;
   SET @V_IDCONSPARFIS  = NULL;
   SET @V_COUNT         = 0;
   SET @V_IMPOSTO       = NULL;
   SET @V_FISOPEITEM    = NULL;
   SET @V_SUFXCFOPPR    = NULL;
   SET @V_SITUTRIBPR    = NULL;
   SET @V_IMPOSINFUSU   = 0;
   SET @V_NRALIQTEMP    = 0;
   SET @V_PARDEDTMP     = 0;
   SET @V_PREDBCTMP     = 0;
   SET @V_ALIQUTMP      = 0;
   SET @V_TRATIMPST     = 0;
   SET @V_PBCSUBTRIB    = 0;
   SET @V_CDIMPOSTRIB   = NULL;
   SET @V_IDVRIMPSTRIB  = NULL;
   SET @V_VRIMPOSTOST   = 0;
   SET @V_TOTAPRODENCA  = 0;
   SET @V_TOTAPRENIMPO  = 0;
   SET @V_TOTAIMPBCALC  = 0;
   SET @V_IMPOSTOIT     = NULL;
   SET @V_BASECALCIT    = 0;
   SET @V_BASECALCTO    = 0;
   SET @V_SOMAITEM      = 0;
   SET @V_DESCITEM      = 0;
   SET @V_VRFATOCONV    = 0;
   SET @V_VRBRUTO       = 0;
   SET @V_VRCONTAB      = 0;
   SET @V_CDFISCTEMP    = NULL;
   SET @V_CHAVE         = NULL;
   SET @V_VRLIQUORIG    = 0;
   SET @V_SOMAENCA      = 0;
   SET @V_MENOENCA      = 0;
   SET @V_SOMAIMPO      = 0;
   SET @V_MENOIMPO      = 0;
   SET @V_VRREDUCAO     = 0;
   SET @V_CDIMPOBCALC   = NULL;
   SET @V_IDITEMISSAO   = NULL;
   SET @V_CDFILIAPFATU  = NULL;
   SET @V_NRAPFATUTNF   = NULL;
   SET @V_IMPOSRETI     = NULL;
   SET @V_VRCONTAREC    = 0;
   SET @V_NRLANBOLREC   = NULL;
   SET @V_IDERROAVISO   = NULL;
   SET @V_ERROAVISO     = 0;
   SET @V_VRPESOBRUTO   = 0;
   SET @V_CDFISOPENTF   = NULL;
   SET @V_VRDIFERENCA   = 0;
   SET @V_NMTIPOOPER    = NULL;
   SET @V_NMFILIRECE    = NULL;
   SET @V_IDRETPROEXP   = NULL;
   SET @V_CDFILIMOVI    = NULL;
   SET @V_IDATUEST      = NULL;
   SET @V_EXISTE_ROT    = 0;
   SET @V_FATOCONV      = NULL;
   SET @V_NRSEQITPROD   = NULL;
   SET @V_QTITEMORIG    = 0;
   SET @V_QTITEMPROD    = 0;
   SET @V_ICMS          = NULL;
   SET @V_NRINSCSUFRAMA = NULL;     
   SET @V_DSDADOADIC    = NULL;

   --VARIVEIS COM A CHAVE PARA AS TABELAS TEMPORRIAS
   SET @V_ALIQTEMP = @P_FILIAL + @P_LANCTONF;
   SET @V_INCITEMP = @P_FILIAL + @P_LANCTONF;
   SET @V_CSTTEMP  = @P_FILIAL + @P_LANCTONF;
   SET @V_CFOPTEMP = @P_FILIAL + @P_LANCTONF;

   SET @V_TOTALNOTA  = 0;
   SET @V_FAIXATOLER = 0.02;

   SET @V_VRADICALIQFECP = NULL;
   SET @V_VRADICFECP = NULL;

   SELECT @V_NRINSJURNF = MAX(N.NRINSJURNF),
          @V_SERIE = MAX(N.CDSERIE),
          @V_CDFILIEMIT = MAX(N.CDFILIEMIT),
          @V_CDFILIRECE = MAX(N.CDFILIRECE),
          @V_CDINTEGRACAO = MAX(N.CDINTEGRACAO),
          @V_IDORIGDESTNF = MAX(N.IDORIGDESTNF),
          @V_IDDOCFINANC = MAX(N.IDDOCFINANC),
          @V_IDDOCREPLIC = MAX(N.IDDOCREPLIC),
          @V_IDSISTEMA = MAX(N.IDSISTEMA),
          @V_IDCTRLESTQ = ISNULL(MAX(P.IDCTRLESTQ),'S'),
          @V_IDUTILALMOX = ISNULL(MAX(P.IDUTILALMOX), 'N') ,
          @V_IDUTILLCESTQ = ISNULL(MAX(P.IDUTILLCESTQ),'N'),
          @V_IDUTILLOTE = ISNULL(MAX(P.IDUTILLOTE),'N'),
          @V_IDTPIJURNF = MAX(N.IDTPIJURNF),
          @V_IDPRESENCIAL = ISNULL(MAX(N.IDPRESENCIAL), '9'),
          @V_IDVERLEIAUTENFE = ISNULL(MAX(I.IDVERLEIAUTENFE), '3.10'),
          @V_CDSITUCRT = ISNULL(MAX(CDSITUCRT), '3'),
          @V_VRSUBLIMITESN = ISNULL(MAX(VRSUBLIMITESN), 0)
   FROM NOTAFISCAL N LEFT JOIN PARAMFILIAL P ON (CDFILIEMIT = P.CDFILIAL)
                          JOIN INSCRESTAD I ON (N.CDEMPRESA = I.CDEMPRESA)
                                           AND (N.CDINSCESTA = I.CDINSCESTA)
                          JOIN PARAMEMPRESA PE ON (N.CDEMPRESA = PE.CDEMPRESA)
   WHERE N.CDFILIAL = @P_FILIAL
     AND NRLANCTONF = @P_LANCTONF;

   SELECT @V_IDDOCESTOQ = MAX(CDFILIAL+NRLANCESTQ)
   FROM LANCTOESTOQ
   WHERE CDFILIAL   = SUBSTRING(@V_IDDOCREPLIC, 1, 4) AND
         NRLANCTONF = SUBSTRING(@V_IDDOCREPLIC, 5, 10);

   IF @V_IDDOCESTOQ IS NULL BEGIN
      SELECT @V_IDDOCESTOQ = MAX(CDFILIAL+NRLANCESTQ)
      FROM LANCTOESTOQ
      WHERE CDFILIAL   = SUBSTRING(@V_CDINTEGRACAO, 1, 4) AND
            NRLANCTONF = SUBSTRING(@V_CDINTEGRACAO, 5, 10);
   END;


   SELECT @V_NRDECITOTANF = ISNULL(NRDECITOTANF,2)
   FROM PARAMGERAL;

   --MAIOR REGISTRO DA TABELA DE DADOS ADICIONAIS
   SELECT @V_DADOADIC = MAX(NRDADOADIC)
   FROM DADOSADIC
   WHERE (CDFILIAL = @P_FILIAL) AND
         (NRLANCTONF = @P_LANCTONF);

   IF (@V_DADOADIC IS NULL) BEGIN
      SET @V_DADOADIC = '001';
   END
   ELSE BEGIN
      SET @V_DADOADIC = RIGHT(REPLICATE('0',3) + RTRIM(CONVERT(VARCHAR, CONVERT(NUMERIC, @V_DADOADIC) + 1)),3);
   END;

   DECLARE C_MENSINSC CURSOR FOR SELECT M.CDMENSAGEM, I.DSMENSINSCRESTA
                                   FROM MENSINSCRESTAD I LEFT JOIN MENSAGEM M ON (M.CDMENSAGEM = I.CDMENSAGEM)
                                  WHERE (I.CDEMPRESA = @P_EMPRESA)
                                    AND (I.CDINSCESTA = @P_INSCESTA)
                                    AND (I.IDENTRSAIDMENS <> 'E')
                                    AND (((I.CDMENSAGEM IS NOT NULL) AND (M.IDSITUACAOMENS  = 'A')) OR (I.CDMENSAGEM IS NULL))
                                    AND NOT EXISTS (SELECT DSDADOADIC
                                                      FROM DADOSADIC
                                                     WHERE (CDFILIAL = @P_FILIAL)
                                                       AND (NRLANCTONF = @P_LANCTONF)
                                                       AND (DSDADOADIC LIKE I.DSMENSINSCRESTA + '%'))
                                  ORDER BY I.NRMENSINSCRESTA;
   OPEN C_MENSINSC;
   FETCH NEXT FROM C_MENSINSC INTO @V_MENSINSC_CDMENSAGEM, @V_MENSINSC_DSMENSINSCRESTA;

   WHILE (@@FETCH_STATUS = 0) BEGIN
      /*PREENCHE AS MENSAGENS ATRELADAS A INSCRICAO ESTADUAL*/
      INSERT INTO DADOSADIC(CDFILIAL, NRLANCTONF, NRDADOADIC, CDMENSAGEM, DSDADOADIC)
                     VALUES(@P_FILIAL, @P_LANCTONF, @V_DADOADIC, @V_MENSINSC_CDMENSAGEM, @V_MENSINSC_DSMENSINSCRESTA);

      SET @V_DADOADIC = RIGHT(REPLICATE('0',3) + RTRIM(CONVERT(VARCHAR, CONVERT(NUMERIC, @V_DADOADIC) + 1)),3);

      FETCH NEXT FROM C_MENSINSC INTO @V_MENSINSC_CDMENSAGEM, @V_MENSINSC_DSMENSINSCRESTA;
   END;
   CLOSE C_MENSINSC;
   DEALLOCATE C_MENSINSC;

   /* GRAVA INFORMAES ADICIONAIS DO PRODUTO */
   SET @V_IDPRODPERIG = 'N';
   DECLARE C_ITEMPRODINF CURSOR FOR SELECT I.NRSEQITPROD, 
                                           P.IDPRODPERIG, 
                                           P.DSINFADICPROD, 
                                           I.CDPRODUTO
                                      FROM ITEMPRODUTO I, PRODUTO P
                                     WHERE I.CDFILIAL = @P_FILIAL
                                       AND I.NRLANCTONF = @P_LANCTONF
                                       AND I.CDPRODUTO = P.CDPRODUTO;
   OPEN C_ITEMPRODINF;
   FETCH NEXT FROM C_ITEMPRODINF INTO @V_ITEMPRODINF_NRSEQITPROD,
                                      @V_ITEMPRODINF_NRSEQITPROD,
                                      @V_ITEMPRODINF_DSINFADICPROD,
                                      @V_ITEMPRODINF_CDPRODUTO;
   WHILE (@@FETCH_STATUS = 0) BEGIN
      UPDATE ITEMPRODUTO
         SET DSINFADICPROD = @V_ITEMPRODINF_DSINFADICPROD
       WHERE CDFILIAL = @P_FILIAL
         AND NRLANCTONF = @P_LANCTONF
         AND NRSEQITPROD = @V_ITEMPRODINF_NRSEQITPROD;
      
      SELECT @V_NRREGISTROANP = NRREGISTROANP,
             @V_DSREGISTROANP = DSREGISTROANP
        FROM INFADICPROD
       WHERE CDPRODUTO = @V_ITEMPRODINF_CDPRODUTO;
      
      IF @V_NRREGISTROANP IS NOT NULL BEGIN
         INSERT INTO DETESPCOMBNFE
            (CDFILIAL, NRLANCTONF, NRSEQITPROD, CDPAIS, 
             SGESTADO, CDPRODANP, DSPRODANP)
         VALUES
            (@P_FILIAL, @P_LANCTONF, @V_ITEMPRODINF_NRSEQITPROD, @V_PAISORIG, 
             @V_ESTAORIG, SUBSTRING(@V_NRREGISTROANP, 1, 9), SUBSTRING(@V_DSREGISTROANP, 1, 255));
      END;

      IF @V_ITEMPRODINF_IDPRODPERIG = 'S' BEGIN
         SET @V_IDPRODPERIG = 'S';
      END;

      FETCH NEXT FROM C_ITEMPRODINF INTO @V_ITEMPRODINF_NRSEQITPROD,
                                         @V_ITEMPRODINF_NRSEQITPROD,
                                         @V_ITEMPRODINF_DSINFADICPROD,
                                         @V_ITEMPRODINF_CDPRODUTO;
   END;
   CLOSE C_ITEMPRODINF;
   DEALLOCATE C_ITEMPRODINF;

   /* GRAVA MENSAGEM REFERENTE A PRODUTO PERIGOSO */
   IF @V_IDPRODPERIG = 'S' BEGIN
      SET @V_MSGPRODPERIG = 'Declaro que os produtos perigosos esto adequadamente ' +
                            'classificados, embalados, identificados, e estivados ' +
                            'para suportar os riscos das operaes de transporte e ' +
                            'que atendem s exigncias da regulamentao.';
      SELECT @V_GRAVAMSGPRODPERIG = COUNT(DSDADOADIC)
        FROM DADOSADIC
       WHERE (CDFILIAL = @P_FILIAL)
         AND (NRLANCTONF = @P_LANCTONF)
         AND (DSDADOADIC LIKE SUBSTRING(@V_MSGPRODPERIG, 1, LEN(@V_MSGPRODPERIG) - 19) + '%');
      
      IF (@V_GRAVAMSGPRODPERIG = 0) BEGIN
         INSERT INTO DADOSADIC(CDFILIAL, NRLANCTONF, NRDADOADIC, CDMENSAGEM, DSDADOADIC)
                        VALUES(@P_FILIAL, @P_LANCTONF, @V_DADOADIC, NULL, @V_MSGPRODPERIG);

         SET @V_DADOADIC = RIGHT(REPLICATE('0',3) + RTRIM(CONVERT(VARCHAR, CONVERT(NUMERIC, @V_DADOADIC) + 1)),3);
      END
   END;

   IF @V_IDORIGDESTNF = 'C' BEGIN
      DECLARE C_MENSCLIENTE CURSOR FOR SELECT M.CDMENSAGEM, C.DSMENSCLIENTE
                                         FROM MENSCLIENTE C LEFT JOIN MENSAGEM M ON (M.CDMENSAGEM = C.CDMENSAGEM)
                                        WHERE C.CDCLIENTE = @P_CLIENTE
                                          AND C.IDENTRSAIDMENS <> 'E'
                                          AND (((C.CDMENSAGEM IS NOT NULL) AND (M.IDSITUACAOMENS  = 'A')) OR (C.CDMENSAGEM IS NULL))
                                          AND NOT EXISTS (SELECT DSDADOADIC
                                                            FROM DADOSADIC
                                                           WHERE (CDFILIAL = @P_FILIAL)
                                                             AND (NRLANCTONF = @P_LANCTONF)
                                                             AND (DSDADOADIC LIKE C.DSMENSCLIENTE + '%'))
                                        ORDER BY C.NRMENSCLIENTE;
      OPEN C_MENSCLIENTE;
      FETCH NEXT FROM C_MENSCLIENTE INTO @V_MENSCLIENTE_CDMENSAGEM, 
                                         @V_MENSCLIENTE_DSMENSCLIENTE;

      WHILE (@@FETCH_STATUS = 0) BEGIN
         INSERT INTO DADOSADIC
            (CDFILIAL, 
             NRLANCTONF, 
             NRDADOADIC, 
             CDMENSAGEM, 
             DSDADOADIC)
          VALUES
             (@P_FILIAL, 
              @P_LANCTONF, 
              @V_DADOADIC, 
              @V_MENSCLIENTE_CDMENSAGEM, 
              @V_MENSCLIENTE_DSMENSCLIENTE);

         SET @V_DADOADIC = RIGHT(REPLICATE('0',3) + RTRIM(CONVERT(VARCHAR, CONVERT(NUMERIC, @V_DADOADIC) + 1)),3);

         FETCH NEXT FROM C_MENSCLIENTE INTO @V_MENSCLIENTE_CDMENSAGEM, 
                                            @V_MENSCLIENTE_DSMENSCLIENTE;
      END;
      CLOSE C_MENSCLIENTE;
      DEALLOCATE C_MENSCLIENTE;
   END;

   SELECT V_DSENDEDEVOEMBA = TEKNISA.TRANSLATE(SUBSTRING('Devolver as embalagens vazias no seguinte endereo: ' + 
                             PRE.DSPOSTORECEMB +
                             ', ' + PRE.DSENDERECEMB +
                             CASE ISNULL(PRE.DSCOMPENDERECEMB, '!X!X!') WHEN '!X!X!' THEN '' ELSE ', ' + PRE.DSCOMPENDERECEMB END +
                             ', ' + B.NMBAIRRO +
                             ', CEP:' + PRE.NRCEPRECEMB +
                             ', ' + M.NMMUNICIPIO +
                             ', ' + E.SGESTADO +
                             ', ' + P.NMPAIS +
                             CASE ISNULL(PRE.NRTELERECEMB, '!X!X!') WHEN '!X!X!' THEN '' ELSE '. Telefone: ' + PRE.NRTELERECEMB END +
                             CASE ISNULL(PRE.NRFAXRECEMB, '!X!X!') WHEN '!X!X!' THEN '' ELSE '. FAX: ' + PRE.NRFAXRECEMB END, 1, 255), NULL, NULL)
     FROM NOTAFISCAL N JOIN ITEMPRODUTO I ON (N.CDFILIAL = I.CDFILIAL) AND
                                             (N.NRLANCTONF = I.NRLANCTONF)
                       JOIN PRODUTO PR ON (I.CDPRODUTO = PR.CDPRODUTO)
                       JOIN (SELECT P.CDPOSTORECEMB, PR.CDARVPROD
                               FROM PRODPOSTORECEMB P JOIN PRODUTO PR ON (P.CDPRODUTO = PR.CDPRODUTO)) PPRE ON (CHARINDEX(ISNULL(RTRIM(PPRE.CDARVPROD), PR.CDARVPROD), PR.CDARVPROD) = 1)
                       JOIN CLIEPOSTORECEMB C ON (N.CDCLIENTE = C.CDCLIENTE) AND
                                                 (PPRE.CDPOSTORECEMB = C.CDPOSTORECEMB)
                       JOIN POSTORECEMB PRE ON (C.CDPOSTORECEMB = PRE.CDPOSTORECEMB)
                       JOIN PAIS P ON (PRE.CDPAIS = P.CDPAIS)
                       JOIN ESTADO E ON (PRE.CDPAIS = E.CDPAIS) AND
                                        (PRE.SGESTADO = E.SGESTADO)
                       JOIN MUNICIPIO M ON (PRE.CDPAIS = M.CDPAIS) AND
                                           (PRE.SGESTADO = M.SGESTADO) AND
                                           (PRE.CDMUNICIPIO = M.CDMUNICIPIO)
                       JOIN BAIRRO B ON (PRE.CDPAIS = B.CDPAIS) AND
                                        (PRE.SGESTADO = B.SGESTADO) AND
                                        (PRE.CDMUNICIPIO = B.CDMUNICIPIO) AND
                                        (PRE.CDBAIRRO = B.CDBAIRRO)
    WHERE N.CDFILIAL = @P_FILIAL
      AND N.NRLANCTONF = @P_LANCTONF
      AND NOT EXISTS (SELECT DSDADOADIC
                        FROM DADOSADIC
                       WHERE (CDFILIAL = @P_FILIAL)
                         AND (NRLANCTONF = @P_LANCTONF)
                         AND (DSDADOADIC LIKE TEKNISA.TRANSLATE(SUBSTRING('Devolver as embalagens vazias no seguinte endereo: ' +
                                              PRE.DSPOSTORECEMB +
                                              ', ' + PRE.DSENDERECEMB +
                                              CASE ISNULL(PRE.DSCOMPENDERECEMB, '!X!X!') WHEN '!X!X!' THEN '' ELSE ', ' + PRE.DSCOMPENDERECEMB END +
                                              ', ' + B.NMBAIRRO +
                                              ', CEP:' + PRE.NRCEPRECEMB +
                                              ', ' + M.NMMUNICIPIO +
                                              ', ' + E.SGESTADO +
                                              ', ' + P.NMPAIS +
                                              CASE ISNULL(PRE.NRTELERECEMB, '!X!X!') WHEN '!X!X!' THEN '' ELSE '. Telefone: ' + PRE.NRTELERECEMB END +
                                              CASE ISNULL(PRE.NRFAXRECEMB, '!X!X!') WHEN '!X!X!' THEN '' ELSE '. FAX: ' + PRE.NRFAXRECEMB END, 1, 255), NULL, NULL) + '%'));
     
   IF (@V_DSENDEDEVOEMBA IS NOT NULL) BEGIN
      INSERT INTO DADOSADIC
         (CDFILIAL, 
          NRLANCTONF, 
          NRDADOADIC, 
          CDMENSAGEM, 
          DSDADOADIC)
      VALUES
         (@P_FILIAL, 
          @P_LANCTONF, 
          @V_DADOADIC, 
          '',
          @V_DSENDEDEVOEMBA);

      SET @V_DADOADIC = RIGHT(REPLICATE('0',3) + RTRIM(CONVERT(VARCHAR, CONVERT(NUMERIC, @V_DADOADIC) + 1)),3);
   END;

   --VARIVEIS PARA CONSULTA DE ALQUOTA, INCIDNCIA, CFOP
   SELECT @V_IDENDCFOP  = ISNULL(MAX(IDENDCFOPFIL),'I'),
          @V_CDEMPRESA  = MAX(CDEMPRESA),
          @V_CDINSCESTA = MAX(CDINSCESTA)
   FROM FILIAL
   WHERE (CDFILIAL = @V_CDFILIEMIT);

   IF @V_IDENDCFOP = 'I' BEGIN
      SELECT @V_PAISORIG = MAX(CDPAIS),
             @V_ESTAORIG = MAX(SGESTADO),
             @V_MUNIORIG = MAX(CDMUNICIPIO)
      FROM INSCRESTAD
      WHERE (CDEMPRESA  = @P_EMPRESA) AND
            (CDINSCESTA = @P_INSCESTA);
   END
   ELSE BEGIN
      SELECT @V_PAISORIG = MAX(CDPAIS),
             @V_ESTAORIG = MAX(SGESTADO),
             @V_MUNIORIG = MAX(CDMUNICIPIO)
      FROM ENDEFILI
      WHERE (CDFILIAL     = @V_CDFILIEMIT) AND
            (IDTPENDEFILI = @V_IDENDCFOP);
   END;

   IF @V_IDORIGDESTNF IS NULL BEGIN
      SELECT @V_ORIGDESTOP = MAX(IDORIGDESTOP)
      FROM TIPOOPERAC
      WHERE IDENTRSAIDOP = 'S' AND
            CDTIPOOPER   = @P_TIPOOPER;
   END
   ELSE BEGIN
      SET @V_ORIGDESTOP = @V_IDORIGDESTNF;
   END;

   SET @V_CDORIGDESTNF = @P_CLIENTE;

   SET @V_IDCONSFINAL = 'N';

   IF @V_ORIGDESTOP = 'L' BEGIN
      SELECT @V_IDENDCFOP  = MAX(ISNULL(IDENDCFOPFIL,'I')),
             @V_IDENDEMIS  = MAX(ISNULL(IDENDEMISFIL,'I')),
             @V_CDEMPRESA  = MAX(CDEMPRESA),
             @V_CDINSCESTA = MAX(CDINSCESTA)
      FROM FILIAL
      WHERE (CDFILIAL = @V_CDFILIRECE);

      SELECT @V_CDPAISST = MAX(CDPAIS),
             @V_SGESTADOST = MAX(SGESTADO),
             @V_CDMUNICIPIOST = MAX(CDMUNICIPIO)
        FROM ENDEFILI
       WHERE CDFILIAL = @V_CDFILIRECE
         AND IDTPENDEFILI = 'P';

      SELECT @V_CDINSCESTAST = MAX(CDINSCESTAST)
        FROM INSCRESTADST
       WHERE CDEMPRESA = @P_EMPRESA
         AND CDINSCESTAST = @P_INSCESTA
         AND CDPAIS = @V_CDPAISST
         AND SGESTADO = @V_SGESTADOST;

      IF @V_IDENDCFOP = 'I' BEGIN
         SELECT @V_PAISCFOP = MAX(CDPAIS),
                @V_ESTACFOP = MAX(SGESTADO)
         FROM INSCRESTAD
         WHERE CDEMPRESA  = @V_CDEMPRESA AND
               CDINSCESTA = @V_CDINSCESTA;
      END
      ELSE BEGIN
         SELECT @V_PAISCFOP = MAX(CDPAIS),
                @V_ESTACFOP = MAX(SGESTADO)
         FROM ENDEFILI
         WHERE (CDFILIAL     = @V_CDFILIRECE) AND
               (IDTPENDEFILI = @V_IDENDCFOP);
      END;

      IF @V_IDENDEMIS = 'I' BEGIN
         SELECT @V_PAISDEST = MAX(CDPAIS),
                @V_ESTADEST = MAX(SGESTADO),
                @V_MUNIDEST = MAX(CDMUNICIPIO)
         FROM INSCRESTAD
         WHERE CDEMPRESA  = @V_CDEMPRESA AND
               CDINSCESTA = @V_CDINSCESTA;
      END
      ELSE BEGIN
         SELECT @V_PAISDEST = MAX(CDPAIS),
                @V_ESTADEST = MAX(SGESTADO),
                @V_MUNIDEST = MAX(CDMUNICIPIO)
         FROM ENDEFILI
         WHERE CDFILIAL     = @V_CDFILIRECE AND
               IDTPENDEFILI = @V_IDENDEMIS;
      END;
      SET @V_CDORIGDESTNF = @V_CDFILIRECE;
   END
   ELSE IF @V_ORIGDESTOP = 'F' BEGIN
      SELECT @V_IDENDCFOP = ISNULL(MAX(IDENDCFOPFOR),'P'),
             @V_IDENDEMIS = ISNULL(MAX(IDENDEMISFOR),'P'),
             @V_IDCONSFINAL = ISNULL(MAX(IDCONSFINAL), 'N'),
             @V_NRINSESTDESNF = MAX(NRINSESTFORN),
             @V_IDCONTRIBICMS = ISNULL(MAX(IDCONTRIBICMS),'N')
      FROM FORNECEDOR
      WHERE (CDFORNECED = @P_CLIENTE);

      SELECT @V_CDPAISST = MAX(CDPAIS),
             @V_SGESTADOST = MAX(SGESTADO),
             @V_CDMUNICIPIOST = MAX(CDMUNICIPIO)
        FROM ENDEFORN
       WHERE CDFORNECED = @P_CLIENTE
         AND IDTPENDEFORN = 'P';

      SELECT @V_CDINSCESTAST = MAX(CDINSCESTAST)
        FROM INSCRESTADST
       WHERE CDEMPRESA = @P_EMPRESA
         AND CDINSCESTAST = @P_INSCESTA
         AND CDPAIS = @V_CDPAISST
         AND SGESTADO = @V_SGESTADOST;

      IF @V_IDENDCFOP = 'I' BEGIN
         SELECT @V_PAISCFOP = CDPAIS,
                @V_ESTACFOP = SGESTADO
           FROM INSCRESTAD
          WHERE CDEMPRESA  = @P_EMPRESA AND
                CDINSCESTA = @P_INSCESTA;
      END
      ELSE BEGIN
         SELECT @V_PAISCFOP = MAX(CDPAIS),
                @V_ESTACFOP = MAX(SGESTADO)
         FROM ENDEFORN
         WHERE (CDFORNECED   = @P_CLIENTE) AND
               (IDTPENDEFORN = @V_IDENDCFOP);
      END;

      SELECT @V_PAISDEST = MAX(CDPAIS),
             @V_ESTADEST = MAX(SGESTADO),
             @V_MUNIDEST = MAX(CDMUNICIPIO)
      FROM ENDEFORN
      WHERE (CDFORNECED   = @P_CLIENTE) AND
            (IDTPENDEFORN = @V_IDENDEMIS);
   END
   ELSE BEGIN
      SELECT @V_IDENDCFOP = ISNULL(MAX(IDENDCFOPCLI),'P'),
             @V_IDENDEMIS = ISNULL(MAX(IDENDEMISCLI),'P'),
             @V_IDUTDESCICMS = ISNULL(MAX(IDUTDESCICMS), 'N'),
             @V_IDCONSFINAL = ISNULL(MAX(IDCONSFINAL), 'N'),
             @V_NRINSESTDESNF = MAX(NRINSESTCLIE),
             @V_IDCONTRIBICMS = ISNULL(MAX(IDCONTRIBICMS),'N')
      FROM CLIENTE
      WHERE (CDCLIENTE = @P_CLIENTE);

      SELECT @V_CDPAISST = MAX(CDPAIS),
             @V_SGESTADOST = MAX(SGESTADO),
             @V_CDMUNICIPIOST = MAX(CDMUNICIPIO)
        FROM ENDECLIE
       WHERE CDCLIENTE = @P_CLIENTE
         AND IDTPENDECLIE = 'P';

      SELECT @V_CDINSCESTAST = MAX(CDINSCESTAST)
        FROM INSCRESTADST
       WHERE CDEMPRESA = @P_EMPRESA
         AND CDINSCESTAST = @P_INSCESTA
         AND CDPAIS = @V_CDPAISST
         AND SGESTADO = @V_SGESTADOST;

      IF @V_IDENDCFOP = 'I' BEGIN
         SELECT @V_PAISCFOP = CDPAIS,
                @V_ESTACFOP = SGESTADO,
                @V_MUNIDEST = CDMUNICIPIO
           FROM INSCRESTAD
          WHERE CDEMPRESA  = @P_EMPRESA AND
                CDINSCESTA = @P_INSCESTA;

         SET @V_PAISDEST = @V_PAISCFOP;
         SET @V_ESTADEST = @V_ESTACFOP;
      END
      ELSE BEGIN
         SELECT @V_PAISCFOP = MAX(CDPAIS),
                @V_ESTACFOP = MAX(SGESTADO)
         FROM ENDECLIE
         WHERE (CDCLIENTE    = @P_CLIENTE) AND
               (IDTPENDECLIE = @V_IDENDCFOP);
      END;
      SELECT @V_PAISDEST = MAX(CDPAIS),
             @V_ESTADEST = MAX(SGESTADO),
             @V_MUNIDEST = MAX(CDMUNICIPIO)
      FROM ENDECLIE
      WHERE (CDCLIENTE    = @P_CLIENTE) AND
            (IDTPENDECLIE = @V_IDENDEMIS);

   END;

   IF (@V_NRINSESTDESNF IS NULL) OR (@V_NRINSESTDESNF = '') BEGIN
      SET @V_IDCONTRIBICMSAUX = 'N';
   END ELSE BEGIN
      SET @V_IDCONTRIBICMSAUX = @V_IDCONTRIBICMS;
   END;

   IF (@V_CDINSCESTAST IS NOT NULL) OR (@V_CDINSCESTAST = '')  BEGIN

      UPDATE NOTAFISCAL
         SET CDINSCESTAST = @V_CDINSCESTAST
       WHERE CDFILIAL = @P_FILIAL
         AND NRLANCTONF = @P_LANCTONF;
         
      DECLARE C_MENSINSCESTAST CURSOR FOR SELECT M.CDMENSAGEM, I.DSMENSINSCESTAST
                                            FROM MENSINSCESTAST I LEFT JOIN MENSAGEM M ON (M.CDMENSAGEM = I.CDMENSAGEM)
                                           WHERE I.CDEMPRESA = @P_EMPRESA
                                             AND I.CDINSCESTA = @P_INSCESTA
                                             AND I.CDINSCESTAST = @V_CDINSCESTAST
                                             AND I.IDENTRSAIDMENSST <> 'E'
                                             AND (((I.CDMENSAGEM IS NOT NULL) AND (M.IDSITUACAOMENS  = 'A')) OR (I.CDMENSAGEM IS NULL))
                                             AND NOT EXISTS (SELECT DSDADOADIC
                                                               FROM DADOSADIC
                                                               WHERE (CDFILIAL = @P_FILIAL)
                                                                 AND (NRLANCTONF = @P_LANCTONF)
                                                                 AND (DSDADOADIC LIKE I.DSMENSINSCESTAST + '%'))
                                           ORDER BY NRMENSINSCESTAST;
      OPEN C_MENSINSCESTAST;
      FETCH NEXT FROM C_MENSINSCESTAST INTO @C_MENSINSCESTAST_CDMENSAGEM, @C_MENSINSCESTAST_DSMENSINSCESTAST;
      WHILE (@@FETCH_STATUS = 0) BEGIN

         /*PREENCHE AS MENSAGENS ATRELADAS A INSCRICAO ESTADUAL DO SUBSTITUTO TRIBUTRIO*/
         INSERT INTO DADOSADIC(CDFILIAL, NRLANCTONF, NRDADOADIC, CDMENSAGEM, DSDADOADIC)
                        VALUES(@P_FILIAL, @P_LANCTONF, @V_DADOADIC, @C_MENSINSCESTAST_CDMENSAGEM, @C_MENSINSCESTAST_DSMENSINSCESTAST);

         SET @V_DADOADIC = RIGHT(REPLICATE('0', 3) + RTRIM(CONVERT(VARCHAR, CONVERT(NUMERIC, @V_DADOADIC) + 1)), 3);

         FETCH NEXT FROM C_MENSINSCESTAS INTO @C_MENSINSCESTAST_CDMENSAGEM, @C_MENSINSCESTAST_DSMENSINSCESTAST;
      END;
      CLOSE C_MENSINSC;
      DEALLOCATE C_MENSINSC;
   END;

   -- PREENCHER CLASSIFICACAO FISCAL NCM NA TABELA ITEMPRODUTO
   DECLARE C_ITEM CURSOR FOR (SELECT I.CDFILIAL, I.NRLANCTONF, I.NRSEQITPROD, P.CDCLASFISC
                                FROM ITEMPRODUTO I, PRODUTO P
                               WHERE I.CDFILIAL   = @P_FILIAL
                                 AND I.NRLANCTONF = @P_LANCTONF
                                 AND I.CDPRODUTO = P.CDPRODUTO);

   OPEN C_ITEM;
   FETCH NEXT FROM C_ITEM INTO @V_ITEM_CDFILIAL, @V_ITEM_NRLANCTONF, @V_ITEM_NRSEQITPROD, @V_ITEM_CDCLASFISC;

   WHILE (@@FETCH_STATUS = 0) BEGIN

      UPDATE ITEMPRODUTO
         SET CDPRODNCMTRANS = @V_ITEM_CDCLASFISC
       WHERE CDFILIAL    = @V_ITEM_CDFILIAL
         AND NRLANCTONF  = @V_ITEM_NRLANCTONF
         AND NRSEQITPROD = @V_ITEM_NRSEQITPROD;

      FETCH NEXT FROM C_ITEM INTO @V_ITEM_CDFILIAL, @V_ITEM_NRLANCTONF, @V_ITEM_NRSEQITPROD, @V_ITEM_CDCLASFISC;
   END;
   CLOSE C_ITEM;
   DEALLOCATE C_ITEM;

   /*
   QUANDO A OPERAO DA NOTA FISCAL FOR PRESENCIAL O SISTEMA USAR COMO ENDEREO
   DE DESTINO O MESMO ENDEREO DA ORIGEM. EST CONDIO FOI NECESSRIA PARA ATENDER 
   A NOTA TCNICA 2015/003
   */
   IF @V_IDPRESENCIAL = '1' BEGIN
      SET @V_PAISDEST = @V_PAISORIG;
      SET @V_ESTADEST = @V_ESTAORIG;
      SET @V_MUNIDEST = @V_MUNIORIG;
      --SET @V_PAISCFOP = @V_PAISORIG;                 
      --SET @V_ESTACFOP = @V_ESTAORIG;
   END;

   SET @V_IDINTEREST = 'N';
   SET @V_IDINTERNA  = 'N';

   IF ((@V_PAISDEST = @V_PAISORIG) AND (@V_ESTADEST <> @V_ESTAORIG)) BEGIN
      SET @V_IDINTEREST = 'S';
   END;

   IF (@V_PAISDEST <> @V_PAISORIG) BEGIN
      SET @V_IDINTERNA  = 'S';
   END;


   IF (@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV') BEGIN
      UPDATE ITEMPRODUTO
      SET VRTOTAITEM = ROUND(VRTOTAITEM,2,2),
          VRCONTITEM = ROUND(VRCONTITEM,2,2)
      WHERE CDFILIAL = @P_FILIAL AND
            NRLANCTONF = @P_LANCTONF;
   END
   ELSE BEGIN
      UPDATE ITEMPRODUTO
      SET VRTOTAITEM = ROUND(VRTOTAITEM,2),
          VRCONTITEM = ROUND(VRCONTITEM,2)
      WHERE CDFILIAL = @P_FILIAL AND
            NRLANCTONF = @P_LANCTONF;
   END;

   SELECT @V_LIQUIDO = (SUM(VRTOTAITEM) - SUM(VRDESCITEM))
   FROM ITEMPRODUTO
   WHERE CDFILIAL = @P_FILIAL AND
         NRLANCTONF = @P_LANCTONF;

   /*PREENCHE O GRUPO FISCAL*/
   IF @V_IDORIGDESTNF = 'U' BEGIN  /*LICENCA DE USO*/
      EXEC CONSULTA_GRUPOFISCAL 'C', @V_CDORIGDESTNF, @V_CDFILIEMIT, 'S', @P_TIPOOPER, @V_CDGRUPOFISC OUTPUT;
   END  /*DEMAIS DESTINATARIOS*/
   ELSE BEGIN
      EXEC CONSULTA_GRUPOFISCAL @V_IDORIGDESTNF, @V_CDORIGDESTNF, @V_CDFILIEMIT, 'S', @P_TIPOOPER, @V_CDGRUPOFISC OUTPUT;
   END;

   /*VERIFICA SE A NOTA UTILIZA DOCUMENTO DE ORIGEM*/
   SELECT @V_IDOPERDEVONF = MAX(IDOPERDEVONF),
          @V_IDCONSPARFIS = MAX(IDCONSPARFIS),
          @V_ESTORNOCANC  = MAX(IDNFESTCANC),
          @V_IDCALCDIFALDENT = MAX(IDCALCDIFALDENT),
          @V_IDUTILVENC = MAX(IDUTILVENC),
          @V_IDNOTADEVO = MAX(IDNOTADEVO),
          @V_IDNFAJUSTE = MAX(IDNFAJUSTE)
     FROM TIPOOPERAC
    WHERE IDENTRSAIDOP = 'S' 
      AND CDTIPOOPER = @P_TIPOOPER;

   IF (@V_IDOPERDEVONF <> 'S') BEGIN /*SE NAO UTILIZA DOCUMENTO DE ORIGEM*/
      IF (@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV') BEGIN
         UPDATE ITEMPRODUTO
         SET VRBRUTITEM   = ROUND((VRTOTAITEM - VRDESCITEM),2,2),
             VRCONTITEM   = ROUND((VRTOTAITEM - VRDESCITEM),2,2)
         WHERE CDFILIAL   = @P_FILIAL   AND
               NRLANCTONF = @P_LANCTONF;
         SET @V_IDOPERDEVONF = 'N';
      END
      ELSE BEGIN
         UPDATE ITEMPRODUTO
         SET VRBRUTITEM   = ROUND((VRTOTAITEM - VRDESCITEM),2),
             VRCONTITEM   = ROUND((VRTOTAITEM - VRDESCITEM),2)
         WHERE CDFILIAL   = @P_FILIAL   AND
               NRLANCTONF = @P_LANCTONF;
         SET @V_IDOPERDEVONF = 'N';
      END;
   END
   ELSE BEGIN
      IF (@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV') BEGIN
         UPDATE ITEMPRODUTO
         SET VRBRUTITEM   = ROUND((VRTOTAITEM - VRDESCITEM),2,2),
             VRCONTITEM   = ROUND((VRTOTAITEM - VRDESCITEM),2,2)
         WHERE CDFILIAL   = @P_FILIAL   AND
               NRLANCTONF = @P_LANCTONF;
         SET @V_IDOPERDEVONF = 'N';
      END
      ELSE BEGIN
         UPDATE ITEMPRODUTO
         SET VRBRUTITEM   = ROUND((VRTOTAITEM - VRDESCITEM),2),
             VRCONTITEM   = ROUND((VRTOTAITEM - VRDESCITEM),2)
         WHERE CDFILIAL   = @P_FILIAL   AND
               NRLANCTONF = @P_LANCTONF;
         SET @V_IDOPERDEVONF = 'N';
      END;
      SELECT @V_COUNT = COUNT(*)
      FROM ITEMNOTAFISC
      WHERE CDFILIAL   = @P_FILIAL AND
            NRLANCTONF = @P_LANCTONF;


      SET @V_IDDEVOLIST = 'N';
      IF (@V_COUNT > 1) BEGIN
         SET @V_IDDEVOLIST = 'S';
      END;

      IF (@V_COUNT = 0) BEGIN
         SET @V_IDOPERDEVONF = 'N';
         IF (@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV') BEGIN
            UPDATE ITEMPRODUTO
            SET VRBRUTITEM   = ROUND((VRTOTAITEM - VRDESCITEM),2,2),
                VRCONTITEM   = ROUND((VRTOTAITEM - VRDESCITEM),2,2)
            WHERE CDFILIAL   = @P_FILIAL   AND
                  NRLANCTONF = @P_LANCTONF;
         END
         ELSE BEGIN
            UPDATE ITEMPRODUTO
            SET VRBRUTITEM   = ROUND((VRTOTAITEM - VRDESCITEM),2),
                VRCONTITEM   = ROUND((VRTOTAITEM - VRDESCITEM),2)
            WHERE CDFILIAL   = @P_FILIAL   AND
                  NRLANCTONF = @P_LANCTONF;
         END;
      END
      ELSE BEGIN
         SET @V_IDOPERDEVONF = 'S';
         IF (@P_TIPOOPER = '03') OR (@P_TIPOOPER = '05') OR (@P_TIPOOPER = '11') BEGIN
            SET @V_IDOPERDEVONF = 'N';
         END;
      END;
   END;

   DECLARE C_IMPOSTORETI CURSOR FOR
      SELECT CDIMPOSTO
      FROM IMPOSTO
      WHERE IDTRATIMPO   = 'R' AND
            IDUTVRMENSBC = 'S';

   OPEN C_IMPOSTORETI;
   FETCH NEXT FROM C_IMPOSTORETI INTO @V_IMPRETI_CDIMPOSTO;

   WHILE (@@FETCH_STATUS = 0) BEGIN

      SELECT @V_IMPOSTO = MAX(CDIMPOSTO)
      FROM IMPOSTONF
      WHERE CDFILIAL     = @P_FILIAL                AND
            NRLANCTONF   = @P_LANCTONF              AND
            CDIMPOSTO    = @V_IMPRETI_CDIMPOSTO     AND
            VRBASECALCNF <> 0.00                    AND
            VRALIQNF     <> 0.00                    AND
            VRIMPOSTONF  = 0.00;

      IF @V_IMPOSTO IS NULL BEGIN
         SET @V_IDRECALCULO = 'S';
      END
      ELSE BEGIN
         SET @V_IDRECALCULO = 'N';
      END;

      FETCH NEXT FROM C_IMPOSTORETI INTO @V_IMPRETI_CDIMPOSTO;
   END;
   CLOSE C_IMPOSTORETI;
   DEALLOCATE C_IMPOSTORETI;

   DELETE FROM DADOSADIC
    WHERE CDFILIAL = @P_FILIAL
      AND NRLANCTONF = @P_LANCTONF
      AND DSDADOADIC LIKE 'ICMS retido anteriormente por substituio tributria: BC %';

   DELETE FROM DADOSADIC
     WHERE CDFILIAL = @P_FILIAL
       AND NRLANCTONF = @P_LANCTONF
       AND DSDADOADIC LIKE 'Permite o aproveitamento do credito do ICMS no valor de R$ %';


   -- ATUALIZAO DAS TABELAS DE NOTAFISCAL, ITEMPRODUTO E DADOS ADICIONAIS
   IF NOT(@P_TIPOOPER IN ('03','07','09','10','12')) AND (@V_IDOPERDEVONF <> 'S') BEGIN
   /*AS NOTAS QUE NAO UTILIZAM DOCUMENTO DE ORIGEM*/

      -- NOTA FISCAL DE MOVIMENTAO - 07
      DECLARE C_ITEMPRODUTO CURSOR FOR
         SELECT VRTOTAITEM, VRDESCITEM, IT.CDPRODUTO, NRSEQITPROD,
                CDCSTINFUSU, CDCFOPINFUSU, CDSUFXINFUSU, P.CDARVPROD,
                IT.QTITEMPROD, IT.IDORIGEMPROD
           FROM ITEMPRODUTO IT, PRODUTO P
          WHERE IT.CDFILIAL   = @P_FILIAL   AND
                IT.NRLANCTONF = @P_LANCTONF AND
                IT.CDPRODUTO  = P.CDPRODUTO;
      OPEN C_ITEMPRODUTO;
      FETCH NEXT FROM C_ITEMPRODUTO INTO @V_ITEMPROD_VRTOTAITEM,   @V_ITEMPROD_VRDESCITEM,
                                         @V_ITEMPROD_CDPRODUTO,    @V_ITEMPROD_NRSEQITPROD,
                                         @V_ITEMPROD_CDCSTINFUSU,  @V_ITEMPROD_CDCFOPINFUSU,
                                         @V_ITEMPROD_CDSUFXINFUSU, @V_ITEMPROD_CDARVPROD,
                                         @V_ITEMPROD_QTITEMPROD,   @V_ITEMPROD_IDORIGEMPROD;

      WHILE (@@FETCH_STATUS = 0) BEGIN

         SET @V_LIQUIITEM = @V_ITEMPROD_VRTOTAITEM - @V_ITEMPROD_VRDESCITEM;

         /*VERIFICA O CST POR ITEM*/
         EXEC CONSULTA_CST 'S', @P_EMPRESA, @V_ITEMPROD_CDARVPROD, @P_INSCESTA, @P_TIPOOPER, @P_FILIAL, @P_LANCTONF, @V_CDGRUPOFISC, @V_IDINTEREST, @V_IDINTERNA, NULL, @V_ITEMPROD_IDORIGEMPROD;

         DECLARE C_CSTTEMP CURSOR FOR
            SELECT DSMENSCSTTMP
            FROM CSTTEMP
            WHERE (NRCSTTEMP = @V_CSTTEMP) AND
                  (NOT (DSMENSCSTTMP IS NULL)) AND
                  (NOT EXISTS (SELECT DSDADOADIC
                                        FROM DADOSADIC
                                        WHERE (CDFILIAL = @P_FILIAL) AND
                                              (NRLANCTONF = @P_LANCTONF) AND
                                              (DSDADOADIC LIKE CSTTEMP.DSMENSCSTTMP + '%')));
         OPEN C_CSTTEMP;
         FETCH NEXT FROM C_CSTTEMP INTO @V_CSTTMP_DSMENSCSTTMP;
      	WHILE (@@FETCH_STATUS = 0) BEGIN
            IF NOT (@V_CSTTMP_DSMENSCSTTMP IS NULL) BEGIN
               INSERT INTO DADOSADIC(CDFILIAL, NRLANCTONF, NRDADOADIC, DSDADOADIC)
               VALUES(@P_FILIAL, @P_LANCTONF, @V_DADOADIC, @V_CSTTMP_DSMENSCSTTMP);
               SET @V_DADOADIC = RIGHT(REPLICATE('0',3) + RTRIM(CONVERT(VARCHAR, CONVERT(NUMERIC, @V_DADOADIC) + 1)),3);
            END;
            FETCH NEXT FROM C_CSTTEMP INTO @V_CSTTMP_DSMENSCSTTMP;
         END;
         CLOSE C_CSTTEMP;
         DEALLOCATE C_CSTTEMP;

         EXEC CONSULTA_CFOP 'S', @P_EMPRESA, @V_ITEMPROD_CDARVPROD, @P_INSCESTA, @P_TIPOOPER, @V_PAISORIG,
                            @V_ESTAORIG, @V_PAISCFOP, @V_ESTACFOP, @P_FILIAL, @P_LANCTONF, @V_CDGRUPOFISC, @P_INIVALID, @V_ITEMPROD_IDORIGEMPROD;

         DECLARE C_CFOPTEMP CURSOR FOR
            SELECT DSMENSCFOTMP FROM CFOPTEMP
            WHERE (NRCFOPTEMP = @V_CFOPTEMP) AND
                  (NOT (DSMENSCFOTMP IS NULL)) AND
                  (NOT EXISTS (SELECT DSDADOADIC FROM DADOSADIC
                                        WHERE (CDFILIAL   = @P_FILIAL)   AND
                                              (NRLANCTONF = @P_LANCTONF) AND
                                              (DSDADOADIC LIKE CFOPTEMP.DSMENSCFOTMP + '%')));
         OPEN C_CFOPTEMP;
         FETCH NEXT FROM C_CFOPTEMP INTO @V_CFOPTMP_DSMENSCFOTMP;
         WHILE (@@FETCH_STATUS = 0) BEGIN
            IF NOT (@V_CFOPTMP_DSMENSCFOTMP IS NULL) BEGIN
               INSERT INTO DADOSADIC(CDFILIAL, NRLANCTONF, NRDADOADIC, DSDADOADIC)
               VALUES(@P_FILIAL, @P_LANCTONF, @V_DADOADIC, @V_CFOPTMP_DSMENSCFOTMP);
               SET @V_DADOADIC = RIGHT(REPLICATE('0',3) + RTRIM(CONVERT(VARCHAR, CONVERT(NUMERIC, @V_DADOADIC) + 1)),3);
            END;
            FETCH NEXT FROM C_CFOPTEMP INTO @V_CFOPTMP_DSMENSCFOTMP;
         END;
         CLOSE C_CFOPTEMP;
         DEALLOCATE C_CFOPTEMP;

         IF @V_ITEMPROD_CDCFOPINFUSU IS NULL BEGIN
            UPDATE NOTAFISCAL
            SET DSCDFISOPENF = (SELECT MAX(DSCFOPTMP) FROM CFOPTEMP
                                WHERE NRCFOPTEMP = @V_CFOPTEMP)
            WHERE CDFILIAL   = @P_FILIAL AND
                  NRLANCTONF = @P_LANCTONF;

            SELECT @V_FISOPEITEM = MAX(CDFISOPETMP),
                   @V_SUFXCFOPPR = MAX(CDSUFCFOPTMP),
                   @V_DSCDFISOPEIT = MAX(DSCFOPTMP)
            FROM CFOPTEMP
            WHERE NRCFOPTEMP = @V_CFOPTEMP;

            SELECT @V_SITUTRIBPR = MAX(CDSITTRIBTMP)
            FROM CSTTEMP
            WHERE NRCSTTEMP = @V_CSTTEMP;
         END
         ELSE BEGIN
            SET @V_FISOPEITEM = @V_ITEMPROD_CDCFOPINFUSU;
            SET @V_SUFXCFOPPR = @V_ITEMPROD_CDSUFXINFUSU;
            SET @V_SITUTRIBPR = @V_ITEMPROD_CDCSTINFUSU;
         END;

         IF @V_IDDOCREPLIC IS NOT NULL BEGIN
            IF LEN(@V_SITUTRIBPR) = 3 BEGIN
               SET @V_SITUTRIBPR = SUBSTRING(@V_SITUTRIBPR,1,1) + '90';
            END
            ELSE BEGIN
               SET @V_SITUTRIBPR = '90';
            END;
         END;

         EXEC CONSULTA_CSOSN 'S', @P_EMPRESA, @V_ITEMPROD_CDARVPROD, @P_INSCESTA, @P_TIPOOPER,@P_FILIAL, @P_LANCTONF, @V_CDGRUPOFISC, @V_IDINTEREST, @P_CDFISCOPERSN = @V_CDFISCOPERSN OUTPUT;

         UPDATE ITEMPRODUTO
         SET CDFISOPEITEM = @V_FISOPEITEM,
             CDSUFXCFOPPR = @V_SUFXCFOPPR,
             CDSITUTRIBPR = @V_SITUTRIBPR,
             DSCDFISOPEIT = @V_DSCDFISOPEIT,
             CDFISCOPERSN = @V_CDFISCOPERSN
         WHERE CDFILIAL    = @P_FILIAL   AND
               NRLANCTONF  = @P_LANCTONF AND
               NRSEQITPROD = @V_ITEMPROD_NRSEQITPROD;

         DELETE FROM CFOPTEMP
         WHERE NRCFOPTEMP = @V_CFOPTEMP;

         DELETE FROM CSTTEMP
         WHERE NRCSTTEMP = @V_CSTTEMP;

         -- ATUALIZAO DA TABELA DE IMPOSTOS POR ITEM
         DELETE FROM ITEMPROIMPOS
         WHERE (CDFILIAL    = @P_FILIAL)   AND
               (NRLANCTONF  = @P_LANCTONF) AND
               (NRSEQITPROD = @V_ITEMPROD_NRSEQITPROD);

         DELETE ITEMPROIMPOSORIG
         WHERE (CDFILIAL    = @P_FILIAL)   AND
               (NRLANCTONF  = @P_LANCTONF) AND
               (NRSEQITPROD = @V_ITEMPROD_NRSEQITPROD);

         SELECT @V_IMPOSINFUSU = COUNT(*)
         FROM IMPOSINFUSU
         WHERE (CDFILIAL    = @P_FILIAL)   AND
               (NRLANCTONF  = @P_LANCTONF) AND
               (NRSEQITPROD = @V_ITEMPROD_NRSEQITPROD);

         IF @V_IMPOSINFUSU = 0 BEGIN

            -- Verifica se h grupo fiscal por servico
            SELECT @V_CDGRPFISCSV = MAX(CDGRUPOFISC)
            FROM SERVCLIE SC, SERVICO S
            WHERE SC.CDFILIAL   = @V_CDFILIEMIT AND
                  SC.CDCLIENTE  = @P_CLIENTE    AND
                  SC.CDFILIAL   = S.CDFILIAL   AND
                  SC.CDSERVFILI = S.CDSERVFILI AND
                  S.CDPRODUTO   = @V_ITEMPROD_CDPRODUTO;

            IF @V_CDGRPFISCSV IS NULL BEGIN
               -- Verifica se h grupo fiscal por cliente da filial
               SELECT @V_CDGRPFISCSV = MAX(CDGRUPOFISC)
               FROM CLIENFILIAL
               WHERE CDFILIAL   = @V_CDFILIEMIT AND
                     CDCLIENTE  = @P_CLIENTE;
            END;

            EXEC CONSULTA_INCIDENCIA 'S', @P_EMPRESA, @V_ITEMPROD_CDARVPROD, @P_INSCESTA, @P_TIPOOPER, @P_FILIAL, @P_LANCTONF, @V_CDGRUPOFISC,
                                      @V_CDGRPFISCSV, @V_IDINTEREST, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, @V_ITEMPROD_IDORIGEMPROD;

            DECLARE C_INCITEMP CURSOR FOR
               SELECT DSMENSINCTMP
               FROM INCITEMP
               WHERE (NRINCITEMP = @V_INCITEMP) AND
                     (NOT (DSMENSINCTMP IS NULL)) AND
                     (NOT EXISTS (SELECT DSDADOADIC
                                    FROM DADOSADIC
                                   WHERE (CDFILIAL = @P_FILIAL)     AND
                                         (NRLANCTONF = @P_LANCTONF) AND
                                         (DSDADOADIC LIKE INCITEMP.DSMENSINCTMP + '%')));
            OPEN C_INCITEMP;
            FETCH NEXT FROM C_INCITEMP INTO @V_INCITMP_DSMENSINCTMP;
            WHILE (@@FETCH_STATUS = 0) BEGIN
               IF NOT(@V_INCITMP_DSMENSINCTMP IS NULL) BEGIN
                  INSERT INTO DADOSADIC(CDFILIAL, NRLANCTONF, NRDADOADIC, DSDADOADIC)
                              VALUES(@P_FILIAL, @P_LANCTONF, @V_DADOADIC, @V_INCITMP_DSMENSINCTMP);
                  SET @V_DADOADIC = RIGHT(REPLICATE('0',3) + RTRIM(CONVERT(VARCHAR, CONVERT(NUMERIC, @V_DADOADIC) + 1)),3);
               END;
               FETCH NEXT FROM C_INCITEMP INTO @V_INCITMP_DSMENSINCTMP;
            END;
            CLOSE C_INCITEMP;
            DEALLOCATE C_INCITEMP;

            DECLARE C_INCIDENCIA CURSOR FOR
               SELECT DISTINCT CDIMPOTEMP, CDFISCTEMP, IDTRATIMPTMP, IDCONSISTENT,
                               IDIMPORECUP, IDUTMUNIORIG, IDUTVLRQTDEIMPO, CDDETALHEPROD,
                               CDREGRATMP, CDIMPOSTONFE, IT.CDENQLEGALIPI, IT.CDCEST,
                               IT.VRADICALIQFECP
               FROM INCITEMP IT, IMPOSTO IP
               WHERE (IT.NRINCITEMP = @V_INCITEMP)    AND
                     (IP.CDIMPOSTO  = IT.CDIMPOTEMP) AND
                     (IP.IDPRODNOTA = 'P')
               ORDER BY CDIMPOTEMP;
            OPEN C_INCIDENCIA;
            FETCH NEXT FROM C_INCIDENCIA INTO @V_INCIDEN_CDIMPOTEMP  ,    @V_INCIDEN_CDFISCTEMP,
                                              @V_INCIDEN_IDTRATIMPTMP,    @V_INCIDEN_IDCONSISTENT,
                                              @V_INCIDEN_IDIMPORECUP,     @V_INCIDEN_IDUTMUNIORIG,
                                              @V_INCIDEN_IDUTVLRQTDEIMPO, @V_INCIDEN_CDDETALHEPROD,
                                              @V_INCIDEN_CDREGRATMP,      @V_INCIDEN_CDIMPOSTONFE,
                                              @V_INCIDEN_CDENQLEGALIPI,   @V_INCIDEN_CDCEST,
                                              @V_INCIDEN_VRADICALIQFECP;
            WHILE (@@FETCH_STATUS = 0) BEGIN

               SET @V_ALIQUTMP = 0;
               SET @V_SIMPLES  = 'N';
               SET @V_BCICMSSTRETIDO = 0;
               SET @V_VRICMSSTRETIDO = 0;
               SET @V_VRADICALIQFECP = @V_INCIDEN_VRADICALIQFECP;

               /*VERIFICA CST POR IMPOSTO*/
               SET @V_IMPOICMS = NULL;
               SET @V_CDGRUPOFISCAUX = NULL;

               SELECT @V_CDGRUPOFISCAUX = MAX(G.CDGRUPOFISC)
                 FROM GRUPOFISCIMPFIL G,
                      (SELECT CDFILIEMIT AS CDFILIAL
                         FROM NOTAFISCAL
                        WHERE CDFILIAL = @P_FILIAL
                          AND NRLANCTONF = @P_LANCTONF) F
                WHERE G.CDFILIAL = F.CDFILIAL
                  AND NOT G.CDGRUPOFISC IS NULL
                  AND G.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;

               IF @V_IDORIGDESTNF = 'C' BEGIN
                  SELECT @V_CDGRUPOFISCAUX = ISNULL(MAX(G.CDGRUPOFISC), @V_CDGRUPOFISCAUX)
                    FROM GRFISIMPIECLIE G,
                         (SELECT CDCLIENTE
                            FROM NOTAFISCAL
                           WHERE CDFILIAL = @P_FILIAL
                             AND NRLANCTONF = @P_LANCTONF) N
                   WHERE G.CDCLIENTE = N.CDCLIENTE
                     AND G.CDEMPRESA = @P_EMPRESA
                     AND G.CDINSCESTA = @P_INSCESTA
                     AND NOT G.CDGRUPOFISC IS NULL
                     AND G.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
               END
               ELSE BEGIN
                  SELECT @V_CDGRUPOFISCAUX = ISNULL(MAX(G.CDGRUPOFISC), @V_CDGRUPOFISCAUX)
                    FROM GRFISIMPIEFORN G,
                        (SELECT CDFORNECED
                           FROM NOTAFISCAL
                          WHERE CDFILIAL = @P_FILIAL
                            AND NRLANCTONF = @P_LANCTONF) N
                   WHERE G.CDFORNECED = N.CDFORNECED
                     AND G.CDEMPRESA = @P_EMPRESA
                     AND G.CDINSCESTA = @P_INSCESTA
                     AND NOT G.CDGRUPOFISC IS NULL
                     AND G.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
               END;

               IF @V_CDGRUPOFISCAUX IS NULL BEGIN
                  EXEC CONSULTA_CST_NFE 'S', @P_EMPRESA, @V_ITEMPROD_CDARVPROD, @P_INSCESTA, @P_TIPOOPER, @V_CDGRUPOFISC, @V_INCIDEN_CDIMPOTEMP, @V_IDINTEREST, @V_IDINTERNA, @P_FILIAL, @P_LANCTONF, '', @V_ITEMPROD_IDORIGEMPROD, @P_CDSITTRIBTMP = @V_CDSITTRIBTMP OUTPUT, @P_IDMODBCNFE = @V_IDMODBCNFE OUTPUT, @P_IDMODBCSTNFE = @V_IDMODBCSTNFE OUTPUT,  @P_CDTPCRPICOSTNFE = @V_CDTPCRPICOSTNFE OUTPUT, @P_CDNATUBCPCSTNFE = @V_CDNATUBCPCSTNFE OUTPUT, @P_IDMOTIDESSTNFE = @V_IDMOTIDESSTNFE OUTPUT;
               END
               ELSE BEGIN
                  EXEC CONSULTA_CST_NFE 'S', @P_EMPRESA, @V_ITEMPROD_CDARVPROD, @P_INSCESTA, @P_TIPOOPER, @V_CDGRUPOFISCAUX, @V_INCIDEN_CDIMPOTEMP, @V_IDINTEREST, @V_IDINTERNA, @P_FILIAL, @P_LANCTONF, '', @V_ITEMPROD_IDORIGEMPROD, @P_CDSITTRIBTMP = @V_CDSITTRIBTMP OUTPUT, @P_IDMODBCNFE = @V_IDMODBCNFE OUTPUT, @P_IDMODBCSTNFE = @V_IDMODBCSTNFE OUTPUT,  @P_CDTPCRPICOSTNFE = @V_CDTPCRPICOSTNFE OUTPUT, @P_CDNATUBCPCSTNFE = @V_CDNATUBCPCSTNFE OUTPUT, @P_IDMOTIDESSTNFE = @V_IDMOTIDESSTNFE OUTPUT;
               END;

               SET @V_CDSIMPLESNACIONAL = NULL;
               SET @V_CDFAIXA = NULL;

               SET @V_BCICMSSTRETIDO = 0;
               SET @V_VRICMSSTRETIDO = 0;

               SET @V_CDREGRAITALIQ = NULL;

               /*SIMPLES NACIONAL*/
               IF (@V_CDSITUCRT <> '3') BEGIN

                  SET @V_FISOPEITEMAUX = SUBSTRING(@V_FISOPEITEM, 2, 3);
                  
                  EXEC CALCULA_ALIQUOTA_SN @P_EMPRESA, 
                                           @P_TIPOOPER, 
                                           @P_INIVALID, 
                                           @V_FISOPEITEMAUX, 
                                           @V_INCIDEN_CDIMPOSTONFE, 
                                           @V_VRSUBLIMITESN,
                                           'N',
                                           @V_RBT12,
                                           @V_RBA,
                                           @V_CDSIMPLESNACIONAL,
                                           @V_CDFAIXA,
                                           @V_VRALIQSIMPLES;

                  IF (@V_CDFAIXA IS NOT NULL) OR ((@V_INCIDEN_CDIMPOSTONFE IN ('00', '31')) AND (@V_RBT12 >= 3600000)) BEGIN

                     UPDATE ITEMPRODUTO
                        SET CDSIMPLESNACIONAL = @V_CDSIMPLESNACIONAL
                      WHERE CDFILIAL    = @P_FILIAL
                        AND NRLANCTONF  = @P_LANCTONF
                        AND NRSEQITPROD = @V_ITEMPROD_NRSEQITPROD;

                     SET @V_ALIQUTMP = @V_VRALIQSIMPLES;
                     SET @V_CDREGRAITALIQ = @V_INCIDEN_CDREGRATMP;
                     SET @V_NRALIQTEMP   = 0;
                     SET @V_PARDEDTMP    = 0;
                     SET @V_PREDBCTMP    = 0;
                     SET @V_TRATIMPST    = '0';
                     SET @V_PBCSUBTRIB   = 0;
                     SET @V_IDPMCBASECAL = 'N';
                     SET @V_SIMPLES      = 'S';
                  END;

                  IF (@V_CDFISCOPERSN = '500') OR (SUBSTRING(@V_CDFISCOPERSN, 2, 3) = '500') BEGIN
                     /*Verifica se o imposto de st (hj o sistema s aceita o icms st)*/
                     SET @V_CDIMPOSICMS  = null;
                     SELECT @V_CDIMPOSICMS = MAX(CDIMPOSTO)
                       FROM IMPOSTO
                      WHERE CDIMPOSTONFE = '00'
                        AND CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;

                     IF (@V_CDIMPOSICMS IS NOT NULL) BEGIN
                        SET @V_ALIQUTMP = 0;
                     END;

                     /*IMPOSTO DE SUBSTITUICAO TRIBUTARIA*/

                     SET @V_CDIMPOSTRIB  = null;
                     SET @V_IDVRIMPSTRIB = null;
                     DECLARE C_ICMSST CURSOR FOR
                           SELECT CDIMPOSTRIB
                             FROM IMPOSTO
                            WHERE CDIMPOSTRIB = @V_INCIDEN_CDIMPOTEMP;

                     OPEN C_ICMSST;
                     FETCH NEXT FROM C_ICMSST INTO @V_ICMSST_CDIMPOSTRIB;
                     WHILE (@@FETCH_STATUS = 0) BEGIN

                        SET @V_CDIMPOSTRIB = ISNULL(@V_CDIMPOSTRIB,'')+@V_ICMSST_CDIMPOSTRIB+'_';
                        FETCH NEXT FROM C_ICMSST INTO @V_ICMSST_CDIMPOSTRIB;
                     END;
                     CLOSE C_ICMSST;
                     DEALLOCATE C_ICMSST;

                     SET @V_MEDIA = 0;
                     SET @V_BCICMSSTRETIDO = 0;
                     SET @V_VRICMSSTRETIDO = 0;

                     IF (@V_CDIMPOSTRIB IS NOT NULL) BEGIN
                        IF (@V_IDUTILLOTE = 'S') BEGIN
                           SELECT @V_IDUTCTRLLOTE = MAX(IDUTCTRLLOTE)
                             FROM PRODFILI
                            WHERE CDFILIAL  = @V_CDFILIEMIT
                              AND CDPRODUTO = @V_ITEMPROD_CDPRODUTO;

                           IF (@V_IDUTCTRLLOTE = 'S') BEGIN
                              SELECT @V_NRLOTEESTQ = MAX(NRLOTEESTQ)
                                FROM ITEMPRODUTO
                               WHERE CDFILIAL    = @P_FILIAL
                                 AND NRLANCTONF  = @P_LANCTONF
                                 AND NRSEQITPROD = @V_ITEMPROD_NRSEQITPROD;

                              SET @V_MEDIA = 0;
                              SET @V_BCICMSSTRETIDO = 0;
                              SET @V_VRICMSSTRETIDO = 0;

                              DECLARE C_ICMSSTRETIDO CURSOR FOR SELECT II.CDFILIAL, II.NRLANCTONF, II.NRSEQITPROD, II.CDIMPOSTO,
                                                                       ROUND(II.VRBASECALCIT/I.QTITEMPROD,2) AS VRBASE, ROUND(II.VRIMPOSTOIT/I.QTITEMPROD,2) AS VRIMPOSTO
                                                                  FROM NOTAFISCAL N, ITEMPRODUTO I, ITEMPROIMPOS II
                                                                 WHERE N.CDFILIAL = I.CDFILIAL
                                                                   AND N.NRLANCTONF = I.NRLANCTONF
                                                                   AND I.CDFILIAL = II.CDFILIAL
                                                                   AND I.NRLANCTONF = II.NRLANCTONF
                                                                   AND I.NRSEQITPROD = II.NRSEQITPROD
                                                                   AND II.NRITPROIMPOS = '1'
                                                                   AND N.IDENTRSAIDOP = 'E'
                                                                   AND I.CDPRODUTO = @V_ITEMPROD_CDPRODUTO
                                                                   AND I.NRLOTEESTQ = @V_NRLOTEESTQ
                                                                   AND N.DTENTRSAID <= @P_INIVALID
                                                                   AND (CHARINDEX(II.CDIMPOSTO+'_', @V_CDIMPOSTRIB) > 0);
                              OPEN C_ICMSSTRETIDO;
                              FETCH NEXT FROM C_ICMSSTRETIDO INTO @V_ICMSSTRETIDO_CDFILIAL, @V_ICMSSTRETIDO_NRLANCTONF, @V_ICMSSTRETIDO_NRSEQITPROD, @V_ICMSSTRETIDO_CDIMPOSTO,
                                                                  @V_ICMSSTRETIDO_VRBASE, @V_ICMSSTRETIDO_VRIMPOSTO;
                              WHILE (@@FETCH_STATUS = 0) BEGIN
                                 SET @V_MEDIA = @V_MEDIA + 1;
                                 SET @V_BCICMSSTRETIDO = @V_BCICMSSTRETIDO + @V_ICMSSTRETIDO_VRBASE;
                                 SET @V_VRICMSSTRETIDO = @V_VRICMSSTRETIDO + @V_ICMSSTRETIDO_VRIMPOSTO;
                                 FETCH NEXT FROM C_ICMSSTRETIDO INTO @V_ICMSSTRETIDO_CDFILIAL, @V_ICMSSTRETIDO_NRLANCTONF, @V_ICMSSTRETIDO_NRSEQITPROD, @V_ICMSSTRETIDO_CDIMPOSTO,
                                                                     @V_ICMSSTRETIDO_VRBASE, @V_ICMSSTRETIDO_VRIMPOSTO;
                              END;
                              CLOSE C_ICMSSTRETIDO;
                              DEALLOCATE C_ICMSSTRETIDO;
                              IF (@V_MEDIA > 0) BEGIN

                                 SET @V_BCICMSSTRETIDO = ROUND(@V_BCICMSSTRETIDO/@V_MEDIA,2);
                                 SET @V_VRICMSSTRETIDO = ROUND(@V_VRICMSSTRETIDO/@V_MEDIA,2);
                              END
                              ELSE BEGIN

                                 SET @V_BCICMSSTRETIDO = 0;
                                 SET @V_VRICMSSTRETIDO = 0;
                              END;
                              SET @V_BCICMSSTRETIDO = ROUND(@V_BCICMSSTRETIDO * @V_ITEMPROD_QTITEMPROD,2);
                              SET @V_VRICMSSTRETIDO = ROUND(@V_VRICMSSTRETIDO * @V_ITEMPROD_QTITEMPROD,2);

                              IF (@V_BCICMSSTRETIDO <> 0) BEGIN

                                 SELECT @V_EXISTDSDADOSADIC = COUNT(*)
                                   FROM DADOSADIC
                                  WHERE CDFILIAL = @P_FILIAL
                                    AND NRLANCTONF = @P_LANCTONF
                                    AND DSDADOADIC LIKE 'ICMS retido anteriormente por substituio tributria: BC %';

                                 IF (@V_EXISTDSDADOSADIC = 0) BEGIN
                                    /*PREENCHE AS MENSAGENS ATRELADAS A INSCRICAO ESTADUAL*/
                                    INSERT INTO DADOSADIC(CDFILIAL, NRLANCTONF, NRDADOADIC, DSDADOADIC)
                                                   VALUES(@P_FILIAL, @P_LANCTONF, @V_DADOADIC, 'ICMS retido anteriormente por substituio tributria: BC '+
                                                   CASE SUBSTRING(LTRIM(CONVERT(DECIMAL(20,2), @V_BCICMSSTRETIDO)),1,1) WHEN '.' THEN '0' + LTRIM(CONVERT(DECIMAL(20,2), @V_BCICMSSTRETIDO)) ELSE LTRIM(CONVERT(DECIMAL(20,2), @V_BCICMSSTRETIDO)) END
                                                   + ' Valor '+
                                                   CASE SUBSTRING(LTRIM(CONVERT(DECIMAL(20,2), @V_VRICMSSTRETIDO)),1,1) WHEN '.' THEN '0' + LTRIM(CONVERT(DECIMAL(20,2), @V_VRICMSSTRETIDO)) ELSE LTRIM(CONVERT(DECIMAL(20,2), @V_VRICMSSTRETIDO)) END);

                                    SET @V_DADOADIC = RIGHT(REPLICATE('0',3) + RTRIM(CONVERT(VARCHAR, CONVERT(NUMERIC, @V_DADOADIC) + 1)),3);
                                 END
                                 ELSE BEGIN
                                    UPDATE DADOSADIC
                                       SET DSDADOADIC = 'ICMS retido anteriormente por substituio tributria: BC '+
                                                   CASE SUBSTRING(LTRIM(CONVERT(DECIMAL(20,2), @V_BCICMSSTRETIDO)),1,1) WHEN '.' THEN '0' + LTRIM(CONVERT(DECIMAL(20,2), @V_BCICMSSTRETIDO)) ELSE LTRIM(CONVERT(DECIMAL(20,2), @V_BCICMSSTRETIDO)) END
                                                   + ' Valor '+
                                                   CASE SUBSTRING(LTRIM(CONVERT(DECIMAL(20,2), @V_VRICMSSTRETIDO)),1,1) WHEN '.' THEN '0' + LTRIM(CONVERT(DECIMAL(20,2), @V_VRICMSSTRETIDO)) ELSE LTRIM(CONVERT(DECIMAL(20,2), @V_VRICMSSTRETIDO)) END
                                      WHERE CDFILIAL = @P_FILIAL
                                        AND NRLANCTONF = @P_LANCTONF
                                        AND DSDADOADIC LIKE 'ICMS retido anteriormente por substituio tributria: BC %';
                                 END;
                              END;
                           END;
                        END
                        ELSE BEGIN
                           SET @V_MEDIA = 0;
                           SET @V_BCICMSSTRETIDO = 0;
                           SET @V_VRICMSSTRETIDO = 0;
                           SELECT @V_DTENTRSAID = MAX(N.DTENTRSAID), @V_CDIMPOSTOI = MAX(II.CDIMPOSTO), @V_CDPRODUTO = MAX(I.CDPRODUTO),
                                  @V_BCICMSSTRETIDO = ROUND(SUM(II.VRBASECALCIT)/SUM(I.QTITEMPROD),2), @V_VRICMSSTRETIDO = ROUND(SUM(II.VRIMPOSTOIT)/SUM(I.QTITEMPROD),2)
                             FROM NOTAFISCAL N, ITEMPRODUTO I, ITEMPROIMPOS II
                            WHERE N.CDFILIAL = I.CDFILIAL
                              AND N.NRLANCTONF = I.NRLANCTONF
                              AND I.CDFILIAL = II.CDFILIAL
                              AND I.NRLANCTONF = II.NRLANCTONF
                              AND I.NRSEQITPROD = II.NRSEQITPROD
                              AND II.NRITPROIMPOS = '1'
                              AND N.IDENTRSAIDOP = 'E'
                              AND I.CDPRODUTO = @V_ITEMPROD_CDPRODUTO
                              AND N.DTENTRSAID <= @P_INIVALID
                              AND (CHARINDEX(II.CDIMPOSTO+'_', @V_CDIMPOSTRIB) > 0);

                           SET @V_BCICMSSTRETIDO = ROUND(@V_BCICMSSTRETIDO * @V_ITEMPROD_QTITEMPROD,2);
                           SET @V_VRICMSSTRETIDO = ROUND(@V_VRICMSSTRETIDO * @V_ITEMPROD_QTITEMPROD,2);


                           IF (@V_BCICMSSTRETIDO <> 0) BEGIN

                              SELECT @V_EXISTDSDADOSADIC = COUNT(*)
                                FROM DADOSADIC
                               WHERE CDFILIAL = @P_FILIAL
                                 AND NRLANCTONF = @P_LANCTONF
                                 AND DSDADOADIC LIKE 'ICMS retido anteriormente por substituio tributria: BC %';

                              IF (@V_EXISTDSDADOSADIC = 0) BEGIN

                                 /*PREENCHE AS MENSAGENS ATRELADAS A INSCRICAO ESTADUAL*/
                                 INSERT INTO DADOSADIC(CDFILIAL, NRLANCTONF, NRDADOADIC, DSDADOADIC)
                                                VALUES(@P_FILIAL, @P_LANCTONF, @V_DADOADIC, 'ICMS retido anteriormente por substituio tributria: BC '+
                                                       CASE SUBSTRING(LTRIM(CONVERT(DECIMAL(20,2), @V_BCICMSSTRETIDO)),1,1) WHEN '.' THEN '0' + LTRIM(CONVERT(DECIMAL(20,2), @V_BCICMSSTRETIDO)) ELSE LTRIM(CONVERT(DECIMAL(20,2), @V_BCICMSSTRETIDO)) END
                                                       + ' Valor '+
                                                       CASE SUBSTRING(LTRIM(CONVERT(DECIMAL(20,2), @V_VRICMSSTRETIDO)),1,1) WHEN '.' THEN '0' + LTRIM(CONVERT(DECIMAL(20,2), @V_VRICMSSTRETIDO)) ELSE LTRIM(CONVERT(DECIMAL(20,2), @V_VRICMSSTRETIDO)) END);

                                 SET @V_DADOADIC = RIGHT(REPLICATE('0',3) + RTRIM(CONVERT(VARCHAR, CONVERT(NUMERIC, @V_DADOADIC) + 1)),3);
                              END
                              ELSE BEGIN
                                 UPDATE DADOSADIC
                                    SET DSDADOADIC = 'ICMS retido anteriormente por substituio tributria: BC '+
                                                     CASE SUBSTRING(LTRIM(CONVERT(DECIMAL(20,2), @V_BCICMSSTRETIDO)),1,1) WHEN '.' THEN '0' + LTRIM(CONVERT(DECIMAL(20,2), @V_BCICMSSTRETIDO)) ELSE LTRIM(CONVERT(DECIMAL(20,2), @V_BCICMSSTRETIDO)) END
                                                     + ' Valor '+
                                                     CASE SUBSTRING(LTRIM(CONVERT(DECIMAL(20,2), @V_VRICMSSTRETIDO)),1,1) WHEN '.' THEN '0' + LTRIM(CONVERT(DECIMAL(20,2), @V_VRICMSSTRETIDO)) ELSE LTRIM(CONVERT(DECIMAL(20,2), @V_VRICMSSTRETIDO)) END
                                  WHERE CDFILIAL = @P_FILIAL
                                    AND NRLANCTONF = @P_LANCTONF
                                    AND DSDADOADIC LIKE 'ICMS retido anteriormente por substituio tributria: BC %';
                              END;
                           END;
                        END;
                     END;
                  END;
               END;

               IF (@V_SIMPLES = 'N') OR ((@V_SIMPLES = 'S') AND (@V_INCIDEN_CDIMPOSTONFE = '00') AND (@V_RBA > (@V_VRSUBLIMITESN * 1.2))) BEGIN
                  SET @V_CDSIMPLESNACIONAL = NULL;
                  SET @V_CDFAIXA = NULL;
                  SET @V_VRADICALIQFECP = NULL;
                  IF @V_INCIDEN_IDUTMUNIORIG = 'D' BEGIN
                     SELECT @V_UTGRUPFISCS = MAX(IDGRUPFISSRV)
                     FROM IMPOSTO
                     WHERE CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;


                     IF @V_UTGRUPFISCS = 'S' BEGIN
                        SET @V_CDGRPFISCSV = NULL;
                        SELECT @V_CDGRPFISCSV = MAX(CDGRUPOFISC)
                        FROM SERVCLIE SC, SERVICO S
                        WHERE SC.CDFILIAL   = @V_CDFILIEMIT AND
                              SC.CDCLIENTE  = @P_CLIENTE    AND
                              SC.CDFILIAL   = S.CDFILIAL   AND
                              SC.CDSERVFILI = S.CDSERVFILI AND
                              S.CDPRODUTO   = @V_ITEMPROD_CDPRODUTO;
                        IF @V_CDGRPFISCSV IS NULL BEGIN
                           SELECT @V_CDGRPFISCSV = MAX(CDGRUPOFISC)
                           FROM CLIENFILIAL
                           WHERE CDFILIAL   = @V_CDFILIEMIT AND
                                 CDCLIENTE  = @P_CLIENTE ;
                        END;


                        EXEC CONSULTA_ALIQUOTA @V_INCIDEN_CDIMPOTEMP, 'S', @P_EMPRESA, @V_ITEMPROD_CDARVPROD, @P_INSCESTA, @V_PAISORIG,
                                               @V_ESTAORIG, @V_PAISDEST, @V_ESTADEST, @V_MUNIDEST, @V_LIQUIITEM, @P_INIVALID, @P_FILIAL, @P_LANCTONF,
                                               @V_CDGRPFISCSV, @P_TIPOOPER, NULL, NULL, NULL, NULL, NULL, NULL, @V_ITEMPROD_IDORIGEMPROD;
                     END
                     ELSE BEGIN

                        EXEC CONSULTA_ALIQUOTA @V_INCIDEN_CDIMPOTEMP, 'S', @P_EMPRESA, @V_ITEMPROD_CDARVPROD, @P_INSCESTA, @V_PAISORIG,
                                               @V_ESTAORIG, @V_PAISDEST, @V_ESTADEST, @V_MUNIDEST, @V_LIQUIITEM, @P_INIVALID, @P_FILIAL, @P_LANCTONF,
                                               @V_CDGRUPOFISC, @P_TIPOOPER, NULL, NULL, NULL, NULL, NULL, NULL, @V_ITEMPROD_IDORIGEMPROD;
                     END;
                  END
                  ELSE BEGIN
                     SELECT @V_UTGRUPFISCS = MAX(IDGRUPFISSRV)
                     FROM IMPOSTO
                     WHERE CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;

                     IF @V_UTGRUPFISCS = 'S' BEGIN
                        SET @V_CDGRPFISCSV = NULL;
                        SELECT @V_CDGRPFISCSV = MAX(CDGRUPOFISC)
                        FROM SERVCLIE SC, SERVICO S
                        WHERE SC.CDFILIAL   = @V_CDFILIEMIT AND
                              SC.CDCLIENTE  = @P_CLIENTE    AND
                              SC.CDFILIAL   = S.CDFILIAL   AND
                              SC.CDSERVFILI = S.CDSERVFILI AND
                              S.CDPRODUTO   = @V_ITEMPROD_CDPRODUTO;
                        IF @V_CDGRPFISCSV IS NULL BEGIN
                           SELECT @V_CDGRPFISCSV = MAX(CDGRUPOFISC)
                           FROM CLIENFILIAL
                           WHERE CDFILIAL   = @V_CDFILIEMIT AND
                                 CDCLIENTE  = @P_CLIENTE ;
                        END;
                        EXEC CONSULTA_ALIQUOTA @V_INCIDEN_CDIMPOTEMP, 'S', @P_EMPRESA, @V_ITEMPROD_CDARVPROD, @P_INSCESTA, @V_PAISORIG,
                                               @V_ESTAORIG, @V_PAISDEST, @V_ESTADEST, @V_MUNIORIG, @V_LIQUIITEM, @P_INIVALID, @P_FILIAL, @P_LANCTONF,
                                               @V_CDGRPFISCSV, @P_TIPOOPER, NULL, NULL, NULL, NULL, NULL, NULL, @V_ITEMPROD_IDORIGEMPROD;

                     END
                     ELSE BEGIN

                        EXEC CONSULTA_ALIQUOTA @V_INCIDEN_CDIMPOTEMP, 'S', @P_EMPRESA, @V_ITEMPROD_CDARVPROD, @P_INSCESTA, @V_PAISORIG,
                                               @V_ESTAORIG, @V_PAISDEST, @V_ESTADEST, @V_MUNIORIG, @V_LIQUIITEM, @P_INIVALID, @P_FILIAL, @P_LANCTONF,
                                               @V_CDGRUPOFISC, @P_TIPOOPER, NULL, NULL, NULL, NULL, NULL, NULL, @V_ITEMPROD_IDORIGEMPROD;

                     END;
                  END;

                  SET @V_NRALIQTEMP = 0;
                  SET @V_PARDEDTMP  = 0;
                  SET @V_PREDBCTMP  = 0;
                  SET @V_ALIQUTMP   = 0;
                  SET @V_IMPOSTOIT  = 0;
                  SET @V_VRADICALIQFECP = NULL;

                  SELECT @V_NRALIQTEMP  = ISNULL(MAX(NRALIQTEMP),0),   @V_PARDEDTMP  = ISNULL(MAX(VRPARDEDTMP),0),
                         @V_PREDBCTMP   = ISNULL(MAX(VRPREDBCTMP),0),  @V_ALIQUTMP   = ISNULL(MAX(VRALIQUTMP),0),
                         @V_IDTRIMPSTII = ISNULL(MAX(IDTRIMPSTTMP),'0'), @V_PBCSUBTRIB = ISNULL(MAX(VRPBCSTTMP),0),
                         @V_IDPMCBASECAL = ISNULL(MAX(IDPMCBSCALTMP), 'S'), @V_CDREGRAITALIQ = MAX(CDREGRATMP),
                         @V_CDFISCOPERREGRA = MAX(CDFISCOPER), @V_IDDIFEALIQREGRA = MAX(IDDIFEALIQ),  @V_IDDIFALIQCUSPRREGRA = MAX(IDDIFALIQCUSPR),
                         @V_VRADICALIQFECP = MAX(VRADICALIQFECP)
                  FROM ALIQTEMP
                  WHERE (NRALIQTEMP = @V_ALIQTEMP);

                  SET @V_ICMS = NULL;
                  DECLARE C_ICMS CURSOR FOR
                     SELECT CDIMPOSTO
                       FROM IMPOSTONFE N, IMPOSTO I
                      WHERE N.CDIMPOSTONFE = I.CDIMPOSTONFE
                        AND N.CDIMPOSTONFE = '00'
                        AND I.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
                  OPEN C_ICMS;
                  FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
                  WHILE (@@FETCH_STATUS = 0) BEGIN
                     SET @V_ICMS = 'S';
                     FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
                  END;
                  CLOSE C_ICMS;
                  DEALLOCATE C_ICMS;

                  IF @V_ICMS = 'S' BEGIN

                     /* Verifica primeiro digito do CFOP */
                     SET @V_CFOP1DIGT = '';

                     IF @V_PAISCFOP = @V_PAISDEST BEGIN
                        IF @V_ESTACFOP = @V_ESTADEST BEGIN
                           SET @V_CFOP1DIGT = '5';
                        END
                        ELSE BEGIN
                           SET @V_CFOP1DIGT = '6';
                        END;
                     END
                     ELSE BEGIN
                        SET @V_CFOP1DIGT = '7';
                     END;

                     IF (@V_CDFISCOPERREGRA IS NOT NULL) BEGIN
                        SET @V_CDFISCOPERREGRA = @V_CFOP1DIGT+@V_CDFISCOPERREGRA;
                        SELECT @V_DSCDFISOPEITREGRA = TEKNISA.DESCRICAO_CFOP(@V_CDFISCOPERREGRA);
                        SET @V_DSCDFISOPEITREGRA = SUBSTRING(@V_DSCDFISOPEITREGRA, 1,45);
                     END;

                     SET @V_FISOPEITEM      = ISNULL(@V_CDFISCOPERREGRA, @V_FISOPEITEM);
                     SET @V_DSCDFISOPEIT    = ISNULL(@V_DSCDFISOPEITREGRA, @V_DSCDFISOPEIT);

                     IF (@V_CDFISCOPERREGRA IS NOT NULL) BEGIN
                        IF (LEN(@V_CDFISCOPERREGRA) < 4) BEGIN
                           SET @V_CDFISCOPERREGRA = @V_CFOP1DIGT+@V_CDFISCOPERREGRA;
                        END;

                        UPDATE ITEMPRODUTO
                           SET CDFISOPEITEM = @V_CDFISCOPERREGRA
                         WHERE CDFILIAL     = @P_FILIAL
                           AND NRLANCTONF  = @P_LANCTONF
                           AND NRSEQITPROD = @V_ITEMPROD_NRSEQITPROD;
                     END;

                     -- ALTERA NATUREZA DE OPERAO DA NOTA FISCAL CASO NO EXISTA
                     IF (@V_DSCDFISOPEITREGRA IS NOT NULL) BEGIN
                        UPDATE NOTAFISCAL
                           SET DSCDFISOPENF = @V_DSCDFISOPEITREGRA
                         WHERE CDFILIAL   = @P_FILIAL   AND
                               NRLANCTONF = @P_LANCTONF;
                     END
                     ELSE BEGIN
                        UPDATE NOTAFISCAL
                           SET DSCDFISOPENF = (SELECT MAX(DSCFOPTMP)
                                                 FROM CFOPTEMP
                                                WHERE NRCFOPTEMP = @V_CFOPTEMP)
                         WHERE CDFILIAL   = @P_FILIAL
                           AND NRLANCTONF = @P_LANCTONF
                           AND DSCDFISOPENF IS NULL;
                     END;
                  END;
               END;
               SET @V_CDIMPOSTRIB  = null;
               SET @V_IDVRIMPSTRIB = null;

               DECLARE C_ICMSST CURSOR FOR
                  SELECT CDIMPOSTO
                    FROM IMPOSTO
                   WHERE CDIMPOSTRIB = @V_INCIDEN_CDIMPOTEMP;

               OPEN C_ICMSST;
               FETCH NEXT FROM C_ICMSST INTO @V_ICMSST_CDIMPOSTRIB;
               WHILE (@@FETCH_STATUS = 0) BEGIN

                  SET @V_CDIMPOSTRIB = ISNULL(@V_CDIMPOSTRIB,'')+@V_ICMSST_CDIMPOSTRIB+'_';
                  FETCH NEXT FROM C_ICMSST INTO @V_ICMSST_CDIMPOSTRIB;
               END;
               CLOSE C_ICMSST;
               DEALLOCATE C_ICMSST;

               -- UTILIZA O PRPRIO VALOR DO IMPOSTO NA SUA BASE DE CLCULO (IMPOSTO POR DENTRO)
               SELECT @V_IDUTILPVRIMPBC = ISNULL(MAX(IDUTILPVRIMPBC), 'N')
                 FROM IMPOSTO
                WHERE CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;

               --IF @V_IDVERLEIAUTENFE = '3.10' BEGIN
                  IF (@V_VRADICALIQFECP IS NOT NULL) AND (@V_VRADICALIQFECP > 0) BEGIN
                     SET @V_ALIQUTMP = @V_ALIQUTMP + @V_VRADICALIQFECP;
                  END;
               --END;

               SET @V_TAXABASECALC = (100 - @V_PREDBCTMP)/100;
               SET @V_TAXAALIQUOTA = (@V_ALIQUTMP/100);
               SET @V_TAXABCSUBSTR = 1 + (@V_PBCSUBTRIB/100);
               SET @V_BASECALCIT = @V_LIQUIITEM * @V_TAXABASECALC;

               -- EM MG O CLCULO DA BASE  REALIZADO DE UMA FORMA DIFERENTE DE ACORDO COM A 
               -- ORIENTAO TRIBUTRIA DOLT/SUTRI N 003/2016. PARA ESTE PROCESSO  NECESSRIO
               -- CALCULAR O IMPOSTO POR DENTRO (ELE COMPONDO A BASE DE CLCULO DELE MESMO)
               IF (@V_IDCALCDIFALDENT = 'S') BEGIN
                  IF ((@V_PAISORIG = '0055') AND (@V_ESTAORIG = 'MG')) AND ((@V_PAISDEST = '0055') AND (@V_ESTADEST = 'MG')) BEGIN
                     IF (@V_IDCONSFINAL = 'S') BEGIN
                        IF (@V_VRADICALIQFECP IS NOT NULL) AND (@V_VRADICALIQFECP > 0) BEGIN
                           IF (@V_IDUTILPVRIMPBC = 'S') BEGIN
                              IF @V_INCIDEN_CDIMPOSTONFE = '00' BEGIN
                                 SET @V_BASECALCIT = @V_BASECALCIT/((100-@V_ALIQUTMP)/100);
                              END;
                           END;
                        END;
                     END;
                  END
                  ELSE BEGIN
                     IF ((@V_PAISORIG = '0055') AND (UPPER(@V_ESTAORIG) = 'MG')) BEGIN
                        SET @V_ALIQICMSDEST = 0;
                        SET @V_ALIQFECPDEST = 0;
                        IF (@V_IDINTEREST = 'S') AND (@V_IDCONSFINAL = 'S') AND (@V_IDCONTRIBICMSAUX = 'N') AND (@V_IDPRESENCIAL <> '1') BEGIN
                           IF @V_INCIDEN_CDIMPOSTONFE = '00' BEGIN
                              -- CONSULTANDO A ALQUOTA INTERNA DO IMPOSTO
                              DELETE 
                                FROM ALIQTEMP
                               WHERE NRALIQTEMP = @V_ALIQTEMP;

                              IF @V_INCIDEN_IDUTMUNIORIG = 'D' BEGIN
                                 EXEC CONSULTA_ALIQUOTA @V_INCIDEN_CDIMPOTEMP, 'S', @P_EMPRESA, @V_ITEMPROD_CDARVPROD, @P_INSCESTA, @V_PAISORIG,
                                                        @V_ESTAORIG, @V_PAISDEST, @V_ESTADEST, @V_MUNIDEST, @V_LIQUIITEM, @P_INIVALID, @P_FILIAL, @P_LANCTONF,
                                                        @V_CDGRUPOFISC, @P_TIPOOPER, NULL, NULL, NULL, NULL, NULL, NULL, @V_ITEMPROD_IDORIGEMPROD;
                              END
                              ELSE BEGIN
                                 EXEC CONSULTA_ALIQUOTA @V_INCIDEN_CDIMPOTEMP, 'S', @P_EMPRESA, @V_ITEMPROD_CDARVPROD, @P_INSCESTA, @V_PAISORIG,
                                                        @V_ESTAORIG, @V_PAISDEST, @V_ESTADEST, @V_MUNIORIG, @V_LIQUIITEM, @P_INIVALID, @P_FILIAL, @P_LANCTONF,
                                                        @V_CDGRUPOFISC, @P_TIPOOPER, NULL, NULL, NULL, NULL, NULL, NULL, @V_ITEMPROD_IDORIGEMPROD;
                              END;
                              SELECT @V_ALIQICMSDEST = MAX(VRALIQUTMP)
                                FROM ALIQTEMP
                               WHERE NRALIQTEMP = @V_ALIQTEMP;
                              IF @V_ALIQICMSDEST IS NULL BEGIN
                                 SELECT @V_ALIQICMSDEST = ISNULL(TEKNISA.CONSULTA_QUADRO_ALIQUOTAS(@V_ESTADEST, @V_ESTADEST), 0);
                              END;
                              -- CONSULTANDO A ALQUOTA DO FCP (FUNDO DE COMBATE A POBREZA)
                              SELECT @V_CDIMPOSTOFECP = CDIMPOSTO
                                FROM IMPOSTO
                               WHERE CDIMPOSTONFE = '01';
                              IF @V_CDIMPOSTOFECP IS NOT NULL BEGIN
                                 DELETE
                                   FROM ALIQTEMP
                                  WHERE NRALIQTEMP = @V_ALIQTEMP;
                                 --VERIFICANDO SE EXISTE A INCIDNCIA DE FECP PARA O PRODUTO
                                 IF @V_INCIDEN_IDUTMUNIORIG = 'D' BEGIN
                                    EXEC CONSULTA_ALIQUOTA @V_CDIMPOSTOFECP, 'S', @P_EMPRESA, @V_ITEMPROD_CDARVPROD, @P_INSCESTA, @V_PAISORIG,
                                                           @V_ESTAORIG, @V_PAISDEST, @V_ESTADEST, @V_MUNIDEST, @V_LIQUIITEM, @P_INIVALID, @P_FILIAL, @P_LANCTONF,
                                                           @V_CDGRUPOFISC, @P_TIPOOPER, NULL, NULL, NULL, NULL, NULL, NULL, @V_ITEMPROD_IDORIGEMPROD;
                                 END
                                 ELSE BEGIN
                                    EXEC CONSULTA_ALIQUOTA @V_CDIMPOSTOFECP, 'S', @P_EMPRESA, @V_ITEMPROD_CDARVPROD, @P_INSCESTA, @V_PAISORIG,
                                                           @V_ESTAORIG, @V_PAISDEST, @V_ESTADEST, @V_MUNIORIG, @V_LIQUIITEM, @P_INIVALID, @P_FILIAL, @P_LANCTONF,
                                                           @V_CDGRUPOFISC, @P_TIPOOPER, NULL, NULL, NULL, NULL, NULL, NULL, @V_ITEMPROD_IDORIGEMPROD;
                                 END;
                                 SELECT @V_ALIQFECPDEST = ISNULL(MAX(VRALIQUTMP), 0)
                                   FROM ALIQTEMP
                                  WHERE NRALIQTEMP = @V_ALIQTEMP;
                              END 
                              ELSE BEGIN
                                 SET @V_ALIQFECPDEST = 0;
                              END;
                              -- REALIZANDO O CLCULO DA BASE COM O IMPOSTO POR DENTRO
                              -- BASE DE CLCULO REAL = BASE DE CLCULO / (1 - ((ALIQUOTA DO IMPOSTO + ALIQUOTA DO FCP) / 100)
                              SET @V_BASECALCIT = @V_BASECALCIT/((100-(@V_ALIQICMSDEST+@V_ALIQFECPDEST))/100);
                           END;
                        END;
                     END;
                  END;
               END;

               SET @V_PERDBCALC  = 100 - @V_PREDBCTMP;

               IF @V_PBCSUBTRIB > 0 BEGIN
                  SET @V_BASECALCIT = (@V_BASECALCIT * @V_TAXABCSUBSTR);
                  SET @V_PREDBCTMP  = @V_PBCSUBTRIB;
                  SET @V_PERDBCALC  = 0;
               END;

               SET @V_BASEVLRMAX  = 0;
               SET @V_VRPEMAXVENDA = 0;
               SET @V_VRMAXVENDA  = 0;
               SET @V_CALCVLRMAX  = 0;

               /*VALOR MAXIMO DE VENDA AO COSUMIDOR*/

               IF @V_ORIGDESTOP = 'L' BEGIN      /* Destinatrio Filial */
                  SELECT @V_NRINSCSUFRAMA = MAX(NRINSCSUFRAMAFI)
                    FROM FILIAL
                   WHERE (CDFILIAL = @P_CLIENTE);
               END
               ELSE IF @V_ORIGDESTOP = 'F' BEGIN /* Destinatrio Fornecedor */
                  SELECT @V_NRINSCSUFRAMA = MAX(NRINSCSUFRAMAFO)
                    FROM FORNECEDOR
                   WHERE (CDFORNECED = @P_CLIENTE);
               END
               ELSE BEGIN                       /* Destinatrio Cliente */
                  SELECT @V_NRINSCSUFRAMA = MAX(NRINSCSUFRAMACL)
                    FROM CLIENTE
                   WHERE (CDCLIENTE = @P_CLIENTE);
               END;

               IF @V_NRINSCSUFRAMA IS NULL BEGIN /*Verifica se h Inscrio Suframa cadastrado p o destinatrio*/
                  SELECT @V_VRMAXVENDA     = ISNULL(MAX(VRMAXVENDA),0),
                         @V_VRPEMAXVENDA   = ISNULL(MAX(VRPEMAXVENDA),0),
                         @V_IDUTILVRMAX    = ISNULL(MAX(IDUTILVRMAX), 'C'),
                         @V_VRDESCMAXVENDA = ISNULL(MAX(VRDESCMAXVENDA),0)
                    FROM VRMAXVENPROD A
                   WHERE (CDPAIS   = @V_PAISDEST) AND
                         (SGESTADO = @V_ESTADEST) AND
                         (A.CDPRODUTO = @V_ITEMPROD_CDPRODUTO);
               END
               ELSE BEGIN
                  SELECT @V_VRMAXVENDA     = ISNULL(MAX(VRMAXVENDA),0),
                         @V_VRPEMAXVENDA   = ISNULL(MAX(VRPEMAXVENDA),0),
                         @V_IDUTILVRMAX    = ISNULL(MAX(IDUTILVRMAX), 'C'),
                         @V_VRDESCMAXVENDA = ISNULL(MAX(VRDESCMAXVENDA),0)
                    FROM VRMAXVENPROD A
                   WHERE (CDPAIS   = @V_PAISDEST) AND
                         (SGESTADO = 'SF'       ) AND
                         (A.CDPRODUTO = @V_ITEMPROD_CDPRODUTO);
               END;

               IF @V_VRMAXVENDA IS NOT NULL BEGIN
                  IF (@V_IDUTILVRMAX = 'C') BEGIN
                     SET @V_FINALVRMAXVENDA = (@V_VRMAXVENDA - ((@V_VRDESCMAXVENDA/100) * @V_VRMAXVENDA)) * (@V_VRPEMAXVENDA/100);
                  END
                  ELSE BEGIN
                     SET @V_FINALVRMAXVENDA = @V_VRMAXVENDA - ((@V_VRDESCMAXVENDA/100) * @V_VRMAXVENDA);
                  END;
                   SET @V_CALCVLRMAX   = @V_ITEMPROD_QTITEMPROD * @V_FINALVRMAXVENDA;
                   SET @V_CALCVLRMAX   = @V_CALCVLRMAX * @V_TAXABASECALC;
                   IF @V_PBCSUBTRIB > 0 BEGIN
                      SET @V_CALCVLRMAX = (@V_CALCVLRMAX * @V_TAXABCSUBSTR);
                      SET @V_PREDBCTMP  = @V_PBCSUBTRIB;
                      SET @V_PERDBCALC  = 0;
                   END;
                   SET @V_BASEVLRMAX = ROUND(@V_CALCVLRMAX, 2);

                   UPDATE ITEMPRODUTO
                      SET VRMAXVENDA = @V_VRMAXVENDA
                    WHERE CDFILIAL = @P_FILIAL
                      AND NRLANCTONF = @P_LANCTONF
                      AND NRSEQITPROD = @V_ITEMPRODUTO_NRSEQITPROD;
               END;

               IF @V_CDIMPOSTRIB IS NULL BEGIN
                  IF (@V_INCIDEN_IDUTVLRQTDEIMPO = 'S') BEGIN
                     SELECT @V_VRFATOCONVES = ISNULL(MAX(VRFATOCONVES), 1)
                       FROM CONVPRODUTO
                      WHERE CDPRODUTO = @V_ITEMPROD_CDPRODUTO;

                     SET @V_BASECALCTO  = (@V_ITEMPROD_QTITEMPROD * @V_VRFATOCONVES);
                     SET @V_IMPOSTOIT   = ((@V_ITEMPROD_QTITEMPROD * @V_VRFATOCONVES) * @V_ALIQUTMP) - @V_PARDEDTMP;
                  END
                  ELSE BEGIN
                     SET @V_BASECALCTO  = @V_BASECALCIT;
                     SET @V_IMPOSTOIT   = (@V_BASECALCIT * @V_TAXAALIQUOTA) - @V_PARDEDTMP;
                  END;
               END
               ELSE BEGIN
                  /* Se utilizar o PMC como comparativo  feito a comparao das bases de calculos j majoradas e/ou reduzidas.
                     O maior  a nova base de clculo.
                     Caso seja prioridade sempre ser o PMC j majorado e/ou reduzido.
                  */
                  IF ISNULL(@V_IDPMCBASECAL, 'S') = 'S' BEGIN
                     IF @V_IDUTILVRMAX = 'C' BEGIN
                        IF @V_BASECALCIT > @V_BASEVLRMAX BEGIN
                           SET @V_BASECALCTO  = @V_BASECALCIT;
                           SET @V_IMPOSTOIT   = (@V_BASECALCIT * @V_TAXAALIQUOTA) - @V_PARDEDTMP;
                        END
                        ELSE BEGIN
                           SET @V_BASECALCTO  = @V_BASEVLRMAX;
                           SET @V_IMPOSTOIT   = (@V_BASEVLRMAX * @V_TAXAALIQUOTA) - @V_PARDEDTMP;
                        END;
                     END
                     ELSE BEGIN
                        SET @V_BASECALCTO  = @V_BASEVLRMAX;
                        SET @V_IMPOSTOIT   = (@V_BASEVLRMAX * @V_TAXAALIQUOTA) - @V_PARDEDTMP;
                     END;
                  END
                  ELSE BEGIN
                     SET @V_BASECALCTO  = @V_BASECALCIT;
                     SET @V_IMPOSTOIT   = (@V_BASECALCIT * @V_TAXAALIQUOTA) - @V_PARDEDTMP;
                  END;
               END;

               IF @V_CDIMPOSTRIB IS NULL BEGIN
                  SET @V_IDTRIMPSTII = NULL;
               END
               ELSE BEGIN
                  IF SUBSTRING(@V_SITUTRIBPR, 2, 2) = '60' BEGIN
                     SET @V_IDTRIMPSTII = '2';
                  END ELSE BEGIN
                     SET @V_IDTRIMPSTII = @V_TRATIMPST;
                  END;
               END;

               SET @V_CONTABCALC = @V_LIQUIITEM - (@V_LIQUIITEM * @V_TAXABASECALC);

               IF (@V_IMPOSTOIT < 0) BEGIN
                  SET @V_IMPOSTOIT = 0;
               END;

               SET @V_VRADICFECPST = 0;
               SET @V_VRADICFECPSTAUX = 0;
               IF (@V_VRADICALIQFECP IS NOT NULL) AND (@V_VRADICALIQFECP > 0) BEGIN
                  SET @V_VRADICFECP = ROUND(@V_BASECALCTO*(@V_VRADICALIQFECP/100), 2);
               END;

               IF @V_CDIMPOSTRIB IS NOT NULL BEGIN
                  SET @V_VRIMPOSST   = 0;
                  SET @V_VRIMPOSTOST = 0;

                  DECLARE C_SUBSTRIB CURSOR FOR
                     SELECT ISNULL(IDVRIMPSTRIB, 'N') IDVRIMPSTRIB, I.CDIMPOSTO
                       FROM ITEMPROIMPOS I, IMPOSTO II
                      WHERE (CDFILIAL     = @P_FILIAL)
                        AND (NRLANCTONF   = @P_LANCTONF)
                        AND (NRSEQITPROD  = @V_ITEMPROD_NRSEQITPROD)
                        AND (NRITPROIMPOS = '1')
                        AND (CHARINDEX(II.CDIMPOSTO+'_', @V_CDIMPOSTRIB) > 0)
                        AND (I.CDIMPOSTO = II.CDIMPOSTO);

                  OPEN C_SUBSTRIB;
                  FETCH NEXT FROM C_SUBSTRIB INTO @V_SUBSTRIB_IDVRIMPSTRIB, @V_SUBSTRIB_CDIMPOSTO;
                  WHILE (@@FETCH_STATUS = 0) BEGIN

                     IF (@V_SUBSTRIB_IDVRIMPSTRIB = 'S') BEGIN
                           SELECT @V_VRIMPOSST = ISNULL(ROUND(MAX(VRIMPOSTOIT), 2),0),
                                  @V_VRADICFECPSTAUX = ISNULL(ROUND(MAX(VRADICFECP), 2),0)
                           FROM ITEMPROIMPOS I
                           WHERE (CDFILIAL     = @P_FILIAL)                     AND
                                 (NRLANCTONF   = @P_LANCTONF)                   AND
                                 (NRSEQITPROD  = @V_ITEMPROD_NRSEQITPROD)     AND
                                 (CDIMPOSTO    = @V_SUBSTRIB_CDIMPOSTO)         AND
                                 (CHARINDEX(CDIMPOSTO+'_', @V_CDIMPOSTRIB) > 0) AND
                                 (NRITPROIMPOS = '1');
                     END
                     ELSE BEGIN
                        SET @V_VRIMPOSST = 0;
                        SET @V_VRADICFECPSTAUX = 0;
                     END;
                     SET @V_VRIMPOSTOST = @V_VRIMPOSTOST + @V_VRIMPOSST;
                     SET @V_VRADICFECPST = @V_VRADICFECPST + @V_VRADICFECPSTAUX;

                     FETCH NEXT FROM C_SUBSTRIB INTO @V_SUBSTRIB_IDVRIMPSTRIB, @V_SUBSTRIB_CDIMPOSTO;
                  END;
                  CLOSE C_SUBSTRIB;
                  DEALLOCATE C_SUBSTRIB;
               END;

               IF (@V_VRADICALIQFECP IS NOT NULL) AND (@V_VRADICALIQFECP > 0) BEGIN
                  SET @V_VRADICFECP = @V_VRADICFECP - @V_VRADICFECPST;
               END;

               /* ROTINA PARA CALCULAR O DIFERIMENTO DO IMPOSTO */
               SET @V_PERDIFERE    = NULL;
               SET @V_IMPOSTOOPERA = NULL;
               SET @V_IMPOSTODIFER = NULL;

               IF @V_INCIDEN_CDIMPOSTONFE = '00' BEGIN
                  IF @V_CDSITTRIBTMP = 51 BEGIN
                     SET @V_VRPERDIFERE = NULL;
                     SET @V_IDDIFECLI = 'N';

                     SELECT @V_VRPERDIFERE = PD.VRPERDIFERE, @V_IDDIFECLI = 'S'
                       FROM PRODDIFEREIMPCLI PD, PRODUTO PR
                      WHERE PD.CDPRODUTO = PR.CDPRODUTO
                        AND PD.CDPAIS = @V_PAISORIG
                        AND PD.SGESTADO = @V_ESTAORIG
                        AND PD.CDCLIENTE = @P_CLIENTE
                        AND PR.CDARVPROD IN (SELECT MAX(PR.CDARVPROD) AS CDARVPROD
                                               FROM PRODDIFEREIMPCLI PD, PRODUTO PR
                                              WHERE PD.CDPRODUTO = PR.CDPRODUTO
                                                AND PD.CDPAIS = @V_PAISORIG
                                                AND PD.SGESTADO = @V_ESTAORIG
                                                AND PD.CDCLIENTE = @P_CLIENTE
                                                AND CHARINDEX(PR.CDARVPROD, ISNULL(RTRIM(@V_ITEMPROD_CDARVPROD), PR.CDARVPROD)) = 1);

                     IF @V_IDDIFECLI = 'N' BEGIN
                        SELECT @V_VRPERDIFERE = PD.VRPERDIFERE
                          FROM PRODDIFEREIMPOS PD, PRODUTO PR
                         WHERE PD.CDPRODUTO = PR.CDPRODUTO
                           AND PD.CDPAIS = @V_PAISORIG
                           AND PD.SGESTADO = @V_ESTAORIG
                           AND PR.CDARVPROD IN (SELECT MAX(PR.CDARVPROD) AS CDARVPROD
                                                  FROM PRODDIFEREIMPOS PD, PRODUTO PR
                                                 WHERE PD.CDPRODUTO = PR.CDPRODUTO
                                                   AND PD.CDPAIS = @V_PAISORIG
                                                   AND PD.SGESTADO = @V_ESTAORIG
                                                   AND CHARINDEX(PR.CDARVPROD, ISNULL(RTRIM(@V_ITEMPROD_CDARVPROD), PR.CDARVPROD)) = 1);
                     END;

                     IF @V_VRPERDIFERE IS NOT NULL BEGIN
                        SET @V_PERDIFERE = ROUND(@V_VRPERDIFERE, 2);
                        SET @V_IMPOSTOOPERA = ROUND(@V_IMPOSTOIT, 2);
                        SET @V_IMPOSTODIFER = ROUND((@V_IMPOSTOOPERA * (@V_VRPERDIFERE/100)), 2);
                        SET @V_IMPOSTOIT = ROUND(@V_IMPOSTOOPERA, 2) - ROUND(@V_IMPOSTODIFER, 2);
                     END;
                  END;
               END;

               SET @V_BASECALCIRRF = @V_BASECALCTO;

               IF (@V_ALIQUTMP = 0) AND (@V_IMPOSTOIT = 0) BEGIN
                  SET @V_BASECALCTO = 0;
               END;
               IF (@V_ALIQUTMP IS NULL) BEGIN
                  SET @V_ALIQUTMP = 0;
               END;

               SELECT @V_IDPERVISIMPSCRE = ISNULL(MAX(IDPERVISIMPSCRE), 'S')
                 FROM PARAMGERAL;

               IF @V_IDPERVISIMPSCRE = 'S' BEGIN
                  SET @V_VRIMPOSTOVISUIT = @V_IMPOSTOIT;
               END
               ELSE BEGIN
                  IF (@V_INCIDEN_CDFISCTEMP = '1') BEGIN
                     SET @V_VRIMPOSTOVISUIT = @V_IMPOSTOIT;
                  END
                  ELSE BEGIN
                     SET @V_VRIMPOSTOVISUIT = 0;
                  END;
               END;

               SET @V_ICMS = NULL;
               DECLARE C_ICMS CURSOR FOR
                  SELECT CDIMPOSTO
                    FROM IMPOSTONFE N, IMPOSTO I
                   WHERE N.CDIMPOSTONFE = I.CDIMPOSTONFE
                     AND N.CDIMPOSTONFE = '00'
                     AND I.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
               OPEN C_ICMS;
               FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
               WHILE (@@FETCH_STATUS = 0) BEGIN
                  SET @V_ICMS = 'S';
                  FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
               END;
               CLOSE C_ICMS;
               DEALLOCATE C_ICMS;

               SELECT @V_CHAVE = CDFILIAL
                 FROM ITEMPROIMPOS
                WHERE CDFILIAL     = @P_FILIAL
                  AND NRLANCTONF   = @P_LANCTONF
                  AND NRSEQITPROD  = @V_ITEMPROD_NRSEQITPROD
                  AND CDIMPOSTO    = @V_INCIDEN_CDIMPOTEMP
                  AND NRITPROIMPOS = '1';

               IF @V_CHAVE IS NULL BEGIN

                  IF (@V_ICMS = 'S') BEGIN

                     IF (@V_ITEMPROD_CDCFOPINFUSU IS NULL) BEGIN
                        SET @V_CDGRUPOFISCAUX = NULL;

                        SELECT @V_CDGRUPOFISCAUX = MAX(G.CDGRUPOFISC)
                          FROM GRUPOFISCIMPFIL G,
                               (SELECT CDFILIEMIT AS CDFILIAL
                                  FROM NOTAFISCAL
                                 WHERE CDFILIAL = @P_FILIAL
                                   AND NRLANCTONF = @P_LANCTONF) F
                         WHERE G.CDFILIAL = F.CDFILIAL
                           AND NOT G.CDGRUPOFISC IS NULL
                           AND G.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;

                        IF @V_IDORIGDESTNF = 'C' BEGIN
                           SELECT @V_CDGRUPOFISCAUX = ISNULL(MAX(G.CDGRUPOFISC), @V_CDGRUPOFISCAUX)
                             FROM GRFISIMPIECLIE G,
                                  (SELECT CDCLIENTE
                                     FROM NOTAFISCAL
                                    WHERE CDFILIAL = @P_FILIAL
                                      AND NRLANCTONF = @P_LANCTONF) N
                            WHERE G.CDCLIENTE = N.CDCLIENTE
                              AND G.CDEMPRESA = @P_EMPRESA
                              AND G.CDINSCESTA = @P_INSCESTA
                              AND NOT G.CDGRUPOFISC IS NULL
                              AND G.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
                        END
                        ELSE BEGIN
                           SELECT @V_CDGRUPOFISCAUX = ISNULL(MAX(G.CDGRUPOFISC), @V_CDGRUPOFISCAUX)
                             FROM GRFISIMPIEFORN G,
                                 (SELECT CDFORNECED
                                    FROM NOTAFISCAL
                                   WHERE CDFILIAL = @P_FILIAL
                                     AND NRLANCTONF = @P_LANCTONF) N
                            WHERE G.CDFORNECED = N.CDFORNECED
                              AND G.CDEMPRESA = @P_EMPRESA
                              AND G.CDINSCESTA = @P_INSCESTA
                              AND NOT G.CDGRUPOFISC IS NULL
                              AND G.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
                        END;

                        IF (@V_CDGRUPOFISCAUX IS NOT NULL) BEGIN
                           EXEC CONSULTA_CFOP 'S', @P_EMPRESA, @V_ITEMPROD_CDARVPROD, @P_INSCESTA, @P_TIPOOPER, @V_PAISORIG,
                            @V_ESTAORIG, @V_PAISCFOP, @V_ESTACFOP, @P_FILIAL, @P_LANCTONF, @V_CDGRUPOFISCAUX, @P_INIVALID, @V_ITEMPROD_IDORIGEMPROD;
                        END
                        ELSE BEGIN
                           EXEC CONSULTA_CFOP 'S', @P_EMPRESA, @V_ITEMPROD_CDARVPROD, @P_INSCESTA, @P_TIPOOPER, @V_PAISORIG,
                            @V_ESTAORIG, @V_PAISCFOP, @V_ESTACFOP, @P_FILIAL, @P_LANCTONF, @V_CDGRUPOFISC, @P_INIVALID, @V_ITEMPROD_IDORIGEMPROD;
                        END;

                        UPDATE NOTAFISCAL
                           SET DSCDFISOPENF = (SELECT MAX(DSCFOPTMP) FROM CFOPTEMP
                                               WHERE NRCFOPTEMP = @V_CFOPTEMP)
                         WHERE CDFILIAL   = @P_FILIAL AND
                               NRLANCTONF = @P_LANCTONF;

                        SELECT @V_FISOPEITEM = MAX(CDFISOPETMP),
                               @V_SUFXCFOPPR = MAX(CDSUFCFOPTMP),
                               @V_DSCDFISOPEIT = MAX(DSCFOPTMP)
                          FROM CFOPTEMP
                         WHERE NRCFOPTEMP = @V_CFOPTEMP;

                        UPDATE ITEMPRODUTO
                           SET CDFISOPEITEM = @V_FISOPEITEM,
                               CDSUFXCFOPPR = @V_SUFXCFOPPR,
                               DSCDFISOPEIT = @V_DSCDFISOPEIT

                         WHERE CDFILIAL    = @P_FILIAL   AND
                               NRLANCTONF  = @P_LANCTONF AND
                               NRSEQITPROD = @V_ITEMPROD_NRSEQITPROD;

                        DELETE FROM CFOPTEMP
                         WHERE NRCFOPTEMP = @V_CFOPTEMP;


                     END;
                     SET @V_CST1DIGT = NULL;

                     SELECT @V_CST1DIGT = MAX(CDCSTDIG1PROD)
                       FROM PRODUTO
                      WHERE (CDARVPROD = @V_ITEMPROD_CDARVPROD);

                     IF @V_CST1DIGT IS NULL BEGIN
                        SELECT @V_CST1DIGT = MAX(CDCSTDIG1SAI)
                        FROM INSCRESTAD
                        WHERE (CDEMPRESA  = @P_EMPRESA) AND
                              (CDINSCESTA = @P_INSCESTA);
                     END;

                     UPDATE ITEMPRODUTO
                        SET CDSITUTRIBPR  = @V_CST1DIGT+ISNULL(@V_CDSITTRIBTMP, SUBSTRING(@V_SITUTRIBPR, 2,2))
                      WHERE CDFILIAL    = @P_FILIAL AND
                            NRLANCTONF  = @P_LANCTONF AND
                            NRSEQITPROD = @V_ITEMPROD_NRSEQITPROD;

                     SET @V_SITUTRIBPR = @V_CST1DIGT+ISNULL(@V_CDSITTRIBTMP, SUBSTRING(@V_SITUTRIBPR, 2,2));
                  END;
               END;

               /*IF (@V_VRADICALIQFECP IS NOT NULL) AND (@V_VRADICALIQFECP > 0) BEGIN
                  SET @V_VRADICFECP = ROUND(@V_BASECALCTO*(@V_VRADICALIQFECP/100), 2);
               END;*/

               INSERT INTO ITEMPROIMPOS(
                   CDFILIAL, NRLANCTONF, NRSEQITPROD, CDIMPOSTO, NRITPROIMPOS,  VRALIQITEM,
                   VRPERREDBCIT, VRPARDEDIT, VRCONTITIMP, VRBASECALCIT, VRIMPOSTOIT, CDFISCALIT,
                   CDSITUTRIBIT, CDFISCOPERIT, CDSUFXCFOPIT, IDERROSIMPIT, IDAVISIMPIT, IDTRIMPSTII,
                   CDSITUTRIBITNFE, IDMODBCITNFE, IDMODBCSTITNFE, CDTPCREDPICOITE, CDNATUBCALPCIT, IDMOTDESONERAIT,
                   CDSIMPLESNACIONAL, CDFAIXA, VRBCICMSSTRETIDO, VRICMSSTRETIDO, CDREGRAIT, CDDETALHEPROD,
                   VRIMPOSTOVISUIT, VRBCALCIRRF, VRPERDIFEREIT, VRIMPOSTOOPERAIT, VRIMPOSTODIFERIT, CDENQLEGALIPI,
                   CDCEST, VRADICALIQFECP, VRADICFECP, VRALIQINTEDEST, VRALIQFCP)
                VALUES(
                   @P_FILIAL, @P_LANCTONF, @V_ITEMPROD_NRSEQITPROD, @V_INCIDEN_CDIMPOTEMP,  '1', @V_ALIQUTMP,
                   @V_PREDBCTMP, @V_PARDEDTMP,@V_BASECALCTO, @V_BASECALCTO, @V_IMPOSTOIT, @V_INCIDEN_CDFISCTEMP,
                   @V_SITUTRIBPR, @V_FISOPEITEM, @V_SUFXCFOPPR, '00000', '00000', @V_IDTRIMPSTII,
                   @V_CDSITTRIBTMP, @V_IDMODBCNFE, @V_IDMODBCSTNFE, @V_CDTPCRPICOSTNFE, @V_CDNATUBCPCSTNFE, @V_IDMOTIDESSTNFE,
                   @V_CDSIMPLESNACIONAL, @V_CDFAIXA, ROUND(@V_BCICMSSTRETIDO,2), ROUND(@V_VRICMSSTRETIDO,2), @V_CDREGRAITALIQ, @V_INCIDEN_CDDETALHEPROD,
                   @V_VRIMPOSTOVISUIT, @V_BASECALCIRRF, @V_PERDIFERE, @V_IMPOSTOOPERA, @V_IMPOSTODIFER, @V_INCIDEN_CDENQLEGALIPI,
                   @V_INCIDEN_CDCEST, @V_VRADICALIQFECP, @V_VRADICFECP, @V_ALIQICMSDEST, @V_ALIQFECPDEST);

               IF (@V_PREDBCTMP > 0) AND (@V_PBCSUBTRIB = 0) BEGIN
                  IF @V_SITUTRIBPR = '060' BEGIN
                     INSERT INTO ITEMPROIMPOS(
                        CDFILIAL, NRLANCTONF, NRSEQITPROD, CDIMPOSTO, NRITPROIMPOS, CDFISCALIT,
                        CDSITUTRIBIT, CDFISCOPERIT, CDSUFXCFOPIT, VRALIQITEM, VRPERREDBCIT, VRPARDEDIT,
                        VRCONTITIMP, VRBASECALCIT, VRIMPOSTOIT, IDERROSIMPIT, IDAVISIMPIT, CDSITUTRIBITNFE,
                        IDMODBCITNFE, IDMODBCSTITNFE, CDTPCREDPICOITE, CDNATUBCALPCIT, IDMOTDESONERAIT,
                        CDSIMPLESNACIONAL, CDFAIXA, VRBCICMSSTRETIDO, VRICMSSTRETIDO, CDREGRAIT, CDDETALHEPROD,
                        VRIMPOSTOVISUIT, CDENQLEGALIPI, CDCEST)
                     VALUES(
                        @P_FILIAL, @P_LANCTONF, @V_ITEMPROD_NRSEQITPROD, @V_INCIDEN_CDIMPOTEMP, '2', '2',
                        @V_SITUTRIBPR, @V_FISOPEITEM, @V_SUFXCFOPPR, 0, @V_PERDBCALC, @V_PARDEDTMP,
                        ROUND(@V_CONTABCALC,2,2), 0, 0, '00000', '00000', @V_CDSITTRIBTMP,
                        @V_IDMODBCNFE, @V_IDMODBCSTNFE, @V_CDTPCRPICOSTNFE, @V_CDNATUBCPCSTNFE, @V_IDMOTIDESSTNFE,
                        @V_CDSIMPLESNACIONAL, @V_CDFAIXA, ROUND(@V_BCICMSSTRETIDO,2,2), ROUND(@V_VRICMSSTRETIDO,2,2), @V_CDREGRAITALIQ, @V_INCIDEN_CDDETALHEPROD,
                        0, @V_INCIDEN_CDENQLEGALIPI, @V_INCIDEN_CDCEST);
                  END
                  ELSE BEGIN
                     INSERT INTO ITEMPROIMPOS(
                        CDFILIAL, NRLANCTONF, NRSEQITPROD, CDIMPOSTO, NRITPROIMPOS, CDFISCALIT,
                        CDSITUTRIBIT, CDFISCOPERIT, CDSUFXCFOPIT, VRALIQITEM, VRPERREDBCIT, VRPARDEDIT,
                        VRCONTITIMP, VRBASECALCIT, VRIMPOSTOIT, IDERROSIMPIT, IDAVISIMPIT, IDTRIMPSTII,
                        CDSITUTRIBITNFE, IDMODBCITNFE, IDMODBCSTITNFE, CDTPCREDPICOITE, CDNATUBCALPCIT, IDMOTDESONERAIT,
                        CDSIMPLESNACIONAL, CDFAIXA, VRBCICMSSTRETIDO, VRICMSSTRETIDO, CDREGRAIT, CDDETALHEPROD,
                        VRIMPOSTOVISUIT, CDENQLEGALIPI, CDCEST)
                     VALUES(
                        @P_FILIAL, @P_LANCTONF, @V_ITEMPROD_NRSEQITPROD, @V_INCIDEN_CDIMPOTEMP, '2', '2',
                        @V_SITUTRIBPR, @V_FISOPEITEM, @V_SUFXCFOPPR, 0, @V_PERDBCALC, @V_PARDEDTMP,
                        ROUND(@V_CONTABCALC,2), 0, 0, '00000', '00000', @V_IDTRIMPSTII,
                        @V_CDSITTRIBTMP, @V_IDMODBCNFE, @V_IDMODBCSTNFE, @V_CDTPCRPICOSTNFE, @V_CDNATUBCPCSTNFE, @V_IDMOTIDESSTNFE,
                        @V_CDSIMPLESNACIONAL, @V_CDFAIXA, ROUND(@V_BCICMSSTRETIDO,2), ROUND(@V_VRICMSSTRETIDO,2), @V_CDREGRAITALIQ, @V_INCIDEN_CDDETALHEPROD,
                        0, @V_INCIDEN_CDENQLEGALIPI, @V_INCIDEN_CDCEST);
                  END;
               END;

               DECLARE C_ALIQTEMP CURSOR FOR
                  SELECT DSMENSALITMP
                  FROM ALIQTEMP
                  WHERE (NRALIQTEMP = @V_ALIQTEMP) AND
                        (NOT (DSMENSALITMP IS NULL)) AND
                        (NOT EXISTS (SELECT DSDADOADIC
                                       FROM DADOSADIC
                                      WHERE (CDFILIAL = @P_FILIAL)     AND
                                            (NRLANCTONF = @P_LANCTONF) AND
                                            (DSDADOADIC LIKE ALIQTEMP.DSMENSALITMP + '%')));
               OPEN C_ALIQTEMP;
               FETCH NEXT FROM C_ALIQTEMP INTO @V_ALIQTMP_DSMENSALITMP;
               WHILE (@@FETCH_STATUS = 0) BEGIN
                  IF NOT(@V_ALIQTMP_DSMENSALITMP IS NULL) BEGIN
                     INSERT INTO DADOSADIC(CDFILIAL, NRLANCTONF, NRDADOADIC, DSDADOADIC)
                                 VALUES(@P_FILIAL, @P_LANCTONF, @V_DADOADIC, @V_ALIQTMP_DSMENSALITMP);
                     SET @V_DADOADIC = RIGHT(REPLICATE('0',3) + RTRIM(CONVERT(VARCHAR, CONVERT(NUMERIC, @V_DADOADIC) + 1)),3);
                  END;
                  FETCH NEXT FROM C_ALIQTEMP INTO @V_ALIQTMP_DSMENSALITMP;
               END;
               CLOSE C_ALIQTEMP;
               DEALLOCATE C_ALIQTEMP;

               DELETE FROM ALIQTEMP
                WHERE NRALIQTEMP = @V_ALIQTEMP;

               SET @V_VRADICALIQFECP = NULL;
               SET @V_VRADICFECP = NULL;

               FETCH NEXT FROM C_INCIDENCIA INTO @V_INCIDEN_CDIMPOTEMP  ,    @V_INCIDEN_CDFISCTEMP,
                                                 @V_INCIDEN_IDTRATIMPTMP,    @V_INCIDEN_IDCONSISTENT,
                                                 @V_INCIDEN_IDIMPORECUP,     @V_INCIDEN_IDUTMUNIORIG,
                                                 @V_INCIDEN_IDUTVLRQTDEIMPO, @V_INCIDEN_CDDETALHEPROD,
                                                 @V_INCIDEN_CDREGRATMP,      @V_INCIDEN_CDIMPOSTONFE,
                                                 @V_INCIDEN_CDENQLEGALIPI,   @V_INCIDEN_CDCEST,
                                                 @V_INCIDEN_VRADICALIQFECP;
            END;
            CLOSE C_INCIDENCIA;
            DEALLOCATE C_INCIDENCIA;

            DELETE FROM INCITEMP
            WHERE NRINCITEMP = @V_INCITEMP;
         END
         ELSE BEGIN
            DECLARE C_IMPOSINFUSU CURSOR FOR
               SELECT II.CDIMPOSTO, II.CDFISCINFUSU,
                      II.VRALIQINFUSU, II.VRRDBCINFUSU, II.VRPDEDINFUSU,
                      I.IDTRATIMPO, I.IDCONSISTENT, I.IDIMPORECUP
               FROM IMPOSINFUSU II, IMPOSTO I
               WHERE (II.CDFILIAL    = @P_FILIAL)               AND
                     (II.NRLANCTONF  = @P_LANCTONF)             AND
                     (II.NRSEQITPROD = @V_ITEMPROD_NRSEQITPROD) AND
                     (II.CDIMPOSTO   = I.CDIMPOSTO);
            OPEN C_IMPOSINFUSU;
            FETCH NEXT FROM C_IMPOSINFUSU INTO @V_IMPOSINFUSU_CDIMPOSTO,    @V_IMPOSINFUSU_CDFISCINFUSU,
                                               @V_IMPOSINFUSU_VRALIQINFUSU, @V_IMPOSINFUSU_VRRDBCINFUSU, @V_IMPOSINFUSU_VRPDEDINFUSU,
                                               @V_IMPOSINFUSU_IDTRATIMPO,   @V_IMPOSINFUSU_IDCONSISTENT, @V_IMPOSINFUSU_IDIMPORECUP;
            WHILE (@@FETCH_STATUS = 0) BEGIN
               SET @V_TAXABASECALC = ((100 - @V_IMPOSINFUSU_VRRDBCINFUSU)/100);
               SET @V_TAXAALIQUOTA = (@V_IMPOSINFUSU_VRALIQINFUSU/100);

               SET @V_IMPOSTOIT  = ((@V_LIQUIITEM * @V_TAXABASECALC) * @V_TAXAALIQUOTA) - @V_IMPOSINFUSU_VRPDEDINFUSU;
               SET @V_CONTABCALC = @V_LIQUIITEM - (@V_LIQUIITEM * @V_TAXABASECALC);
               SET @V_PERDBCALC  = 100 - @V_IMPOSINFUSU_VRRDBCINFUSU;

               IF (@V_IMPOSTOIT < 0) BEGIN
                  SET @V_IMPOSTOIT = 0;
               END;

               IF (@V_IMPOSINFUSU_VRALIQINFUSU = 0) AND (@V_IMPOSTOIT = 0) BEGIN
                  SET @V_BASECALCIT = 0;
               END
               ELSE BEGIN
                  SET @V_BASECALCIT = (@V_LIQUIITEM * @V_TAXABASECALC);
               END;

               SELECT @V_IDPERVISIMPSCRE = ISNULL(MAX(IDPERVISIMPSCRE),'S')
                 FROM PARAMGERAL;
               IF @V_IDPERVISIMPSCRE = 'S' BEGIN
                  SET @V_VRIMPOSTOVISUIT = @V_IMPOSTOIT;
               END
               ELSE BEGIN
                  IF (@V_IMPOSINFUSU_CDFISCINFUSU = '1') BEGIN
                     SET @V_VRIMPOSTOVISUIT = @V_IMPOSTOIT;
                  END
                  ELSE BEGIN
                     SET @V_VRIMPOSTOVISUIT = 0;
                  END;
               END;

               INSERT INTO ITEMPROIMPOS(
                  CDFILIAL, NRLANCTONF, NRSEQITPROD, CDIMPOSTO, NRITPROIMPOS, CDFISCALIT,
                  CDSITUTRIBIT, CDFISCOPERIT, CDSUFXCFOPIT, VRALIQITEM, VRPERREDBCIT, VRPARDEDIT,
                  VRCONTITIMP, VRBASECALCIT, VRIMPOSTOIT, IDERROSIMPIT, IDAVISIMPIT, VRIMPOSTOVISUIT)
               VALUES(
                  @P_FILIAL, @P_LANCTONF, @V_ITEMPROD_NRSEQITPROD, @V_IMPOSINFUSU_CDIMPOSTO, '1', @V_IMPOSINFUSU_CDFISCINFUSU,
                  @V_SITUTRIBPR, @V_FISOPEITEM, @V_SUFXCFOPPR, @V_IMPOSINFUSU_VRALIQINFUSU, @V_IMPOSINFUSU_VRRDBCINFUSU, @V_IMPOSINFUSU_VRPDEDINFUSU,
                  @V_BASECALCIT, @V_BASECALCIT, @V_IMPOSTOIT, '00000', '00000', @V_VRIMPOSTOVISUIT);

               IF @V_PREDBCTMP > 0 BEGIN
                  INSERT INTO ITEMPROIMPOS(
                     CDFILIAL, NRLANCTONF, NRSEQITPROD, CDIMPOSTO, NRITPROIMPOS, CDFISCALIT,
                     CDSITUTRIBIT, CDFISCOPERIT, CDSUFXCFOPIT, VRALIQITEM, VRPERREDBCIT, VRPARDEDIT,
                     VRCONTITIMP, VRBASECALCIT, VRIMPOSTOIT, IDERROSIMPIT, IDAVISIMPIT, VRIMPOSTOVISUIT)
                  VALUES(
                     @P_FILIAL, @P_LANCTONF, @V_ITEMPROD_NRSEQITPROD, @V_IMPOSINFUSU_CDIMPOSTO, '2', '2',
                     @V_SITUTRIBPR, @V_FISOPEITEM, @V_SUFXCFOPPR, 0, @V_PERDBCALC, @V_IMPOSINFUSU_VRPDEDINFUSU,
                     ROUND(@V_CONTABCALC,2), 0, 0, '00000', '00000', 0);
               END;
               FETCH NEXT FROM C_IMPOSINFUSU INTO @V_IMPOSINFUSU_CDIMPOSTO,    @V_IMPOSINFUSU_CDFISCINFUSU,
                                                  @V_IMPOSINFUSU_VRALIQINFUSU, @V_IMPOSINFUSU_VRRDBCINFUSU, @V_IMPOSINFUSU_VRPDEDINFUSU,
                                                  @V_IMPOSINFUSU_IDTRATIMPO,   @V_IMPOSINFUSU_IDCONSISTENT, @V_IMPOSINFUSU_IDIMPORECUP;
            END;
            CLOSE C_IMPOSINFUSU;
            DEALLOCATE C_IMPOSINFUSU;
         END;

         FETCH NEXT FROM C_ITEMPRODUTO INTO @V_ITEMPROD_VRTOTAITEM,   @V_ITEMPROD_VRDESCITEM,
                                            @V_ITEMPROD_CDPRODUTO,    @V_ITEMPROD_NRSEQITPROD,
                                            @V_ITEMPROD_CDCSTINFUSU,  @V_ITEMPROD_CDCFOPINFUSU,
                                            @V_ITEMPROD_CDSUFXINFUSU, @V_ITEMPROD_CDARVPROD,
                                            @V_ITEMPROD_QTITEMPROD,   @V_ITEMPROD_IDORIGEMPROD;
      END;
      CLOSE C_ITEMPRODUTO;
      DEALLOCATE C_ITEMPRODUTO;

      IF (@V_CDSITUCRT <> '3') BEGIN
         SELECT @V_EXISTDSDADOSADIC = COUNT(*)
           FROM ITEMPRODUTO
         WHERE CDFILIAL   = @P_FILIAL
           AND NRLANCTONF = @P_LANCTONF
           AND (CDFISCOPERSN IN ('101', '201') OR  SUBSTRING(CDFISCOPERSN, 2, 3) IN ('101', '201'));
         IF @V_EXISTDSDADOSADIC > 0 BEGIN
            SET @V_CDIMPOSICMS  = null;
            DECLARE C_ICMS CURSOR FOR
                     SELECT CDIMPOSTO
                       FROM IMPOSTO
                      WHERE CDIMPOSTONFE = '00';
            OPEN C_ICMS;
            FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
            WHILE(@@FETCH_STATUS = 0) BEGIN
               SET @V_CDIMPOSICMS = ISNULL(@V_CDIMPOSICMS, '')+@V_IMPOSTOTMP+'_';
               FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
            END;
            CLOSE C_ICMS;
            DEALLOCATE C_ICMS;

            IF @V_CDIMPOSICMS IS NOT NULL BEGIN
               SELECT @V_APROVICMS = SUM(VRIMPOSTOIT), @V_ALIQAPROVICMS = MAX(VRALIQITEM)
                 FROM ITEMPROIMPOS I
                WHERE I.CDFILIAL   = @P_FILIAL
                  AND I.NRLANCTONF   = @P_LANCTONF
                  AND I.NRITPROIMPOS = '1'
                  AND (CHARINDEX(I.CDIMPOSTO+'_', @V_CDIMPOSICMS) > 0)
                  AND I.NRSEQITPROD IN (SELECT NRSEQITPROD
                                          FROM ITEMPRODUTO IP
                                         WHERE IP.CDFILIAL = @P_FILIAL
                                           AND IP.NRLANCTONF = @P_LANCTONF
                                           AND (IP.CDFISCOPERSN IN ('101', '201') OR SUBSTRING(IP.CDFISCOPERSN,2, 3) IN ('101', '201')));

               SELECT @V_EXISTDSDADOSADIC = COUNT(*)
                 FROM DADOSADIC
                WHERE CDFILIAL = @P_FILIAL
                  AND NRLANCTONF = @P_LANCTONF
                  AND DSDADOADIC LIKE 'Permite o aproveitamento do credito do ICMS no valor de R$ %';

               IF @V_EXISTDSDADOSADIC = 0 BEGIN
                  INSERT INTO DADOSADIC(CDFILIAL, NRLANCTONF, NRDADOADIC, DSDADOADIC)
                                 VALUES(@P_FILIAL, @P_LANCTONF, @V_DADOADIC, 'Permite o aproveitamento do credito do ICMS no valor de R$ '+
                                                                              CASE SUBSTRING(LTRIM(CONVERT(DECIMAL(20,2), @V_APROVICMS)),1,1) WHEN '.' THEN '0' + LTRIM(CONVERT(DECIMAL(20,2), @V_APROVICMS)) ELSE LTRIM(CONVERT(DECIMAL(20,2), @V_APROVICMS)) END +
                                                                              ' corresp. a alquota de '+ CASE SUBSTRING(LTRIM(CONVERT(DECIMAL(20,2), @V_ALIQAPROVICMS)),1,1) WHEN '.' THEN '0' + LTRIM(CONVERT(DECIMAL(20,2), @V_ALIQAPROVICMS)) ELSE LTRIM(CONVERT(DECIMAL(20,2), @V_ALIQAPROVICMS)) END
                                                                              + '% conf. Art.23 da LC 123/06.');

                  SET @V_DADOADIC = RIGHT(REPLICATE('0',3) + RTRIM(CONVERT(VARCHAR, CONVERT(NUMERIC, @V_DADOADIC) + 1)),3);
               END
               ELSE BEGIN
                  UPDATE DADOSADIC
                     SET DSDADOADIC = 'Permite o aproveitamento do credito do ICMS no valor de R$ '+
                                                                              CASE SUBSTRING(LTRIM(CONVERT(DECIMAL(20,2), @V_APROVICMS)),1,1) WHEN '.' THEN '0' + LTRIM(CONVERT(DECIMAL(20,2), @V_APROVICMS)) ELSE LTRIM(CONVERT(DECIMAL(20,2), @V_APROVICMS)) END +
                                                                              ' corresp. a alquota de '+ CASE SUBSTRING(LTRIM(CONVERT(DECIMAL(20,2), @V_ALIQAPROVICMS)),1,1) WHEN '.' THEN '0' + LTRIM(CONVERT(DECIMAL(20,2), @V_ALIQAPROVICMS)) ELSE LTRIM(CONVERT(DECIMAL(20,2), @V_ALIQAPROVICMS)) END
                                                                              + '% conf. Art.23 da LC 123/06.'
                    WHERE CDFILIAL = @P_FILIAL
                      AND NRLANCTONF = @P_LANCTONF
                      AND DSDADOADIC LIKE 'Permite o aproveitamento do credito do ICMS no valor de R$ %';
               END;
            END;
         END;
      END;

      --RATEIO DOS ENCARGOS

      DECLARE C_ITEMENCARGO CURSOR FOR
         SELECT IE.CDENCARGO AS CDENCARGO, VRITEMENCA, IDENCARGO,
                EN.CDCTBLENTREN, EN.CDCTBLSAIDEN
         FROM ITEMENCARGO IE, ENCARGO EN
         WHERE (IE.CDFILIAL   = @P_FILIAL)     AND
               (IE.NRLANCTONF = @P_LANCTONF)   AND
               (IE.VRITEMENCA > 0)            AND
               (EN.CDENCARGO  = IE.CDENCARGO);
      OPEN C_ITEMENCARGO;
      FETCH NEXT FROM C_ITEMENCARGO INTO @V_ITEMENC_CDENCARGO, @V_ITEMENC_VRITEMENCA,
                                         @V_ITEMENC_IDENCARGO, @V_ITEMENC_CDCTBLENTREN,
   	                       				  @V_ITEMENC_CDCTBLSAIDEN;

      WHILE (@@FETCH_STATUS = 0) BEGIN
         SET @V_TOTAPRODENCA = 0;
         DECLARE C_VRLIQRATEIO CURSOR FOR
            SELECT DISTINCT(IP.NRSEQITPROD) AS NRSEQITPROD, (ISNULL(VRTOTAITEM,0) - ISNULL(VRDESCITEM,0)) AS VRLIQUIDO
            FROM ITEMPRODUTO IP, ITEMPROIMPOS II
            WHERE (IP.CDFILIAL    = @P_FILIAL)       AND
                  (IP.NRLANCTONF  = @P_LANCTONF)     AND
                  (II.CDFILIAL    = IP.CDFILIAL)    AND
                  (II.NRLANCTONF  = IP.NRLANCTONF)  AND
                  (II.NRSEQITPROD = IP.NRSEQITPROD) AND
                  (II.CDIMPOSTO IN (SELECT MIN(BC.CDIMPOSTO)
                                    FROM BASECALC BC
                                    WHERE (BC.CDENCARGO = @V_ITEMENC_CDENCARGO)    AND
                                          (BC.CDIMPOSTO = II.CDIMPOSTO)            AND
                                          (BC.CDIMPOSTO = (SELECT MIN(B.CDIMPOSTO)
                                                           FROM BASECALC B
                                                           WHERE B.CDENCARGO = @V_ITEMENC_CDENCARGO))));
         OPEN C_VRLIQRATEIO;
         FETCH NEXT FROM C_VRLIQRATEIO INTO @V_VRLIQRAT_NRSEQITPROD, @V_VRLIQRAT_VRLIQUIDO;
         WHILE (@@FETCH_STATUS = 0) BEGIN
            IF NOT (@V_VRLIQRAT_VRLIQUIDO IS NULL) BEGIN
               SET @V_TOTAPRODENCA = @V_TOTAPRODENCA + @V_VRLIQRAT_VRLIQUIDO;
            END;
            FETCH NEXT FROM C_VRLIQRATEIO INTO @V_VRLIQRAT_NRSEQITPROD, @V_VRLIQRAT_VRLIQUIDO;
         END;
         CLOSE C_VRLIQRATEIO;
         DEALLOCATE C_VRLIQRATEIO;

         IF @V_TOTAPRODENCA = 0 BEGIN
            SELECT @V_TOTAPRODENCA = SUM(VRTOTAITEM - VRDESCITEM)
            FROM ITEMPRODUTO IP
            WHERE (IP.CDFILIAL   = @P_FILIAL)   AND
                  (IP.NRLANCTONF = @P_LANCTONF);

            IF NOT @V_TOTAPRODENCA IS NULL BEGIN
            	DECLARE C_ATUAVRCONT CURSOR FOR
                  SELECT IP.NRSEQITPROD, (VRTOTAITEM - VRDESCITEM) AS VRLIQUIDO
                  FROM ITEMPRODUTO IP
                  WHERE (IP.CDFILIAL    = @P_FILIAL) AND
                        (IP.NRLANCTONF  = @P_LANCTONF);
               OPEN C_ATUAVRCONT;
               FETCH NEXT FROM C_ATUAVRCONT INTO @V_ATUAVR_NRSEQITPROD, @V_ATUAVR_VRLIQUIDO;
               WHILE (@@FETCH_STATUS = 0) BEGIN
                  IF (@V_ITEMENC_IDENCARGO = 'A') BEGIN
                     SET @V_VRBRUTO = (@V_ITEMENC_VRITEMENCA/@V_TOTAPRODENCA);
                  END
                  ELSE IF (@V_ITEMENC_IDENCARGO = 'D') BEGIN
                     SET @V_VRBRUTO = - (@V_ITEMENC_VRITEMENCA/@V_TOTAPRODENCA);
                  END
                  ELSE BEGIN
                     SET @V_VRBRUTO = 0;
                  END;
                  IF (@V_ITEMENC_CDCTBLSAIDEN IS NULL) BEGIN
                     SET @V_VRCONTAB = @V_VRBRUTO;
                  END
                  ELSE BEGIN
                     SET @V_VRCONTAB = 0;
                  END;

                  IF (@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV') BEGIN
                     UPDATE ITEMPRODUTO
                     SET VRBRUTITEM = ROUND(VRBRUTITEM + (@V_VRBRUTO  * (VRTOTAITEM - VRDESCITEM)),2,2),
                         VRCONTITEM = ROUND(VRCONTITEM + (@V_VRCONTAB * (VRTOTAITEM - VRDESCITEM)),2,2)
                     WHERE CDFILIAL    = @P_FILIAL   AND
                           NRLANCTONF  = @P_LANCTONF AND
                           NRSEQITPROD = @V_ATUAVR_NRSEQITPROD;
                  END
                  ELSE BEGIN
                     UPDATE ITEMPRODUTO
                     SET VRBRUTITEM = ROUND(VRBRUTITEM + (@V_VRBRUTO  * (VRTOTAITEM - VRDESCITEM)),2),
                         VRCONTITEM = ROUND(VRCONTITEM + (@V_VRCONTAB * (VRTOTAITEM - VRDESCITEM)),2)
                     WHERE CDFILIAL    = @P_FILIAL   AND
                           NRLANCTONF  = @P_LANCTONF AND
                           NRSEQITPROD = @V_ATUAVR_NRSEQITPROD;
                  END;
                  FETCH NEXT FROM C_ATUAVRCONT INTO @V_ATUAVR_NRSEQITPROD, @V_ATUAVR_VRLIQUIDO;
               END;
               CLOSE C_ATUAVRCONT;
               DEALLOCATE C_ATUAVRCONT;
            END;
         END
         ELSE BEGIN
            DECLARE C_ATUAVRCONT CURSOR FOR
               SELECT DISTINCT(IP.NRSEQITPROD) AS NRSEQITPROD, (VRTOTAITEM - VRDESCITEM) AS VRLIQUIDO
               FROM ITEMPRODUTO IP, ITEMPROIMPOS II
               WHERE (IP.CDFILIAL    = @P_FILIAL)       AND
                     (IP.NRLANCTONF  = @P_LANCTONF)     AND
                     (II.CDFILIAL    = IP.CDFILIAL)    AND
                     (II.NRLANCTONF  = IP.NRLANCTONF)  AND
                     (II.NRSEQITPROD = IP.NRSEQITPROD) AND
                     (II.CDIMPOSTO IN (SELECT BC.CDIMPOSTO
                                       FROM BASECALC BC
                                       WHERE (BC.CDENCARGO = @V_ITEMENC_CDENCARGO) AND
                                             (BC.CDIMPOSTO = II.CDIMPOSTO)            AND
                                             (BC.CDIMPOSTO = (SELECT MIN(B.CDIMPOSTO)
                                                              FROM BASECALC B
                                                              WHERE B.CDENCARGO = @V_ITEMENC_CDENCARGO))));
            OPEN C_ATUAVRCONT;
            FETCH NEXT FROM C_ATUAVRCONT INTO @V_ATUAVR_NRSEQITPROD, @V_ATUAVR_VRLIQUIDO;
            WHILE (@@FETCH_STATUS = 0) BEGIN
               IF (@V_ITEMENC_IDENCARGO = 'A') BEGIN
                  SET @V_VRBRUTO  = (@V_ITEMENC_VRITEMENCA/@V_TOTAPRODENCA);
               END
               ELSE IF (@V_ITEMENC_IDENCARGO = 'D') BEGIN
                  SET @V_VRBRUTO  = - (@V_ITEMENC_VRITEMENCA/@V_TOTAPRODENCA);
               END
               ELSE BEGIN
                  SET @V_VRBRUTO = 0;
               END;
               IF (@V_ITEMENC_CDCTBLSAIDEN IS NULL) BEGIN
                  SET @V_VRCONTAB = @V_VRBRUTO;
               END
               ELSE BEGIN
                  SET @V_VRCONTAB = 0;
               END;

               IF (@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV') BEGIN
                  UPDATE ITEMPRODUTO
                  SET VRBRUTITEM = ROUND(VRBRUTITEM + (@V_VRBRUTO  * (VRTOTAITEM - VRDESCITEM)),2,2),
                      VRCONTITEM = ROUND(VRCONTITEM + (@V_VRCONTAB * (VRTOTAITEM - VRDESCITEM)),2,2)
                  WHERE CDFILIAL    = @P_FILIAL   AND
                        NRLANCTONF  = @P_LANCTONF AND
                        NRSEQITPROD = @V_ATUAVR_NRSEQITPROD;
               END
               ELSE BEGIN
                  UPDATE ITEMPRODUTO
                  SET VRBRUTITEM = ROUND(VRBRUTITEM + (@V_VRBRUTO  * (VRTOTAITEM - VRDESCITEM)),2),
                      VRCONTITEM = ROUND(VRCONTITEM + (@V_VRCONTAB * (VRTOTAITEM - VRDESCITEM)),2)
                  WHERE CDFILIAL    = @P_FILIAL   AND
                        NRLANCTONF  = @P_LANCTONF AND
                        NRSEQITPROD = @V_ATUAVR_NRSEQITPROD;
               END;
               FETCH NEXT FROM C_ATUAVRCONT INTO @V_ATUAVR_NRSEQITPROD, @V_ATUAVR_VRLIQUIDO;
            END;
            CLOSE C_ATUAVRCONT;
            DEALLOCATE C_ATUAVRCONT;

            DECLARE C_ITEMPROIMPOS CURSOR FOR
               SELECT II.NRSEQITPROD, II.NRITPROIMPOS, II.CDIMPOSTO, II.VRPERREDBCIT, II.VRALIQITEM, II.VRPARDEDIT, II.IDTRIMPSTII, (VRTOTAITEM - VRDESCITEM) AS VRLIQUIDO,
                      ISNULL(II.VRALIQINTEDEST, 0) AS VRALIQINTEDEST, ISNULL(II.VRALIQFCP, 0) AS VRALIQFCP
               FROM ITEMPROIMPOS II, ITEMPRODUTO IP, BASECALC BC
               WHERE (II.CDFILIAL    = @P_FILIAL)      AND
                     (II.NRLANCTONF  = @P_LANCTONF)    AND
                     (IP.CDFILIAL    = @P_FILIAL)      AND
                     (IP.NRLANCTONF  = @P_LANCTONF)    AND
                     (IP.NRSEQITPROD = II.NRSEQITPROD) AND
                     (BC.CDIMPOSTO   = II.CDIMPOSTO)   AND
                     (BC.CDENCARGO   = @V_ITEMENC_CDENCARGO)
               ORDER BY II.NRSEQITPROD, II.NRITPROIMPOS, II.CDIMPOSTO;
            OPEN C_ITEMPROIMPOS;
            FETCH NEXT FROM C_ITEMPROIMPOS INTO @V_ITEMPROI_NRSEQITPROD , @V_ITEMPROI_NRITPROIMPOS, @V_ITEMPROI_CDIMPOSTO,
                                                @V_ITEMPROI_VRPERREDBCIT, @V_ITEMPROI_VRALIQITEM,   @V_ITEMPROI_VRPARDEDIT,
                                                @V_IDTRIMPSTII,           @V_ITEMPROI_VRLIQUIDO,    @V_ITEMPROI_VRALIQINTEDEST,
                                                @V_ITEMPROI_VRALIQFCP;
            WHILE (@@FETCH_STATUS = 0) BEGIN
               SELECT @V_TOTAPRENIMPO = SUM(VRTOTAITEM - VRDESCITEM)
               FROM ITEMPRODUTO IP
               WHERE (IP.CDFILIAL     = @P_FILIAL)      AND
                     (IP.NRLANCTONF   = @P_LANCTONF);

               IF (@V_TOTAPRODENCA <> 0) BEGIN
                  IF (@V_ITEMENC_IDENCARGO = 'A') BEGIN
                     SET @V_PRODUENCARGO = +(@V_ITEMENC_VRITEMENCA/@V_TOTAPRENIMPO)*@V_ITEMPROI_VRLIQUIDO;
                  END
                  ELSE IF (@V_ITEMENC_IDENCARGO = 'D') BEGIN
                     SET @V_PRODUENCARGO = -(@V_ITEMENC_VRITEMENCA/@V_TOTAPRENIMPO)*@V_ITEMPROI_VRLIQUIDO;
                  END
                  ELSE BEGIN
                     SET @V_PRODUENCARGO = 0;
                  END;
               END;

               SET @V_CDIMPOSTRIB  = NULL;
               SET @V_IDVRIMPSTRIB = NULL;

               DECLARE C_ICMSST CURSOR FOR
                  SELECT CDIMPOSTO
                    FROM IMPOSTO
                   WHERE CDIMPOSTRIB = @V_ITEMPROI_CDIMPOSTO;

               OPEN C_ICMSST;
               FETCH NEXT FROM C_ICMSST INTO @V_ICMSST_CDIMPOSTRIB;

               WHILE (@@FETCH_STATUS = 0) BEGIN

                  SET @V_CDIMPOSTRIB = ISNULL(@V_CDIMPOSTRIB,'')+@V_ICMSST_CDIMPOSTRIB+'_';
                  FETCH NEXT FROM C_ICMSST INTO @V_ICMSST_CDIMPOSTRIB;
               END;
               CLOSE C_ICMSST;
               DEALLOCATE C_ICMSST;

               SET @V_VRIMPOSTOST = 0;
               IF @V_CDIMPOSTRIB IS NULL BEGIN
                  SET @V_TAXABASECALC = (100 - @V_ITEMPROI_VRPERREDBCIT)/100;
                  SET @V_TAXAALIQUOTA = (@V_ITEMPROI_VRALIQITEM/100);
               END
               ELSE BEGIN
                  SET @V_TAXABASECALC = 1 + (@V_ITEMPROI_VRPERREDBCIT)/100;
                  SET @V_TAXAALIQUOTA = (@V_ITEMPROI_VRALIQITEM/100);

                  SELECT @V_IDVRIMPSTRIB = ISNULL(MAX(IDVRIMPSTRIB), 'N')
                    FROM ITEMPROIMPOS I, IMPOSTO II
                   WHERE (CDFILIAL     = @P_FILIAL)
                     AND (NRLANCTONF   = @P_LANCTONF)
                     AND (NRSEQITPROD  = @V_ITEMPROI_NRSEQITPROD)
                     AND (CHARINDEX(II.CDIMPOSTO+'_', @V_CDIMPOSTRIB) > 0)
                     AND (I.CDIMPOSTO = II.CDIMPOSTO);

                  IF (@V_IDTRIMPSTII <> '1') AND (ISNULL(@V_IDVRIMPSTRIB,'N') = 'S') BEGIN
                     SELECT @V_VRIMPOSTOST = ISNULL(MAX(VRIMPOSTOIT),0)
                     FROM ITEMPROIMPOS I
                     WHERE (CDFILIAL     = @P_FILIAL)               AND
                           (NRLANCTONF   = @P_LANCTONF)             AND
                           (NRSEQITPROD  = @V_ITEMPROI_NRSEQITPROD) AND
                           (CHARINDEX(CDIMPOSTO+'_', @V_CDIMPOSTRIB) > 0) AND
                           (NRITPROIMPOS = @V_ITEMPROI_NRITPROIMPOS);
                  END;
               END;

               SELECT @V_IDPERVISIMPSCRE = ISNULL(MAX(IDPERVISIMPSCRE),'S')
                 FROM PARAMGERAL;

               UPDATE ITEMPROIMPOS
               SET VRCONTITIMP  = VRCONTITIMP  + (@V_PRODUENCARGO * @V_TAXABASECALC),
                   VRBASECALCIT = VRBASECALCIT + ((@V_PRODUENCARGO * @V_TAXABASECALC) / (1 - ((@V_ITEMPROI_VRALIQINTEDEST + @V_ITEMPROI_VRALIQFCP) / 100))),
                   VRIMPOSTOIT  = (VRIMPOSTOIT  + (((@V_PRODUENCARGO * @V_TAXABASECALC) / (1 - ((@V_ITEMPROI_VRALIQINTEDEST + @V_ITEMPROI_VRALIQFCP) / 100))) * @V_TAXAALIQUOTA)) - (((@V_VRIMPOSTOST * @V_TAXABASECALC) * @V_TAXAALIQUOTA) / (1 - ((@V_ITEMPROI_VRALIQINTEDEST + @V_ITEMPROI_VRALIQFCP) / 100))),
                   VRIMPOSTOVISUIT = CASE @V_IDPERVISIMPSCRE WHEN 'S' THEN (VRIMPOSTOIT  + ((@V_PRODUENCARGO * @V_TAXABASECALC) * @V_TAXAALIQUOTA)) - ((@V_VRIMPOSTOST * @V_TAXABASECALC) * @V_TAXAALIQUOTA) ELSE CASE CDFISCALIT WHEN '1' THEN (VRIMPOSTOIT  + ((@V_PRODUENCARGO * @V_TAXABASECALC) * @V_TAXAALIQUOTA)) - ((@V_VRIMPOSTOST * @V_TAXABASECALC) * @V_TAXAALIQUOTA) ELSE 0 END END
               WHERE (CDFILIAL     = @P_FILIAL)               AND
                     (NRLANCTONF   = @P_LANCTONF)             AND
                     (NRSEQITPROD  = @V_ITEMPROI_NRSEQITPROD) AND
                     (CDIMPOSTO    = @V_ITEMPROI_CDIMPOSTO)   AND
                     (NRITPROIMPOS = @V_ITEMPROI_NRITPROIMPOS);

               /* ROTINA PARA RECALCULAR O DIFERIMENTO DO IMPOSTO */
               SET @V_VRIMPOSTOOPERAIT = 0;
               SET @V_VRPERDIFEREIT    = 0;

               SELECT @V_VRIMPOSTOOPERAIT = MAX(VRIMPOSTOOPERAIT),
                      @V_VRPERDIFEREIT = MAX(VRPERDIFEREIT)
                 FROM ITEMPROIMPOS
                WHERE (CDFILIAL     = @P_FILIAL)                AND
                      (NRLANCTONF   = @P_LANCTONF)              AND
                      (NRSEQITPROD  = @V_ITEMPROI_NRSEQITPROD)  AND
                      (CDIMPOSTO    = @V_ITEMPROI_CDIMPOSTO)    AND
                      (NRITPROIMPOS = @V_ITEMPROI_NRITPROIMPOS) AND
                      (VRPERDIFEREIT <> 0);

               IF @V_VRPERDIFEREIT <> 0 BEGIN
                  SET @V_VRIMPOSTOOPERAIT = ROUND((@V_VRIMPOSTOOPERAIT + ((ROUND(@V_PRODUENCARGO, 2) * @V_TAXABASECALC) * @V_TAXAALIQUOTA)) - ((@V_VRIMPOSTOST * @V_TAXABASECALC) * @V_TAXAALIQUOTA),2);
                  SET @V_VRIMPOSTODIFERIT = ROUND((@V_VRIMPOSTOOPERAIT * @V_VRPERDIFEREIT/100), 2);

                  UPDATE ITEMPROIMPOS
                     SET VRIMPOSTOOPERAIT = @V_VRIMPOSTOOPERAIT,
                         VRIMPOSTODIFERIT = @V_VRIMPOSTODIFERIT,
                         VRIMPOSTOIT = (@V_VRIMPOSTOOPERAIT - @V_VRIMPOSTODIFERIT),
                         VRIMPOSTOVISUIT = (@V_VRIMPOSTOOPERAIT - @V_VRIMPOSTODIFERIT)
                   WHERE (CDFILIAL     = @P_FILIAL)                AND
                         (NRLANCTONF   = @P_LANCTONF)              AND
                         (NRSEQITPROD  = @V_ITEMPROI_NRSEQITPROD)  AND
                         (CDIMPOSTO    = @V_ITEMPROI_CDIMPOSTO)    AND
                         (NRITPROIMPOS = @V_ITEMPROI_NRITPROIMPOS) AND
                         (VRPERDIFEREIT <> 0);
               END;

               FETCH NEXT FROM C_ITEMPROIMPOS INTO @V_ITEMPROI_NRSEQITPROD , @V_ITEMPROI_NRITPROIMPOS, @V_ITEMPROI_CDIMPOSTO,
                                                   @V_ITEMPROI_VRPERREDBCIT, @V_ITEMPROI_VRALIQITEM,   @V_ITEMPROI_VRPARDEDIT,
                                                   @V_IDTRIMPSTII,           @V_ITEMPROI_VRLIQUIDO,    @V_ITEMPROI_VRALIQINTEDEST,
                                                   @V_ITEMPROI_VRALIQFCP;
            END;
            CLOSE C_ITEMPROIMPOS;
            DEALLOCATE C_ITEMPROIMPOS;
         END;
         FETCH NEXT FROM C_ITEMENCARGO INTO @V_ITEMENC_CDENCARGO, @V_ITEMENC_VRITEMENCA,
                                            @V_ITEMENC_IDENCARGO, @V_ITEMENC_CDCTBLENTREN,
                                   					    @V_ITEMENC_CDCTBLSAIDEN;
      END;
      CLOSE C_ITEMENCARGO;
      DEALLOCATE C_ITEMENCARGO;

      UPDATE ITEMPROIMPOS
      SET VRIMPOSTOIT = 0,
          VRIMPOSTOVISUIT = 0
      WHERE (NRLANCTONF  = @P_LANCTONF) AND
            (CDFILIAL    = @P_FILIAL) AND
            (VRIMPOSTOIT < 0);

      UPDATE ITEMPROIMPOS
      SET VRBASECALCIT = 0,
          VRIMPOSTOVISUIT = 0
      WHERE (NRLANCTONF  = @P_LANCTONF) AND
            (CDFILIAL    = @P_FILIAL) AND
            (VRBASECALCIT < 0);

      --CLCULO DO VALOR DOS IMPOSTOS QUE CONTM OUTROS IMPOSTOS NA SUA BASE DE CLCULO
      DECLARE C_PRODUTO CURSOR FOR
         SELECT IP.NRSEQITPROD AS NRSEQITPROD, II.CDIMPOSTO, VRPERREDBCIT,
                VRALIQITEM, VRPARDEDIT, CDFISCALIT, VRIMPOSTOIT, IDTRATIMPO,
                IM.IDIMPORECUP, IM.CDCCTBLPASS, IM.CDCCTBLATIV, NRITPROIMPOS,
                II.IDTRIMPSTII, IM.IDTIPCONTAB, II.VRBASECALCIT
         FROM ITEMPRODUTO IP, ITEMPROIMPOS II, IMPOSTO IM
         WHERE (IP.CDFILIAL     = @P_FILIAL)     AND
               (IP.NRLANCTONF   = @P_LANCTONF)   AND
               (II.CDFILIAL     = IP.CDFILIAL)   AND
               (II.NRLANCTONF   = IP.NRLANCTONF) AND
               (IM.CDIMPOSTO    = II.CDIMPOSTO)  AND
               (II.NRITPROIMPOS = '1')           AND
               (II.NRSEQITPROD  = IP.NRSEQITPROD)
         ORDER BY IP.NRSEQITPROD, II.CDIMPOSTO;
      OPEN C_PRODUTO;
      FETCH NEXT FROM C_PRODUTO INTO @V_PRODUTO_NRSEQITPROD , @V_PRODUTO_CDIMPOSTO,
                                     @V_PRODUTO_VRPERREDBCIT, @V_PRODUTO_VRALIQITEM,
                                     @V_PRODUTO_VRPARDEDIT  , @V_PRODUTO_CDFISCALIT,
                                     @V_PRODUTO_VRIMPOSTOIT , @V_PRODUTO_IDTRATIMPO,
                                     @V_PRODUTO_IDIMPORECUP , @V_PRODUTO_CDCCTBLPASS,
                                     @V_PRODUTO_CDCCTBLATIV , @V_PRODUTO_NRITPROIMPOS,
                                     @V_IDTRIMPSTII         , @V_PRODUTO_IDTIPCONTAB,
                                     @V_PRODUTO_VRBASECALCIT;

      WHILE (@@FETCH_STATUS = 0) BEGIN
         SET @V_IDIMPOBCALTPOP = NULL;

         SELECT @V_IDIMPOBCALTPOP = MAX('S') , @V_TOTAIMPBCALC = ISNULL(SUM(VRIMPOSTOIT),0)
         FROM ITEMPRODUTO IP, ITEMPROIMPOS II, BASECALCTPOPER BC , IMPOSTO I
         WHERE (BC.CDIMPOSTO    = @V_PRODUTO_CDIMPOSTO)    AND
               (IP.CDFILIAL     = @P_FILIAL)               AND
               (IP.NRLANCTONF   = @P_LANCTONF)             AND
               (II.NRLANCTONF   = IP.NRLANCTONF)          AND
               (II.CDFILIAL     = IP.CDFILIAL)            AND
               (IP.NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD)  AND
               (II.NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD)  AND
               (II.NRITPROIMPOS = @V_PRODUTO_NRITPROIMPOS) AND
               ((SUBSTRING(IP.CDSITUTRIBPR,2,2) = BC.CDCSTIMPOTPOP)  OR (BC.CDCSTIMPOTPOP  IS NULL)) AND
               ((SUBSTRING(IP.CDFISOPEITEM,2,4) = BC.CDCFOPIMPOTPOP) OR (BC.CDCFOPIMPOTPOP IS NULL)) AND
               ((@V_PRODUTO_CDFISCALIT        = BC.CDFISCIMPOTPOP) OR (BC.CDFISCIMPOTPOP IS NULL)) AND
               (BC.IDENTRSAIDOP = 'S')             AND
               (BC.CDTIPOOPER = @P_TIPOOPER)               AND
               (II.CDIMPOSTO = BC.CDIMPOBCALC)            AND
               (BC.CDIMPOBCALC = I.CDIMPOSTO)             AND
               (ISNULL(BC.IDTRATIMPOBCTPOP, I.IDTRATIMPO) <> 'D');

         IF @V_IDIMPOBCALTPOP IS NULL BEGIN
            SELECT @V_TOTAIMPBCALC = ISNULL(SUM(VRIMPOSTOIT),0)
              FROM ITEMPRODUTO IP, ITEMPROIMPOS II, BASECALC BC, IMPOSTO I
             WHERE (BC.CDIMPOSTO    = @V_PRODUTO_CDIMPOSTO)    AND
                   (IP.CDFILIAL     = @P_FILIAL)               AND
                   (IP.NRLANCTONF   = @P_LANCTONF)             AND
                   (II.NRLANCTONF   = IP.NRLANCTONF)           AND
                   (II.CDFILIAL     = IP.CDFILIAL)             AND
                   (IP.NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD)  AND
                   (II.NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD)  AND
                   (II.NRITPROIMPOS = @V_PRODUTO_NRITPROIMPOS) AND
                   ((SUBSTRING(IP.CDSITUTRIBPR,2,2) = BC.CDCSTIMPO)  OR (BC.CDCSTIMPO  IS NULL)) AND
                   ((SUBSTRING(IP.CDFISOPEITEM,2,4) = BC.CDCFOPIMPO) OR (BC.CDCFOPIMPO IS NULL)) AND
                   ((@V_PRODUTO_CDFISCALIT          = BC.CDFISCIMPO) OR (BC.CDFISCIMPO IS NULL)) AND
                   (II.CDIMPOSTO     = BC.CDIMPOBCALC) AND
                   (BC.IDTIPOBCALC   = 'I') AND
                   (BC.CDIMPOBCALC = I.CDIMPOSTO)  AND
                   (ISNULL(BC.IDTRATIMPOBC, I.IDTRATIMPO) <> 'D');
         END;

         SET @V_IDIMBCALTPOPDE = NULL;

         SELECT @V_IDIMBCALTPOPDE = MAX('S'), @V_TOTAIMPBCDES = (ISNULL(SUM(VRIMPOSTOIT),0)*-1)
           FROM ITEMPRODUTO IP, ITEMPROIMPOS II, BASECALCTPOPER BC, IMPOSTO I
          WHERE (BC.CDIMPOSTO    = @V_PRODUTO_CDIMPOSTO)    AND
                (IP.CDFILIAL     = @P_FILIAL)               AND
                (IP.NRLANCTONF   = @P_LANCTONF)             AND
                (II.NRLANCTONF   = IP.NRLANCTONF)          AND
                (II.CDFILIAL     = IP.CDFILIAL)            AND
                (IP.NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD)  AND
                (II.NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD)  AND
                (II.NRITPROIMPOS = @V_PRODUTO_NRITPROIMPOS) AND
                ((SUBSTRING(IP.CDSITUTRIBPR,2,2) = BC.CDCSTIMPOTPOP)  OR (BC.CDCSTIMPOTPOP  IS NULL)) AND
                ((SUBSTRING(IP.CDFISOPEITEM,2,4) = BC.CDCFOPIMPOTPOP) OR (BC.CDCFOPIMPOTPOP IS NULL)) AND
                ((@V_PRODUTO_CDFISCALIT        = BC.CDFISCIMPOTPOP) OR (BC.CDFISCIMPOTPOP IS NULL)) AND
                (BC.IDENTRSAIDOP = 'S')  AND
                (BC.CDTIPOOPER = @P_TIPOOPER)    AND
                (II.CDIMPOSTO = BC.CDIMPOBCALC) AND
                (BC.CDIMPOBCALC = I.CDIMPOSTO)  AND
                (ISNULL(BC.IDTRATIMPOBCTPOP, I.IDTRATIMPO) = 'D');

         IF @V_IDIMBCALTPOPDE IS NULL BEGIN
            SELECT @V_TOTAIMPBCDES = (ISNULL(SUM(VRIMPOSTOIT),0)*-1)
              FROM ITEMPRODUTO IP, ITEMPROIMPOS II, BASECALC BC, IMPOSTO I
             WHERE (BC.CDIMPOSTO    = @V_PRODUTO_CDIMPOSTO)    AND
                   (IP.CDFILIAL     = @P_FILIAL)               AND
                   (IP.NRLANCTONF   = @P_LANCTONF)             AND
                   (II.NRLANCTONF   = IP.NRLANCTONF)           AND
                   (II.CDFILIAL     = IP.CDFILIAL)             AND
                   (IP.NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD)  AND
                   (II.NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD)  AND
                   (II.NRITPROIMPOS = @V_PRODUTO_NRITPROIMPOS) AND
                   ((SUBSTRING(IP.CDSITUTRIBPR,2,2) = BC.CDCSTIMPO)  OR (BC.CDCSTIMPO  IS NULL)) AND
                   ((SUBSTRING(IP.CDFISOPEITEM,2,4) = BC.CDCFOPIMPO) OR (BC.CDCFOPIMPO IS NULL)) AND
                   ((@V_PRODUTO_CDFISCALIT          = BC.CDFISCIMPO) OR (BC.CDFISCIMPO IS NULL)) AND
                   (II.CDIMPOSTO     = BC.CDIMPOBCALC) AND
                   (BC.IDTIPOBCALC   = 'I') AND
                   (BC.CDIMPOBCALC = I.CDIMPOSTO)  AND
                   (ISNULL(BC.IDTRATIMPOBC, I.IDTRATIMPO) = 'D');
         END;

         SET @V_VRIMPOSTO = @V_PRODUTO_VRIMPOSTOIT;

         SET @V_CDIMPOSTRIB  = NULL;
         SET @V_IDVRIMPSTRIB = NULL;

         DECLARE C_ICMSST CURSOR FOR
           SELECT CDIMPOSTO
             FROM IMPOSTO
            WHERE CDIMPOSTRIB = @V_PRODUTO_CDIMPOSTO;

         OPEN C_ICMSST;
         FETCH NEXT FROM C_ICMSST INTO @V_ICMSST_CDIMPOSTRIB;

         WHILE (@@FETCH_STATUS = 0) BEGIN

            SET @V_CDIMPOSTRIB = ISNULL(@V_CDIMPOSTRIB,'')+@V_ICMSST_CDIMPOSTRIB+'_';
            FETCH NEXT FROM C_ICMSST INTO @V_ICMSST_CDIMPOSTRIB;
         END;
         CLOSE C_ICMSST;
         DEALLOCATE C_ICMSST;

         SET @V_VRIMPOSTOST = 0;

         /*S ir fazer o clculo de outro imposto compondo a base de clculo,
           se o valor do mesmo no estiver zerado OU
           se for o imposto de st, pois o icms pode ter sido recalculado(por ter alguem compondo sua bc)
           e o imposto st precisa retirar o valor final do st*/
         IF (NOT(@V_TOTAIMPBCALC IS NULL) AND (@V_TOTAIMPBCALC <> 0)) OR
            (NOT(@V_TOTAIMPBCDES IS NULL) AND (@V_TOTAIMPBCDES <> 0)) OR
            (@V_CDIMPOSTRIB IS NOT NULL) BEGIN
            SELECT @V_IDPERVISIMPSCRE = ISNULL(MAX(IDPERVISIMPSCRE),'S')
              FROM PARAMGERAL;

            IF @V_CDIMPOSTRIB IS NULL BEGIN
               SET @V_TAXABASECALC = (100 - @V_PRODUTO_VRPERREDBCIT)/100;
               SET @V_TAXAALIQUOTA = (@V_PRODUTO_VRALIQITEM/100);
               SET @V_VRIMPOSTO    = @V_VRIMPOSTO + (((@V_TOTAIMPBCALC+@V_TOTAIMPBCDES) * @V_TAXABASECALC) * @V_TAXAALIQUOTA);


               UPDATE ITEMPROIMPOS
                  SET VRBASECALCIT = VRBASECALCIT + ((@V_TOTAIMPBCALC+@V_TOTAIMPBCDES) * @V_TAXABASECALC),
                      VRIMPOSTOIT  = (VRIMPOSTOIT  + (((@V_TOTAIMPBCALC+@V_TOTAIMPBCDES) * @V_TAXABASECALC) * @V_TAXAALIQUOTA)),
                      VRIMPOSTOVISUIT = CASE @V_IDPERVISIMPSCRE WHEN 'S' THEN (VRIMPOSTOIT  + (((@V_TOTAIMPBCALC+@V_TOTAIMPBCDES) * @V_TAXABASECALC) * @V_TAXAALIQUOTA)) ELSE CASE CDFISCALIT WHEN '1' THEN (VRIMPOSTOIT  + (((@V_TOTAIMPBCALC+@V_TOTAIMPBCDES) * @V_TAXABASECALC) * @V_TAXAALIQUOTA)) ELSE 0 END END
                WHERE (CDFILIAL     = @P_FILIAL)              AND
                      (NRLANCTONF   = @P_LANCTONF)            AND
                      (NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD) AND
                      (CDIMPOSTO    = @V_PRODUTO_CDIMPOSTO)   AND
                     (NRITPROIMPOS = @V_PRODUTO_NRITPROIMPOS);

               /* ROTINA PARA RECALCULAR O DIFERIMENTO DO IMPOSTO */
               SET @V_VRIMPOSTOOPERAIT = 0;
               SET @V_VRPERDIFEREIT    = 0;

               SELECT @V_VRIMPOSTOOPERAIT = MAX(VRIMPOSTOOPERAIT),
                      @V_VRPERDIFEREIT =  MAX(VRPERDIFEREIT)
                 FROM ITEMPROIMPOS
                WHERE (CDFILIAL     = @P_FILIAL)               AND
                      (NRLANCTONF   = @P_LANCTONF)             AND
                      (NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD)  AND
                      (CDIMPOSTO    = @V_PRODUTO_CDIMPOSTO)    AND
                      (NRITPROIMPOS = @V_PRODUTO_NRITPROIMPOS) AND
                      (VRPERDIFEREIT <> 0);

               IF @V_VRPERDIFEREIT <> 0 BEGIN
                  SET @V_VRIMPOSTOOPERAIT = ROUND((@V_VRIMPOSTOOPERAIT + ((ROUND((@V_TOTAIMPBCALC+@V_TOTAIMPBCDES), 2) * @V_TAXABASECALC) * @V_TAXAALIQUOTA)),2);
                  SET @V_VRIMPOSTODIFERIT = ROUND((@V_VRIMPOSTOOPERAIT * @V_VRPERDIFEREIT/100), 2);

                  UPDATE ITEMPROIMPOS
                     SET VRIMPOSTOOPERAIT = @V_VRIMPOSTOOPERAIT,
                         VRIMPOSTODIFERIT = @V_VRIMPOSTODIFERIT,
                         VRIMPOSTOIT = (@V_VRIMPOSTOOPERAIT - @V_VRIMPOSTODIFERIT),
                         VRIMPOSTOVISUIT = (@V_VRIMPOSTOOPERAIT - @V_VRIMPOSTODIFERIT)
                   WHERE (CDFILIAL     = @P_FILIAL)               AND
                         (NRLANCTONF   = @P_LANCTONF)             AND
                         (NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD)  AND
                         (CDIMPOSTO    = @V_PRODUTO_CDIMPOSTO)    AND
                         (NRITPROIMPOS = @V_PRODUTO_NRITPROIMPOS) AND
                         (VRPERDIFEREIT <> 0);
               END;
            END
            ELSE BEGIN
               SET @V_VRIMPOSST   = 0;
               SET @V_VRIMPOSTOST = 0;

               DECLARE C_SUBSTRIB CURSOR FOR
                  SELECT ISNULL(IDVRIMPSTRIB, 'N') IDVRIMPSTRIB, I.CDIMPOSTO
                    FROM ITEMPROIMPOS I, IMPOSTO II
                   WHERE (CDFILIAL     = @P_FILIAL)
                     AND (NRLANCTONF   = @P_LANCTONF)
                     AND (NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD)
                     AND (NRITPROIMPOS = '1')
                     AND (CHARINDEX(II.CDIMPOSTO+'_', @V_CDIMPOSTRIB) > 0)
                     AND (I.CDIMPOSTO = II.CDIMPOSTO);

               OPEN C_SUBSTRIB;
               FETCH NEXT FROM C_SUBSTRIB INTO @V_SUBSTRIB_IDVRIMPSTRIB, @V_SUBSTRIB_CDIMPOSTO;
               WHILE (@@FETCH_STATUS = 0) BEGIN

                  IF (@V_SUBSTRIB_IDVRIMPSTRIB = 'S') BEGIN
                        SELECT @V_VRIMPOSST = ISNULL(ROUND(MAX(VRIMPOSTOIT), 2),0)
                        FROM ITEMPROIMPOS I
                        WHERE (CDFILIAL     = @P_FILIAL)                     AND
                              (NRLANCTONF   = @P_LANCTONF)                   AND
                              (NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD)     AND
                              (CDIMPOSTO    = @V_SUBSTRIB_CDIMPOSTO)         AND
                              (CHARINDEX(CDIMPOSTO+'_', @V_CDIMPOSTRIB) > 0) AND
                              (NRITPROIMPOS = '1');
                  END
                  ELSE BEGIN
                     SET @V_VRIMPOSST = 0;
                  END;
                  SET @V_VRIMPOSTOST = @V_VRIMPOSTOST + @V_VRIMPOSST;

                  FETCH NEXT FROM C_SUBSTRIB INTO @V_SUBSTRIB_IDVRIMPSTRIB, @V_SUBSTRIB_CDIMPOSTO;
               END;
               CLOSE C_SUBSTRIB;
               DEALLOCATE C_SUBSTRIB;

               SET @V_TAXABASECALC = 1 + (@V_PRODUTO_VRPERREDBCIT)/100;
               SET @V_TAXAALIQUOTA = (@V_PRODUTO_VRALIQITEM/100);
               SET @V_VRIMPOSTO    = ((@V_PRODUTO_VRBASECALCIT+ ((@V_TOTAIMPBCALC+@V_TOTAIMPBCDES) * @V_TAXABASECALC)) * @V_TAXAALIQUOTA);


               IF @V_VRIMPOSTOST > @V_VRIMPOSTO BEGIN
                  UPDATE ITEMPROIMPOS
                  SET VRBASECALCIT = VRBASECALCIT + ((@V_TOTAIMPBCALC+@V_TOTAIMPBCDES) * @V_TAXABASECALC),
                      VRIMPOSTOIT  = 0,
                      VRIMPOSTOVISUIT = 0
                WHERE (CDFILIAL     = @P_FILIAL)              AND
                      (NRLANCTONF   = @P_LANCTONF)            AND
                      (NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD) AND
                      (CDIMPOSTO    = @V_PRODUTO_CDIMPOSTO)   AND
                      (NRITPROIMPOS = @V_PRODUTO_NRITPROIMPOS);

                  SET @V_VRIMPOSTO  = 0;
               END
               ELSE BEGIN
                  UPDATE ITEMPROIMPOS
                     SET VRBASECALCIT = VRBASECALCIT + ((@V_TOTAIMPBCALC+@V_TOTAIMPBCDES) * @V_TAXABASECALC),
                         VRIMPOSTOIT  = @V_VRIMPOSTO - @V_VRIMPOSTOST,
                         VRIMPOSTOVISUIT = CASE @V_IDPERVISIMPSCRE WHEN 'S' THEN @V_VRIMPOSTO - @V_VRIMPOSTOST ELSE CASE CDFISCALIT WHEN '1' THEN @V_VRIMPOSTO - @V_VRIMPOSTOST ELSE 0 END END
                   WHERE (CDFILIAL     = @P_FILIAL)              AND
                         (NRLANCTONF   = @P_LANCTONF)            AND
                         (NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD) AND
                         (CDIMPOSTO    = @V_PRODUTO_CDIMPOSTO)   AND
                         (NRITPROIMPOS = @V_PRODUTO_NRITPROIMPOS);

                  SET  @V_VRIMPOSTO = @V_VRIMPOSTO - @V_VRIMPOSTOST;
               END;
--               SET @V_VRIMPOSTO    = ((@V_VRIMPOSTO + (((@V_TOTAIMPBCALC+@V_TOTAIMPBCDES) * @V_TAXABASECALC) * @V_TAXAALIQUOTA)) - ((@V_VRIMPOSTOST * @V_TAXABASECALC) * @V_TAXAALIQUOTA));
            END;
         END;

         SET @V_IMPOCONTAB = 0;

         IF (@V_PRODUTO_IDTRATIMPO = 'A') BEGIN
            IF ((@V_PRODUTO_IDIMPORECUP = 'S')  AND (@V_PRODUTO_CDFISCALIT = '1')) OR
               ((@V_PRODUTO_IDIMPORECUP <> 'S') AND (@V_PRODUTO_CDCCTBLPASS IS NOT NULL)) AND
               (@V_CDIMPOSTRIB IS NULL) AND (@V_PRODUTO_IDTIPCONTAB = 'D') BEGIN

               UPDATE ITEMPRODUTO
               SET VRBRUTITEM = ROUND(VRBRUTITEM + @V_VRIMPOSTO,2)
               WHERE CDFILIAL    = @P_FILIAL   AND
                     NRLANCTONF  = @P_LANCTONF AND
                     NRSEQITPROD = @V_PRODUTO_NRSEQITPROD;
            END
            ELSE BEGIN
               IF ((@V_CDIMPOSTRIB IS NOT NULL) AND (@V_IDTRIMPSTII = '0')) OR
                   (@V_CDIMPOSTRIB IS NULL) BEGIN
                  UPDATE ITEMPRODUTO
                  SET VRBRUTITEM = ROUND(VRBRUTITEM + @V_VRIMPOSTO,2),
                      VRCONTITEM = ROUND(VRCONTITEM + @V_VRIMPOSTO,2)
                  WHERE CDFILIAL    = @P_FILIAL   AND
                        NRLANCTONF  = @P_LANCTONF AND
                        NRSEQITPROD = @V_PRODUTO_NRSEQITPROD;
               END;
            END;
         END
         ELSE IF (@V_PRODUTO_IDTRATIMPO = 'D') BEGIN
            IF ((@V_PRODUTO_IDIMPORECUP = 'S') AND (@V_PRODUTO_CDFISCALIT = '1')) OR
               ((@V_PRODUTO_IDIMPORECUP <> 'S') AND (@V_PRODUTO_CDCCTBLATIV IS NOT NULL)) AND
               (@V_PRODUTO_IDTIPCONTAB = 'D') BEGIN

               UPDATE ITEMPRODUTO
               SET VRBRUTITEM = ROUND(VRBRUTITEM - @V_VRIMPOSTO,2)
               WHERE CDFILIAL    = @P_FILIAL   AND
                     NRLANCTONF  = @P_LANCTONF AND
                     NRSEQITPROD = @V_PRODUTO_NRSEQITPROD;
            END
            ELSE BEGIN
               UPDATE ITEMPRODUTO
               SET VRBRUTITEM = ROUND(VRBRUTITEM - @V_VRIMPOSTO,2),
                   VRCONTITEM = ROUND(VRCONTITEM - @V_VRIMPOSTO,2)
               WHERE CDFILIAL    = @P_FILIAL   AND
                     NRLANCTONF  = @P_LANCTONF AND
                     NRSEQITPROD = @V_PRODUTO_NRSEQITPROD;
            END;
         END
         ELSE IF (@V_PRODUTO_IDTRATIMPO = 'R') BEGIN
            IF (@V_PRODUTO_IDIMPORECUP = 'S') BEGIN
               IF (@V_PRODUTO_CDCCTBLATIV IS NULL) OR
                  (@V_PRODUTO_CDFISCALIT <> '1') BEGIN
                  SET @V_IMPOCONTAB = - @V_VRIMPOSTO;
               END;
            END
            ELSE BEGIN
               IF (@V_PRODUTO_CDCCTBLATIV IS NULL) BEGIN
                  SET @V_IMPOCONTAB = - @V_VRIMPOSTO;
               END;
            END;

            IF (@V_PRODUTO_IDTIPCONTAB = 'D') BEGIN
               UPDATE ITEMPRODUTO
               SET VRCONTITEM = ROUND(VRCONTITEM + @V_IMPOCONTAB,2)
               WHERE CDFILIAL    = @P_FILIAL   AND
                     NRLANCTONF  = @P_LANCTONF AND
                     NRSEQITPROD = @V_PRODUTO_NRSEQITPROD;
            END;

         END
         ELSE IF (@V_PRODUTO_IDTRATIMPO = 'V') BEGIN
            IF (@V_PRODUTO_IDIMPORECUP = 'S') AND (@V_IDORIGDESTNF = 'L') BEGIN
               IF (@V_PRODUTO_CDCCTBLPASS IS NOT NULL) AND
                  (@V_PRODUTO_CDFISCALIT = '1') BEGIN

                  SET @V_IMPOCONTAB = - @V_VRIMPOSTO;
               END;
            END;

            IF (@V_PRODUTO_IDTIPCONTAB = 'D') BEGIN
               UPDATE ITEMPRODUTO
               SET VRCONTITEM = ROUND(VRCONTITEM + @V_IMPOCONTAB,2)
               WHERE CDFILIAL    = @P_FILIAL   AND
                     NRLANCTONF  = @P_LANCTONF AND
                     NRSEQITPROD = @V_PRODUTO_NRSEQITPROD;
            END;
         END;

         FETCH NEXT FROM C_PRODUTO INTO @V_PRODUTO_NRSEQITPROD , @V_PRODUTO_CDIMPOSTO,
                                        @V_PRODUTO_VRPERREDBCIT, @V_PRODUTO_VRALIQITEM,
                                        @V_PRODUTO_VRPARDEDIT  , @V_PRODUTO_CDFISCALIT,
                                        @V_PRODUTO_VRIMPOSTOIT , @V_PRODUTO_IDTRATIMPO,
                                        @V_PRODUTO_IDIMPORECUP , @V_PRODUTO_CDCCTBLPASS,
                                        @V_PRODUTO_CDCCTBLATIV , @V_PRODUTO_NRITPROIMPOS,
                                        @V_IDTRIMPSTII         , @V_PRODUTO_IDTIPCONTAB,
                                        @V_PRODUTO_VRBASECALCIT;
      END;
      CLOSE C_PRODUTO;
      DEALLOCATE C_PRODUTO;

      DECLARE C_ITEMIMPOS CURSOR FOR SELECT II.CDIMPOSTO,  I.NRSEQITPROD, II.NRITPROIMPOS
                                  FROM ITEMPRODUTO I, ITEMPROIMPOS II
                                 WHERE I.CDFILIAL    = @P_FILIAL
                                   AND I.NRLANCTONF  = @P_LANCTONF
                                   AND I.CDFILIAL    = II.CDFILIAL
                                   AND I.NRLANCTONF  = II.NRLANCTONF
                                   AND I.NRSEQITPROD = II.NRSEQITPROD;
      OPEN C_ITEMIMPOS;
      FETCH NEXT FROM C_ITEMIMPOS INTO @V_ITEMIMPOS_CDIMPOSTO, @V_ITEMIMPOS_NRSEQITPROD, @V_ITEMIMPOS_NRITPROIMPOS;
      WHILE (@@FETCH_STATUS = 0) BEGIN

         SET @V_ICMS = NULL;
         DECLARE C_ICMS CURSOR FOR
            SELECT CDIMPOSTO
              FROM IMPOSTONFE N, IMPOSTO I
             WHERE N.CDIMPOSTONFE = I.CDIMPOSTONFE
               AND N.CDIMPOSTONFE = '00'
               AND I.CDIMPOSTO = @V_ITEMIMPOS_CDIMPOSTO;
         OPEN C_ICMS;
         FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
         WHILE (@@FETCH_STATUS = 0) BEGIN
            SET @V_ICMS = 'S';
            FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
         END;
         CLOSE C_ICMS;
         DEALLOCATE C_ICMS;
         SELECT @V_IDPERVISIMPSCRE = ISNULL(MAX(IDPERVISIMPSCRE), 'S')
           FROM PARAMGERAL;

         IF ((@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV'))  AND (@V_ICMS = 'S') BEGIN
            UPDATE ITEMPROIMPOS
               SET VRCONTITIMP  = ROUND(VRCONTITIMP,2,2),
                   VRBASECALCIT = ROUND(VRBASECALCIT,2,2),
                   VRIMPOSTOIT  = ROUND(VRIMPOSTOIT,2,2),
                   VRIMPOSTOVISUIT = CASE @V_IDPERVISIMPSCRE WHEN 'S' THEN ROUND(VRIMPOSTOIT,2,2) ELSE CASE CDFISCALIT WHEN '1' THEN ROUND(VRIMPOSTOIT,2,2) ELSE 0 END END
             WHERE (CDFILIAL     = @P_FILIAL)
               AND (NRLANCTONF   = @P_LANCTONF)
               AND (CDIMPOSTO    = @V_ITEMIMPOS_CDIMPOSTO)
               AND (NRSEQITPROD  = @V_ITEMIMPOS_NRSEQITPROD)
               AND (NRITPROIMPOS = @V_ITEMIMPOS_NRITPROIMPOS);
         END
         ELSE BEGIN
           UPDATE ITEMPROIMPOS
               SET VRCONTITIMP  = ROUND(VRCONTITIMP,2),
                   VRBASECALCIT = ROUND(VRBASECALCIT,2),
                   VRIMPOSTOIT  = ROUND(VRIMPOSTOIT,2),
                   VRIMPOSTOVISUIT = CASE @V_IDPERVISIMPSCRE WHEN 'S' THEN ROUND(VRIMPOSTOIT,2) ELSE CASE CDFISCALIT WHEN '1' THEN ROUND(VRIMPOSTOIT,2) ELSE 0 END END
             WHERE (CDFILIAL     = @P_FILIAL)
               AND (NRLANCTONF   = @P_LANCTONF)
               AND (CDIMPOSTO    = @V_ITEMIMPOS_CDIMPOSTO)
               AND (NRSEQITPROD  = @V_ITEMIMPOS_NRSEQITPROD)
               AND (NRITPROIMPOS = @V_ITEMIMPOS_NRITPROIMPOS);
         END;
         FETCH NEXT FROM C_ITEMIMPOS INTO @V_ITEMIMPOS_CDIMPOSTO, @V_ITEMIMPOS_NRSEQITPROD, @V_ITEMIMPOS_NRITPROIMPOS;
      END;
      CLOSE C_ITEMIMPOS;
      DEALLOCATE C_ITEMIMPOS;
      --FIM DA ATUALIZAO NA TABELA DE ITEMPROIMPOS

      --TOTALIZAO DOS IMPOSTOS
      DELETE FROM IMPOSNFTOT
      WHERE (CDFILIAL = @P_FILIAL) AND
            (NRLANCTONF = @P_LANCTONF);

      DECLARE C_IMPOSNFTOT CURSOR FOR
         SELECT CDIMPOSTO
         FROM ITEMPROIMPOS
         WHERE (CDFILIAL   = @P_FILIAL)   AND
               (NRLANCTONF = @P_LANCTONF)
         GROUP BY CDIMPOSTO;
      OPEN C_IMPOSNFTOT;
      FETCH NEXT FROM C_IMPOSNFTOT INTO @V_IMPOSNFTOT_CDIMPOSTO
      WHILE (@@FETCH_STATUS = 0) BEGIN
         SET @V_IMPOSTOIT = 0;

         SET @V_BASECALCIT = 0;
         SELECT @V_IMPOSTOIT = ISNULL(SUM(ROUND(IT.VRIMPOSTOIT,2)),0),
                @V_BASECALCIT = ISNULL(SUM(ROUND(IT.VRBASECALCIT,2)),0)
         FROM ITEMPROIMPOS IT, IMPOSTO I
         WHERE (IT.CDFILIAL   = @P_FILIAL)            AND
               (IT.NRLANCTONF = @P_LANCTONF)          AND
               (IT.CDIMPOSTO  = @V_IMPOSNFTOT_CDIMPOSTO) AND
               (IT.CDIMPOSTO  = I.CDIMPOSTO);

         SET @V_ICMS = NULL;
         DECLARE C_ICMS CURSOR FOR
            SELECT CDIMPOSTO
              FROM IMPOSTONFE N, IMPOSTO I
             WHERE N.CDIMPOSTONFE = I.CDIMPOSTONFE
               AND N.CDIMPOSTONFE = '00'
               AND I.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
         OPEN C_ICMS;
         FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
         WHILE (@@FETCH_STATUS = 0) BEGIN
            SET @V_ICMS = 'S';
            FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
         END;
         CLOSE C_ICMS;
         DEALLOCATE C_ICMS;

         IF ((@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV')) AND (@V_ICMS = 'S') BEGIN
            INSERT INTO IMPOSNFTOT(CDFILIAL, NRLANCTONF, CDIMPOSTO, VRTOTIMPONF, VRTOTBCALCNF)
            VALUES (@P_FILIAL, @P_LANCTONF, @V_IMPOSNFTOT_CDIMPOSTO, ROUND(@V_IMPOSTOIT ,@V_NRDECITOTANF,2), ROUND(@V_BASECALCIT,@V_NRDECITOTANF,2));
            FETCH NEXT FROM C_IMPOSNFTOT INTO @V_IMPOSNFTOT_CDIMPOSTO;
         END
         ELSE BEGIN
            INSERT INTO IMPOSNFTOT(CDFILIAL, NRLANCTONF, CDIMPOSTO, VRTOTIMPONF, VRTOTBCALCNF)
            VALUES (@P_FILIAL, @P_LANCTONF, @V_IMPOSNFTOT_CDIMPOSTO, ROUND(@V_IMPOSTOIT ,@V_NRDECITOTANF), ROUND(@V_BASECALCIT,@V_NRDECITOTANF));
            FETCH NEXT FROM C_IMPOSNFTOT INTO @V_IMPOSNFTOT_CDIMPOSTO;
         END;
      END;
      CLOSE C_IMPOSNFTOT;
      DEALLOCATE C_IMPOSNFTOT;

      --INCLUSO DOS IMPOSTOS DE CORPO DE NOTA
      SET @V_SEQUIMPOSTNF = '01';

      DELETE FROM IMPOSTONF
      WHERE (CDFILIAL = @P_FILIAL) AND
            (NRLANCTONF = @P_LANCTONF);

      EXEC CONSULTA_INCIDENCIA 'S', @P_EMPRESA, null, @P_INSCESTA, @P_TIPOOPER, @P_FILIAL, @P_LANCTONF, @V_CDGRUPOFISC, @V_IDINTEREST;

      DECLARE C_INCIDENCIA CURSOR FOR
         SELECT DISTINCT (CDIMPOTEMP) AS CDIMPOTEMP, CDFISCTEMP,
                IDTRATIMPTMP, IDIMPORECUP, IDUTMUNIORIG, IP.CDIMPOSTONFE
         FROM INCITEMP IT, IMPOSTO IP
         WHERE (IT.NRINCITEMP  = @V_INCITEMP)  AND
               (IT.CDIMPOTEMP  = IP.CDIMPOSTO) AND
               (IP.IDPRODNOTA  = 'C');

      OPEN C_INCIDENCIA;
      FETCH NEXT FROM C_INCIDENCIA INTO @V_INCIDEN_CDIMPOTEMP, @V_INCIDEN_CDFISCTEMP,
                                        @V_INCIDEN_IDTRATIMPTMP, @V_INCIDEN_IDIMPORECUP,
                                        @V_INCIDEN_IDUTMUNIORIG, @V_INCIDEN_CDIMPOSTONFE;
      WHILE (@@FETCH_STATUS = 0) BEGIN
         SET @V_ALIQUTMP  = 0;
         SET @V_PARDEDTMP = 0;
         SET @V_PREDBCTMP = 0;

         /*VERIFICA CST POR IMPOSTO*/
         SET @V_IMPOICMS = NULL;
         SET @V_CDGRUPOFISCAUX = NULL;

         SELECT @V_CDGRUPOFISCAUX = MAX(G.CDGRUPOFISC)
           FROM GRUPOFISCIMPFIL G,
                (SELECT CDFILIEMIT AS CDFILIAL
                   FROM NOTAFISCAL
                  WHERE CDFILIAL = @P_FILIAL
                    AND NRLANCTONF = @P_LANCTONF) F
          WHERE G.CDFILIAL = F.CDFILIAL
            AND NOT G.CDGRUPOFISC IS NULL
            AND G.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;

         IF @V_IDORIGDESTNF = 'C' BEGIN
            SELECT @V_CDGRUPOFISCAUX = ISNULL(MAX(G.CDGRUPOFISC), @V_CDGRUPOFISCAUX)
              FROM GRFISIMPIECLIE G,
                   (SELECT CDCLIENTE
                      FROM NOTAFISCAL
                     WHERE CDFILIAL = @P_FILIAL
                       AND NRLANCTONF = @P_LANCTONF) N
             WHERE G.CDCLIENTE = N.CDCLIENTE
               AND G.CDEMPRESA = @P_EMPRESA
               AND G.CDINSCESTA = @P_INSCESTA
               AND NOT G.CDGRUPOFISC IS NULL
               AND G.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
         END
         ELSE BEGIN
            SELECT @V_CDGRUPOFISCAUX = ISNULL(MAX(G.CDGRUPOFISC), @V_CDGRUPOFISCAUX)
              FROM GRFISIMPIEFORN G,
                  (SELECT CDFORNECED
                     FROM NOTAFISCAL
                    WHERE CDFILIAL = @P_FILIAL
                      AND NRLANCTONF = @P_LANCTONF) N
             WHERE G.CDFORNECED = N.CDFORNECED
               AND G.CDEMPRESA = @P_EMPRESA
               AND G.CDINSCESTA = @P_INSCESTA
               AND NOT G.CDGRUPOFISC IS NULL
               AND G.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
         END;

         IF @V_CDGRUPOFISCAUX IS NULL BEGIN
            EXEC CONSULTA_CST_NFE 'S', @P_EMPRESA, '', @P_INSCESTA, @P_TIPOOPER, @V_CDGRUPOFISC, @V_INCIDEN_CDIMPOTEMP, @V_IDINTEREST, @V_IDINTERNA, @P_FILIAL, @P_LANCTONF, '', @P_CDSITTRIBTMP = @V_CDSITTRIBTMP OUTPUT, @P_IDMODBCNFE = @V_IDMODBCNFE OUTPUT, @P_IDMODBCSTNFE = @V_IDMODBCSTNFE OUTPUT, @P_CDTPCRPICOSTNFE = @V_CDTPCRPICOSTNFE OUTPUT, @P_CDNATUBCPCSTNFE = @V_CDNATUBCPCSTNFE OUTPUT, @P_IDMOTIDESSTNFE = @V_IDMOTIDESSTNFE OUTPUT;
         END
         ELSE BEGIN
            EXEC CONSULTA_CST_NFE 'S', @P_EMPRESA, '', @P_INSCESTA, @P_TIPOOPER, @V_CDGRUPOFISCAUX, @V_INCIDEN_CDIMPOTEMP, @V_IDINTEREST, @V_IDINTERNA, @P_FILIAL, @P_LANCTONF, '', @P_CDSITTRIBTMP = @V_CDSITTRIBTMP OUTPUT, @P_IDMODBCNFE = @V_IDMODBCNFE OUTPUT, @P_IDMODBCSTNFE = @V_IDMODBCSTNFE OUTPUT, @P_CDTPCRPICOSTNFE = @V_CDTPCRPICOSTNFE OUTPUT, @P_CDNATUBCPCSTNFE = @V_CDNATUBCPCSTNFE OUTPUT, @P_IDMOTIDESSTNFE = @V_IDMOTIDESSTNFE OUTPUT;
         END;

         SET @V_ALIQUTMP = 0;
         SET @V_SIMPLES  = 'N';

         SET @V_CDSIMPLESNACIONAL = NULL;
         SET @V_CDFAIXA = NULL;

         /*SIMPLES NACIONAL*/
         IF (@V_CDSITUCRT <> '3') BEGIN

            SET @V_FISOPEITEMAUX = SUBSTRING(@V_FISOPEITEM, 2, 3);

            EXEC CALCULA_ALIQUOTA_SN @P_EMPRESA, 
                                     @P_TIPOOPER, 
                                     @P_INIVALID, 
                                     @V_FISOPEITEMAUX, 
                                     @V_INCIDEN_CDIMPOSTONFE, 
                                     @V_VRSUBLIMITESN,
                                     'N',
                                     @V_RBT12,
                                     @V_RBA,
                                     @V_CDSIMPLESNACIONAL,
                                     @V_CDFAIXA,
                                     @V_VRALIQSIMPLES;

            IF (@V_CDFAIXA IS NOT NULL) OR ((@V_INCIDEN_CDIMPOSTONFE IN ('00', '31')) AND (@V_RBT12 >= 3600000)) BEGIN
               SET @V_ALIQUTMP = @V_VRALIQSIMPLES;
               SET @V_NRALIQTEMP   = 0;
               SET @V_PARDEDTMP    = 0;
               SET @v_PREDBCTMP    = 0;
               SET @V_TRATIMPST    = '0';
               SET @V_PBCSUBTRIB   = 0;
               SET @V_IDPMCBASECAL = 'N';
               SET @V_SIMPLES      = 'S';
            END;
         END;

         IF (@V_SIMPLES = 'N') BEGIN
            SET @V_CDSIMPLESNACIONAL = NULL;
            SET @V_CDFAIXA = NULL;
            IF @V_INCIDEN_IDUTMUNIORIG = 'D' BEGIN
               EXEC CONSULTA_ALIQUOTA @V_INCIDEN_CDIMPOTEMP, 'S', @P_EMPRESA, null, @P_INSCESTA, @V_PAISORIG,
                                      @V_ESTAORIG, @V_PAISDEST, @V_ESTADEST, @V_MUNIDEST, @V_LIQUIITEM, @P_INIVALID, @P_FILIAL, @P_LANCTONF,
                                      @V_CDGRUPOFISC, @P_TIPOOPER;
            END
            ELSE BEGIN
               EXEC CONSULTA_ALIQUOTA @V_INCIDEN_CDIMPOTEMP, 'S', @P_EMPRESA, null, @P_INSCESTA, @V_PAISORIG,
                                      @V_ESTAORIG, @V_PAISDEST, @V_ESTADEST, @V_MUNIORIG, @V_LIQUIITEM, @P_INIVALID, @P_FILIAL, @P_LANCTONF,
                                      @V_CDGRUPOFISC, @P_TIPOOPER;
            END;
            SELECT @V_NRALIQTEMP = MAX(NRALIQTEMP),  @V_PARDEDTMP = MAX(VRPARDEDTMP),
                   @V_PREDBCTMP  = MAX(VRPREDBCTMP), @V_ALIQUTMP  = MAX(VRALIQUTMP),
                   @V_PBCSUBTRIB = MAX(VRPBCSTTMP)
            FROM ALIQTEMP
            WHERE (NRALIQTEMP = @V_ALIQTEMP);
         END;

         IF (@V_ALIQUTMP IS NULL) BEGIN
            SET @V_ALIQUTMP = 0;
         END;

         SET @V_PRODUENCARGO = 0;

         SELECT @V_SOMAITEM = SUM(VRITEMENCA)
         FROM ITEMENCARGO IE, ENCARGO EN, BASECALC BC
         WHERE (IE.CDFILIAL   = @P_FILIAL) AND
               (IE.NRLANCTONF = @P_LANCTONF) AND
               (EN.CDENCARGO  = IE.CDENCARGO) AND
               (BC.CDENCARGO  = IE.CDENCARGO) AND
               (BC.CDIMPOSTO  = @V_INCIDEN_CDIMPOTEMP) AND
               (EN.IDENCARGO  = 'A');

         SELECT @V_DESCITEM = SUM(VRITEMENCA)
         FROM ITEMENCARGO IE, ENCARGO EN, BASECALC BC
         WHERE (IE.CDFILIAL   = @P_FILIAL) AND
               (IE.NRLANCTONF = @P_LANCTONF) AND
               (EN.CDENCARGO  = IE.CDENCARGO) AND
               (BC.CDENCARGO  = IE.CDENCARGO) AND
               (BC.CDIMPOSTO  = @V_INCIDEN_CDIMPOTEMP) AND
               (EN.IDENCARGO  = 'D');

         IF @V_SOMAITEM IS NULL BEGIN
            SET @V_SOMAITEM = 0;
         END;
         IF @V_DESCITEM IS NULL BEGIN
            SET @V_DESCITEM = 0;
         END;
         IF (@V_ALIQUTMP IS NULL) BEGIN
            SET @V_ALIQUTMP = 0;
         END;
         IF (@V_PREDBCTMP IS NULL) BEGIN
            SET @V_PREDBCTMP = 0;
         END;
         IF (@V_PARDEDTMP IS NULL) BEGIN
             SET @V_PARDEDTMP = 0;
         END;

         SET @V_PRODUENCARGO = @V_SOMAITEM - @V_DESCITEM;
         SET @V_TAXABASECALC = (100 - @V_PREDBCTMP)/100;
         SET @V_TAXAALIQUOTA = (@V_ALIQUTMP/100);
         SET @V_TAXABCSUBSTR = 1 + (@V_PBCSUBTRIB/100);
         SET @V_BASECALCIT   = (@V_LIQUIDO + @V_PRODUENCARGO) * @V_TAXABASECALC;

         SET @V_PERDBCALC    = 100 - @V_PREDBCTMP;

         IF @V_PBCSUBTRIB > 0 BEGIN
            SET @V_BASECALCIT = (@V_BASECALCIT * @V_TAXABCSUBSTR);
            SET @V_PREDBCTMP  = @V_PBCSUBTRIB;
            SET @V_PERDBCALC  = 0;
         END;

         SET @V_CONTIMPO     = @V_BASECALCIT;
         SET @V_IMPOSTOIT    = (@V_BASECALCIT * @V_TAXAALIQUOTA) - @V_PARDEDTMP;
         IF @V_BASECALCIT < 0 BEGIN
            SET @V_BASECALCIT = 0;
         END;
         SET @V_CONTABCALC = (@V_LIQUIDO + @V_PRODUENCARGO) - ((@V_LIQUIDO + @V_PRODUENCARGO) * @V_TAXABASECALC);
         SET @V_PERDBCALC  = 100 - @V_PREDBCTMP;
         IF @V_IMPOSTOIT < 0 BEGIN
            SET @V_IMPOSTOIT = 0;
         END;

         SET @V_ICMS = NULL;
         DECLARE C_ICMS CURSOR FOR
            SELECT CDIMPOSTO
              FROM IMPOSTONFE N, IMPOSTO I
             WHERE N.CDIMPOSTONFE = I.CDIMPOSTONFE
               AND N.CDIMPOSTONFE = '00'
               AND I.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
         OPEN C_ICMS;
         FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
         WHILE (@@FETCH_STATUS = 0) BEGIN
            SET @V_ICMS = 'S';
            FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
         END;
         CLOSE C_ICMS;
         DEALLOCATE C_ICMS;

         IF ((@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV')) AND (@V_ICMS = 'S') BEGIN
            INSERT INTO IMPOSNFTOT(CDFILIAL, NRLANCTONF, CDIMPOSTO, VRTOTIMPONF, VRTOTBCALCNF)
            VALUES (@P_FILIAL, @P_LANCTONF, @V_INCIDEN_CDIMPOTEMP, ROUND(ISNULL(@V_IMPOSTOIT,0),@V_NRDECITOTANF,2), ROUND(ISNULL(@V_BASECALCIT,0),@V_NRDECITOTANF,2));
         END
         ELSE BEGIN
            INSERT INTO IMPOSNFTOT(CDFILIAL, NRLANCTONF, CDIMPOSTO, VRTOTIMPONF, VRTOTBCALCNF)
            VALUES (@P_FILIAL, @P_LANCTONF, @V_INCIDEN_CDIMPOTEMP, ROUND(ISNULL(@V_IMPOSTOIT,0),@V_NRDECITOTANF), ROUND(ISNULL(@V_BASECALCIT,0),@V_NRDECITOTANF));
         END;

         IF (@V_INCIDEN_IDIMPORECUP = 'S') OR (@V_INCIDEN_IDIMPORECUP <> 'S' AND @V_ALIQUTMP <> 0) BEGIN
            IF (@V_INCIDEN_IDIMPORECUP = 'S') AND
               (@V_INCIDEN_CDFISCTEMP <> '1') BEGIN
               SET @V_BASECALCIT = 0;
               SET @V_ALIQUTMP   = 0;
               SET @V_IMPOSTOIT  = 0;
               SET @V_PREDBCTMP  = 0;
               SET @V_PARDEDTMP  = 0;
            END;

            SET @V_ICMS = NULL;
            DECLARE C_ICMS CURSOR FOR
               SELECT CDIMPOSTO
                 FROM IMPOSTONFE N, IMPOSTO I
                WHERE N.CDIMPOSTONFE = I.CDIMPOSTONFE
                  AND N.CDIMPOSTONFE = '00'
                  AND I.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
            OPEN C_ICMS;
            FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
            WHILE (@@FETCH_STATUS = 0) BEGIN
               SET @V_ICMS = 'S';
               FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
            END;
            CLOSE C_ICMS;
            DEALLOCATE C_ICMS;

            IF ((@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV')) AND (@V_ICMS = 'S') BEGIN
               INSERT INTO IMPOSTONF(
                  CDFILIAL, NRLANCTONF, CDIMPOSTO, NRIMPOSNF, VRCONTABILNF, VRPERREDBCNF,
                  VRBASECALCNF, VRALIQNF, VRPARDEDNF, VRIMPOSTONF, CDFISCALNF, IDTRIMPOSTNF,
                  CDSITUTRIBIMNFE, CDTPCREDPICONF, CDNATUBCALPCNF, IDMOTDESONERANF)
               VALUES(
                  @P_FILIAL, @P_LANCTONF, @V_INCIDEN_CDIMPOTEMP, @V_SEQUIMPOSTNF, ROUND(@V_CONTIMPO,2,2), @V_PREDBCTMP,
                  ROUND(@V_BASECALCIT,2,2), @V_ALIQUTMP, ROUND(@V_PARDEDTMP,2,2), ROUND(@V_IMPOSTOIT,2,2), @V_INCIDEN_CDFISCTEMP, @V_TRATIMPST,
                  @V_CDSITTRIBTMP, @V_CDTPCRPICOSTNFE, @V_CDTPCRPICOSTNFE, @V_IDMOTIDESSTNFE);
            END
            ELSE BEGIN
               INSERT INTO IMPOSTONF(
                  CDFILIAL, NRLANCTONF, CDIMPOSTO, NRIMPOSNF, VRCONTABILNF, VRPERREDBCNF,
                  VRBASECALCNF, VRALIQNF, VRPARDEDNF, VRIMPOSTONF, CDFISCALNF, IDTRIMPOSTNF,
                  CDSITUTRIBIMNFE, CDTPCREDPICONF, CDNATUBCALPCNF, IDMOTDESONERANF)
               VALUES(
                  @P_FILIAL, @P_LANCTONF, @V_INCIDEN_CDIMPOTEMP, @V_SEQUIMPOSTNF, ROUND(@V_CONTIMPO,2), @V_PREDBCTMP,
                  @V_BASECALCIT, @V_ALIQUTMP, @V_PARDEDTMP, @V_IMPOSTOIT, @V_INCIDEN_CDFISCTEMP, @V_TRATIMPST,
                  @V_CDSITTRIBTMP, @V_CDTPCRPICOSTNFE, @V_CDTPCRPICOSTNFE, @V_IDMOTIDESSTNFE);
            END;

            SET @V_SEQUIMPOSTNF = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(NUMERIC, @V_SEQUIMPOSTNF) + 1)),2);

            IF (@V_INCIDEN_IDIMPORECUP = 'S') AND
               (@V_PREDBCTMP > 0) AND (@V_INCIDEN_CDFISCTEMP = '1') BEGIN
               INSERT INTO IMPOSTONF(
                  CDFILIAL, NRLANCTONF, CDIMPOSTO, NRIMPOSNF, VRCONTABILNF, VRPERREDBCNF,
                  VRBASECALCNF, VRALIQNF, VRPARDEDNF, VRIMPOSTONF, CDFISCALNF, CDSITUTRIBIMNFE,
                  CDTPCREDPICONF, CDNATUBCALPCNF, IDMOTDESONERANF)
               VALUES(
                  @P_FILIAL, @P_LANCTONF, @V_INCIDEN_CDIMPOTEMP, @V_SEQUIMPOSTNF, @V_CONTABCALC, @V_PERDBCALC,
                  0, 0, @V_PARDEDTMP, 0, '2', @V_CDSITTRIBTMP,
                  @V_CDTPCRPICOSTNFE, @V_CDTPCRPICOSTNFE, @V_IDMOTIDESSTNFE);

               SET @V_SEQUIMPOSTNF = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(NUMERIC, @V_SEQUIMPOSTNF) + 1)),2);
            END;
         END;
         DELETE FROM ALIQTEMP
         WHERE NRALIQTEMP = @V_ALIQTEMP;
         FETCH NEXT FROM C_INCIDENCIA INTO @V_INCIDEN_CDIMPOTEMP, @V_INCIDEN_CDFISCTEMP,
                                           @V_INCIDEN_IDTRATIMPTMP, @V_INCIDEN_IDIMPORECUP,
                                           @V_INCIDEN_IDUTMUNIORIG, @V_INCIDEN_CDIMPOSTONFE;
      END;
      CLOSE C_INCIDENCIA;
      DEALLOCATE C_INCIDENCIA;

      SET @V_TOTIMPOCONT = 0;
      SET @V_TOTIMPOBRUT = 0;

      DECLARE C_IMPOSCONTAB CURSOR FOR
         SELECT VRTOTIMPONF, IDIMPORECUP, CDCCTBLPASS, CDCCTBLATIV,
                IDTRATIMPO,  CDFISCTEMP, IDTIPCONTAB
         FROM IMPOSNFTOT INF, IMPOSTO IP, INCITEMP IT
         WHERE CDFILIAL      = @P_FILIAL      AND
               NRLANCTONF    = @P_LANCTONF    AND
               IP.CDIMPOSTO  = INF.CDIMPOSTO AND
               IT.CDIMPOTEMP = IP.CDIMPOSTO  AND
               IT.NRINCITEMP = @V_INCITEMP    AND
               IP.IDPRODNOTA = 'C';
      OPEN C_IMPOSCONTAB;
      FETCH NEXT FROM C_IMPOSCONTAB INTO @V_IMPOSCNTTAB_VRTOTIMPONF, @V_IMPOSCNTTAB_IDIMPORECUP,
                                         @V_IMPOSCNTTAB_CDCCTBLPASS, @V_IMPOSCNTTAB_CDCCTBLATIV,
                                         @V_IMPOSCNTTAB_IDTRATIMPO , @V_IMPOSCNTTAB_CDFISCTEMP,
                                         @V_IMPOSCNTTAB_IDTIPCONTAB;
      WHILE (@@FETCH_STATUS = 0) BEGIN
         IF (@V_IMPOSCNTTAB_IDTRATIMPO = 'A') BEGIN
            IF @V_IMPOSCNTTAB_IDTIPCONTAB = 'D' BEGIN
               SET @V_TOTIMPOCONT = @V_TOTIMPOCONT + @V_IMPOSCNTTAB_VRTOTIMPONF;
            END;
            SET @V_TOTIMPOBRUT = @V_TOTIMPOBRUT + @V_IMPOSCNTTAB_VRTOTIMPONF;
         END
         ELSE IF (@V_IMPOSCNTTAB_IDTRATIMPO = 'D') BEGIN
            IF @V_IMPOSCNTTAB_IDTIPCONTAB = 'D' BEGIN
               SET @V_TOTIMPOCONT = @V_TOTIMPOCONT - @V_IMPOSCNTTAB_VRTOTIMPONF;
            END;
            SET @V_TOTIMPOBRUT = @V_TOTIMPOBRUT - @V_IMPOSCNTTAB_VRTOTIMPONF;
         END
         ELSE IF (@V_IMPOSCNTTAB_IDTRATIMPO = 'R') BEGIN
            IF (@V_IMPOSCNTTAB_IDIMPORECUP = 'S') BEGIN
               IF (@V_IMPOSCNTTAB_CDCCTBLATIV IS NULL) OR
                  (@V_IMPOSCNTTAB_CDFISCTEMP <> '1') AND (@V_IMPOSCNTTAB_IDTIPCONTAB = 'D') BEGIN
                  SET @V_TOTIMPOCONT = @V_TOTIMPOCONT - @V_IMPOSCNTTAB_VRTOTIMPONF;
               END;
            END
            ELSE BEGIN
               IF (@V_IMPOSCNTTAB_CDCCTBLATIV IS NULL) AND (@V_IMPOSCNTTAB_IDTIPCONTAB = 'D') BEGIN
                  SET @V_TOTIMPOCONT = @V_TOTIMPOCONT - @V_IMPOSCNTTAB_VRTOTIMPONF;
               END;
            END;
         END;
         FETCH NEXT FROM C_IMPOSCONTAB INTO @V_IMPOSCNTTAB_VRTOTIMPONF, @V_IMPOSCNTTAB_IDIMPORECUP,
                                            @V_IMPOSCNTTAB_CDCCTBLPASS, @V_IMPOSCNTTAB_CDCCTBLATIV,
                                            @V_IMPOSCNTTAB_IDTRATIMPO , @V_IMPOSCNTTAB_CDFISCTEMP,
                                            @V_IMPOSCNTTAB_IDTIPCONTAB;
      END;
      CLOSE C_IMPOSCONTAB;
      DEALLOCATE C_IMPOSCONTAB;

      IF (@V_TOTIMPOBRUT <> 0) OR (@V_TOTIMPOCONT <> 0) BEGIN
         DECLARE C_ITPRODUTO CURSOR FOR
            SELECT NRSEQITPROD, (VRTOTAITEM - VRDESCITEM) AS VRLIQUIDO
            FROM ITEMPRODUTO
            WHERE CDFILIAL   = @P_FILIAL AND
                  NRLANCTONF = @P_LANCTONF;
         OPEN C_ITPRODUTO;
         FETCH NEXT FROM C_ITPRODUTO INTO @V_ITPROD_NRSEQITPROD, @V_ITPROD_VRLIQUIDO;
         WHILE (@@FETCH_STATUS = 0) BEGIN
            IF (@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV') BEGIN
               UPDATE ITEMPRODUTO
               SET VRBRUTITEM = ROUND(VRBRUTITEM + ((@V_TOTIMPOBRUT / @V_LIQUIDO) * @V_ITPROD_VRLIQUIDO),2,2),
                   VRCONTITEM = ROUND(VRCONTITEM + ((@V_TOTIMPOCONT / @V_LIQUIDO) * @V_ITPROD_VRLIQUIDO),2,2)
               WHERE CDFILIAL    = @P_FILIAL   AND
                     NRLANCTONF  = @P_LANCTONF AND
                     NRSEQITPROD = @V_ITPROD_NRSEQITPROD;
            END
            ELSE BEGIN
               UPDATE ITEMPRODUTO
               SET VRBRUTITEM = ROUND(VRBRUTITEM + ((@V_TOTIMPOBRUT / @V_LIQUIDO) * @V_ITPROD_VRLIQUIDO),2),
                   VRCONTITEM = ROUND(VRCONTITEM + ((@V_TOTIMPOCONT / @V_LIQUIDO) * @V_ITPROD_VRLIQUIDO),2)
               WHERE CDFILIAL    = @P_FILIAL   AND
                     NRLANCTONF  = @P_LANCTONF AND
                     NRSEQITPROD = @V_ITPROD_NRSEQITPROD;
            END;
            FETCH NEXT FROM C_ITPRODUTO INTO @V_ITPROD_NRSEQITPROD, @V_ITPROD_VRLIQUIDO;
         END;
         CLOSE C_ITPRODUTO;
         DEALLOCATE C_ITPRODUTO;
      END;

      DELETE FROM INCITEMP
      WHERE NRINCITEMP = @V_INCITEMP;

      SELECT @V_BCICMSRET = SUM(ISNULL(VRBCICMSSTRETIDO,0)), @V_ICMSRET = SUM(ISNULL(VRICMSSTRETIDO,0))
        FROM ITEMPROIMPOS
       WHERE CDFILIAL = @P_FILIAL
         AND NRLANCTONF = @P_LANCTONF;

      IF @V_ICMSRET <> 0 BEGIN
         SELECT @V_EXISTDSDADOSADIC = COUNT(*)
           FROM DADOSADIC
          WHERE CDFILIAL = @P_FILIAL
            AND NRLANCTONF = @P_LANCTONF
            AND DSDADOADIC LIKE 'ICMS retido anteriormente por substituio tributria: BC %';

         IF @V_EXISTDSDADOSADIC = 0 BEGIN

            INSERT INTO DADOSADIC(CDFILIAL, NRLANCTONF, NRDADOADIC, DSDADOADIC)
                           VALUES(@P_FILIAL, @P_LANCTONF, @V_DADOADIC, 'ICMS retido anteriormente por substituio tributria: BC '+CONVERT(VARCHAR,@V_BCICMSSTRETIDO)+ ' Valor '+ CONVERT(VARCHAR,@V_ICMSRET));

            SET @V_DADOADIC = RIGHT(REPLICATE('0',3) + RTRIM(CONVERT(VARCHAR, CONVERT(NUMERIC, @V_DADOADIC) + 1)),3);
         END
         ELSE BEGIN
            UPDATE DADOSADIC
               SET DSDADOADIC = 'ICMS retido anteriormente por substituio tributria: BC '+CONVERT(VARCHAR,@V_BCICMSRET)+ ' Valor '+ CONVERT(VARCHAR,@V_ICMSRET)
             WHERE CDFILIAL = @P_FILIAL
               AND NRLANCTONF = @P_LANCTONF
               AND DSDADOADIC LIKE 'ICMS retido anteriormente por substituio tributria: BC %';
         END;
      END;
      DECLARE C_ITEMPRODUTO_DIFAL CURSOR FOR SELECT NRSEQITPROD
                                               FROM ITEMPRODUTO
                                              WHERE CDFILIAL = @P_FILIAL
                                                AND NRLANCTONF = @P_LANCTONF;
      OPEN C_ITEMPRODUTO_DIFAL;
      FETCH NEXT FROM C_ITEMPRODUTO_DIFAL INTO @V_ITEMPRODUTO_DIFAL_NRSEQITPROD;
      WHILE (@@FETCH_STATUS = 0) BEGIN
         EXEC GERA_ICMS_INTERESTADUAL @P_FILIAL, @P_LANCTONF, @V_ITEMPRODUTO_DIFAL_NRSEQITPROD, @P_INIVALID;
         FETCH NEXT FROM C_ITEMPRODUTO_DIFAL INTO @V_ITEMPRODUTO_DIFAL_NRSEQITPROD;
      END;
      CLOSE C_ITEMPRODUTO_DIFAL;
      DEALLOCATE C_ITEMPRODUTO_DIFAL;

      SELECT @V_DADOADIC = MAX(NRDADOADIC)
        FROM DADOSADIC
       WHERE (CDFILIAL = @P_FILIAL) 
         AND (NRLANCTONF = @P_LANCTONF);

      IF (@V_DADOADIC IS NULL) BEGIN
         SET @V_DADOADIC = '001';
      END
      ELSE BEGIN
         SET @V_DADOADIC = RIGHT(REPLICATE('0',3) + RTRIM(CONVERT(VARCHAR, CONVERT(NUMERIC, @V_DADOADIC) + 1)),3);
      END;

      --FIM DA TOTALIZAO DOS IMPOSTOS

   --NOTA FISCAL DE MOVIMENTAO - 07
   --NOTAS COM DOCUMENTO DE ORIGEM
   END
   ELSE IF @P_TIPOOPER IN ('07','10') OR (@V_IDOPERDEVONF = 'S') OR (@V_ESTORNOCANC = 'S')BEGIN
      DELETE FROM ITEMPROIMPOS
      WHERE CDFILIAL   = @P_FILIAL AND
            NRLANCTONF = @P_LANCTONF;

      DELETE FROM ITEMPROIMPOSORIG
      WHERE CDFILIAL   = @P_FILIAL AND
            NRLANCTONF = @P_LANCTONF;

      SET @V_VRTOTALIPI    = 0;
      SET @V_VRTOTALICMSST = 0;
      SET @V_CDENQLEGALIPI = NULL;
      SET @V_CDCEST        = NULL;

      SELECT @V_IDGERICMSTDESPA  = ISNULL(MAX(IDGERICMSTDESPA), 'N'),
             @V_CDENCARGOICMST   = MAX(CDENCARGOICMST),
             @V_IDPEINFICMSTDEME = ISNULL(MAX(IDPEINFICMSTDEME), 'N'),
             @V_IDGERIPIDESPA    = ISNULL(MAX(IDGERIPIDESPA), 'N')
        FROM TIPOOPERAC
       WHERE IDENTRSAIDOP = 'S'
         AND CDTIPOOPER   = @P_TIPOOPER;

      SELECT @V_IDUTCTRLFISSAID = MAX(IDUTCTRLFISSAID)
        FROM PARAMGERAL;

      SELECT @V_IDUTCTRLFISFIL = MAX(IDUTCTRLFISSAID)
        FROM PARAMFILIAL
       WHERE CDFILIAL = @V_CDFILIEMIT;

      IF @V_IDUTCTRLFISSAID = 'S' BEGIN
         SET @V_IDUTCTRLFIS = 'S';
      END
      ELSE BEGIN
         IF @V_IDUTCTRLFISFIL = 'S' BEGIN
            SET @V_IDUTCTRLFIS = 'S';
         END
         ELSE BEGIN
            SET @V_IDUTCTRLFIS = 'N';
         END;
      END;

   	DECLARE C_ITEMPROD CURSOR FOR
         SELECT CDFILIAL    , NRLANCTONF,   NRSEQITPROD , I.CDPRODUTO,
        	       CDPRODEMIS  , DSPRODEMIS,   IDATUVRESTOQ, QTITEMPROD,
	             VRUNITITEM  , VRDESCITEM,   VRTOTAITEM  , VRCONTITEM,
	             IDCONFORITEM, CDFISOPEITEM, CDSUFXCFOPPR, CDSITUTRIBPR,
	             IDERROSITEM , IDAVISOSITEM, VRBRUTITEM, P.CDARVPROD,
                NRLOTEESTQ, NRSUBLOTE, IDORIGEMPROD
         FROM ITEMPRODUTO I, PRODUTO P
         WHERE CDFILIAL   = @P_FILIAL AND
               NRLANCTONF = @P_LANCTONF AND
               I.CDPRODUTO = P.CDPRODUTO;

      OPEN C_ITEMPROD;
      FETCH NEXT FROM C_ITEMPROD INTO @V_ITEMPRODU_CDFILIAL    , @V_ITEMPRODU_NRLANCTONF,
                                      @V_ITEMPRODU_NRSEQITPROD , @V_ITEMPRODU_CDPRODUTO,
                                      @V_ITEMPRODU_CDPRODEMIS  , @V_ITEMPRODU_DSPRODEMIS,
                                      @V_ITEMPRODU_IDATUVRESTOQ, @V_ITEMPRODU_QTITEMPROD,
                                      @V_ITEMPRODU_VRUNITITEM  , @V_ITEMPRODU_VRDESCITEM,
                                      @V_ITEMPRODU_VRTOTAITEM  , @V_ITEMPRODU_VRCONTITEM,
                                      @V_ITEMPRODU_IDCONFORITEM, @V_ITEMPRODU_CDFISOPEITEM,
                                      @V_ITEMPRODU_CDSUFXCFOPPR, @V_ITEMPRODU_CDSITUTRIBPR,
                                      @V_ITEMPRODU_IDERROSITEM , @V_ITEMPRODU_IDAVISOSITEM,
                                      @V_ITEMPRODU_VRBRUTITEM, @V_ITEMPRODU_CDARVPROD,
                                      @V_ITEMPRODU_NRLOTEESTQ, @V_ITEMPRODU_NRSUBLOTE,
                                      @V_ITEMPRODU_IDORIGEMPROD;

      WHILE (@@FETCH_STATUS = 0) BEGIN

         SET @V_LIQUIITEM = @V_ITEMPRODU_VRTOTAITEM - @V_ITEMPRODU_VRDESCITEM;

         EXEC CONSULTA_CST 'S', @P_EMPRESA, @V_ITEMPRODU_CDARVPROD, @P_INSCESTA, @P_TIPOOPER, @P_FILIAL, @P_LANCTONF, @V_CDGRUPOFISC, @V_IDINTEREST, @V_IDINTERNA, NULL, @V_ITEMPRODU_IDORIGEMPROD;

         SELECT @V_SITUTRIBPR = MAX(CDSITTRIBTMP)
         FROM CSTTEMP
         WHERE (NRCSTTEMP = @V_CSTTEMP);

         IF (@V_IDOPERDEVONF <> 'S') BEGIN
            DECLARE C_CSTTEMP CURSOR FOR
               SELECT DSMENSCSTTMP
               FROM CSTTEMP
               WHERE (NRCSTTEMP = @V_CSTTEMP) AND
                     (NOT (DSMENSCSTTMP IS NULL)) AND
                     (NOT EXISTS (SELECT MAX(DSDADOADIC)
                                    FROM DADOSADIC
                                   WHERE (CDFILIAL   = @P_FILIAL)   AND
                                         (NRLANCTONF = @P_LANCTONF) AND
                                         (DSDADOADIC LIKE CSTTEMP.DSMENSCSTTMP + '%')));
            OPEN C_CSTTEMP;
            FETCH NEXT FROM C_CSTTEMP INTO @V_CSTTMP_DSMENSCSTTMP;
            WHILE (@@FETCH_STATUS = 0) BEGIN
               IF NOT (@V_CSTTMP_DSMENSCSTTMP IS NULL) BEGIN
                  INSERT INTO DADOSADIC(CDFILIAL, NRLANCTONF, NRDADOADIC, DSDADOADIC)
                  VALUES(@P_FILIAL, @P_LANCTONF, @V_DADOADIC, @V_CSTTMP_DSMENSCSTTMP);
                  SET @V_DADOADIC = RIGHT(REPLICATE('0',3) + RTRIM(CONVERT(VARCHAR, CONVERT(NUMERIC, @V_DADOADIC) + 1)),3);
               END;
               FETCH NEXT FROM C_CSTTEMP INTO @V_CSTTMP_DSMENSCSTTMP;
            END;
            CLOSE C_CSTTEMP;
            DEALLOCATE C_CSTTEMP;
         END;

         EXEC CONSULTA_CFOP 'S', @P_EMPRESA, @V_ITEMPRODU_CDARVPROD, @P_INSCESTA, @P_TIPOOPER, @V_PAISORIG,
                            @V_ESTAORIG, @V_PAISCFOP, @V_ESTACFOP, @P_FILIAL, @P_LANCTONF, @V_CDGRUPOFISC, @P_INIVALID, @V_ITEMPRODU_IDORIGEMPROD;

         DECLARE C_CFOPTEMP CURSOR FOR
            SELECT DSMENSCFOTMP
            FROM CFOPTEMP
            WHERE (NRCFOPTEMP = @V_CFOPTEMP) AND
                  (NOT (DSMENSCFOTMP IS NULL)) AND
                  (NOT EXISTS (SELECT MAX(DSDADOADIC)
                                 FROM DADOSADIC
                                WHERE (CDFILIAL = @P_FILIAL)     AND
                                      (NRLANCTONF = @P_LANCTONF) AND
                                      (DSDADOADIC LIKE CFOPTEMP.DSMENSCFOTMP + '%')));
         OPEN C_CFOPTEMP;
         FETCH NEXT FROM C_CFOPTEMP INTO @V_CFOPTMP_DSMENSCFOTMP;
         WHILE (@@FETCH_STATUS = 0) BEGIN
            IF NOT(@V_CFOPTMP_DSMENSCFOTMP IS NULL) BEGIN
               INSERT INTO DADOSADIC(CDFILIAL, NRLANCTONF, NRDADOADIC, DSDADOADIC)
               VALUES(@P_FILIAL, @P_LANCTONF, @V_DADOADIC, @V_CFOPTMP_DSMENSCFOTMP);
               SET @V_DADOADIC = RIGHT(REPLICATE('0',3) + RTRIM(CONVERT(VARCHAR, CONVERT(NUMERIC, @V_DADOADIC) + 1)),3);
            END;
            FETCH NEXT FROM C_CFOPTEMP INTO @V_CFOPTMP_DSMENSCFOTMP;
         END;
         CLOSE C_CFOPTEMP;
         DEALLOCATE C_CFOPTEMP;

         UPDATE NOTAFISCAL
         SET DSCDFISOPENF = (SELECT MAX(DSCFOPTMP)
                               FROM CFOPTEMP
                               WHERE NRCFOPTEMP = @V_CFOPTEMP)
         WHERE CDFILIAL   = @P_FILIAL   AND
               NRLANCTONF = @P_LANCTONF AND
               DSCDFISOPENF IS NULL;

         SELECT @V_FISOPEITEM = MAX(CDFISOPETMP), @V_SUFXCFOPPR = MAX(CDSUFCFOPTMP), @V_DSCDFISOPEIT = MAX(DSCFOPTMP)
         FROM CFOPTEMP
         WHERE NRCFOPTEMP = @V_CFOPTEMP;

         EXEC CONSULTA_CSOSN 'S', @P_EMPRESA, @V_ITEMPRODU_CDARVPROD, @P_INSCESTA, @P_TIPOOPER,@P_FILIAL, @P_LANCTONF, @V_CDGRUPOFISC, @V_IDINTEREST, @P_CDFISCOPERSN = @V_CDFISCOPERSN OUTPUT;

         UPDATE ITEMPRODUTO
         SET CDFISOPEITEM = @V_FISOPEITEM,
             CDSUFXCFOPPR = @V_SUFXCFOPPR,
             CDSITUTRIBPR  = ISNULL(@V_SITUTRIBPR,CDSITUTRIBPR) ,
             DSCDFISOPEIT = @V_DSCDFISOPEIT,
             CDFISCOPERSN = @V_CDFISCOPERSN
         WHERE CDFILIAL = @P_FILIAL     AND
               NRLANCTONF = @P_LANCTONF AND
               NRSEQITPROD = @V_ITEMPRODU_NRSEQITPROD;

         IF @V_IDOPERDEVONF = 'S' BEGIN

            DECLARE C_ITEMNOTAFISC CURSOR FOR
               SELECT CDFILIALIT, NRLANCTONFIT
               FROM ITEMNOTAFISC
               WHERE CDFILIAL   = @P_FILIAL AND
                     NRLANCTONF = @P_LANCTONF;

            OPEN C_ITEMNOTAFISC;
            FETCH NEXT FROM C_ITEMNOTAFISC INTO @V_CDFILIALIT, @V_NRLANCTONFIT;
            WHILE (@@FETCH_STATUS = 0) BEGIN

               IF @V_IDDEVOLIST = 'S' BEGIN /*SE A NOTA POSSUI VARIOS DOCUMENTOS DE ORIGEM*/
                  SELECT @V_QTITEMORIG = SUM(I.QTITEMPROD),
                         @V_VRBRUTO    = ISNULL(MAX(VRBRUTITEM),0),
                         @V_VRCONTAB   = ISNULL(MAX(VRCONTITEM),0)
                  FROM ITEMPRODUTO I
                  WHERE CDFILIAL   = @V_CDFILIALIT                                                           AND
                        NRLANCTONF = @V_NRLANCTONFIT                                                         AND
                        CDPRODUTO  = @V_ITEMPRODU_CDPRODUTO                                                  AND
                        ROUND(VRUNITITEM, @V_NRDECITOTANF) = ROUND(@V_ITEMPRODU_VRUNITITEM, @V_NRDECITOTANF) AND
                        (ISNULL(NRLOTEESTQ, ' ') = (ISNULL(@V_ITEMPRODU_NRLOTEESTQ, ' ')))                   AND
                        (ISNULL(NRSUBLOTE , ' ') = (ISNULL(@V_ITEMPRODU_NRSUBLOTE , ' ')));

                  IF @V_QTITEMORIG = 0 BEGIN
                     SET @V_QTITEMORIG = 1;
                  END;

                  SET  @V_VRFATOCONV = ISNULL(@V_ITEMPRODU_QTITEMPROD,1) / @V_QTITEMORIG;

                  IF @V_CDINTEGRACAO IS NOT NULL BEGIN
                     IF (@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV') BEGIN
                        UPDATE ITEMPRODUTO
                        SET VRCONTITEM = ROUND((@V_VRCONTAB * @V_VRFATOCONV),2,2),
                            VRBRUTITEM = ROUND((@V_VRBRUTO * @V_VRFATOCONV),2,2)
                        WHERE CDFILIAL    = @P_FILIAL                                                              AND
                              NRLANCTONF  = @P_LANCTONF                                                            AND
                              CDPRODUTO = @V_ITEMPRODU_CDPRODUTO                                                   AND
                              ROUND(VRUNITITEM, @V_NRDECITOTANF) = ROUND(@V_ITEMPRODU_VRUNITITEM, @V_NRDECITOTANF) AND
                              (ISNULL(NRLOTEESTQ, ' ')  = (ISNULL(@V_ITEMPRODU_NRLOTEESTQ, ' ')))                  AND
                              (ISNULL(NRSUBLOTE , ' ')  = (ISNULL(@V_ITEMPRODU_NRSUBLOTE , ' ')));
                     END
                     ELSE BEGIN
                        UPDATE ITEMPRODUTO
                        SET VRCONTITEM = ROUND(@V_VRCONTAB * @V_VRFATOCONV,2),
                            VRBRUTITEM = ROUND(@V_VRBRUTO * @V_VRFATOCONV,2)
                        WHERE CDFILIAL    = @P_FILIAL   AND
                              NRLANCTONF  = @P_LANCTONF AND
                              CDPRODUTO = @V_ITEMPRODU_CDPRODUTO AND
                              ROUND(VRUNITITEM, @V_NRDECITOTANF) = ROUND(@V_ITEMPRODU_VRUNITITEM, @V_NRDECITOTANF) AND
                              (ISNULL(NRLOTEESTQ, ' ')  = (ISNULL(@V_ITEMPRODU_NRLOTEESTQ, ' '))) AND
                              (ISNULL(NRSUBLOTE , ' ')  = (ISNULL(@V_ITEMPRODU_NRSUBLOTE , ' ')));
                     END;
                  END;

                  /*IMPOSTOS POR ITEM DA NOTA DE ORIGEM*/
                  DECLARE C_ITEMPRODUIMPOS CURSOR FOR
                     (SELECT VRPERREDBCIT, NRITPROIMPOS, IT.CDIMPOSTO, CDFISCALIT, VRALIQITEM, VRPARDEDIT, SUM(VRCONTITIMP) AS VRCONTITIMP,
                             SUM(VRBASECALCIT) AS VRBASECALCIT, SUM(VRIMPOSTOIT) AS VRIMPOSTOIT, CDSITUTRIBITNFE AS CDSITUTRIBNFE,
                             IDMODBCITNFE AS IDMODBCNFE, IDMODBCSTITNFE AS IDMODBCSTNFE, CDTPCREDPICOITE, CDNATUBCALPCIT, IDMOTDESONERAIT,
                             IDTRIMPSTII, ISNULL(IDDIFALIQCUSPRI, 'N') AS IDDIFALIQCUSPRI, IM.CDIMPOSTONFE, IT.CDENQLEGALIPI, IT.CDCEST,
                             ISNULL(I.IDUTVRPAUTAPROD, 'N') AS IDUTVRPAUTAPROD, ISNULL(I.VRPAUTAMINPROD, 1) AS VRPAUTAMINPROD, I.QTITEMPROD, IM.IDUTVRPAUTA
                      FROM ITEMPROIMPOS IT, ITEMPRODUTO I, IMPOSTO IM
                      WHERE IT.CDFILIAL   = @V_CDFILIALIT                                                          AND
                            IT.NRLANCTONF = @V_NRLANCTONFIT                                                        AND
                            I.CDFILIAL    = @V_CDFILIALIT                                                          AND
                            I.NRLANCTONF  = @V_NRLANCTONFIT                                                        AND
                            IT.NRSEQITPROD = I.NRSEQITPROD                                                         AND
                            IT.CDIMPOSTO   = IM.CDIMPOSTO                                                          AND
                            I.CDPRODUTO = @V_ITEMPRODU_CDPRODUTO                                                   AND
                            IT.NRITPROIMPOS = '1'                                                                  AND
                            ROUND(I.VRUNITITEM, @V_NRDECITOTANF) = ROUND(@V_ITEMPRODU_VRUNITITEM, @V_NRDECITOTANF) AND
                            (ISNULL(I.NRLOTEESTQ, ' ')  = (ISNULL(@V_ITEMPRODU_NRLOTEESTQ, ' ')))                  AND
                            (ISNULL(I.NRSUBLOTE,  ' ')  = (ISNULL(@V_ITEMPRODU_NRSUBLOTE , ' ')))
                      GROUP BY VRPERREDBCIT,   NRITPROIMPOS,    IT.CDIMPOSTO,    CDFISCALIT,     VRALIQITEM,
                               VRPARDEDIT,     CDSITUTRIBITNFE, IDMODBCITNFE, IDMODBCSTITNFE, CDTPCREDPICOITE,
                               CDNATUBCALPCIT, IDMOTDESONERAIT, IDTRIMPSTII,  IDDIFALIQCUSPRI, IM.CDIMPOSTONFE,
                               IT.CDENQLEGALIPI, IT.CDCEST, ISNULL(I.IDUTVRPAUTAPROD, 'N'), ISNULL(I.VRPAUTAMINPROD, 1), 
                               I.QTITEMPROD, IM.IDUTVRPAUTA);

                  OPEN C_ITEMPRODUIMPOS;
                  FETCH NEXT FROM C_ITEMPRODUIMPOS INTO @C_ITEMPROIMPOS_VRPERREDBCIT,    @C_ITEMPROIMPOS_NRITPROIMPOS,    @C_ITEMPROIMPOS_CDIMPOSTO,
                                                        @C_ITEMPROIMPOS_CDFISCALIT,      @C_ITEMPROIMPOS_VRALIQITEM,      @C_ITEMPROIMPOS_VRPARDEDIT,
                                                        @C_ITEMPROIMPOS_VRCONTITIMP,     @C_ITEMPROIMPOS_VRBASECALCIT,    @C_ITEMPROIMPOS_VRIMPOSTOIT,
                                                        @C_ITEMPROIMPOS_CDSITUTRIBNFE,   @C_ITEMPROIMPOS_IDMODBCNFE,      @C_ITEMPROIMPOS_IDMODBCSTNFE,
                                                        @C_ITEMPROIMPOS_CDTPCREDPICOITE, @C_ITEMPROIMPOS_CDNATUBCALPCIT,  @C_ITEMPROIMPOS_IDMOTDESONERAIT,
                                                        @C_ITEMPROIMPOS_IDTRIMPSTII,     @C_ITEMPROIMPOS_IDDIFALIQCUSPRI, @C_ITEMPROIMPOS_CDIMPOSTONFE,
                                                        @C_ITEMPROIMPOS_CDENQLEGALIPI,   @C_ITEMPROIMPOS_CDCEST,          @C_ITEMPROIMPOS_IDUTVRPAUTAPROD,
                                                        @C_ITEMPROIMPOS_VRPAUTAMINPROD,  @C_ITEMPROIMPOS_QTITEMPROD,      @C_ITEMPROIMPOS_IDUTVRPAUTA;
                  WHILE (@@FETCH_STATUS = 0) BEGIN

                     EXEC CONSULTA_INCIDENCIA 'S', @P_EMPRESA, @V_ITEMPRODU_CDARVPROD, @P_INSCESTA, @P_TIPOOPER, @P_FILIAL, @P_LANCTONF, @V_CDGRUPOFISC,
                                               @V_IDINTEREST, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, @V_ITEMPRODU_IDORIGEMPROD;

                     SELECT @V_CDFISCTEMP = MAX(CDFISCTEMP),
                            @V_CDDETALHEPRODTEMP = MAX(CDDETALHEPROD),
                            @V_CDENQLEGALIPI = MAX(CDENQLEGALIPI),
                            @V_CDCEST = MAX(CDCEST)
                       FROM INCITEMP IT, IMPOSTO IP
                      WHERE IT.NRINCITEMP = @V_INCITEMP
                        AND IP.CDIMPOSTO  = IT.CDIMPOTEMP
                        AND IP.IDPRODNOTA = 'P'
                        AND IT.CDIMPOTEMP = @C_ITEMPROIMPOS_CDIMPOSTO;

                     IF (@C_ITEMPROIMPOS_VRPERREDBCIT > 0.00) AND
                        (@C_ITEMPROIMPOS_NRITPROIMPOS = '2')  BEGIN
                        SET @V_CDFISCTEMP = '2';
                     END
                     ELSE BEGIN
                        IF (@V_CDFISCTEMP IS NULL) BEGIN
                            SET @V_CDFISCTEMP = @C_ITEMPROIMPOS_CDFISCALIT;
                        END;
                     END;

                     IF @V_CDENQLEGALIPI IS NULL BEGIN
                        SET @V_CDENQLEGALIPI = @C_ITEMPROIMPOS_CDENQLEGALIPI;
                     END;

                     IF @V_CDCEST IS NULL BEGIN
                        SET @V_CDCEST = @C_ITEMPROIMPOS_CDCEST;
                     END;

                     DELETE FROM INCITEMP
                      WHERE NRINCITEMP = @V_INCITEMP;

                     /*VERIFICA CST POR IMPOSTO*/
                     SET @V_IMPOICMS = NULL;
                     SET @V_CDGRUPOFISCAUX = NULL;

                     SELECT @V_CDGRUPOFISCAUX = MAX(G.CDGRUPOFISC)
                       FROM GRUPOFISCIMPFIL G,
                            (SELECT CDFILIEMIT AS CDFILIAL
                               FROM NOTAFISCAL
                              WHERE CDFILIAL = @P_FILIAL
                                AND NRLANCTONF = @P_LANCTONF) F
                      WHERE G.CDFILIAL = F.CDFILIAL
                        AND NOT G.CDGRUPOFISC IS NULL
                        AND G.CDIMPOSTO = @C_ITEMPROIMPOS_CDIMPOSTO;

                     IF @V_IDORIGDESTNF = 'C' BEGIN
                        SELECT @V_CDGRUPOFISCAUX = ISNULL(MAX(G.CDGRUPOFISC), @V_CDGRUPOFISCAUX)
                          FROM GRFISIMPIECLIE G,
                               (SELECT CDCLIENTE
                                  FROM NOTAFISCAL
                                 WHERE CDFILIAL = @P_FILIAL
                                   AND NRLANCTONF = @P_LANCTONF) N
                         WHERE G.CDCLIENTE = N.CDCLIENTE
                           AND G.CDEMPRESA = @P_EMPRESA
                           AND G.CDINSCESTA = @P_INSCESTA
                           AND NOT G.CDGRUPOFISC IS NULL
                           AND G.CDIMPOSTO = @C_ITEMPROIMPOS_CDIMPOSTO;
                     END
                     ELSE BEGIN
                        SELECT @V_CDGRUPOFISCAUX = ISNULL(MAX(G.CDGRUPOFISC), @V_CDGRUPOFISCAUX)
                          FROM GRFISIMPIEFORN G,
                              (SELECT CDFORNECED
                                 FROM NOTAFISCAL
                                WHERE CDFILIAL = @P_FILIAL
                                  AND NRLANCTONF = @P_LANCTONF) N
                         WHERE G.CDFORNECED = N.CDFORNECED
                           AND G.CDEMPRESA = @P_EMPRESA
                           AND G.CDINSCESTA = @P_INSCESTA
                           AND NOT G.CDGRUPOFISC IS NULL
                           AND G.CDIMPOSTO = @C_ITEMPROIMPOS_CDIMPOSTO;
                     END;

                     IF @V_CDGRUPOFISCAUX IS NULL BEGIN
                        EXEC CONSULTA_CST_NFE 'S', @P_EMPRESA, @V_ITEMPRODU_CDARVPROD, @P_INSCESTA, @P_TIPOOPER, @V_CDGRUPOFISC, @C_ITEMPROIMPOS_CDIMPOSTO, @V_IDINTEREST, @V_IDINTERNA, @P_FILIAL, @P_LANCTONF, '', @V_ITEMPRODU_IDORIGEMPROD, @P_CDSITTRIBTMP = @V_CDSITTRIBTMP OUTPUT, @P_IDMODBCNFE = @V_IDMODBCNFE OUTPUT, @P_IDMODBCSTNFE = @V_IDMODBCSTNFE OUTPUT, @P_CDTPCRPICOSTNFE = @V_CDTPCRPICOSTNFE OUTPUT, @P_CDNATUBCPCSTNFE = @V_CDNATUBCPCSTNFE OUTPUT, @P_IDMOTIDESSTNFE = @V_IDMOTIDESSTNFE OUTPUT;
                     END
                     ELSE BEGIN
                        EXEC CONSULTA_CST_NFE 'S', @P_EMPRESA, @V_ITEMPRODU_CDARVPROD, @P_INSCESTA, @P_TIPOOPER, @V_CDGRUPOFISCAUX, @C_ITEMPROIMPOS_CDIMPOSTO, @V_IDINTEREST, @V_IDINTERNA, @P_FILIAL, @P_LANCTONF, '', @V_ITEMPRODU_IDORIGEMPROD, @P_CDSITTRIBTMP = @V_CDSITTRIBTMP OUTPUT, @P_IDMODBCNFE = @V_IDMODBCNFE OUTPUT, @P_IDMODBCSTNFE = @V_IDMODBCSTNFE OUTPUT, @P_CDTPCRPICOSTNFE = @V_CDTPCRPICOSTNFE OUTPUT, @P_CDNATUBCPCSTNFE = @V_CDNATUBCPCSTNFE OUTPUT, @P_IDMOTIDESSTNFE = @V_IDMOTIDESSTNFE OUTPUT;
                     END;

                     IF (@V_CDSITTRIBTMP IS NULL) BEGIN
                        SET @V_CDSITUTRIBNFE = @C_ITEMPROIMPOS_CDSITUTRIBNFE;
                     END
                     ELSE BEGIN
                        SET @V_CDSITUTRIBNFE = @V_CDSITTRIBTMP;
                     END;

                     IF (@V_IDMODBCNFE IS NULL) BEGIN
                        SET @V_IDMODBCNFEIT = @C_ITEMPROIMPOS_IDMODBCNFE;
                     END
                     ELSE BEGIN
                        SET @V_IDMODBCNFEIT = @V_IDMODBCNFE;
                     END;

                     IF (@V_IDMODBCSTNFE IS NULL) BEGIN
                        SET @V_IDMODBCSTNFEIT = @C_ITEMPROIMPOS_IDMODBCSTNFE;
                     END
                     ELSE BEGIN
                        SET @V_IDMODBCSTNFEIT = @V_IDMODBCSTNFE;
                     END;

                     IF (@C_ITEMPROIMPOS_CDTPCREDPICOITE IS NULL) BEGIN
                        SET @V_CDTPCRPICOSTNFEIT = @V_CDTPCRPICOSTNFE;
                     END
                     ELSE BEGIN
                        SET @V_CDTPCRPICOSTNFEIT = @C_ITEMPROIMPOS_CDTPCREDPICOITE;
                     END;

                     IF (@C_ITEMPROIMPOS_CDNATUBCALPCIT IS NULL) BEGIN
                        SET @V_CDNATUBCPCSTNFEIT = @V_CDNATUBCPCSTNFE;
                     END
                     ELSE BEGIN
                        SET @V_CDNATUBCPCSTNFEIT = @C_ITEMPROIMPOS_CDNATUBCALPCIT;
                     END;

                     IF (@V_IDMOTIDESSTNFE IS NULL) BEGIN
                        SET @V_IDMOTIDESSTNFE = @C_ITEMPROIMPOS_IDMOTDESONERAIT;
                     END
                     ELSE BEGIN
                        SET @V_IDMOTIDESSTNFE = @V_IDMOTIDESSTNFE;
                     END;

                     SELECT @V_IDUTMUNIORIG = ISNULL(MAX(IDUTMUNIORIG),'N')
                       FROM IMPOSTO
                      WHERE CDIMPOSTO = @C_ITEMPROIMPOS_CDIMPOSTO;

                     IF (@C_ITEMPROIMPOS_IDUTVRPAUTAPROD = 'S') AND (@C_ITEMPROIMPOS_IDUTVRPAUTA = 'S') BEGIN
                        SET @V_LIQUIITEM = (@V_ITEMPRODU_QTITEMPROD * @C_ITEMPROIMPOS_VRPAUTAMINPROD) / @C_ITEMPROIMPOS_QTITEMPROD;
                     END ELSE BEGIN
                        SET @V_LIQUIITEM = @V_ITEMPRODU_VRTOTAITEM - @V_ITEMPRODU_VRDESCITEM;
                     END;

                     IF ((@V_IDUTMUNIORIG = 'O') OR (@V_IDUTMUNIORIG = 'N')) BEGIN
                        EXEC CONSULTA_ALIQUOTA @C_ITEMPROIMPOS_CDIMPOSTO, 'S', @P_EMPRESA, @V_ITEMPRODU_CDARVPROD, @P_INSCESTA, @V_PAISORIG,
                                               @V_ESTAORIG, @V_PAISDEST, @V_ESTADEST, @V_MUNIORIG, @V_LIQUIITEM, @P_INIVALID, @P_FILIAL, @P_LANCTONF, @V_CDGRUPOFISC, @P_TIPOOPER,
                                               NULL, NULL, NULL, NULL, NULL, NULL, @V_ITEMPRODU_IDORIGEMPROD;
                     END
                     ELSE BEGIN
                        EXEC CONSULTA_ALIQUOTA @C_ITEMPROIMPOS_CDIMPOSTO, 'S', @P_EMPRESA, @V_ITEMPRODU_CDARVPROD, @P_INSCESTA, @V_PAISORIG,
                                               @V_ESTAORIG, @V_PAISDEST, @V_ESTADEST, @V_MUNIDEST, @V_LIQUIITEM, @P_INIVALID, @P_FILIAL, @P_LANCTONF, @V_CDGRUPOFISC, @P_TIPOOPER,
                                               NULL, NULL, NULL, NULL, NULL, NULL, @V_ITEMPRODU_IDORIGEMPROD;
                     END;

                     SET @V_NRALIQTEMP = 0;
                     SET @V_PARDEDTMP  = 0;
                     SET @V_PREDBCTMP  = 0;
                     SET @V_ALIQUTMP   = 0;
                     SET @V_IMPOSTOIT  = 0;
                     SET @V_CDTIPOOPER = NULL;
                     SET @V_CDREGRAITALIQ = NULL;

                     SELECT @V_NRALIQTEMP = ISNULL(MAX(NRALIQTEMP),0),
                            @V_PARDEDTMP = ISNULL(MAX(VRPARDEDTMP),0),
                            @V_PREDBCTMP = ISNULL(MAX(VRPREDBCTMP),0),
                            @V_ALIQUTMP = ISNULL(MAX(VRALIQUTMP),0),
                            @V_TRATIMPST = ISNULL(MAX(IDTRIMPSTTMP), '0'),
                            @V_PBCSUBTRIB = ISNULL(MAX(VRPBCSTTMP),0),
                            @V_IDPMCBASECAL = ISNULL(MAX(IDPMCBSCALTMP), 'S'),
                            @V_CDTIPOOPER = MAX(CDTIPOOPERTMP),
                            @V_CDREGRAITALIQ = MAX(CDREGRATMP)
                     FROM ALIQTEMP
                     WHERE (NRALIQTEMP = @V_ALIQTEMP);

                     /*QUANDO H ALIQUOTA CADASTRADA POR TIPO DE OPERAO ENTO
                     ELE NO BUSCA OS DADOS DA ORIGEM E SIM A PARAMETRIZADA NA SADA
                     DESDE QUE NO SEJA NOTA DE ESTORNO DE CANCELAMENTO*/
                     IF ((@V_NRALIQTEMP IS NOT NULL) AND (@V_CDTIPOOPER IS NOT NULL) AND (@V_ESTORNOCANC <> 'S')) BEGIN
                        IF /*(@C_ITEMPROIMPOS_VRPERREDBCIT > 0.00) AND*/
                           (@C_ITEMPROIMPOS_NRITPROIMPOS = '2')  BEGIN

                           SET @V_CDIMPOSTRIB  = null;
                           SET @V_IDVRIMPSTRIB = null;
                        END
                        ELSE BEGIN
                           SET @V_CDIMPOSTRIB  = null;
                           SET @V_IDVRIMPSTRIB = null;

                           /*IMPOSTO DE SUBSTITUICAO TRIBUTARIA*/
                           DECLARE C_ICMSST CURSOR FOR
                              SELECT CDIMPOSTO
                                FROM IMPOSTO
                               WHERE CDIMPOSTRIB = @C_ITEMPROIMPOS_CDIMPOSTO;

                           OPEN C_ICMSST;
                           FETCH NEXT FROM C_ICMSST INTO @V_ICMSST_CDIMPOSTRIB;

                           WHILE (@@FETCH_STATUS = 0) BEGIN
                              SET @V_CDIMPOSTRIB = ISNULL(@V_CDIMPOSTRIB,'')+@V_ICMSST_CDIMPOSTRIB+'_';
                              FETCH NEXT FROM C_ICMSST INTO @V_ICMSST_CDIMPOSTRIB;
                           END;
                           CLOSE C_ICMSST;
                           DEALLOCATE C_ICMSST;

                           SET @V_TAXABASECALC = (100 - @V_PREDBCTMP)/100;
                           SET @V_TAXAALIQUOTA = (@V_ALIQUTMP/100);
                           SET @V_TAXABCSUBSTR = 1 + (@V_PBCSUBTRIB/100);
                           SET @V_BASECALCIT   = @V_LIQUIITEM * @V_TAXABASECALC;

                           SET @V_PERDBCALC    = 100 - @V_PREDBCTMP;

                           IF @V_PBCSUBTRIB > 0 BEGIN
                              SET @V_BASECALCIT = (@V_BASECALCIT * @V_TAXABCSUBSTR);
                              SET @V_PREDBCTMP  = @V_PBCSUBTRIB;
                              SET @V_PERDBCALC  = 0;
                           END;


                           SET @V_BASECALCTO  = @V_BASECALCIT;
                           SET @V_IMPOSTOIT   = (@V_BASECALCIT * @V_TAXAALIQUOTA) - @V_PARDEDTMP;

                           IF @V_CDIMPOSTRIB IS NULL BEGIN
                              SET @V_IDTRIMPSTII = NULL;
                           END
                           ELSE BEGIN
                              IF SUBSTRING(@V_SITUTRIBPR, 2, 2) = '60' BEGIN
                                 SET @V_IDTRIMPSTII = '2';
                              END ELSE BEGIN
                                 SET @V_IDTRIMPSTII = @V_TRATIMPST;
                              END;
                           END;

                           SET @V_CONTABCALC  = @V_LIQUIITEM - (@V_LIQUIITEM * @V_TAXABASECALC);

                           IF @V_CDIMPOSTRIB IS NOT NULL BEGIN
                              SELECT @V_IDVRIMPSTRIB = ISNULL(MAX(IDVRIMPSTRIB), 'N')
                                FROM ITEMPROIMPOS I, IMPOSTO II
                               WHERE (CDFILIAL     = @P_FILIAL)
                                 AND (NRLANCTONF   = @P_LANCTONF)
                                 AND (NRSEQITPROD  = @V_ITEMPRODU_NRSEQITPROD)
                                 AND (CHARINDEX(II.CDIMPOSTO+'_', @V_CDIMPOSTRIB) > 0)
                                 AND (I.CDIMPOSTO = II.CDIMPOSTO);

                              IF (@V_TRATIMPST = '1') OR (ISNULL(@V_IDVRIMPSTRIB,'N') = 'N') BEGIN
                                 SET @V_VRIMPOSTOST = 0;
                              END
                              ELSE BEGIN
                                 SELECT @V_VRIMPOSTOST = ISNULL(VRIMPOSTOIT,0)
                                   FROM ITEMPROIMPOS I
                                  WHERE (CDFILIAL     = @P_FILIAL)
                                    AND (NRLANCTONF   = @P_LANCTONF)
                                    AND (NRSEQITPROD  = @V_ITEMPRODU_NRSEQITPROD)
                                    AND (CHARINDEX(CDIMPOSTO+'_', @V_CDIMPOSTRIB) > 0)
                                    AND (NRITPROIMPOS = '1');
                              END;
                              SET @V_IMPOSTOIT = @V_IMPOSTOIT - @V_VRIMPOSTOST;

                              IF @V_IMPOSTOIT < 0 BEGIN
                                 SET @V_IMPOSTOIT = 0;
                              END;
                           END;

                           IF (@V_ALIQUTMP = 0) AND (@V_IMPOSTOIT = 0) BEGIN
                              SET @V_BASECALCTO = 0;
                           END;

                           SELECT @V_IDPERVISIMPSCRE = ISNULL(MAX(IDPERVISIMPSCRE), 'S')
                             FROM PARAMGERAL;

                           IF @V_IDPERVISIMPSCRE = 'S' BEGIN
                              SET @V_VRIMPOSTOVISUIT = @V_IMPOSTOIT;
                           END
                           ELSE BEGIN
                              IF (@V_CDFISCTEMP = '1') BEGIN
                                 SET @V_VRIMPOSTOVISUIT = @V_IMPOSTOIT;
                              END
                              ELSE BEGIN
                                 SET @V_VRIMPOSTOVISUIT = 0;
                              END;
                           END;
                           SELECT @V_CHAVE = CDFILIAL
                             FROM ITEMPROIMPOS
                            WHERE CDFILIAL     = @P_FILIAL                 AND
                                  NRLANCTONF   = @P_LANCTONF               AND
                                  NRSEQITPROD  = @V_ITEMPRODU_NRSEQITPROD   AND
                                  CDIMPOSTO    = @C_ITEMPROIMPOS_CDIMPOSTO AND
                                  NRITPROIMPOS = @C_ITEMPROIMPOS_NRITPROIMPOS;

                           IF @V_CHAVE IS NULL BEGIN
                              SET @V_ICMS = NULL;
                              DECLARE C_ICMS CURSOR FOR
                                 SELECT CDIMPOSTO
                                   FROM IMPOSTONFE N, IMPOSTO I
                                  WHERE N.CDIMPOSTONFE = I.CDIMPOSTONFE
                                    AND N.CDIMPOSTONFE = '00'
                                    AND I.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
                              OPEN C_ICMS;
                              FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
                              WHILE (@@FETCH_STATUS = 0) BEGIN
                                 SET @V_ICMS = 'S';
                                 FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
                              END;
                              CLOSE C_ICMS;
                              DEALLOCATE C_ICMS;

                              IF (@V_ICMS = 'S') BEGIN

                                 SET @V_CDGRUPOFISCAUX = NULL;

                                 SELECT @V_CDGRUPOFISCAUX = MAX(G.CDGRUPOFISC)
                                   FROM GRUPOFISCIMPFIL G,
                                        (SELECT CDFILIEMIT AS CDFILIAL
                                           FROM NOTAFISCAL
                                          WHERE CDFILIAL = @P_FILIAL
                                            AND NRLANCTONF = @P_LANCTONF) F
                                  WHERE G.CDFILIAL = F.CDFILIAL
                                    AND NOT G.CDGRUPOFISC IS NULL
                                    AND G.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;

                                 IF @V_IDORIGDESTNF = 'C' BEGIN
                                    SELECT @V_CDGRUPOFISCAUX = ISNULL(MAX(G.CDGRUPOFISC), @V_CDGRUPOFISCAUX)
                                      FROM GRFISIMPIECLIE G,
                                           (SELECT CDCLIENTE
                                              FROM NOTAFISCAL
                                             WHERE CDFILIAL = @P_FILIAL
                                               AND NRLANCTONF = @P_LANCTONF) N
                                     WHERE G.CDCLIENTE = N.CDCLIENTE
                                       AND G.CDEMPRESA = @P_EMPRESA
                                       AND G.CDINSCESTA = @P_INSCESTA
                                       AND NOT G.CDGRUPOFISC IS NULL
                                       AND G.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
                                 END
                                 ELSE BEGIN
                                    SELECT @V_CDGRUPOFISCAUX = ISNULL(MAX(G.CDGRUPOFISC), @V_CDGRUPOFISCAUX)
                                      FROM GRFISIMPIEFORN G,
                                          (SELECT CDFORNECED
                                             FROM NOTAFISCAL
                                            WHERE CDFILIAL = @P_FILIAL
                                              AND NRLANCTONF = @P_LANCTONF) N
                                     WHERE G.CDFORNECED = N.CDFORNECED
                                       AND G.CDEMPRESA = @P_EMPRESA
                                       AND G.CDINSCESTA = @P_INSCESTA
                                       AND NOT G.CDGRUPOFISC IS NULL
                                       AND G.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
                                 END;

                                 IF (@V_CDGRUPOFISCAUX IS NOT NULL) BEGIN
                                    EXEC CONSULTA_CFOP 'S', @P_EMPRESA, @V_ITEMPRODU_CDARVPROD, @P_INSCESTA, @P_TIPOOPER, @V_PAISORIG,
                                     @V_ESTAORIG, @V_PAISCFOP, @V_ESTACFOP, @P_FILIAL, @P_LANCTONF, @V_CDGRUPOFISCAUX, @P_INIVALID, @V_ITEMPRODU_IDORIGEMPROD;
                                 END
                                 ELSE BEGIN
                                    EXEC CONSULTA_CFOP 'S', @P_EMPRESA, @V_ITEMPRODU_CDARVPROD, @P_INSCESTA, @P_TIPOOPER, @V_PAISORIG,
                                     @V_ESTAORIG, @V_PAISCFOP, @V_ESTACFOP, @P_FILIAL, @P_LANCTONF, @V_CDGRUPOFISCAUX, @P_INIVALID, @V_ITEMPRODU_IDORIGEMPROD;
                                 END;

                                 UPDATE NOTAFISCAL
                                    SET DSCDFISOPENF = (SELECT MAX(DSCFOPTMP) FROM CFOPTEMP
                                                        WHERE NRCFOPTEMP = @V_CFOPTEMP)
                                  WHERE CDFILIAL   = @P_FILIAL AND
                                        NRLANCTONF = @P_LANCTONF;

                                 SELECT @V_FISOPEITEM = MAX(CDFISOPETMP),
                                        @V_SUFXCFOPPR = MAX(CDSUFCFOPTMP),
                                        @V_DSCDFISOPEIT = MAX(DSCFOPTMP)
                                   FROM CFOPTEMP
                                  WHERE NRCFOPTEMP = @V_CFOPTEMP;

                                 UPDATE ITEMPRODUTO
                                    SET CDFISOPEITEM = @V_FISOPEITEM,
                                        CDSUFXCFOPPR = @V_SUFXCFOPPR,
                                        DSCDFISOPEIT = @V_DSCDFISOPEIT

                                  WHERE CDFILIAL    = @P_FILIAL   AND
                                        NRLANCTONF  = @P_LANCTONF AND
                                        NRSEQITPROD = @V_ITEMPROD_NRSEQITPROD;

                                 DELETE FROM CFOPTEMP
                                  WHERE NRCFOPTEMP = @V_CFOPTEMP;


                                 SET @V_CST1DIGT = NULL;

                                 SELECT @V_CST1DIGT = MAX(CDCSTDIG1PROD)
                                   FROM PRODUTO
                                  WHERE (CDARVPROD = @V_ITEMPROD_CDARVPROD);

                                 IF @V_CST1DIGT IS NULL BEGIN
                                    SELECT @V_CST1DIGT = MAX(CDCSTDIG1SAI)
                                    FROM INSCRESTAD
                                    WHERE (CDEMPRESA  = @P_EMPRESA) AND
                                          (CDINSCESTA = @P_INSCESTA);
                                 END;
                                 UPDATE ITEMPRODUTO
                                    SET CDSITUTRIBPR  = @V_CST1DIGT+ISNULL(@V_CDSITTRIBTMP, SUBSTRING(@V_SITUTRIBPR, 2,2))
                                  WHERE CDFILIAL    = @P_FILIAL AND
                                        NRLANCTONF  = @P_LANCTONF AND
                                        NRSEQITPROD = @V_ITEMPROD_NRSEQITPROD;

                                 SET @V_SITUTRIBPR = @V_CST1DIGT+ISNULL(@V_CDSITTRIBTMP, SUBSTRING(@V_SITUTRIBPR, 2,2));
                              END;

                              /* ROTINA PARA CALCULAR O DIFERIMENTO DO IMPOSTO */
                              SET @V_PERDIFERE    = NULL;
                              SET @V_IMPOSTOOPERA = NULL;
                              SET @V_IMPOSTODIFER = NULL;

                              IF @C_ITEMPROIMPOS_CDIMPOSTONFE = '00' BEGIN
                                 IF @V_CDSITTRIBTMP = 51 BEGIN
                                    SET @V_VRPERDIFERE = NULL;
                                    SET @V_IDDIFECLI = 'N';

                                    SELECT @V_VRPERDIFERE = PD.VRPERDIFERE, @V_IDDIFECLI = 'S'
                                      FROM PRODDIFEREIMPCLI PD, PRODUTO PR
                                     WHERE PD.CDPRODUTO = PR.CDPRODUTO
                                       AND PD.CDPAIS = @V_PAISORIG
                                       AND PD.SGESTADO = @V_ESTAORIG
                                       AND PD.CDCLIENTE = @P_CLIENTE
                                       AND PR.CDARVPROD IN (SELECT MAX(PR.CDARVPROD) AS CDARVPROD
                                                              FROM PRODDIFEREIMPCLI PD, PRODUTO PR
                                                             WHERE PD.CDPRODUTO = PR.CDPRODUTO
                                                               AND PD.CDPAIS = @V_PAISORIG
                                                               AND PD.SGESTADO = @V_ESTAORIG
                                                               AND PD.CDCLIENTE = @P_CLIENTE
                                                               AND CHARINDEX(PR.CDARVPROD, ISNULL(RTRIM(@V_ITEMPROD_CDARVPROD), PR.CDARVPROD)) = 1);

                                    IF @V_IDDIFECLI = 'N' BEGIN
                                       SELECT @V_VRPERDIFERE = PD.VRPERDIFERE
                                         FROM PRODDIFEREIMPOS PD, PRODUTO PR
                                        WHERE PD.CDPRODUTO = PR.CDPRODUTO
                                          AND PD.CDPAIS = @V_PAISORIG
                                          AND PD.SGESTADO = @V_ESTAORIG
                                          AND PR.CDARVPROD IN (SELECT MAX(PR.CDARVPROD) AS CDARVPROD
                                                                 FROM PRODDIFEREIMPOS PD, PRODUTO PR
                                                                WHERE PD.CDPRODUTO = PR.CDPRODUTO
                                                                  AND PD.CDPAIS = @V_PAISORIG
                                                                  AND PD.SGESTADO = @V_ESTAORIG
                                                                  AND CHARINDEX(PR.CDARVPROD, ISNULL(RTRIM(@V_ITEMPROD_CDARVPROD), PR.CDARVPROD)) = 1);
                                    END;
                                                                  
                                    IF @V_VRPERDIFERE IS NOT NULL BEGIN
                                       SET @V_PERDIFERE = @V_VRPERDIFERE;
                                       SET @V_IMPOSTOOPERA = @V_IMPOSTOIT;
                                       SET @V_IMPOSTODIFER = @V_IMPOSTOOPERA * (@V_VRPERDIFERE/100);
                                       SET @V_IMPOSTOIT = @V_IMPOSTOOPERA - @V_IMPOSTODIFER;
                                    END;
                                 END;
                              END;

                              IF ((@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV')) AND (@V_ICMS = 'S') BEGIN
                                 INSERT INTO ITEMPROIMPOS(
                                    CDFILIAL,        NRLANCTONF,   NRSEQITPROD,    CDIMPOSTO,       NRITPROIMPOS,   CDFISCALIT,
                                    CDSITUTRIBIT,    CDFISCOPERIT, CDSUFXCFOPIT,   VRALIQITEM,      VRPERREDBCIT,   VRPARDEDIT,
                                    VRCONTITIMP,     VRBASECALCIT, VRIMPOSTOIT,    IDERROSIMPIT,    IDAVISIMPIT,    IDTRIMPSTII,
                                    CDSITUTRIBITNFE, IDMODBCITNFE, IDMODBCSTITNFE, CDTPCREDPICOITE, CDNATUBCALPCIT, IDMOTDESONERAIT,
                                    CDDETALHEPROD,   CDREGRAIT, VRIMPOSTOVISUIT, VRPERDIFEREIT, VRIMPOSTOOPERAIT, VRIMPOSTODIFERIT,
                                    CDENQLEGALIPI,   CDCEST)
                                 VALUES(
                                    @P_FILIAL,                 @P_LANCTONF,     @V_ITEMPRODU_NRSEQITPROD, @C_ITEMPROIMPOS_CDIMPOSTO, '1',             @V_CDFISCTEMP,
                                    @V_ITEMPRODU_CDSITUTRIBPR, @V_FISOPEITEM,   @V_SUFXCFOPPR,            @V_ALIQUTMP,               @V_PREDBCTMP,    @V_PARDEDTMP,
                                    ROUND(@V_BASECALCTO,2,2),  @V_BASECALCTO,   ROUND(@V_IMPOSTOIT,2,2),  '00000',                   '00000',         @V_IDTRIMPSTII,
                                    @V_CDSITUTRIBNFE,          @V_IDMODBCNFEIT, @V_IDMODBCSTNFEIT,        @V_CDTPCRPICOSTNFEIT, @V_CDNATUBCPCSTNFEIT, @V_IDMOTIDESSTNFE,
                                    @V_CDDETALHEPRODTEMP,      @V_CDREGRAITALIQ, ROUND(@V_VRIMPOSTOVISUIT,2,2), @V_PERDIFERE, @V_IMPOSTOOPERA, @V_IMPOSTODIFER,
                                    @V_CDENQLEGALIPI,          @V_CDCEST);
                              END
                              ELSE BEGIN
                                 INSERT INTO ITEMPROIMPOS(
                                    CDFILIAL,        NRLANCTONF,   NRSEQITPROD,    CDIMPOSTO,       NRITPROIMPOS,   CDFISCALIT,
                                    CDSITUTRIBIT,    CDFISCOPERIT, CDSUFXCFOPIT,   VRALIQITEM,      VRPERREDBCIT,   VRPARDEDIT,
                                    VRCONTITIMP,     VRBASECALCIT, VRIMPOSTOIT,    IDERROSIMPIT,    IDAVISIMPIT,    IDTRIMPSTII,
                                    CDSITUTRIBITNFE, IDMODBCITNFE, IDMODBCSTITNFE, CDTPCREDPICOITE, CDNATUBCALPCIT, IDMOTDESONERAIT,
                                    CDDETALHEPROD,   CDREGRAIT, VRIMPOSTOVISUIT, VRPERDIFEREIT, VRIMPOSTOOPERAIT, VRIMPOSTODIFERIT,
                                    CDENQLEGALIPI,   CDCEST)
                                 VALUES(
                                    @P_FILIAL,                 @P_LANCTONF,     @V_ITEMPRODU_NRSEQITPROD, @C_ITEMPROIMPOS_CDIMPOSTO, '1',                  @V_CDFISCTEMP,
                                    @V_ITEMPRODU_CDSITUTRIBPR, @V_FISOPEITEM,   @V_SUFXCFOPPR,            @V_ALIQUTMP,               @V_PREDBCTMP,         @V_PARDEDTMP,
                                    ROUND(@V_BASECALCTO,2),    @V_BASECALCTO,   ROUND(@V_IMPOSTOIT,2),    '00000',                   '00000',              @V_IDTRIMPSTII,
                                    @V_CDSITUTRIBNFE,          @V_IDMODBCNFEIT, @V_IDMODBCSTNFEIT,        @V_CDTPCRPICOSTNFEIT,      @V_CDNATUBCPCSTNFEIT, @V_IDMOTIDESSTNFE,
                                    @V_CDDETALHEPRODTEMP,      @V_CDREGRAITALIQ, ROUND(@V_VRIMPOSTOVISUIT,2), @V_PERDIFERE, @V_IMPOSTOOPERA, @V_IMPOSTODIFER,
                                    @V_CDENQLEGALIPI,          @V_CDCEST);
                              END;

                              IF (@C_ITEMPROIMPOS_NRITPROIMPOS = '1') BEGIN
                                 IF (@V_PREDBCTMP > 0) AND (@V_PBCSUBTRIB = 0) BEGIN
                                    IF @V_ITEMPRODU_CDSITUTRIBPR = '060' BEGIN
                                       INSERT INTO ITEMPROIMPOS(
                                          CDFILIAL,        NRLANCTONF,   NRSEQITPROD,    CDIMPOSTO,       NRITPROIMPOS,   CDFISCALIT,
                                          CDSITUTRIBIT,    CDFISCOPERIT, CDSUFXCFOPIT,   VRALIQITEM,      VRPERREDBCIT,   VRPARDEDIT,
                                          VRCONTITIMP,     VRBASECALCIT, VRIMPOSTOIT,    IDERROSIMPIT,    IDAVISIMPIT,    IDTRIMPSTII,
                                          CDSITUTRIBITNFE, IDMODBCITNFE, IDMODBCSTITNFE, CDTPCREDPICOITE, CDNATUBCALPCIT, IDMOTDESONERAIT,
                                          CDDETALHEPROD,   CDREGRAIT,    VRIMPOSTOVISUIT, CDENQLEGALIPI, CDCEST)
                                       VALUES(
                                          @P_FILIAL,                 @P_LANCTONF,     @V_ITEMPRODU_NRSEQITPROD, @C_ITEMPROIMPOS_CDIMPOSTO, '2',                  '2',
                                          @V_ITEMPRODU_CDSITUTRIBPR, @V_FISOPEITEM,   @V_SUFXCFOPPR,            0,                         @V_PERDBCALC,         @V_PARDEDTMP,
                                          ROUND(@V_CONTABCALC,2),    0,               0,                        '00000',                   '00000',              @V_IDTRIMPSTII,
                                          @V_CDSITUTRIBNFE,          @V_IDMODBCNFEIT, @V_IDMODBCSTNFEIT,        @V_CDTPCRPICOSTNFEIT,      @V_CDNATUBCPCSTNFEIT, @V_IDMOTIDESSTNFE,
                                          @V_CDDETALHEPRODTEMP,      @V_CDREGRAITALIQ, 0, @V_CDENQLEGALIPI, @V_CDCEST);
                                    END
                                    ELSE BEGIN
                                       INSERT INTO ITEMPROIMPOS(
                                          CDFILIAL,        NRLANCTONF,   NRSEQITPROD,    CDIMPOSTO,       NRITPROIMPOS,   CDFISCALIT,
                                          CDSITUTRIBIT,    CDFISCOPERIT, CDSUFXCFOPIT,   VRALIQITEM,      VRPERREDBCIT,   VRPARDEDIT,
                                          VRCONTITIMP,     VRBASECALCIT, VRIMPOSTOIT,    IDERROSIMPIT,    IDAVISIMPIT,    IDTRIMPSTII,
                                          CDSITUTRIBITNFE, IDMODBCITNFE, IDMODBCSTITNFE, CDTPCREDPICOITE, CDNATUBCALPCIT, IDMOTDESONERAIT,
                                          CDDETALHEPROD,   CDREGRAIT,    VRIMPOSTOVISUIT, CDENQLEGALIPI, CDCEST)
                                       VALUES(
                                          @P_FILIAL,                 @P_LANCTONF,     @V_ITEMPRODU_NRSEQITPROD, @C_ITEMPROIMPOS_CDIMPOSTO, '2',                  '2',
                                          @V_ITEMPRODU_CDSITUTRIBPR, @V_FISOPEITEM,   @V_SUFXCFOPPR,            0,                         @V_PERDBCALC,         @V_PARDEDTMP,
                                          ROUND(@V_CONTABCALC,2),    0,               0,                        '00000',                   '00000',              @V_IDTRIMPSTII,
                                          @V_CDSITUTRIBNFE,          @V_IDMODBCNFEIT, @V_IDMODBCSTNFEIT,        @V_CDTPCRPICOSTNFEIT,      @V_CDNATUBCPCSTNFEIT, @V_IDMOTIDESSTNFE,
                                          @V_CDDETALHEPRODTEMP,      @V_CDREGRAITALIQ, 0, @V_CDENQLEGALIPI, @V_CDCEST);
                                    END;
                                 END;
                              END;
                           END;
                        END;
                     END
                     ELSE BEGIN
                        SELECT @V_IDPERVISIMPSCRE = ISNULL(MAX(IDPERVISIMPSCRE), 'S')
                          FROM PARAMGERAL;
                        IF @V_IDPERVISIMPSCRE = 'S' BEGIN
                           SET @V_VRIMPOSTOVISUIT = (@C_ITEMPROIMPOS_VRIMPOSTOIT * @V_VRFATOCONV);
                        END
                        ELSE BEGIN
                           IF (@V_CDFISCTEMP = '1') BEGIN
                              SET @V_VRIMPOSTOVISUIT = (@C_ITEMPROIMPOS_VRIMPOSTOIT * @V_VRFATOCONV);
                           END
                           ELSE BEGIN
                              SET @V_VRIMPOSTOVISUIT = 0;
                           END;
                        END;
                        SELECT @V_CHAVE = MAX(CDFILIAL)
                        FROM ITEMPROIMPOS
                        WHERE CDFILIAL = @P_FILIAL AND
                              NRLANCTONF = @P_LANCTONF AND
                              NRSEQITPROD = @V_ITEMPRODU_NRSEQITPROD AND
                              CDIMPOSTO = @C_ITEMPROIMPOS_CDIMPOSTO AND
                              NRITPROIMPOS = @C_ITEMPROIMPOS_NRITPROIMPOS;

                        IF @V_CHAVE IS NULL BEGIN
                           SET @V_ICMS = NULL;
                           DECLARE C_ICMS CURSOR FOR
                              SELECT CDIMPOSTO
                                FROM IMPOSTONFE N, IMPOSTO I
                               WHERE N.CDIMPOSTONFE = I.CDIMPOSTONFE
                                 AND N.CDIMPOSTONFE = '00'
                                 AND I.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
                           OPEN C_ICMS;
                           FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
                           WHILE (@@FETCH_STATUS = 0) BEGIN
                              SET @V_ICMS = 'S';
                              FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
                           END;
                           CLOSE C_ICMS;
                           DEALLOCATE C_ICMS;

                           IF ((@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV')) AND (@V_ICMS = 'S') BEGIN
                              INSERT INTO ITEMPROIMPOS(CDFILIAL,     NRLANCTONF,     NRSEQITPROD,     CDIMPOSTO,      NRITPROIMPOS,    CDFISCALIT,
                                                       CDSITUTRIBIT, CDFISCOPERIT,   CDSUFXCFOPIT,    VRALIQITEM,     VRPERREDBCIT,    VRPARDEDIT,
                                                       VRCONTITIMP,  VRBASECALCIT,   VRIMPOSTOIT,     IDERROSIMPIT,   IDAVISIMPIT,     CDSITUTRIBITNFE,
                                                       IDMODBCITNFE, IDMODBCSTITNFE, CDTPCREDPICOITE, CDNATUBCALPCIT, IDMOTDESONERAIT, IDTRIMPSTII,
                                                       CDDETALHEPROD, VRIMPOSTOVISUIT, CDENQLEGALIPI, CDCEST)
                                                VALUES(@P_FILIAL, @P_LANCTONF, @V_ITEMPRODU_NRSEQITPROD, @C_ITEMPROIMPOS_CDIMPOSTO, @C_ITEMPROIMPOS_NRITPROIMPOS, @V_CDFISCTEMP,
                                                       @V_ITEMPRODU_CDSITUTRIBPR, @V_FISOPEITEM, @V_SUFXCFOPPR, @C_ITEMPROIMPOS_VRALIQITEM, @C_ITEMPROIMPOS_VRPERREDBCIT, ROUND((@C_ITEMPROIMPOS_VRPARDEDIT * @V_VRFATOCONV),2,2),
                                                       ROUND((@C_ITEMPROIMPOS_VRCONTITIMP * @V_VRFATOCONV),2,2), ROUND((@C_ITEMPROIMPOS_VRBASECALCIT * @V_VRFATOCONV),2,2),
                                                       ROUND((@C_ITEMPROIMPOS_VRIMPOSTOIT * @V_VRFATOCONV),2,2), '00000', '00000', @V_CDSITUTRIBNFE,
                                                       @V_IDMODBCNFEIT, @V_IDMODBCSTNFEIT, @V_CDTPCRPICOSTNFEIT, @V_CDNATUBCPCSTNFEIT, @V_IDMOTIDESSTNFE, @C_ITEMPROIMPOS_IDTRIMPSTII,
                                                       @V_CDDETALHEPRODTEMP, ROUND(@V_VRIMPOSTOVISUIT,2,2), @V_CDENQLEGALIPI, @V_CDCEST);
                           END
                           ELSE BEGIN
                              IF (@C_ITEMPROIMPOS_NRITPROIMPOS = '3')  BEGIN
                                 /*Inserir a linha de diferencial de alquota*/

                                 SET @V_DIFALIQ = 0;

                                 SELECT @V_DIFALIQ = VRALIQITEM
                                   FROM ITEMPROIMPOS IT, ITEMPRODUTO I
                                  WHERE IT.CDFILIAL     = @V_CDFILIALIT
                                    AND IT.NRLANCTONF   = @V_NRLANCTONFIT
                                    AND I.CDFILIAL      = @V_CDFILIALIT
                                    AND I.NRLANCTONF    = @V_NRLANCTONFIT
                                    AND IT.NRSEQITPROD  = I.NRSEQITPROD
                                    AND I.CDPRODUTO     = @V_ITEMPRODU_CDPRODUTO
                                    AND ROUND(I.VRUNITITEM, @V_NRDECITOTANF) = ROUND(@V_ITEMPRODU_VRUNITITEM, @V_NRDECITOTANF)
                                    AND (ISNULL(NRLOTEESTQ, ' ') = (ISNULL(@V_ITEMPRODU_NRLOTEESTQ, ' ')))
                                    AND (ISNULL(NRSUBLOTE, ' ')  = (ISNULL(@V_ITEMPRODU_NRSUBLOTE , ' ')))
                                    AND IT.CDIMPOSTO    = @C_ITEMPROIMPOS_CDIMPOSTO
                                    AND IT.NRITPROIMPOS = '1';

                                 IF  (@V_ALIQUTMP = @V_DIFALIQ) BEGIN

                                    INSERT INTO ITEMPROIMPOS(
                                       CDFILIAL,        NRLANCTONF,   NRSEQITPROD,    CDIMPOSTO,       NRITPROIMPOS,   CDFISCALIT,
                                       CDSITUTRIBIT,    CDFISCOPERIT, CDSUFXCFOPIT,   VRALIQITEM,      VRPERREDBCIT,   VRPARDEDIT,
                                       VRCONTITIMP,     VRBASECALCIT, VRIMPOSTOIT,    IDERROSIMPIT,    IDAVISIMPIT,    IDTRIMPSTII,
                                       CDSITUTRIBITNFE, IDMODBCITNFE, IDMODBCSTITNFE, CDTPCREDPICOITE, CDNATUBCALPCIT, IDMOTDESONERAIT,
                                       CDDETALHEPROD,   VRIMPOSTOVISUIT,   CDREGRAIT, IDDIFALIQCUSPRI, CDENQLEGALIPI,  CDCEST)
                                    VALUES(
                                       @P_FILIAL, @P_LANCTONF, @V_ITEMPRODU_NRSEQITPROD, @C_ITEMPROIMPOS_CDIMPOSTO, @C_ITEMPROIMPOS_NRITPROIMPOS, @C_ITEMPROIMPOS_CDFISCALIT,
                                       @V_ITEMPRODU_CDSITUTRIBPR, @V_FISOPEITEM, @V_SUFXCFOPPR, @C_ITEMPROIMPOS_VRALIQITEM, @C_ITEMPROIMPOS_VRPERREDBCIT, (@C_ITEMPROIMPOS_VRPARDEDIT * @V_VRFATOCONV),
                                       ROUND((@C_ITEMPROIMPOS_VRCONTITIMP * @V_VRFATOCONV),2), (@C_ITEMPROIMPOS_VRBASECALCIT * @V_VRFATOCONV),
                                       (@C_ITEMPROIMPOS_VRIMPOSTOIT * @V_VRFATOCONV), '00000', '00000', @C_ITEMPROIMPOS_IDTRIMPSTII, @C_ITEMPROIMPOS_CDSITUTRIBNFE,
                                       @C_ITEMPROIMPOS_IDMODBCNFE, @C_ITEMPROIMPOS_IDMODBCSTNFE, @C_ITEMPROIMPOS_CDTPCREDPICOITE, @C_ITEMPROIMPOS_CDNATUBCALPCIT, ISNULL(@C_ITEMPROIMPOS_IDMOTDESONERAIT,'9'),
                                       @V_CDDETALHEPRODTEMP, (@C_ITEMPROIMPOS_VRIMPOSTOIT * @V_VRFATOCONV), @V_CDREGRAITALIQ, @C_ITEMPROIMPOS_IDDIFALIQCUSPRI, @V_CDENQLEGALIPI, @V_CDCEST);
                                 END;
                                 /*Inserir a linha de diferencial de alquota*/

                              END
                              ELSE BEGIN
                                 INSERT INTO ITEMPROIMPOS(CDFILIAL,     NRLANCTONF,     NRSEQITPROD,     CDIMPOSTO,      NRITPROIMPOS,    CDFISCALIT,
                                                          CDSITUTRIBIT, CDFISCOPERIT,   CDSUFXCFOPIT,    VRALIQITEM,     VRPERREDBCIT,    VRPARDEDIT,
                                                          VRCONTITIMP,  VRBASECALCIT,   VRIMPOSTOIT,     IDERROSIMPIT,   IDAVISIMPIT,     CDSITUTRIBITNFE,
                                                          IDMODBCITNFE, IDMODBCSTITNFE, CDTPCREDPICOITE, CDNATUBCALPCIT, IDMOTDESONERAIT, IDTRIMPSTII,
                                                          CDDETALHEPROD, VRIMPOSTOVISUIT, CDENQLEGALIPI, CDCEST)
                                                   VALUES(@P_FILIAL, @P_LANCTONF, @V_ITEMPRODU_NRSEQITPROD, @C_ITEMPROIMPOS_CDIMPOSTO, @C_ITEMPROIMPOS_NRITPROIMPOS, @V_CDFISCTEMP,
                                                          @V_ITEMPRODU_CDSITUTRIBPR, @V_FISOPEITEM, @V_SUFXCFOPPR, @C_ITEMPROIMPOS_VRALIQITEM, @C_ITEMPROIMPOS_VRPERREDBCIT, (@C_ITEMPROIMPOS_VRPARDEDIT * @V_VRFATOCONV),
                                                          ROUND((@C_ITEMPROIMPOS_VRCONTITIMP * @V_VRFATOCONV),2), (@C_ITEMPROIMPOS_VRBASECALCIT * @V_VRFATOCONV),
                                                          (@C_ITEMPROIMPOS_VRIMPOSTOIT * @V_VRFATOCONV), '00000', '00000', @V_CDSITUTRIBNFE,
                                                          @V_IDMODBCNFEIT, @V_IDMODBCSTNFEIT,  @V_CDTPCRPICOSTNFEIT, @V_CDNATUBCPCSTNFEIT, @V_IDMOTIDESSTNFE, @C_ITEMPROIMPOS_IDTRIMPSTII,
                                                          @V_CDDETALHEPRODTEMP, ROUND(@V_VRIMPOSTOVISUIT,2), @V_CDENQLEGALIPI, @V_CDCEST);
                              END;
                           END;
                        END;

                     END;

                     DELETE ALIQTEMP
                      WHERE NRALIQTEMP = @V_ALIQTEMP;

                     FETCH NEXT FROM C_ITEMPRODUIMPOS INTO @C_ITEMPROIMPOS_VRPERREDBCIT,    @C_ITEMPROIMPOS_NRITPROIMPOS,    @C_ITEMPROIMPOS_CDIMPOSTO,
                                                           @C_ITEMPROIMPOS_CDFISCALIT,      @C_ITEMPROIMPOS_VRALIQITEM,      @C_ITEMPROIMPOS_VRPARDEDIT,
                                                           @C_ITEMPROIMPOS_VRCONTITIMP,     @C_ITEMPROIMPOS_VRBASECALCIT,    @C_ITEMPROIMPOS_VRIMPOSTOIT,
                                                           @C_ITEMPROIMPOS_CDSITUTRIBNFE,   @C_ITEMPROIMPOS_IDMODBCNFE,      @C_ITEMPROIMPOS_IDMODBCSTNFE,
                                                           @C_ITEMPROIMPOS_CDTPCREDPICOITE, @C_ITEMPROIMPOS_CDNATUBCALPCIT,  @C_ITEMPROIMPOS_IDMOTDESONERAIT,
                                                           @C_ITEMPROIMPOS_IDTRIMPSTII,     @C_ITEMPROIMPOS_IDDIFALIQCUSPRI, @C_ITEMPROIMPOS_CDIMPOSTONFE,
                                                           @C_ITEMPROIMPOS_CDENQLEGALIPI,   @C_ITEMPROIMPOS_CDCEST,          @C_ITEMPROIMPOS_IDUTVRPAUTAPROD,
                                                           @C_ITEMPROIMPOS_VRPAUTAMINPROD,  @C_ITEMPROIMPOS_QTITEMPROD,      @C_ITEMPROIMPOS_IDUTVRPAUTA;

                  END;
                  CLOSE C_ITEMPRODUIMPOS;
                  DEALLOCATE C_ITEMPRODUIMPOS;

                  DELETE ALIQTEMP
                  WHERE NRALIQTEMP = @V_ALIQTEMP;

               END
               ELSE BEGIN /*SE A NOTA POSSUI UM UNICO DOCUMENTO DE ORIGEM*/
                  SELECT @V_QTITEMORIG = ISNULL(SUM(I.QTITEMPROD),1),
                         @V_VRBRUTO    = ISNULL(MAX(VRBRUTITEM),0),
                         @V_VRCONTAB   = ISNULL(MAX(VRCONTITEM),0)
                  FROM ITEMPRODUTO I
                  WHERE CDFILIAL    = @V_CDFILIALIT                                                          AND
                        NRLANCTONF  = @V_NRLANCTONFIT                                                        AND
                        CDPRODUTO   = @V_ITEMPRODU_CDPRODUTO                                                 AND
                        ROUND(VRUNITITEM, @V_NRDECITOTANF) = ROUND(@V_ITEMPRODU_VRUNITITEM, @V_NRDECITOTANF) AND
                        (ISNULL(NRLOTEESTQ, ' ') = (ISNULL(@V_ITEMPRODU_NRLOTEESTQ, ' ')))                   AND
                        (ISNULL(NRSUBLOTE , ' ') = (ISNULL(@V_ITEMPRODU_NRSUBLOTE , ' ')));

                        IF @V_QTITEMORIG = 0 BEGIN
                           SET @V_QTITEMORIG = 1;
                        END;

                  SET @V_VRFATOCONV = ISNULL(@V_ITEMPRODU_QTITEMPROD,1)/@V_QTITEMORIG;

                  /*IF @P_TIPOOPER = '03' BEGIN
                     SELECT @V_QTITEMORIG = ISNULL(SUM(I.VRTOTAITEM),1),
                            @V_VRBRUTO = ISNULL(MAX(VRBRUTITEM),0),
                            @V_VRCONTAB = ISNULL(MAX(VRCONTITEM),0)
                     FROM ITEMPRODUTO I
                     WHERE CDFILIAL    = @V_CDFILIALIT                                                          AND
                           NRLANCTONF  = @V_NRLANCTONFIT                                                        AND
                           CDPRODUTO   = @V_ITEMPRODU_CDPRODUTO                                                 AND
                           ROUND(VRUNITITEM, @V_NRDECITOTANF) = ROUND(@V_ITEMPRODU_VRUNITITEM, @V_NRDECITOTANF) AND
                           (ISNULL(NRLOTEESTQ, ' ') = (ISNULL(@V_ITEMPRODU_NRLOTEESTQ, ' ')))                   AND
                           (ISNULL(NRSUBLOTE , ' ') = (ISNULL(@V_ITEMPRODU_NRSUBLOTE , ' ')));
                    IF @V_QTITEMORIG = 0 BEGIN
                       SET @V_QTITEMORIG = 1;
                    END;
                    SET @V_VRFATOCONV = ISNULL(@V_ITEMPRODU_VRTOTAITEM ,1)/@V_QTITEMORIG;
                  END;*/

                  IF @P_TIPOOPER <> '03' BEGIN
                    UPDATE ITEMPRODUTO
                       SET VRCONTITEMORIG = ROUND(@V_VRCONTAB * @V_VRFATOCONV,2),
                           VRBRUTITEMORIG = ROUND(@V_VRBRUTO * @V_VRFATOCONV,2),
                           VRCONTITEM     = ROUND(@V_VRCONTAB * @V_VRFATOCONV,2),
                           VRBRUTITEM     = ROUND(@V_VRBRUTO * @V_VRFATOCONV,2)
                     WHERE CDFILIAL    = @P_FILIAL                                                           AND
                           NRLANCTONF  = @P_LANCTONF                                                         AND
                           CDPRODUTO   = @V_ITEMPRODU_CDPRODUTO                                                 AND
                           ROUND(VRUNITITEM, @V_NRDECITOTANF) = ROUND(@V_ITEMPRODU_VRUNITITEM, @V_NRDECITOTANF) AND
                           (ISNULL(NRLOTEESTQ, ' ') = (ISNULL(@V_ITEMPRODU_NRLOTEESTQ, ' ')))                   AND
                           (ISNULL(NRSUBLOTE , ' ') = (ISNULL(@V_ITEMPRODU_NRSUBLOTE , ' ')));
                  END;
                  IF NOT @V_CDINTEGRACAO IS NULL BEGIN
                     IF (@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV') BEGIN
                        UPDATE ITEMPRODUTO
                        SET VRCONTITEM = ROUND((@V_VRCONTAB * @V_VRFATOCONV),2,2),
                            VRBRUTITEM = ROUND((@V_VRBRUTO * @V_VRFATOCONV),2,2)
                        WHERE CDFILIAL    = @P_FILIAL                                                              AND
                              NRLANCTONF  = @P_LANCTONF                                                            AND
                              CDPRODUTO   = @V_ITEMPRODU_CDPRODUTO                                                 AND
                              ROUND(VRUNITITEM, @V_NRDECITOTANF) = ROUND(@V_ITEMPRODU_VRUNITITEM, @V_NRDECITOTANF) AND
                              (ISNULL(NRLOTEESTQ, ' ')  = (ISNULL(@V_ITEMPRODU_NRLOTEESTQ, ' ')))                  AND
                              (ISNULL(NRSUBLOTE , ' ')  = (ISNULL(@V_ITEMPRODU_NRSUBLOTE , ' ')));
                     END
                     ELSE BEGIN
                        UPDATE ITEMPRODUTO
                        SET VRCONTITEM = ROUND(@V_VRCONTAB * @V_VRFATOCONV,2),
                            VRBRUTITEM = ROUND(@V_VRBRUTO * @V_VRFATOCONV,2)
                        WHERE CDFILIAL    = @P_FILIAL                                                              AND
                              NRLANCTONF  = @P_LANCTONF                                                            AND
                              CDPRODUTO   = @V_ITEMPRODU_CDPRODUTO                                                 AND
                              ROUND(VRUNITITEM, @V_NRDECITOTANF) = ROUND(@V_ITEMPRODU_VRUNITITEM, @V_NRDECITOTANF) AND
                              (ISNULL(NRLOTEESTQ, ' ') = (ISNULL(@V_ITEMPRODU_NRLOTEESTQ, ' ')))                   AND
                              (ISNULL(NRSUBLOTE , ' ') = (ISNULL(@V_ITEMPRODU_NRSUBLOTE , ' ')));
                     END;
                  END;
                  SET @V_CDIMPOSRECALC = NULL;
                  DECLARE C_ITEMPRODUIMPOS CURSOR FOR
                     (SELECT VRPERREDBCIT, NRITPROIMPOS, IT.CDIMPOSTO, CDFISCALIT, VRALIQITEM, VRPARDEDIT, SUM(VRCONTITIMP) AS VRCONTITIMP,
                             SUM(VRBASECALCIT) AS VRBASECALCIT, SUM(VRIMPOSTOIT) AS VRIMPOSTOIT, CDSITUTRIBITNFE AS CDSITUTRIBNFE,
                             IDMODBCITNFE AS IDMODBCNFE, IDMODBCSTITNFE AS IDMODBCSTNFE, CDTPCREDPICOITE, CDNATUBCALPCIT, IDMOTDESONERAIT,
                             IDTRIMPSTII, ISNULL(IDDIFALIQCUSPRI, 'N') AS IDDIFALIQCUSPRI, IM.CDIMPOSTONFE, IT.CDENQLEGALIPI, IT.CDCEST,
                             ISNULL(I.IDUTVRPAUTAPROD, 'N') AS IDUTVRPAUTAPROD, ISNULL(I.VRPAUTAMINPROD, 1) AS VRPAUTAMINPROD, I.QTITEMPROD, IM.IDUTVRPAUTA
                      FROM ITEMPROIMPOS IT, ITEMPRODUTO I, IMPOSTO IM
                      WHERE IT.CDFILIAL   = @V_CDFILIALIT                                                          AND
                            IT.NRLANCTONF = @V_NRLANCTONFIT                                                        AND
                            I.CDFILIAL    = @V_CDFILIALIT                                                          AND
                            I.NRLANCTONF  = @V_NRLANCTONFIT                                                        AND
                            IT.NRSEQITPROD = I.NRSEQITPROD                                                         AND
                            IT.CDIMPOSTO   = IM.CDIMPOSTO                                                          AND
                            I.CDPRODUTO   = @V_ITEMPRODU_CDPRODUTO                                                 AND
                            IT.NRITPROIMPOS = '1'                                                                  AND
                            ROUND(I.VRUNITITEM, @V_NRDECITOTANF) = ROUND(@V_ITEMPRODU_VRUNITITEM, @V_NRDECITOTANF) AND
                            (ISNULL(I.NRLOTEESTQ, ' ') = (ISNULL(@V_ITEMPRODU_NRLOTEESTQ, ' ')))                   AND
                            (ISNULL(I.NRSUBLOTE , ' ') = (ISNULL(@V_ITEMPRODU_NRSUBLOTE, ' ')))
                      GROUP BY VRPERREDBCIT,   NRITPROIMPOS,    IT.CDIMPOSTO,       CDFISCALIT,
                               VRALIQITEM,     VRPARDEDIT,      CDSITUTRIBITNFE, IDMODBCITNFE,
                               IDMODBCSTITNFE, CDTPCREDPICOITE, CDNATUBCALPCIT,  IDMOTDESONERAIT,
                               IDTRIMPSTII, IDDIFALIQCUSPRI, IM.CDIMPOSTONFE, IT.CDENQLEGALIPI, IT.CDCEST,
                               ISNULL(I.IDUTVRPAUTAPROD, 'N'), ISNULL(I.VRPAUTAMINPROD, 1), I.QTITEMPROD, IM.IDUTVRPAUTA);

                  OPEN C_ITEMPRODUIMPOS;
                  FETCH NEXT FROM C_ITEMPRODUIMPOS INTO @C_ITEMPROIMPOS_VRPERREDBCIT,    @C_ITEMPROIMPOS_NRITPROIMPOS,    @C_ITEMPROIMPOS_CDIMPOSTO,
                                                        @C_ITEMPROIMPOS_CDFISCALIT,      @C_ITEMPROIMPOS_VRALIQITEM,      @C_ITEMPROIMPOS_VRPARDEDIT,
                                                        @C_ITEMPROIMPOS_VRCONTITIMP,     @C_ITEMPROIMPOS_VRBASECALCIT,    @C_ITEMPROIMPOS_VRIMPOSTOIT,
                                                        @C_ITEMPROIMPOS_CDSITUTRIBNFE,   @C_ITEMPROIMPOS_IDMODBCNFE,      @C_ITEMPROIMPOS_IDMODBCSTNFE,
                                                        @C_ITEMPROIMPOS_CDTPCREDPICOITE, @C_ITEMPROIMPOS_CDNATUBCALPCIT,  @C_ITEMPROIMPOS_IDMOTDESONERAIT,
                                                        @C_ITEMPROIMPOS_IDTRIMPSTII,     @C_ITEMPROIMPOS_IDDIFALIQCUSPRI, @C_ITEMPROIMPOS_CDIMPOSTONFE,
                                                        @C_ITEMPROIMPOS_CDENQLEGALIPI,   @C_ITEMPROIMPOS_CDCEST,          @C_ITEMPROIMPOS_IDUTVRPAUTAPROD,
                                                        @C_ITEMPROIMPOS_VRPAUTAMINPROD,  @C_ITEMPROIMPOS_QTITEMPROD,      @C_ITEMPROIMPOS_IDUTVRPAUTA;

                  WHILE (@@FETCH_STATUS = 0) BEGIN

                     /*IMPOSTO DE SUBSTITUICAO TRIBUTARIA*/
                     SET @V_CDIMPOSTRIB  = null;
                     SET @V_IDVRIMPSTRIB = null;
                     DECLARE C_ICMSST CURSOR FOR
                           SELECT CDIMPOSTRIB
                             FROM IMPOSTO
                            WHERE CDIMPOSTRIB = @V_INCIDEN_CDIMPOTEMP;

                     OPEN C_ICMSST;
                     FETCH NEXT FROM C_ICMSST INTO @V_ICMSST_CDIMPOSTRIB;
                     WHILE (@@FETCH_STATUS = 0) BEGIN
                        SET @V_CDIMPOSTRIB = ISNULL(@V_CDIMPOSTRIB,'')+@V_ICMSST_CDIMPOSTRIB+'_';
                        FETCH NEXT FROM C_ICMSST INTO @V_ICMSST_CDIMPOSTRIB;
                     END;
                     CLOSE C_ICMSST;
                     DEALLOCATE C_ICMSST;

                     SET @V_CDIMPOSIPI = null;
                     SELECT @V_IDGERIPIDESPA = ISNULL(MAX(IDGERIPIDESPA), 'N'),
                            @V_CDIMPOSIPI    = MAX(CDIMPOSTOIPI)
                       FROM TIPOOPERAC
                      WHERE IDENTRSAIDOP = 'S'
                        AND CDTIPOOPER   = @P_TIPOOPER
                        AND CDIMPOSTOIPI = @C_ITEMPROIMPOS_CDIMPOSTO;

                     IF (@V_IDGERICMSTDESPA = 'S') AND (@V_CDIMPOSTRIB IS NOT NULL) AND (@V_IDUTCTRLFIS = 'S') BEGIN
                        IF NOT((@C_ITEMPROIMPOS_VRPERREDBCIT > 0.00) AND (@C_ITEMPROIMPOS_NRITPROIMPOS = '2')) BEGIN
                           SET @V_VRTOTALICMSST = @V_VRTOTALICMSST + (@C_ITEMPROIMPOS_VRIMPOSTOIT * @V_VRFATOCONV);
                        END;
                        IF ((@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV')) AND (@V_ICMS = 'S') BEGIN
                           INSERT INTO ITEMPROIMPOSORIG(CDFILIAL,     NRLANCTONF,     NRSEQITPROD,     CDIMPOSTO,      NRITPROIMPOS,    CDFISCALIT,
                                                    CDSITUTRIBIT, CDFISCOPERIT,   CDSUFXCFOPIT,    VRALIQITEM,     VRPERREDBCIT,    VRPARDEDIT,
                                                    VRCONTITIMP,  VRBASECALCIT,   VRIMPOSTOIT,     IDERROSIMPIT,   IDAVISIMPIT,     CDSITUTRIBITNFE,
                                                    IDMODBCITNFE, IDMODBCSTITNFE, CDTPCREDPICOITE, CDNATUBCALPCIT, IDMOTDESONERAIT, IDTRIMPSTII,
                                                    CDDETALHEPROD, CDENQLEGALIPI, CDCEST)
                           VALUES(@P_FILIAL, @P_LANCTONF, @V_ITEMPRODU_NRSEQITPROD, @C_ITEMPROIMPOS_CDIMPOSTO, @C_ITEMPROIMPOS_NRITPROIMPOS, @C_ITEMPROIMPOS_CDFISCALIT,
                                  @V_ITEMPRODU_CDSITUTRIBPR, @V_FISOPEITEM,   @V_SUFXCFOPPR, @C_ITEMPROIMPOS_VRALIQITEM, @C_ITEMPROIMPOS_VRPERREDBCIT, ROUND((@C_ITEMPROIMPOS_VRPARDEDIT * @V_VRFATOCONV),2,2),
                                  ROUND((@C_ITEMPROIMPOS_VRCONTITIMP * @V_VRFATOCONV),2,2), ROUND((@C_ITEMPROIMPOS_VRBASECALCIT * @V_VRFATOCONV),2,2),
                                  ROUND((@C_ITEMPROIMPOS_VRIMPOSTOIT * @V_VRFATOCONV),2,2), '00000',                   '00000', @C_ITEMPROIMPOS_CDSITUTRIBNFE,
                                  @C_ITEMPROIMPOS_IDMODBCNFE,  @C_ITEMPROIMPOS_IDMODBCSTNFE, @C_ITEMPROIMPOS_CDTPCREDPICOITE, @C_ITEMPROIMPOS_CDNATUBCALPCIT, ISNULL(@C_ITEMPROIMPOS_IDMOTDESONERAIT,'9'), @C_ITEMPROIMPOS_IDTRIMPSTII,
                                  @V_CDDETALHEPRODTEMP, @C_ITEMPROIMPOS_CDENQLEGALIPI, @C_ITEMPROIMPOS_CDCEST);
                        END
                        ELSE BEGIN
                           INSERT INTO ITEMPROIMPOSORIG(CDFILIAL,     NRLANCTONF,     NRSEQITPROD,     CDIMPOSTO,      NRITPROIMPOS,    CDFISCALIT,
                                                    CDSITUTRIBIT, CDFISCOPERIT,   CDSUFXCFOPIT,    VRALIQITEM,     VRPERREDBCIT,    VRPARDEDIT,
                                                    VRCONTITIMP,  VRBASECALCIT,   VRIMPOSTOIT,     IDERROSIMPIT,   IDAVISIMPIT,     CDSITUTRIBITNFE,
                                                    IDMODBCITNFE, IDMODBCSTITNFE, CDTPCREDPICOITE, CDNATUBCALPCIT, IDMOTDESONERAIT, IDTRIMPSTII,
                                                    CDDETALHEPROD, CDENQLEGALIPI, CDCEST)
                           VALUES(@P_FILIAL, @P_LANCTONF, @V_ITEMPRODU_NRSEQITPROD, @C_ITEMPROIMPOS_CDIMPOSTO, @C_ITEMPROIMPOS_NRITPROIMPOS, @C_ITEMPROIMPOS_CDFISCALIT,
                                  @V_ITEMPRODU_CDSITUTRIBPR, @V_FISOPEITEM,   @V_SUFXCFOPPR, @C_ITEMPROIMPOS_VRALIQITEM, @C_ITEMPROIMPOS_VRPERREDBCIT, ROUND((@C_ITEMPROIMPOS_VRPARDEDIT * @V_VRFATOCONV),2),
                                  ROUND((@C_ITEMPROIMPOS_VRCONTITIMP * @V_VRFATOCONV),2), ROUND((@C_ITEMPROIMPOS_VRBASECALCIT * @V_VRFATOCONV),2),
                                  ROUND((@C_ITEMPROIMPOS_VRIMPOSTOIT * @V_VRFATOCONV),2), '00000',                   '00000', @C_ITEMPROIMPOS_CDSITUTRIBNFE,
                                  @C_ITEMPROIMPOS_IDMODBCNFE,  @C_ITEMPROIMPOS_IDMODBCSTNFE, @C_ITEMPROIMPOS_CDTPCREDPICOITE, @C_ITEMPROIMPOS_CDNATUBCALPCIT, ISNULL(@C_ITEMPROIMPOS_IDMOTDESONERAIT,'9'), @C_ITEMPROIMPOS_IDTRIMPSTII,
                                  @V_CDDETALHEPRODTEMP, @C_ITEMPROIMPOS_CDENQLEGALIPI, @C_ITEMPROIMPOS_CDCEST);
                        END;
                     END;
                     IF (@V_IDGERIPIDESPA = 'S') AND (@V_CDIMPOSIPI IS NOT NULL) AND (@V_IDUTCTRLFIS = 'S') BEGIN
                        IF NOT((@C_ITEMPROIMPOS_VRPERREDBCIT > 0.00) AND (@C_ITEMPROIMPOS_NRITPROIMPOS = '2')) BEGIN
                           SET @V_VRTOTALIPI = @V_VRTOTALIPI + (@C_ITEMPROIMPOS_VRIMPOSTOIT * @V_VRFATOCONV);
                        END;
                        IF ((@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV')) AND (@V_ICMS = 'S') BEGIN
                           INSERT INTO ITEMPROIMPOSORIG(CDFILIAL,     NRLANCTONF,     NRSEQITPROD,     CDIMPOSTO,      NRITPROIMPOS,    CDFISCALIT,
                                                    CDSITUTRIBIT, CDFISCOPERIT,   CDSUFXCFOPIT,    VRALIQITEM,     VRPERREDBCIT,    VRPARDEDIT,
                                                    VRCONTITIMP,  VRBASECALCIT,   VRIMPOSTOIT,     IDERROSIMPIT,   IDAVISIMPIT,     CDSITUTRIBITNFE,
                                                    IDMODBCITNFE, IDMODBCSTITNFE, CDTPCREDPICOITE, CDNATUBCALPCIT, IDMOTDESONERAIT, IDTRIMPSTII,
                                                    CDDETALHEPROD, CDENQLEGALIPI, CDCEST)
                           VALUES(@P_FILIAL, @P_LANCTONF, @V_ITEMPRODU_NRSEQITPROD, @C_ITEMPROIMPOS_CDIMPOSTO, @C_ITEMPROIMPOS_NRITPROIMPOS, @C_ITEMPROIMPOS_CDFISCALIT,
                                  @V_ITEMPRODU_CDSITUTRIBPR, @V_FISOPEITEM,   @V_SUFXCFOPPR, @C_ITEMPROIMPOS_VRALIQITEM, @C_ITEMPROIMPOS_VRPERREDBCIT, ROUND((@C_ITEMPROIMPOS_VRPARDEDIT * @V_VRFATOCONV),2,2),
                                  ROUND((@C_ITEMPROIMPOS_VRCONTITIMP * @V_VRFATOCONV),2,2), ROUND((@C_ITEMPROIMPOS_VRBASECALCIT * @V_VRFATOCONV),2,2),
                                  ROUND((@C_ITEMPROIMPOS_VRIMPOSTOIT * @V_VRFATOCONV),2,2), '00000',                   '00000', @C_ITEMPROIMPOS_CDSITUTRIBNFE,
                                  @C_ITEMPROIMPOS_IDMODBCNFE,  @C_ITEMPROIMPOS_IDMODBCSTNFE, @C_ITEMPROIMPOS_CDTPCREDPICOITE, @C_ITEMPROIMPOS_CDNATUBCALPCIT, ISNULL(@C_ITEMPROIMPOS_IDMOTDESONERAIT,'9'), @C_ITEMPROIMPOS_IDTRIMPSTII,
                                  @V_CDDETALHEPRODTEMP, @C_ITEMPROIMPOS_CDENQLEGALIPI, @C_ITEMPROIMPOS_CDCEST);
                        END
                        ELSE BEGIN
                           INSERT INTO ITEMPROIMPOSORIG(CDFILIAL,     NRLANCTONF,     NRSEQITPROD,     CDIMPOSTO,      NRITPROIMPOS,    CDFISCALIT,
                                                    CDSITUTRIBIT, CDFISCOPERIT,   CDSUFXCFOPIT,    VRALIQITEM,     VRPERREDBCIT,    VRPARDEDIT,
                                                    VRCONTITIMP,  VRBASECALCIT,   VRIMPOSTOIT,     IDERROSIMPIT,   IDAVISIMPIT,     CDSITUTRIBITNFE,
                                                    IDMODBCITNFE, IDMODBCSTITNFE, CDTPCREDPICOITE, CDNATUBCALPCIT, IDMOTDESONERAIT, IDTRIMPSTII,
                                                    CDDETALHEPROD, CDENQLEGALIPI, CDCEST)
                           VALUES(@P_FILIAL, @P_LANCTONF, @V_ITEMPRODU_NRSEQITPROD, @C_ITEMPROIMPOS_CDIMPOSTO, @C_ITEMPROIMPOS_NRITPROIMPOS, @C_ITEMPROIMPOS_CDFISCALIT,
                                  @V_ITEMPRODU_CDSITUTRIBPR, @V_FISOPEITEM,   @V_SUFXCFOPPR, @C_ITEMPROIMPOS_VRALIQITEM, @C_ITEMPROIMPOS_VRPERREDBCIT, ROUND((@C_ITEMPROIMPOS_VRPARDEDIT * @V_VRFATOCONV),2),
                                  ROUND((@C_ITEMPROIMPOS_VRCONTITIMP * @V_VRFATOCONV),2), ROUND((@C_ITEMPROIMPOS_VRBASECALCIT * @V_VRFATOCONV),2),
                                  ROUND((@C_ITEMPROIMPOS_VRIMPOSTOIT * @V_VRFATOCONV),2), '00000',                   '00000', @C_ITEMPROIMPOS_CDSITUTRIBNFE,
                                  @C_ITEMPROIMPOS_IDMODBCNFE,  @C_ITEMPROIMPOS_IDMODBCSTNFE, @C_ITEMPROIMPOS_CDTPCREDPICOITE, @C_ITEMPROIMPOS_CDNATUBCALPCIT, ISNULL(@C_ITEMPROIMPOS_IDMOTDESONERAIT,'9'), @C_ITEMPROIMPOS_IDTRIMPSTII,
                                  @V_CDDETALHEPRODTEMP, @C_ITEMPROIMPOS_CDENQLEGALIPI, @C_ITEMPROIMPOS_CDCEST);
                        END;
                     END;

                     IF (NOT((@V_IDGERICMSTDESPA = 'S') AND (@V_CDIMPOSTRIB IS NOT NULL) OR (@V_IDGERIPIDESPA = 'S')
                        AND (@V_CDIMPOSIPI IS NOT NULL)) AND (@V_IDUTCTRLFIS = 'S')) OR (@V_IDUTCTRLFIS = 'N')  BEGIN

                        EXEC CONSULTA_INCIDENCIA 'S', @P_EMPRESA, @V_ITEMPRODU_CDARVPROD, @P_INSCESTA, @P_TIPOOPER, @P_FILIAL, @P_LANCTONF, @V_CDGRUPOFISC,
                                                 @V_IDINTEREST, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, @V_ITEMPRODU_IDORIGEMPROD;

                        SELECT @V_CDFISCTEMP = MAX(CDFISCTEMP),
                               @V_CDDETALHEPRODTEMP = MAX(CDDETALHEPROD),
                               @V_CDENQLEGALIPI = MAX(CDENQLEGALIPI),
                               @V_CDCEST = MAX(CDCEST)
                          FROM INCITEMP IT, IMPOSTO IP
                         WHERE IT.NRINCITEMP = @V_INCITEMP
                           AND IP.CDIMPOSTO  = IT.CDIMPOTEMP
                           AND IP.IDPRODNOTA = 'P'
                           AND IT.CDIMPOTEMP = @C_ITEMPROIMPOS_CDIMPOSTO;

                        IF (@C_ITEMPROIMPOS_VRPERREDBCIT > 0.00) AND
                           (@C_ITEMPROIMPOS_NRITPROIMPOS = '2')  BEGIN
                           SET @V_CDFISCTEMP = '2';
                        END
                        ELSE BEGIN
                           IF (@V_CDFISCTEMP IS NULL) BEGIN
                               SET @V_CDFISCTEMP = @C_ITEMPROIMPOS_CDFISCALIT;
                           END;
                        END;

                        IF @V_CDENQLEGALIPI IS NULL BEGIN
                           SET @V_CDENQLEGALIPI = @C_ITEMPROIMPOS_CDENQLEGALIPI;
                        END;

                        IF @V_CDCEST IS NULL BEGIN
                           SET @V_CDCEST = @C_ITEMPROIMPOS_CDCEST;
                        END;

                        DELETE INCITEMP
                         WHERE NRINCITEMP = @V_INCITEMP;

                        /*VERIFICA CST POR IMPOSTO*/
                        SET @V_IMPOICMS = NULL;
                        SET @V_CDGRUPOFISCAUX = NULL;

                        SELECT @V_CDGRUPOFISCAUX = MAX(G.CDGRUPOFISC)
                          FROM GRUPOFISCIMPFIL G,
                               (SELECT CDFILIEMIT AS CDFILIAL
                                  FROM NOTAFISCAL
                                 WHERE CDFILIAL = @P_FILIAL
                                   AND NRLANCTONF = @P_LANCTONF) F
                         WHERE G.CDFILIAL = F.CDFILIAL
                           AND NOT G.CDGRUPOFISC IS NULL
                           AND G.CDIMPOSTO = @C_ITEMPROIMPOS_CDIMPOSTO;

                        IF @V_IDORIGDESTNF = 'C' BEGIN
                           SELECT @V_CDGRUPOFISCAUX = ISNULL(MAX(G.CDGRUPOFISC), @V_CDGRUPOFISCAUX)
                             FROM GRFISIMPIECLIE G,
                                  (SELECT CDCLIENTE
                                     FROM NOTAFISCAL
                                    WHERE CDFILIAL = @P_FILIAL
                                      AND NRLANCTONF = @P_LANCTONF) N
                            WHERE G.CDCLIENTE = N.CDCLIENTE
                              AND G.CDEMPRESA = @P_EMPRESA
                              AND G.CDINSCESTA = @P_INSCESTA
                              AND NOT G.CDGRUPOFISC IS NULL
                              AND G.CDIMPOSTO = @C_ITEMPROIMPOS_CDIMPOSTO;
                        END
                        ELSE BEGIN
                           SELECT @V_CDGRUPOFISCAUX = ISNULL(MAX(G.CDGRUPOFISC), @V_CDGRUPOFISCAUX)
                             FROM GRFISIMPIEFORN G,
                                 (SELECT CDFORNECED
                                    FROM NOTAFISCAL
                                   WHERE CDFILIAL = @P_FILIAL
                                     AND NRLANCTONF = @P_LANCTONF) N
                            WHERE G.CDFORNECED = N.CDFORNECED
                              AND G.CDEMPRESA = @P_EMPRESA
                              AND G.CDINSCESTA = @P_INSCESTA
                              AND NOT G.CDGRUPOFISC IS NULL
                              AND G.CDIMPOSTO = @C_ITEMPROIMPOS_CDIMPOSTO;
                        END;

                        IF @V_CDGRUPOFISCAUX IS NULL BEGIN
                           EXEC CONSULTA_CST_NFE 'S', @P_EMPRESA, @V_ITEMPRODU_CDARVPROD, @P_INSCESTA, @P_TIPOOPER, @V_CDGRUPOFISC, @C_ITEMPROIMPOS_CDIMPOSTO, @V_IDINTEREST, @V_IDINTERNA, @P_FILIAL, @P_LANCTONF, '', @P_CDSITTRIBTMP = @V_CDSITTRIBTMP OUTPUT, @P_IDMODBCNFE = @V_IDMODBCNFE OUTPUT, @P_IDMODBCSTNFE = @V_IDMODBCSTNFE OUTPUT, @P_CDTPCRPICOSTNFE = @V_CDTPCRPICOSTNFE OUTPUT, @P_CDNATUBCPCSTNFE = @V_CDNATUBCPCSTNFE OUTPUT, @P_IDMOTIDESSTNFE = @V_IDMOTIDESSTNFE OUTPUT;
                        END
                        ELSE BEGIN
                           EXEC CONSULTA_CST_NFE 'S', @P_EMPRESA, @V_ITEMPRODU_CDARVPROD, @P_INSCESTA, @P_TIPOOPER, @V_CDGRUPOFISCAUX, @C_ITEMPROIMPOS_CDIMPOSTO, @V_IDINTEREST, @V_IDINTERNA, @P_FILIAL, @P_LANCTONF, '', @P_CDSITTRIBTMP = @V_CDSITTRIBTMP OUTPUT, @P_IDMODBCNFE = @V_IDMODBCNFE OUTPUT, @P_IDMODBCSTNFE = @V_IDMODBCSTNFE OUTPUT, @P_CDTPCRPICOSTNFE = @V_CDTPCRPICOSTNFE OUTPUT, @P_CDNATUBCPCSTNFE = @V_CDNATUBCPCSTNFE OUTPUT, @P_IDMOTIDESSTNFE = @V_IDMOTIDESSTNFE OUTPUT;
                        END;

                        IF (@V_CDSITTRIBTMP IS NULL) BEGIN
                           SET @V_CDSITUTRIBNFE = @C_ITEMPROIMPOS_CDSITUTRIBNFE;
                        END
                        ELSE BEGIN
                           SET @V_CDSITUTRIBNFE = @V_CDSITTRIBTMP;
                        END;

                        IF (@V_IDMODBCNFE IS NULL) BEGIN
                           SET @V_IDMODBCNFEIT = @C_ITEMPROIMPOS_IDMODBCNFE;
                        END
                        ELSE BEGIN
                           SET @V_IDMODBCNFEIT = @V_IDMODBCNFE;
                        END;

                        IF (@V_IDMODBCSTNFE IS NULL) BEGIN
                           SET @V_IDMODBCSTNFEIT = @C_ITEMPROIMPOS_IDMODBCSTNFE;
                        END
                        ELSE BEGIN
                           SET @V_IDMODBCSTNFEIT = @V_IDMODBCSTNFE;
                        END;

                        IF (@C_ITEMPROIMPOS_CDTPCREDPICOITE IS NULL) BEGIN
                           SET @V_CDTPCRPICOSTNFEIT = @V_CDTPCRPICOSTNFE;
                        END
                        ELSE BEGIN
                           SET @V_CDTPCRPICOSTNFEIT = @C_ITEMPROIMPOS_CDTPCREDPICOITE;
                        END;

                        IF (@C_ITEMPROIMPOS_CDNATUBCALPCIT IS NULL) BEGIN
                           SET @V_CDNATUBCPCSTNFEIT = @V_CDNATUBCPCSTNFE;
                        END
                        ELSE BEGIN
                           SET @V_CDNATUBCPCSTNFEIT = @C_ITEMPROIMPOS_CDNATUBCALPCIT;
                        END;

                        IF (@V_IDMOTIDESSTNFE IS NULL) BEGIN
                           SET @V_IDMOTIDESSTNFE = @C_ITEMPROIMPOS_IDMOTDESONERAIT;
                        END
                        ELSE BEGIN
                           SET @V_IDMOTIDESSTNFE = @V_IDMOTIDESSTNFE;
                        END;


                        SELECT @V_IDUTMUNIORIG = ISNULL(MAX(IDUTMUNIORIG),'N')
                          FROM IMPOSTO
                         WHERE CDIMPOSTO = @C_ITEMPROIMPOS_CDIMPOSTO;

                        IF (@C_ITEMPROIMPOS_IDUTVRPAUTAPROD = 'S') AND (@C_ITEMPROIMPOS_IDUTVRPAUTA = 'S') BEGIN
                           SET @V_LIQUIITEM = (@V_ITEMPRODU_QTITEMPROD * @C_ITEMPROIMPOS_VRPAUTAMINPROD) / @C_ITEMPROIMPOS_QTITEMPROD;
                        END ELSE BEGIN
                           SET @V_LIQUIITEM = @V_ITEMPRODU_VRTOTAITEM - @V_ITEMPRODU_VRDESCITEM;
                        END;

                        IF ((@V_IDUTMUNIORIG = 'O') OR (@V_IDUTMUNIORIG = 'N')) BEGIN
                           EXEC CONSULTA_ALIQUOTA @C_ITEMPROIMPOS_CDIMPOSTO, 'S', @P_EMPRESA, @V_ITEMPRODU_CDARVPROD, @P_INSCESTA, @V_PAISORIG,
                                                  @V_ESTAORIG, @V_PAISDEST, @V_ESTADEST, @V_MUNIORIG, @V_LIQUIITEM, @P_INIVALID, @P_FILIAL, @P_LANCTONF, @V_CDGRUPOFISC, @P_TIPOOPER,
                                                  NULL, NULL, NULL, NULL, NULL, NULL, @V_ITEMPRODU_IDORIGEMPROD;
                        END
                        ELSE BEGIN
                           EXEC CONSULTA_ALIQUOTA @C_ITEMPROIMPOS_CDIMPOSTO, 'S', @P_EMPRESA, @V_ITEMPRODU_CDARVPROD, @P_INSCESTA, @V_PAISORIG,
                                                  @V_ESTAORIG, @V_PAISDEST, @V_ESTADEST, @V_MUNIDEST, @V_LIQUIITEM, @P_INIVALID, @P_FILIAL, @P_LANCTONF, @V_CDGRUPOFISC, @P_TIPOOPER,
                                                  NULL, NULL, NULL, NULL, NULL, NULL, @V_ITEMPRODU_IDORIGEMPROD;
                        END;

                        SET @V_NRALIQTEMP = 0;
                        SET @V_PARDEDTMP  = 0;
                        SET @V_PREDBCTMP  = 0;
                        SET @V_ALIQUTMP   = 0;
                        SET @V_IMPOSTOIT  = 0;
                        SET @V_CDTIPOOPER = NULL;
                        SET @V_CDREGRAITALIQ = NULL;


                        SELECT @V_NRALIQTEMP = ISNULL(MAX(NRALIQTEMP),0),
                               @V_PARDEDTMP = ISNULL(MAX(VRPARDEDTMP),0),
                               @V_PREDBCTMP = ISNULL(MAX(VRPREDBCTMP),0),
                               @V_ALIQUTMP = ISNULL(MAX(VRALIQUTMP),0),
                               @V_TRATIMPST = ISNULL(MAX(IDTRIMPSTTMP), '0'),
                               @V_PBCSUBTRIB = ISNULL(MAX(VRPBCSTTMP),0),
                               @V_IDPMCBASECAL = ISNULL(MAX(IDPMCBSCALTMP), 'S'),
                               @V_CDTIPOOPER = MAX(CDTIPOOPERTMP),
                               @V_CDREGRAITALIQ = MAX(CDREGRATMP)
                        FROM ALIQTEMP
                        WHERE (NRALIQTEMP = @V_ALIQTEMP);

                        /*QUANDO H ALIQUOTA CADASTRADA POR TIPO DE OPERAO ENTO
                        ELE NO BUSCA OS DADOS DA ORIGEM E SIM A PARAMETRIZADA NA SADA
                        DESDE QUE NO SEJA NOTA DE ESTORNO DE CANCELAMENTO*/
                        IF ((@V_NRALIQTEMP IS NOT NULL) AND (@V_CDTIPOOPER IS NOT NULL) AND (@V_ESTORNOCANC <> 'S')) BEGIN

                           SET @V_CDIMPOSRECALC = ISNULL(@V_CDIMPOSRECALC,'')+@C_ITEMPROIMPOS_CDIMPOSTO+'_';
                           IF /*(@C_ITEMPROIMPOS_VRPERREDBCIT > 0.00) AND*/
                              (@C_ITEMPROIMPOS_NRITPROIMPOS = '2')  BEGIN

                              SET @V_CDIMPOSTRIB  = null;
                              SET @V_IDVRIMPSTRIB = null;
                           END
                           ELSE BEGIN
                              SET @V_CDIMPOSTRIB  = null;
                              SET @V_IDVRIMPSTRIB = null;

                              /*IMPOSTO DE SUBSTITUICAO TRIBUTARIA*/
                              DECLARE C_ICMSST CURSOR FOR
                                 SELECT CDIMPOSTO
                                   FROM IMPOSTO
                                  WHERE CDIMPOSTRIB = @C_ITEMPROIMPOS_CDIMPOSTO;

                              OPEN C_ICMSST;
                              FETCH NEXT FROM C_ICMSST INTO @V_ICMSST_CDIMPOSTRIB;

                              WHILE (@@FETCH_STATUS = 0) BEGIN
                                 SET @V_CDIMPOSTRIB = ISNULL(@V_CDIMPOSTRIB,'')+@V_ICMSST_CDIMPOSTRIB+'_';
                                 FETCH NEXT FROM C_ICMSST INTO @V_ICMSST_CDIMPOSTRIB;
                              END;
                              CLOSE C_ICMSST;
                              DEALLOCATE C_ICMSST;

                              SET @V_TAXABASECALC = (100 - @V_PREDBCTMP)/100;
                              SET @V_TAXAALIQUOTA = (@V_ALIQUTMP/100);
                              SET @V_TAXABCSUBSTR = 1 + (@V_PBCSUBTRIB/100);
                              SET @V_BASECALCIT   = @V_LIQUIITEM * @V_TAXABASECALC;

                              SET @V_PERDBCALC    = 100 - @V_PREDBCTMP;

                              IF @V_PBCSUBTRIB > 0 BEGIN
                                 SET @V_BASECALCIT = (@V_BASECALCIT * @V_TAXABCSUBSTR);
                                 SET @V_PREDBCTMP  = @V_PBCSUBTRIB;
                                 SET @V_PERDBCALC  = 0;
                              END;


                              SELECT @V_IDUTVLRQTDEIMPO = ISNULL(MAX(IDUTVLRQTDEIMPO), 'N')
                                FROM IMPOSTO
                               WHERE CDIMPOSTO = @C_ITEMPROIMPOS_CDIMPOSTO;

                              IF (@V_IDUTVLRQTDEIMPO = 'S') BEGIN
                                 SELECT @V_VRFATOCONVES = ISNULL(MAX(VRFATOCONVES), 1)
                                   FROM CONVPRODUTO
                                  WHERE CDPRODUTO = @V_ITEMPRODU_CDPRODUTO;

                                 SET @V_BASECALCTO  = (@V_ITEMPRODU_QTITEMPROD * @V_VRFATOCONVES);
                                 SET @V_IMPOSTOIT   = ((@V_ITEMPRODU_QTITEMPROD * @V_VRFATOCONVES) * @V_ALIQUTMP) - @V_PARDEDTMP;
                              END
                              ELSE BEGIN
                                 SET @V_BASECALCTO  = @V_BASECALCIT;
                                 SET @V_IMPOSTOIT   = (@V_BASECALCIT * @V_TAXAALIQUOTA) - @V_PARDEDTMP;
                              END;

                              IF @V_CDIMPOSTRIB IS NULL BEGIN
                                 SET @V_IDTRIMPSTII = NULL;
                              END
                              ELSE BEGIN
                                 IF SUBSTRING(@V_SITUTRIBPR, 2, 2) = '60' BEGIN
                                    SET @V_IDTRIMPSTII = '2';
                                 END ELSE BEGIN
                                    SET @V_IDTRIMPSTII = @V_TRATIMPST;
                                 END;
                              END;

                              SET @V_CONTABCALC  = @V_LIQUIITEM - (@V_LIQUIITEM * @V_TAXABASECALC);

                              IF @V_CDIMPOSTRIB IS NOT NULL BEGIN
                                 /*VALOR MAXIMO DE VENDA AO COSUMIDOR*/
                                 IF @V_ORIGDESTOP = 'L' BEGIN    /* Destinatrio Filial */
                                    SELECT @V_NRINSCSUFRAMA = MAX(NRINSCSUFRAMAFI)
                                      FROM FILIAL
                                     WHERE (CDFILIAL = @P_CLIENTE);
                                 END
                                 ELSE IF @V_ORIGDESTOP = 'F' BEGIN /* Destinatrio Fornecedor */
                                    SELECT @V_NRINSCSUFRAMA = MAX(NRINSCSUFRAMAFO)
                                      FROM FORNECEDOR
                                     WHERE (CDFORNECED = @P_CLIENTE);
                                 END
                                 ELSE BEGIN                         /* Destinatrio Cliente */
                                    SELECT @V_NRINSCSUFRAMA = MAX(NRINSCSUFRAMACL)
                                      FROM CLIENTE
                                     WHERE (CDCLIENTE = @P_CLIENTE);
                                 END;

                                 IF (@V_NRINSCSUFRAMA IS NULL) BEGIN /*Verifica se h Inscrio Suframa cadastrado p o destinatrio*/
                                    SELECT @V_VRMAXVENDA     = ISNULL(MAX(VRMAXVENDA),0),
                                           @V_VRPEMAXVENDA   = ISNULL(MAX(VRPEMAXVENDA),0),
                                           @V_IDUTILVRMAX    = ISNULL(MAX(IDUTILVRMAX), 'C'),
                                           @V_VRDESCMAXVENDA = ISNULL(MAX(VRDESCMAXVENDA),0)
                                         FROM VRMAXVENPROD A
                                        WHERE (CDPAIS   = @V_PAISDEST) AND
                                              (SGESTADO = @V_ESTADEST) AND
                                              (A.CDPRODUTO = @V_ITEMPRODU_CDPRODUTO);
                                 END
                                 ELSE BEGIN
                                    SELECT @V_VRMAXVENDA     = ISNULL(MAX(VRMAXVENDA),0),
                                           @V_VRPEMAXVENDA   = ISNULL(MAX(VRPEMAXVENDA),0),
                                           @V_IDUTILVRMAX    = ISNULL(MAX(IDUTILVRMAX), 'C'),
                                           @V_VRDESCMAXVENDA = ISNULL(MAX(VRDESCMAXVENDA),0)
                                      FROM VRMAXVENPROD A
                                     WHERE (CDPAIS   = @V_PAISDEST) AND
                                           (SGESTADO = 'SF'       ) AND
                                           (A.CDPRODUTO = @V_ITEMPRODU_CDPRODUTO);
                                 END;

                                 IF (@V_VRMAXVENDA IS NOT NULL) BEGIN
                                    IF @V_IDUTILVRMAX = 'C' BEGIN
                                       SET @V_FINALVRMAXVENDA = (@V_VRMAXVENDA - ((@V_VRDESCMAXVENDA/100) * @V_VRMAXVENDA)) * (@V_VRPEMAXVENDA/100);
                                    END
                                    ELSE BEGIN
                                       SET @V_FINALVRMAXVENDA = @V_VRMAXVENDA - ((@V_VRDESCMAXVENDA/100) * @V_VRMAXVENDA);
                                    END;
                                    SET @V_CALCVLRMAX  = @V_ITEMPRODU_QTITEMPROD * @V_FINALVRMAXVENDA;
                                    SET @V_CALCVLRMAX  = @V_CALCVLRMAX * @V_TAXABASECALC;
                                    IF @V_PBCSUBTRIB > 0 BEGIN
                                       SET @V_CALCVLRMAX = (@V_CALCVLRMAX * @V_TAXABCSUBSTR);
                                       SET @V_PREDBCTMP  = @V_PBCSUBTRIB;
                                       SET @V_PERDBCALC  = 0;
                                    END;
                                    SET @V_BASEVLRMAX = ROUND(@V_CALCVLRMAX, 2);

                                    UPDATE ITEMPRODUTO
                                       SET VRMAXVENDA = @V_VRMAXVENDA
                                     WHERE CDFILIAL = @P_FILIAL
                                       AND NRLANCTONF = @P_LANCTONF
                                       AND NRSEQITPROD = @V_ITEMPRODUTO_NRSEQITPROD;
                                 END;

                                 /* Se utilizar o PMC como comparativo  feito a comparao das bases de calculos j majoradas e/ou reduzidas.
                                    O maior  a nova base de clculo.
                                    Caso seja prioridade sempre ser o PMC j majorado e/ou reduzido.
                                 */
                                 IF ISNULL(@V_IDPMCBASECAL, 'S') = 'S' BEGIN
                                    IF (@V_IDUTILVRMAX = 'C') BEGIN
                                       IF @V_BASECALCIT > @V_BASEVLRMAX BEGIN
                                          SET @V_BASECALCTO  = @V_BASECALCIT;
                                          SET @V_IMPOSTOIT   = (@V_BASECALCIT * @V_TAXAALIQUOTA) - @V_PARDEDTMP;
                                       END
                                       ELSE BEGIN
                                          SET @V_BASECALCTO  = @V_BASEVLRMAX;
                                          SET @V_IMPOSTOIT   = (@V_BASEVLRMAX * @V_TAXAALIQUOTA) - @V_PARDEDTMP;
                                       END;
                                    END
                                    ELSE BEGIN
                                       SET @V_BASECALCTO  = @V_BASEVLRMAX;
                                       SET @V_IMPOSTOIT   = (@V_BASEVLRMAX * @V_TAXAALIQUOTA) - @V_PARDEDTMP;
                                    END;
                                 END
                                 ELSE BEGIN
                                    SET @V_BASECALCTO  = @V_BASECALCIT;
                                    SET @V_IMPOSTOIT   = (@V_BASECALCIT * @V_TAXAALIQUOTA) - @V_PARDEDTMP;
                                 END;

                                 SELECT @V_IDVRIMPSTRIB = ISNULL(MAX(IDVRIMPSTRIB), 'N')
                                   FROM ITEMPROIMPOS I, IMPOSTO II
                                  WHERE (CDFILIAL     = @P_FILIAL)
                                       AND (NRLANCTONF   = @P_LANCTONF)
                                       AND (NRSEQITPROD  = @V_ITEMPRODU_NRSEQITPROD)
                                       AND (CHARINDEX(II.CDIMPOSTO+'_', @V_CDIMPOSTRIB) > 0)
                                    AND (I.CDIMPOSTO = II.CDIMPOSTO);

                                 IF (@V_TRATIMPST = '1') OR (ISNULL(@V_IDVRIMPSTRIB,'N') = 'N') BEGIN
                                    SET @V_VRIMPOSTOST = 0;
                                 END
                                 ELSE BEGIN
                                    SELECT @V_VRIMPOSTOST = ISNULL(VRIMPOSTOIT,0)
                                      FROM ITEMPROIMPOS I
                                     WHERE (CDFILIAL     = @P_FILIAL)
                                       AND (NRLANCTONF   = @P_LANCTONF)
                                       AND (NRSEQITPROD  = @V_ITEMPRODU_NRSEQITPROD)
                                       AND (CHARINDEX(CDIMPOSTO+'_', @V_CDIMPOSTRIB) > 0)
                                       AND (NRITPROIMPOS = '1');
                                 END;
                                 SET @V_IMPOSTOIT = @V_IMPOSTOIT - @V_VRIMPOSTOST;

                                 IF @V_IMPOSTOIT < 0 BEGIN
                                    SET @V_IMPOSTOIT = 0;
                                 END;
                              END;

                              IF (@V_ALIQUTMP = 0) AND (@V_IMPOSTOIT = 0) BEGIN
                                 SET @V_BASECALCTO = 0;
                              END;

                              SELECT @V_CHAVE = CDFILIAL
                                FROM ITEMPROIMPOS
                               WHERE CDFILIAL     = @P_FILIAL                 AND
                                     NRLANCTONF   = @P_LANCTONF               AND
                                     NRSEQITPROD  = @V_ITEMPRODU_NRSEQITPROD   AND
                                     CDIMPOSTO    = @C_ITEMPROIMPOS_CDIMPOSTO AND
                                     NRITPROIMPOS = @C_ITEMPROIMPOS_NRITPROIMPOS;

                              SELECT @V_IDPERVISIMPSCRE = ISNULL(MAX(IDPERVISIMPSCRE), 'S')
                                FROM PARAMGERAL;

                              IF @V_IDPERVISIMPSCRE = 'S' BEGIN
                                 SET @V_VRIMPOSTOVISUIT = @V_IMPOSTOIT;
                              END
                              ELSE BEGIN
                                 IF (@V_CDFISCTEMP = '1') BEGIN
                                    SET @V_VRIMPOSTOVISUIT = @V_IMPOSTOIT;
                                 END
                                 ELSE BEGIN
                                    SET @V_VRIMPOSTOVISUIT = 0;
                                 END;
                              END;

                              /* ROTINA PARA CALCULAR O DIFERIMENTO DO IMPOSTO */
                              SET @V_PERDIFERE    = NULL;
                              SET @V_IMPOSTOOPERA = NULL;
                              SET @V_IMPOSTODIFER = NULL;

                              IF @C_ITEMPROIMPOS_CDIMPOSTONFE = '00' BEGIN
                                 IF @V_CDSITTRIBTMP = 51 BEGIN
                                    SET @V_VRPERDIFERE = NULL;
                                    SET @V_IDDIFECLI = 'N';

                                    SELECT @V_VRPERDIFERE = PD.VRPERDIFERE, @V_IDDIFECLI = 'S'
                                      FROM PRODDIFEREIMPCLI PD, PRODUTO PR
                                     WHERE PD.CDPRODUTO = PR.CDPRODUTO
                                       AND PD.CDPAIS = @V_PAISORIG
                                       AND PD.SGESTADO = @V_ESTAORIG
                                       AND PD.CDCLIENTE = @P_CLIENTE
                                       AND PR.CDARVPROD IN (SELECT MAX(PR.CDARVPROD) AS CDARVPROD
                                                              FROM PRODDIFEREIMPCLI PD, PRODUTO PR
                                                             WHERE PD.CDPRODUTO = PR.CDPRODUTO
                                                               AND PD.CDPAIS = @V_PAISORIG
                                                               AND PD.SGESTADO = @V_ESTAORIG
                                                               AND PD.CDCLIENTE = @P_CLIENTE
                                                               AND CHARINDEX(PR.CDARVPROD, ISNULL(RTRIM(@V_ITEMPROD_CDARVPROD), PR.CDARVPROD)) = 1);

                                    IF @V_IDDIFECLI = 'N' BEGIN
                                       SELECT @V_VRPERDIFERE = PD.VRPERDIFERE
                                         FROM PRODDIFEREIMPOS PD, PRODUTO PR
                                        WHERE PD.CDPRODUTO = PR.CDPRODUTO
                                          AND PD.CDPAIS = @V_PAISORIG
                                          AND PD.SGESTADO = @V_ESTAORIG
                                          AND PR.CDARVPROD IN (SELECT MAX(PR.CDARVPROD) AS CDARVPROD
                                                                 FROM PRODDIFEREIMPOS PD, PRODUTO PR
                                                                WHERE PD.CDPRODUTO = PR.CDPRODUTO
                                                                  AND PD.CDPAIS = @V_PAISORIG
                                                                  AND PD.SGESTADO = @V_ESTAORIG
                                                                  AND CHARINDEX(PR.CDARVPROD, ISNULL(RTRIM(@V_ITEMPROD_CDARVPROD), PR.CDARVPROD)) = 1);
                                    END;
                                                                  
                                    IF @V_VRPERDIFERE IS NOT NULL BEGIN
                                       SET @V_PERDIFERE = @V_VRPERDIFERE;
                                       SET @V_IMPOSTOOPERA = @V_IMPOSTOIT;
                                       SET @V_IMPOSTODIFER = @V_IMPOSTOOPERA * (@V_VRPERDIFERE/100);
                                       SET @V_IMPOSTOIT = @V_IMPOSTOOPERA - @V_IMPOSTODIFER;
                                    END;
                                 END;
                              END;

                              IF @V_CHAVE IS NULL BEGIN
                                 SET @V_ICMS = NULL;
                                 DECLARE C_ICMS CURSOR FOR
                                    SELECT CDIMPOSTO
                                      FROM IMPOSTONFE N, IMPOSTO I
                                     WHERE N.CDIMPOSTONFE = I.CDIMPOSTONFE
                                       AND N.CDIMPOSTONFE = '00'
                                       AND I.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
                                 OPEN C_ICMS;
                                 FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
                                 WHILE (@@FETCH_STATUS = 0) BEGIN
                                    SET @V_ICMS = 'S';
                                    FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
                                 END;
                                 CLOSE C_ICMS;
                                 DEALLOCATE C_ICMS;

                                 IF ((@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV')) AND (@V_ICMS = 'S') BEGIN
                                    INSERT INTO ITEMPROIMPOS(
                                       CDFILIAL,        NRLANCTONF,   NRSEQITPROD,    CDIMPOSTO,       NRITPROIMPOS,   CDFISCALIT,
                                       CDSITUTRIBIT,    CDFISCOPERIT, CDSUFXCFOPIT,   VRALIQITEM,      VRPERREDBCIT,   VRPARDEDIT,
                                       VRCONTITIMP,     VRBASECALCIT, VRIMPOSTOIT,    IDERROSIMPIT,    IDAVISIMPIT,    IDTRIMPSTII,
                                       CDSITUTRIBITNFE, IDMODBCITNFE, IDMODBCSTITNFE, CDTPCREDPICOITE, CDNATUBCALPCIT, IDMOTDESONERAIT,
                                       CDDETALHEPROD,   CDREGRAIT, VRIMPOSTOVISUIT, VRPERDIFEREIT, VRIMPOSTOOPERAIT, VRIMPOSTODIFERIT,
                                       CDENQLEGALIPI,   CDCEST)
                                    VALUES(
                                       @P_FILIAL,                 @P_LANCTONF,     @V_ITEMPRODU_NRSEQITPROD, @C_ITEMPROIMPOS_CDIMPOSTO, '1',                  @V_CDFISCTEMP,
                                       @V_ITEMPRODU_CDSITUTRIBPR, @V_FISOPEITEM,   @V_SUFXCFOPPR,            @V_ALIQUTMP,               @V_PREDBCTMP,         @V_PARDEDTMP,
                                       ROUND(@V_BASECALCTO,2,2),  @V_BASECALCTO,   ROUND(@V_IMPOSTOIT,2,2),  '00000',                   '00000',              @V_IDTRIMPSTII,
                                       @V_CDSITUTRIBNFE,          @V_IDMODBCNFEIT, @V_IDMODBCSTNFEIT,        @V_CDTPCRPICOSTNFEIT,      @V_CDNATUBCPCSTNFEIT, @V_IDMOTIDESSTNFE,
                                       @V_CDDETALHEPRODTEMP,      @V_CDREGRAITALIQ, ROUND(@V_VRIMPOSTOVISUIT,2,2), @V_PERDIFERE, @V_IMPOSTOOPERA, @V_IMPOSTODIFER,
                                       @V_CDENQLEGALIPI,          @V_CDCEST);
                                 END
                                 ELSE BEGIN
                                    IF (@C_ITEMPROIMPOS_NRITPROIMPOS = '3')  BEGIN
                                        SET @V_DIFALIQ = 0;

                                       SELECT @V_DIFALIQ = VRALIQITEM
                                         FROM ITEMPROIMPOS IT, ITEMPRODUTO I
                                        WHERE IT.CDFILIAL     = @V_CDFILIALIT
                                          AND IT.NRLANCTONF   = @V_NRLANCTONFIT
                                          AND I.CDFILIAL      = @V_CDFILIALIT
                                          AND I.NRLANCTONF    = @V_NRLANCTONFIT
                                          AND IT.NRSEQITPROD  = I.NRSEQITPROD
                                          AND I.CDPRODUTO     = @V_ITEMPRODU_CDPRODUTO
                                          AND ROUND(I.VRUNITITEM, @V_NRDECITOTANF) = ROUND(@V_ITEMPRODU_VRUNITITEM, @V_NRDECITOTANF)
                                          AND (ISNULL(NRLOTEESTQ, ' ') = (ISNULL(@V_ITEMPRODU_NRLOTEESTQ, ' ')))
                                          AND (ISNULL(NRSUBLOTE, ' ')  = (ISNULL(@V_ITEMPRODU_NRSUBLOTE , ' ')))
                                          AND IT.CDIMPOSTO    = @C_ITEMPROIMPOS_CDIMPOSTO
                                          AND IT.NRITPROIMPOS = '1';


                                       IF  (@V_ALIQUTMP = @V_DIFALIQ) BEGIN

                                          INSERT INTO ITEMPROIMPOS(
                                             CDFILIAL,        NRLANCTONF,   NRSEQITPROD,    CDIMPOSTO,       NRITPROIMPOS,   CDFISCALIT,
                                             CDSITUTRIBIT,    CDFISCOPERIT, CDSUFXCFOPIT,   VRALIQITEM,      VRPERREDBCIT,   VRPARDEDIT,
                                             VRCONTITIMP,     VRBASECALCIT, VRIMPOSTOIT,    IDERROSIMPIT,    IDAVISIMPIT,    IDTRIMPSTII,
                                             CDSITUTRIBITNFE, IDMODBCITNFE, IDMODBCSTITNFE, CDTPCREDPICOITE, CDNATUBCALPCIT, IDMOTDESONERAIT,
                                             CDDETALHEPROD,   VRIMPOSTOVISUIT,   CDREGRAIT, IDDIFALIQCUSPRI, CDENQLEGALIPI,  CDCEST)
                                          VALUES(
                                             @P_FILIAL, @P_LANCTONF, @V_ITEMPROD_NRSEQITPROD, @C_ITEMPROIMPOS_CDIMPOSTO, @C_ITEMPROIMPOS_NRITPROIMPOS, @C_ITEMPROIMPOS_CDFISCALIT,
                                             @V_ITEMPRODU_CDSITUTRIBPR, @V_FISOPEITEM, @V_SUFXCFOPPR, @C_ITEMPROIMPOS_VRALIQITEM, @C_ITEMPROIMPOS_VRPERREDBCIT, (@C_ITEMPROIMPOS_VRPARDEDIT * @V_VRFATOCONV),
                                             ROUND((@C_ITEMPROIMPOS_VRCONTITIMP * @V_VRFATOCONV),2), (@C_ITEMPROIMPOS_VRBASECALCIT * @V_VRFATOCONV),
                                             (@C_ITEMPROIMPOS_VRIMPOSTOIT * @V_VRFATOCONV), '00000', '00000', @C_ITEMPROIMPOS_IDTRIMPSTII, @C_ITEMPROIMPOS_CDSITUTRIBNFE,
                                             @C_ITEMPROIMPOS_IDMODBCNFE, @C_ITEMPROIMPOS_IDMODBCSTNFE, @C_ITEMPROIMPOS_CDTPCREDPICOITE, @C_ITEMPROIMPOS_CDNATUBCALPCIT, ISNULL(@C_ITEMPROIMPOS_IDMOTDESONERAIT,'9'),
                                             @V_CDDETALHEPRODTEMP, (@C_ITEMPROIMPOS_VRIMPOSTOIT * @V_VRFATOCONV), @V_CDREGRAITALIQ, @C_ITEMPROIMPOS_IDDIFALIQCUSPRI, @V_CDENQLEGALIPI, @V_CDCEST);
                                       /*Inserir a linha de diferencial de alquota*/
                                       END;
                                    END
                                    ELSE BEGIN
                                       INSERT INTO ITEMPROIMPOS(
                                          CDFILIAL,        NRLANCTONF,   NRSEQITPROD,    CDIMPOSTO,       NRITPROIMPOS,   CDFISCALIT,
                                          CDSITUTRIBIT,    CDFISCOPERIT, CDSUFXCFOPIT,   VRALIQITEM,      VRPERREDBCIT,   VRPARDEDIT,
                                          VRCONTITIMP,     VRBASECALCIT, VRIMPOSTOIT,    IDERROSIMPIT,    IDAVISIMPIT,    IDTRIMPSTII,
                                          CDSITUTRIBITNFE, IDMODBCITNFE, IDMODBCSTITNFE, CDTPCREDPICOITE, CDNATUBCALPCIT, IDMOTDESONERAIT,
                                          CDDETALHEPROD,   CDREGRAIT,    VRIMPOSTOVISUIT, VRPERDIFEREIT, VRIMPOSTOOPERAIT, VRIMPOSTODIFERIT,
                                          CDENQLEGALIPI,   CDCEST)
                                       VALUES(
                                          @P_FILIAL,                 @P_LANCTONF,     @V_ITEMPRODU_NRSEQITPROD, @C_ITEMPROIMPOS_CDIMPOSTO, '1',                  @V_CDFISCTEMP,
                                          @V_ITEMPRODU_CDSITUTRIBPR, @V_FISOPEITEM,   @V_SUFXCFOPPR,            @V_ALIQUTMP,               @V_PREDBCTMP,         @V_PARDEDTMP,
                                          ROUND(@V_BASECALCTO,2),    @V_BASECALCTO,   ROUND(@V_IMPOSTOIT,2),    '00000',                   '00000',              @V_IDTRIMPSTII,
                                          @V_CDSITUTRIBNFE,          @V_IDMODBCNFEIT, @V_IDMODBCSTNFEIT,        @V_CDTPCRPICOSTNFEIT,      @V_CDNATUBCPCSTNFEIT, @V_IDMOTIDESSTNFE,
                                          @V_CDDETALHEPRODTEMP,      @V_CDREGRAITALIQ, ROUND(@V_VRIMPOSTOVISUIT,2), @V_PERDIFERE, @V_IMPOSTOOPERA, @V_IMPOSTODIFER,
                                          @V_CDENQLEGALIPI,          @V_CDCEST);
                                     END;
                                 END;

                                 IF (@C_ITEMPROIMPOS_NRITPROIMPOS = '1') BEGIN
                                    IF (@V_PREDBCTMP > 0) AND (@V_PBCSUBTRIB = 0) BEGIN
                                       IF @V_ITEMPRODU_CDSITUTRIBPR = '060' BEGIN
                                          INSERT INTO ITEMPROIMPOS(
                                             CDFILIAL,        NRLANCTONF,   NRSEQITPROD,    CDIMPOSTO,       NRITPROIMPOS,   CDFISCALIT,
                                             CDSITUTRIBIT,    CDFISCOPERIT, CDSUFXCFOPIT,   VRALIQITEM,      VRPERREDBCIT,   VRPARDEDIT,
                                             VRCONTITIMP,     VRBASECALCIT, VRIMPOSTOIT,    IDERROSIMPIT,    IDAVISIMPIT,    IDTRIMPSTII,
                                             CDSITUTRIBITNFE, IDMODBCITNFE, IDMODBCSTITNFE, CDTPCREDPICOITE, CDNATUBCALPCIT, IDMOTDESONERAIT,
                                             CDDETALHEPROD,   CDREGRAIT,    VRIMPOSTOVISUIT, CDENQLEGALIPI, CDCEST)
                                          VALUES(
                                             @P_FILIAL,                 @P_LANCTONF,     @V_ITEMPRODU_NRSEQITPROD, @C_ITEMPROIMPOS_CDIMPOSTO, '2',                  '2',
                                             @V_ITEMPRODU_CDSITUTRIBPR, @V_FISOPEITEM,   @V_SUFXCFOPPR,            0,                         @V_PERDBCALC,         @V_PARDEDTMP,
                                             ROUND(@V_CONTABCALC,2),    0,               0,                        '00000',                   '00000',              @V_IDTRIMPSTII,
                                             @V_CDSITUTRIBNFE,          @V_IDMODBCNFEIT, @V_IDMODBCSTNFEIT,        @V_CDTPCRPICOSTNFEIT,      @V_CDNATUBCPCSTNFEIT, @V_IDMOTIDESSTNFE,
                                             @V_CDDETALHEPRODTEMP,      @V_CDREGRAITALIQ, 0, @V_CDENQLEGALIPI, @V_CDCEST);
                                       END
                                       ELSE BEGIN
                                          INSERT INTO ITEMPROIMPOS(
                                             CDFILIAL,        NRLANCTONF,   NRSEQITPROD,    CDIMPOSTO,       NRITPROIMPOS,   CDFISCALIT,
                                             CDSITUTRIBIT,    CDFISCOPERIT, CDSUFXCFOPIT,   VRALIQITEM,      VRPERREDBCIT,   VRPARDEDIT,
                                             VRCONTITIMP,     VRBASECALCIT, VRIMPOSTOIT,    IDERROSIMPIT,    IDAVISIMPIT,    IDTRIMPSTII,
                                             CDSITUTRIBITNFE, IDMODBCITNFE, IDMODBCSTITNFE, CDTPCREDPICOITE, CDNATUBCALPCIT, IDMOTDESONERAIT,
                                             CDDETALHEPROD,   CDREGRAIT, VRIMPOSTOVISUIT, CDENQLEGALIPI, CDCEST)
                                          VALUES(
                                             @P_FILIAL,                 @P_LANCTONF,     @V_ITEMPRODU_NRSEQITPROD, @C_ITEMPROIMPOS_CDIMPOSTO, '2',                  '2',
                                             @V_ITEMPRODU_CDSITUTRIBPR, @V_FISOPEITEM,   @V_SUFXCFOPPR,            0,                         @V_PERDBCALC,         @V_PARDEDTMP,
                                             ROUND(@V_CONTABCALC,2),    0,               0,                        '00000',                   '00000',              @V_IDTRIMPSTII,
                                             @V_CDSITUTRIBNFE,          @V_IDMODBCNFEIT, @V_IDMODBCSTNFEIT,        @V_CDTPCRPICOSTNFEIT,      @V_CDNATUBCPCSTNFEIT, @V_IDMOTIDESSTNFE,
                                             @V_CDDETALHEPRODTEMP,      @V_CDREGRAITALIQ, 0, @V_CDENQLEGALIPI, @V_CDCEST);
                                       END;
                                    END;
                                 END;
                                 IF ((@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV')) AND (@V_ICMS = 'S') BEGIN
                                    INSERT INTO ITEMPROIMPOSORIG(CDFILIAL,     NRLANCTONF,     NRSEQITPROD,     CDIMPOSTO,      NRITPROIMPOS,    CDFISCALIT,
                                                             CDSITUTRIBIT, CDFISCOPERIT,   CDSUFXCFOPIT,    VRALIQITEM,     VRPERREDBCIT,    VRPARDEDIT,
                                                             VRCONTITIMP,  VRBASECALCIT,   VRIMPOSTOIT,     IDERROSIMPIT,   IDAVISIMPIT,     CDSITUTRIBITNFE,
                                                             IDMODBCITNFE, IDMODBCSTITNFE, CDTPCREDPICOITE, CDNATUBCALPCIT, IDMOTDESONERAIT, IDTRIMPSTII,
                                                             CDDETALHEPROD, CDENQLEGALIPI, CDCEST)
                                    VALUES(@P_FILIAL, @P_LANCTONF, @V_ITEMPRODU_NRSEQITPROD, @C_ITEMPROIMPOS_CDIMPOSTO, @C_ITEMPROIMPOS_NRITPROIMPOS, @C_ITEMPROIMPOS_CDFISCALIT,
                                           @V_ITEMPRODU_CDSITUTRIBPR, @V_FISOPEITEM,   @V_SUFXCFOPPR, @C_ITEMPROIMPOS_VRALIQITEM, @C_ITEMPROIMPOS_VRPERREDBCIT, ROUND((@C_ITEMPROIMPOS_VRPARDEDIT * @V_VRFATOCONV),2,2),
                                           ROUND((@C_ITEMPROIMPOS_VRCONTITIMP * @V_VRFATOCONV),2,2), ROUND((@C_ITEMPROIMPOS_VRBASECALCIT * @V_VRFATOCONV),2,2),
                                           ROUND((@C_ITEMPROIMPOS_VRIMPOSTOIT * @V_VRFATOCONV),2,2), '00000',                   '00000', @C_ITEMPROIMPOS_CDSITUTRIBNFE,
                                           @C_ITEMPROIMPOS_IDMODBCNFE,  @C_ITEMPROIMPOS_IDMODBCSTNFE, @C_ITEMPROIMPOS_CDTPCREDPICOITE, @C_ITEMPROIMPOS_CDNATUBCALPCIT, ISNULL(@C_ITEMPROIMPOS_IDMOTDESONERAIT,'9'), @C_ITEMPROIMPOS_IDTRIMPSTII,
                                           @V_CDDETALHEPRODTEMP, @V_CDENQLEGALIPI, @V_CDCEST);
                                 END
                                 ELSE BEGIN
                                    INSERT INTO ITEMPROIMPOSORIG(CDFILIAL,     NRLANCTONF,     NRSEQITPROD,     CDIMPOSTO,      NRITPROIMPOS,    CDFISCALIT,
                                                             CDSITUTRIBIT, CDFISCOPERIT,   CDSUFXCFOPIT,    VRALIQITEM,     VRPERREDBCIT,    VRPARDEDIT,
                                                             VRCONTITIMP,  VRBASECALCIT,   VRIMPOSTOIT,     IDERROSIMPIT,   IDAVISIMPIT,     CDSITUTRIBITNFE,
                                                             IDMODBCITNFE, IDMODBCSTITNFE, CDTPCREDPICOITE, CDNATUBCALPCIT, IDMOTDESONERAIT, IDTRIMPSTII,
                                                             CDDETALHEPROD, CDENQLEGALIPI, CDCEST)
                                    VALUES(@P_FILIAL, @P_LANCTONF, @V_ITEMPRODU_NRSEQITPROD, @C_ITEMPROIMPOS_CDIMPOSTO, @C_ITEMPROIMPOS_NRITPROIMPOS, @C_ITEMPROIMPOS_CDFISCALIT,
                                           @V_ITEMPRODU_CDSITUTRIBPR, @V_FISOPEITEM,   @V_SUFXCFOPPR, @C_ITEMPROIMPOS_VRALIQITEM, @C_ITEMPROIMPOS_VRPERREDBCIT, ROUND((@C_ITEMPROIMPOS_VRPARDEDIT * @V_VRFATOCONV),2),
                                           ROUND((@C_ITEMPROIMPOS_VRCONTITIMP * @V_VRFATOCONV),2), ROUND((@C_ITEMPROIMPOS_VRBASECALCIT * @V_VRFATOCONV),2),
                                           ROUND((@C_ITEMPROIMPOS_VRIMPOSTOIT * @V_VRFATOCONV),2), '00000',                   '00000', @C_ITEMPROIMPOS_CDSITUTRIBNFE,
                                           @C_ITEMPROIMPOS_IDMODBCNFE,  @C_ITEMPROIMPOS_IDMODBCSTNFE, @C_ITEMPROIMPOS_CDTPCREDPICOITE, @C_ITEMPROIMPOS_CDNATUBCALPCIT, ISNULL(@C_ITEMPROIMPOS_IDMOTDESONERAIT,'9'), @C_ITEMPROIMPOS_IDTRIMPSTII,
                                           @V_CDDETALHEPRODTEMP, @V_CDENQLEGALIPI, @V_CDCEST);
                                 END;
                              END;
                           END;
                        END
                        ELSE BEGIN
                           SELECT @V_IDPERVISIMPSCRE = ISNULL(MAX(IDPERVISIMPSCRE), 'S')
                             FROM PARAMGERAL;

                           IF @V_IDPERVISIMPSCRE = 'S' BEGIN
                              SET @V_VRIMPOSTOVISUIT = (@C_ITEMPROIMPOS_VRCONTITIMP * @V_VRFATOCONV);
                           END
                           ELSE BEGIN
                              IF (@V_CDFISCTEMP = '1') BEGIN
                                 SET @V_VRIMPOSTOVISUIT = (@C_ITEMPROIMPOS_VRCONTITIMP * @V_VRFATOCONV);
                              END
                              ELSE BEGIN
                                 SET @V_VRIMPOSTOVISUIT = 0;
                              END;
                           END;

                           SELECT @V_CHAVE = MAX(CDFILIAL)
                           FROM ITEMPROIMPOS
                           WHERE CDFILIAL = @P_FILIAL AND
                                 NRLANCTONF = @P_LANCTONF AND
                                 NRSEQITPROD = @V_ITEMPRODU_NRSEQITPROD AND
                                 CDIMPOSTO = @C_ITEMPROIMPOS_CDIMPOSTO AND
                                 NRITPROIMPOS = @C_ITEMPROIMPOS_NRITPROIMPOS;

                           IF @V_CHAVE IS NULL BEGIN
                              SET @V_ICMS = NULL;
                              DECLARE C_ICMS CURSOR FOR
                                 SELECT CDIMPOSTO
                                   FROM IMPOSTONFE N, IMPOSTO I
                                  WHERE N.CDIMPOSTONFE = I.CDIMPOSTONFE
                                    AND N.CDIMPOSTONFE = '00'
                                    AND I.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
                              OPEN C_ICMS;
                              FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
                              WHILE (@@FETCH_STATUS = 0) BEGIN
                                 SET @V_ICMS = 'S';
                                 FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
                              END;
                              CLOSE C_ICMS;
                              DEALLOCATE C_ICMS;

                              IF ((@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV')) AND (@V_ICMS = 'S') BEGIN
                                 INSERT INTO ITEMPROIMPOS(CDFILIAL,     NRLANCTONF,     NRSEQITPROD,     CDIMPOSTO,      NRITPROIMPOS,    CDFISCALIT,
                                                          CDSITUTRIBIT, CDFISCOPERIT,   CDSUFXCFOPIT,    VRALIQITEM,     VRPERREDBCIT,    VRPARDEDIT,
                                                          VRCONTITIMP,  VRBASECALCIT,   VRIMPOSTOIT,     IDERROSIMPIT,   IDAVISIMPIT,     CDSITUTRIBITNFE,
                                                          IDMODBCITNFE, IDMODBCSTITNFE, CDTPCREDPICOITE, CDNATUBCALPCIT, IDMOTDESONERAIT, IDTRIMPSTII,
                                                          CDDETALHEPROD, VRIMPOSTOVISUIT, CDENQLEGALIPI, CDCEST)
                                                   VALUES(@P_FILIAL, @P_LANCTONF, @V_ITEMPRODU_NRSEQITPROD, @C_ITEMPROIMPOS_CDIMPOSTO, @C_ITEMPROIMPOS_NRITPROIMPOS, @V_CDFISCTEMP,
                                                          @V_ITEMPRODU_CDSITUTRIBPR, @V_FISOPEITEM, @V_SUFXCFOPPR, @C_ITEMPROIMPOS_VRALIQITEM, @C_ITEMPROIMPOS_VRPERREDBCIT, ROUND((@C_ITEMPROIMPOS_VRPARDEDIT * @V_VRFATOCONV),2,2),
                                                          ROUND((@C_ITEMPROIMPOS_VRCONTITIMP * @V_VRFATOCONV),2,2), ROUND((@C_ITEMPROIMPOS_VRBASECALCIT * @V_VRFATOCONV),2,2),
                                                          ROUND((@C_ITEMPROIMPOS_VRIMPOSTOIT * @V_VRFATOCONV),2,2), '00000', '00000', @V_CDSITUTRIBNFE,
                                                          @V_IDMODBCNFEIT, @V_IDMODBCSTNFEIT, @V_CDTPCRPICOSTNFE, @V_CDNATUBCPCSTNFE, @V_IDMOTIDESSTNFE, @C_ITEMPROIMPOS_IDTRIMPSTII,
                                                          @V_CDDETALHEPRODTEMP, ROUND(@V_VRIMPOSTOVISUIT,2,2), @V_CDENQLEGALIPI, @V_CDCEST);
                              END
                              ELSE BEGIN
                                 INSERT INTO ITEMPROIMPOS(CDFILIAL,     NRLANCTONF,     NRSEQITPROD,     CDIMPOSTO,      NRITPROIMPOS,    CDFISCALIT,
                                                          CDSITUTRIBIT, CDFISCOPERIT,   CDSUFXCFOPIT,    VRALIQITEM,     VRPERREDBCIT,    VRPARDEDIT,
                                                          VRCONTITIMP,  VRBASECALCIT,   VRIMPOSTOIT,     IDERROSIMPIT,   IDAVISIMPIT,     CDSITUTRIBITNFE,
                                                          IDMODBCITNFE, IDMODBCSTITNFE, CDTPCREDPICOITE, CDNATUBCALPCIT, IDMOTDESONERAIT, IDTRIMPSTII,
                                                          CDDETALHEPROD, VRIMPOSTOVISUIT, IDDIFALIQCUSPRI, CDENQLEGALIPI, CDCEST)
                                                   VALUES(@P_FILIAL, @P_LANCTONF, @V_ITEMPRODU_NRSEQITPROD, @C_ITEMPROIMPOS_CDIMPOSTO, @C_ITEMPROIMPOS_NRITPROIMPOS,@V_CDFISCTEMP,
                                                          @V_ITEMPRODU_CDSITUTRIBPR, @V_FISOPEITEM, @V_SUFXCFOPPR, @C_ITEMPROIMPOS_VRALIQITEM, @C_ITEMPROIMPOS_VRPERREDBCIT, (@C_ITEMPROIMPOS_VRPARDEDIT * @V_VRFATOCONV),
                                                          ROUND((@C_ITEMPROIMPOS_VRCONTITIMP * @V_VRFATOCONV),2), (@C_ITEMPROIMPOS_VRBASECALCIT * @V_VRFATOCONV), (@C_ITEMPROIMPOS_VRIMPOSTOIT * @V_VRFATOCONV), '00000', '00000', @V_CDSITUTRIBNFE,
                                                          @V_IDMODBCNFEIT, @V_IDMODBCSTNFEIT, @V_CDTPCRPICOSTNFE, @V_CDNATUBCPCSTNFE, @V_IDMOTIDESSTNFE, @C_ITEMPROIMPOS_IDTRIMPSTII,
                                                          @V_CDDETALHEPRODTEMP, ROUND(@V_VRIMPOSTOVISUIT,2), @C_ITEMPROIMPOS_IDDIFALIQCUSPRI, @V_CDENQLEGALIPI, @V_CDCEST);
                              END;
                              IF ((@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV')) AND (@V_ICMS = 'S') BEGIN
                                 INSERT INTO ITEMPROIMPOSORIG(CDFILIAL,     NRLANCTONF,     NRSEQITPROD,     CDIMPOSTO,      NRITPROIMPOS,    CDFISCALIT,
                                                          CDSITUTRIBIT, CDFISCOPERIT,   CDSUFXCFOPIT,    VRALIQITEM,     VRPERREDBCIT,    VRPARDEDIT,
                                                          VRCONTITIMP,  VRBASECALCIT,   VRIMPOSTOIT,     IDERROSIMPIT,   IDAVISIMPIT,     CDSITUTRIBITNFE,
                                                          IDMODBCITNFE, IDMODBCSTITNFE, CDTPCREDPICOITE, CDNATUBCALPCIT, IDMOTDESONERAIT, IDTRIMPSTII,
                                                          CDDETALHEPROD, CDENQLEGALIPI, CDCEST)
                                 VALUES(@P_FILIAL, @P_LANCTONF, @V_ITEMPRODU_NRSEQITPROD, @C_ITEMPROIMPOS_CDIMPOSTO, @C_ITEMPROIMPOS_NRITPROIMPOS, @C_ITEMPROIMPOS_CDFISCALIT,
                                        @V_ITEMPRODU_CDSITUTRIBPR, @V_FISOPEITEM,   @V_SUFXCFOPPR, @C_ITEMPROIMPOS_VRALIQITEM, @C_ITEMPROIMPOS_VRPERREDBCIT, ROUND((@C_ITEMPROIMPOS_VRPARDEDIT * @V_VRFATOCONV),2,2),
                                        ROUND((@C_ITEMPROIMPOS_VRCONTITIMP * @V_VRFATOCONV),2,2), ROUND((@C_ITEMPROIMPOS_VRBASECALCIT * @V_VRFATOCONV),2,2),
                                        ROUND((@C_ITEMPROIMPOS_VRIMPOSTOIT * @V_VRFATOCONV),2,2), '00000',                   '00000', @C_ITEMPROIMPOS_CDSITUTRIBNFE,
                                        @C_ITEMPROIMPOS_IDMODBCNFE,  @C_ITEMPROIMPOS_IDMODBCSTNFE, @C_ITEMPROIMPOS_CDTPCREDPICOITE, @C_ITEMPROIMPOS_CDNATUBCALPCIT, ISNULL(@C_ITEMPROIMPOS_IDMOTDESONERAIT,'9'), @C_ITEMPROIMPOS_IDTRIMPSTII,
                                        @V_CDDETALHEPRODTEMP, @V_CDENQLEGALIPI, @V_CDCEST);
                              END
                              ELSE BEGIN
                                 INSERT INTO ITEMPROIMPOSORIG(CDFILIAL,     NRLANCTONF,     NRSEQITPROD,     CDIMPOSTO,      NRITPROIMPOS,    CDFISCALIT,
                                                          CDSITUTRIBIT, CDFISCOPERIT,   CDSUFXCFOPIT,    VRALIQITEM,     VRPERREDBCIT,    VRPARDEDIT,
                                                          VRCONTITIMP,  VRBASECALCIT,   VRIMPOSTOIT,     IDERROSIMPIT,   IDAVISIMPIT,     CDSITUTRIBITNFE,
                                                          IDMODBCITNFE, IDMODBCSTITNFE, CDTPCREDPICOITE, CDNATUBCALPCIT, IDMOTDESONERAIT, IDTRIMPSTII,
                                                          CDDETALHEPROD, CDENQLEGALIPI, CDCEST)
                                 VALUES(@P_FILIAL, @P_LANCTONF, @V_ITEMPRODU_NRSEQITPROD, @C_ITEMPROIMPOS_CDIMPOSTO, @C_ITEMPROIMPOS_NRITPROIMPOS, @C_ITEMPROIMPOS_CDFISCALIT,
                                        @V_ITEMPRODU_CDSITUTRIBPR, @V_FISOPEITEM,   @V_SUFXCFOPPR, @C_ITEMPROIMPOS_VRALIQITEM, @C_ITEMPROIMPOS_VRPERREDBCIT, ROUND((@C_ITEMPROIMPOS_VRPARDEDIT * @V_VRFATOCONV),2),
                                        ROUND((@C_ITEMPROIMPOS_VRCONTITIMP * @V_VRFATOCONV),2), ROUND((@C_ITEMPROIMPOS_VRBASECALCIT * @V_VRFATOCONV),2),
                                        ROUND((@C_ITEMPROIMPOS_VRIMPOSTOIT * @V_VRFATOCONV),2), '00000',                   '00000', @C_ITEMPROIMPOS_CDSITUTRIBNFE,
                                        @C_ITEMPROIMPOS_IDMODBCNFE,  @C_ITEMPROIMPOS_IDMODBCSTNFE, @C_ITEMPROIMPOS_CDTPCREDPICOITE, @C_ITEMPROIMPOS_CDNATUBCALPCIT, ISNULL(@C_ITEMPROIMPOS_IDMOTDESONERAIT,'9'), @C_ITEMPROIMPOS_IDTRIMPSTII,
                                        @V_CDDETALHEPRODTEMP, @V_CDENQLEGALIPI, @V_CDCEST);
                              END;
                           END;
                        END;

					         DELETE ALIQTEMP
                         WHERE NRALIQTEMP = @V_ALIQTEMP;
                     END;
                     FETCH NEXT FROM C_ITEMPRODUIMPOS INTO @C_ITEMPROIMPOS_VRPERREDBCIT,    @C_ITEMPROIMPOS_NRITPROIMPOS,    @C_ITEMPROIMPOS_CDIMPOSTO,
                                                           @C_ITEMPROIMPOS_CDFISCALIT,      @C_ITEMPROIMPOS_VRALIQITEM,      @C_ITEMPROIMPOS_VRPARDEDIT,
                                                           @C_ITEMPROIMPOS_VRCONTITIMP,     @C_ITEMPROIMPOS_VRBASECALCIT,    @C_ITEMPROIMPOS_VRIMPOSTOIT,
                                                           @C_ITEMPROIMPOS_CDSITUTRIBNFE,   @C_ITEMPROIMPOS_IDMODBCNFE,      @C_ITEMPROIMPOS_IDMODBCSTNFE,
                                                           @C_ITEMPROIMPOS_CDTPCREDPICOITE, @C_ITEMPROIMPOS_CDNATUBCALPCIT,  @C_ITEMPROIMPOS_IDMOTDESONERAIT,
                                                           @C_ITEMPROIMPOS_IDTRIMPSTII,     @C_ITEMPROIMPOS_IDDIFALIQCUSPRI, @C_ITEMPROIMPOS_CDIMPOSTONFE,
                                                           @C_ITEMPROIMPOS_CDENQLEGALIPI,   @C_ITEMPROIMPOS_CDCEST,          @C_ITEMPROIMPOS_IDUTVRPAUTAPROD,
                                                           @C_ITEMPROIMPOS_VRPAUTAMINPROD,  @C_ITEMPROIMPOS_QTITEMPROD,      @C_ITEMPROIMPOS_IDUTVRPAUTA;

                  END;
                  CLOSE C_ITEMPRODUIMPOS;
                  DEALLOCATE C_ITEMPRODUIMPOS;

                  DELETE ALIQTEMP
                  WHERE NRALIQTEMP = @V_ALIQTEMP;

               END;
               FETCH NEXT FROM C_ITEMNOTAFISC INTO @V_CDFILIALIT, @V_NRLANCTONFIT;
            END;
            CLOSE C_ITEMNOTAFISC;
            DEALLOCATE C_ITEMNOTAFISC;
         END;

         DELETE FROM CFOPTEMP
         WHERE NRCFOPTEMP = @V_CFOPTEMP;

         IF (@V_IDOPERDEVONF <> 'S') BEGIN

            IF NOT @V_IDDOCREPLIC IS NULL BEGIN
               IF LEN(@V_SITUTRIBPR) = 3 BEGIN
                  SET @V_SITUTRIBPR = SUBSTRING(@V_SITUTRIBPR,1,1) + '90';
               END
               ELSE BEGIN
                  SET @V_SITUTRIBPR = '90';
               END;
            END;

            UPDATE ITEMPRODUTO
            SET CDSITUTRIBPR  = @V_SITUTRIBPR
            WHERE CDFILIAL    = @P_FILIAL   AND
                  NRLANCTONF  = @P_LANCTONF AND
                  NRSEQITPROD = @V_ITEMPRODU_NRSEQITPROD;
         END

         DELETE FROM CSTTEMP
         WHERE NRCSTTEMP = @V_CSTTEMP;

         SET @V_IMPOCONTAB = 0;

         FETCH NEXT FROM C_ITEMPROD INTO @V_ITEMPRODU_CDFILIAL    , @V_ITEMPRODU_NRLANCTONF,
                                         @V_ITEMPRODU_NRSEQITPROD , @V_ITEMPRODU_CDPRODUTO,
                                         @V_ITEMPRODU_CDPRODEMIS  , @V_ITEMPRODU_DSPRODEMIS,
                                         @V_ITEMPRODU_IDATUVRESTOQ, @V_ITEMPRODU_QTITEMPROD,
                                         @V_ITEMPRODU_VRUNITITEM  , @V_ITEMPRODU_VRDESCITEM,
                                         @V_ITEMPRODU_VRTOTAITEM  , @V_ITEMPRODU_VRCONTITEM,
                                         @V_ITEMPRODU_IDCONFORITEM, @V_ITEMPRODU_CDFISOPEITEM,
                                         @V_ITEMPRODU_CDSUFXCFOPPR, @V_ITEMPRODU_CDSITUTRIBPR,
                                         @V_ITEMPRODU_IDERROSITEM , @V_ITEMPRODU_IDAVISOSITEM,
                                         @V_ITEMPRODU_VRBRUTITEM, @V_ITEMPRODU_CDARVPROD,
                                         @V_ITEMPRODU_NRLOTEESTQ, @V_ITEMPRODU_NRSUBLOTE,
                                         @V_ITEMPRODU_IDORIGEMPROD;
      END;
      CLOSE C_ITEMPROD;
      DEALLOCATE C_ITEMPROD;


      SELECT @V_IDUTCTRLFISSAID = MAX(IDUTCTRLFISSAID)
        FROM PARAMGERAL;

      SELECT @V_IDUTCTRLFISFIL = MAX(IDUTCTRLFISSAID)
        FROM PARAMFILIAL
       WHERE CDFILIAL = @V_CDFILIEMIT;

      IF @V_IDUTCTRLFISSAID = 'S' BEGIN
         SET @V_IDUTCTRLFIS = 'S';
      END
      ELSE BEGIN
         IF @V_IDUTCTRLFISFIL = 'S' BEGIN
            SET @V_IDUTCTRLFIS = 'S';
         END
         ELSE BEGIN
            SET @V_IDUTCTRLFIS = 'N';
         END;
      END;

      SELECT @V_IDGERICMSTDESPA  = ISNULL(MAX(IDGERICMSTDESPA), 'N'),
             @V_CDENCARGOICMST   = MAX(CDENCARGOICMST),
             @V_IDPEINFICMSTDEME = ISNULL(MAX(IDPEINFICMSTDEME), 'N'),
             @V_IDGERIPIDESPA    = ISNULL(MAX(IDGERIPIDESPA), 'N')
        FROM TIPOOPERAC
       WHERE IDENTRSAIDOP = 'S'
         AND CDTIPOOPER = @P_TIPOOPER;

      IF ((@V_IDGERICMSTDESPA = 'S') OR (@V_IDGERIPIDESPA = 'S')) AND (@V_IDUTCTRLFIS = 'S') BEGIN
         UPDATE ITEMENCARGO
            SET VRITEMENCA = 0
          WHERE CDFILIAL   = @P_FILIAL
            AND NRLANCTONF = @P_LANCTONF
            AND IDALTERADO = 'N';
      END;

      SET @V_VRENCAICMSSTIT = 0;
      DECLARE C_ITEMNOTAFISC CURSOR FOR
      SELECT CDFILIALIT, NRLANCTONFIT
        FROM ITEMNOTAFISC
       WHERE CDFILIAL   = @P_FILIAL AND
             NRLANCTONF = @P_LANCTONF;
      OPEN C_ITEMNOTAFISC;
      FETCH NEXT FROM C_ITEMNOTAFISC INTO @V_CDFILIALIT, @V_NRLANCTONFIT;
      WHILE (@@FETCH_STATUS = 0) BEGIN

         SELECT @V_VRLIQUORIG = SUM(VRTOTAITEM - VRDESCITEM)
         FROM ITEMPRODUTO I
         WHERE CDFILIAL    = @V_CDFILIALIT AND
               NRLANCTONF  = @V_NRLANCTONFIT;

         IF @V_VRLIQUORIG = 0 BEGIN
            SET @V_VRFATOCONV = 0;
         END ELSE BEGIN
            SET @V_VRFATOCONV = @V_LIQUIDO / @V_VRLIQUORIG;
         END;

         SELECT @V_VRENCAICMSSTIT = SUM(VRITEMENCA)
           FROM ITEMENCARGO
          WHERE CDFILIAL   = @V_CDFILIALIT
            AND NRLANCTONF = @V_NRLANCTONFIT
            AND CDENCARGO  = @V_CDENCARGOICMST;


         DECLARE C_ITEMENCARGO CURSOR FOR
         SELECT CDENCARGO, SUM(VRITEMENCA) AS VRITEMENCA
           FROM ITEMENCARGO
          WHERE CDFILIAL = @V_CDFILIALIT AND
                NRLANCTONF = @V_NRLANCTONFIT AND
                VRITEMENCA > 0
         GROUP BY CDENCARGO;
         OPEN C_ITEMENCARGO;
         FETCH NEXT FROM C_ITEMENCARGO INTO @V_ITEMENC_CDENCARGO, @V_ITEMENC_VRITEMENCA;
         WHILE (@@FETCH_STATUS = 0) BEGIN
            SELECT @V_IDALTERADO_ENCA = ISNULL(MAX(IDALTERADO), 'N')
              FROM ITEMENCARGO
             WHERE CDFILIAL   = @P_FILIAL
               AND NRLANCTONF = @P_LANCTONF
               AND CDENCARGO  = @V_ITEMENC_CDENCARGO;
            IF @V_IDALTERADO_ENCA = 'N' BEGIN
               UPDATE ITEMENCARGO
               SET VRITEMENCA = (@V_ITEMENC_VRITEMENCA * @V_VRFATOCONV)
               WHERE CDFILIAL   = @P_FILIAL  AND
                     NRLANCTONF = @P_LANCTONF AND
                     CDENCARGO  = @V_ITEMENC_CDENCARGO;
            END;
            FETCH NEXT FROM C_ITEMENCARGO INTO @V_ITEMENC_CDENCARGO, @V_ITEMENC_VRITEMENCA;
         END;
         CLOSE C_ITEMENCARGO;
         DEALLOCATE C_ITEMENCARGO;
         FETCH NEXT FROM C_ITEMNOTAFISC INTO @V_CDFILIALIT, @V_NRLANCTONFIT;

      END;
      CLOSE C_ITEMNOTAFISC;
      DEALLOCATE C_ITEMNOTAFISC;

      /*CALCULA DESCONTO DE BONIFICAO NA DEVOLUO DE NOTAS */
      SELECT @V_CDENCDESCBONDEV = MAX(CDENCDESCBONDEV)
        FROM PARAMGERAL;

      IF @V_CDENCDESCBONDEV IS NOT NULL BEGIN
         SELECT @V_IDCONDESBONFORN = ISNULL(MAX(IDCONDESBONFORN), 'S')
           FROM PARAMFILIAL
          WHERE CDFILIAL = @V_CDFILIEMIT;

         SELECT @V_CDAJUCTPAG = MAX(F.CDAJUCTPAG),
                @V_VRPEDESCFORN = MAX(F.VRPEDESCFORN),
                @V_DTINIVRPDESC = CONVERT(DATETIME, ISNULL(MAX(DTINIVRPDESC), '01/01/1760'))
           FROM FORNECEDOR F
          WHERE (F.CDFORNECED   = @P_CLIENTE)
            AND (NOT F.VRPEDESCFORN IS NULL)
            AND (F.IDTPDESCFORN = 'B');

         IF (@V_VRPEDESCFORN IS NOT NULL) AND (@V_VRPEDESCFORN <> 0) AND (@V_IDCONDESBONFORN = 'S') BEGIN
            IF (@P_INIVALID >= @V_DTINIVRPDESC) BEGIN
               SET @V_VRENCARBONI = ROUND(@V_LIQUIDO * (@V_VRPEDESCFORN/100),2);

               UPDATE ITEMENCARGO
               SET VRITEMENCA = @V_VRENCARBONI
               WHERE CDFILIAL = @P_FILIAL
                 AND NRLANCTONF = @P_LANCTONF
                 AND CDENCARGO = @V_CDENCDESCBONDEV;
            END;
         END;
      END;

      DELETE FROM DADOSADIC
       WHERE CDFILIAL   = @P_FILIAL
         AND NRLANCTONF = @P_LANCTONF
         AND DSDADOADIC LIKE 'Base de Clculo do ICMS ST%';
      DELETE FROM DADOSADIC
       WHERE CDFILIAL   = @P_FILIAL
         AND NRLANCTONF = @P_LANCTONF
         AND DSDADOADIC LIKE 'ICMS ST: R$%';
      DELETE FROM DADOSADIC
       WHERE CDFILIAL   = @P_FILIAL
         AND NRLANCTONF = @P_LANCTONF
         AND DSDADOADIC LIKE 'Valor de IPI: R$%';


      IF (@V_IDUTCTRLFIS = 'S') BEGIN
         IF @V_IDGERICMSTDESPA = 'S' BEGIN
            IF @V_CDENCARGOICMST IS NOT NULL BEGIN
               SELECT @V_IDALTERADO_ENCA = ISNULL(MAX(IDALTERADO), 'N')
                 FROM ITEMENCARGO
               WHERE CDFILIAL   = @P_FILIAL
                 AND NRLANCTONF = @P_LANCTONF
                 AND CDENCARGO  = @V_CDENCARGOICMST;

               IF @V_IDALTERADO_ENCA = 'N' BEGIN
                  UPDATE ITEMENCARGO
                     SET VRITEMENCA = 0
                   WHERE CDFILIAL   = @P_FILIAL
                     AND NRLANCTONF = @P_LANCTONF
                     AND CDENCARGO  = @V_CDENCARGOICMST;
               END;

               SELECT @V_CDENCARGOOD = MAX(CDENCARGO)
                 FROM ENCARGO
                WHERE CDENCARGONFE = '04';

               IF @V_CDENCARGOOD IS NOT NULL BEGIN
                  SELECT @V_IDALTERADO_ENCA = ISNULL(MAX(IDALTERADO), 'N')
                    FROM ITEMENCARGO
                   WHERE CDFILIAL   = @P_FILIAL
                     AND NRLANCTONF = @P_LANCTONF
                     AND CDENCARGO  = @V_CDENCARGOOD;

                  IF @V_IDALTERADO_ENCA = 'N' BEGIN
                     IF (@V_VRENCAICMSSTIT > 0) OR (@V_VRTOTALICMSST > 0) BEGIN
                        IF @V_IDPEINFICMSTDEME = 'S' BEGIN
                           SELECT @V_VRICMSST = ISNULL(SUM(VRICMSST),0), @V_VRBASECALC = ISNULL(SUM(VRBASECALC),0)
                             FROM INFICMSST
                            WHERE CDFILIAL   = @P_FILIAL
                              AND NRLANCTONF = @P_LANCTONF;

                           IF @V_VRICMSST > 0 BEGIN

                              UPDATE ITEMENCARGO
                                 SET VRITEMENCA = ROUND(VRITEMENCA + @V_VRICMSST,2)
                               WHERE CDFILIAL   = @P_FILIAL
                                 AND NRLANCTONF = @P_LANCTONF
                                 AND CDENCARGO  = @V_CDENCARGOOD;

                              IF @V_VRBASECALC > 0 BEGIN
                                 SELECT @V_EXISTDSDADOSADIC = COUNT(*)
                                   FROM DADOSADIC
                                  WHERE CDFILIAL   = @P_FILIAL
                                    AND NRLANCTONF = @P_LANCTONF
                                    AND DSDADOADIC LIKE 'Base de Clculo do ICMS ST%';

                                 IF @V_EXISTDSDADOSADIC = 0 BEGIN

                                    INSERT INTO DADOSADIC(CDFILIAL, NRLANCTONF, NRDADOADIC, DSDADOADIC)
                                                   VALUES(@P_FILIAL, @P_LANCTONF, @V_DADOADIC, 'Base de Clculo do ICMS ST: R$' +CASE SUBSTRING(LTRIM(CONVERT(DECIMAL(20,2), ROUND(@V_VRBASECALC, 2))),1,1) WHEN '.' THEN '0' + LTRIM(CONVERT(DECIMAL(20,2), ROUND(@V_VRBASECALC, 2))) ELSE LTRIM(CONVERT(DECIMAL(20,2), ROUND(@V_VRBASECALC, 2))) END
                                                                                               + ' ICMS ST: R$' +
                                                                                               CASE SUBSTRING(LTRIM(CONVERT(DECIMAL(20,2), ROUND(@V_VRICMSST, 2))),1,1) WHEN '.' THEN '0' + LTRIM(CONVERT(DECIMAL(20,2), ROUND(@V_VRICMSST, 2))) ELSE LTRIM(CONVERT(DECIMAL(20,2), ROUND(@V_VRICMSST, 2))) END);

                                    SET @V_DADOADIC = RIGHT(REPLICATE('0',3) + RTRIM(CONVERT(VARCHAR, CONVERT(NUMERIC, @V_DADOADIC) + 1)),3);
                                 END
                                 ELSE BEGIN
                                    UPDATE DADOSADIC
                                       SET DSDADOADIC = 'Base de Clculo do ICMS ST: R$' + CASE SUBSTRING(LTRIM(CONVERT(DECIMAL(20,2), ROUND(@V_VRBASECALC, 2))),1,1) WHEN '.' THEN '0' + LTRIM(CONVERT(DECIMAL(20,2), ROUND(@V_VRBASECALC, 2))) ELSE LTRIM(CONVERT(DECIMAL(20,2), ROUND(@V_VRBASECALC, 2))) END
                                                                                         + ' ICMS ST: R$' +
                                                                                           CASE SUBSTRING(LTRIM(CONVERT(DECIMAL(20,2), ROUND(@V_VRICMSST, 2))),1,1) WHEN '.' THEN '0' + LTRIM(CONVERT(DECIMAL(20,2), ROUND(@V_VRICMSST, 2))) ELSE LTRIM(CONVERT(DECIMAL(20,2), ROUND(@V_VRICMSST, 2))) END
                                      WHERE CDFILIAL   = @P_FILIAL
                                        AND NRLANCTONF = @P_LANCTONF
                                        AND DSDADOADIC LIKE 'Base de Clculo do ICMS ST%';
                                 END;
                              END
                              ELSE BEGIN
                                 SELECT @V_EXISTDSDADOSADIC = COUNT(*)
                                   FROM DADOSADIC
                                  WHERE CDFILIAL   = @P_FILIAL
                                    AND NRLANCTONF = @P_LANCTONF
                                    AND DSDADOADIC LIKE 'ICMS ST: R$%';

                                 IF @V_EXISTDSDADOSADIC = 0 BEGIN
                                    INSERT INTO DADOSADIC(CDFILIAL, NRLANCTONF, NRDADOADIC, DSDADOADIC)
                                                   VALUES(@P_FILIAL, @P_LANCTONF, @V_DADOADIC, 'ICMS ST: R$ ' + CASE SUBSTRING(LTRIM(CONVERT(DECIMAL(20,2), ROUND(@V_VRICMSST, 2))),1,1) WHEN '.' THEN '0' + LTRIM(CONVERT(DECIMAL(20,2), ROUND(@V_VRICMSST, 2))) ELSE LTRIM(CONVERT(DECIMAL(20,2), ROUND(@V_VRICMSST, 2))) END);

                                    SET @V_DADOADIC = RIGHT(REPLICATE('0',3) + RTRIM(CONVERT(VARCHAR, CONVERT(NUMERIC, @V_DADOADIC) + 1)),3);
                                 END
                                 ELSE BEGIN
                                    UPDATE DADOSADIC
                                       SET DSDADOADIC  = 'ICMS ST: R$ ' + CASE SUBSTRING(LTRIM(CONVERT(DECIMAL(20,2), ROUND(@V_VRICMSST, 2))),1,1) WHEN '.' THEN '0' + LTRIM(CONVERT(DECIMAL(20,2), ROUND(@V_VRICMSST, 2))) ELSE LTRIM(CONVERT(DECIMAL(20,2), ROUND(@V_VRICMSST, 2))) END
                                      WHERE CDFILIAL   = @P_FILIAL
                                        AND NRLANCTONF = @P_LANCTONF
                                        AND DSDADOADIC LIKE 'ICMS ST: R$%';
                                 END;
                              END;
                           END;
                        END
                        ELSE BEGIN
                           UPDATE ITEMENCARGO
                              SET VRITEMENCA = ROUND(VRITEMENCA + (@V_VRENCAICMSSTIT * @V_VRFATOCONV) + @V_VRTOTALICMSST,2)
                            WHERE CDFILIAL   = @P_FILIAL
                              AND NRLANCTONF = @P_LANCTONF
                              AND CDENCARGO  = @V_CDENCARGOOD;

                           SELECT @V_EXISTDSDADOSADIC = COUNT(*)
                             FROM DADOSADIC
                            WHERE CDFILIAL   = @P_FILIAL
                              AND NRLANCTONF = @P_LANCTONF
                              AND DSDADOADIC LIKE 'ICMS ST: R$%';

                           IF @V_EXISTDSDADOSADIC = 0 BEGIN
                              INSERT INTO DADOSADIC(CDFILIAL, NRLANCTONF, NRDADOADIC, DSDADOADIC)
                                             VALUES(@P_FILIAL, @P_LANCTONF, @V_DADOADIC, 'ICMS ST: R$ ' + CASE SUBSTRING(LTRIM(CONVERT(DECIMAL(20,2), ROUND(@V_VRTOTALICMSST + (@V_VRENCAICMSSTIT * @V_VRFATOCONV), 2))),1,1) WHEN '.' THEN '0' + LTRIM(CONVERT(DECIMAL(20,2), ROUND(@V_VRTOTALICMSST + (@V_VRENCAICMSSTIT * @V_VRFATOCONV), 2))) ELSE LTRIM(CONVERT(DECIMAL(20,2), ROUND(@V_VRTOTALICMSST + (@V_VRENCAICMSSTIT * @V_VRFATOCONV), 2))) END);

                              SET @V_DADOADIC = RIGHT(REPLICATE('0',3) + RTRIM(CONVERT(VARCHAR, CONVERT(NUMERIC, @V_DADOADIC) + 1)),3);
                           END
                           ELSE BEGIN
                              UPDATE DADOSADIC
                                 SET DSDADOADIC  = 'ICMS ST: R$ ' + CASE SUBSTRING(LTRIM(CONVERT(DECIMAL(20,2), ROUND(@V_VRTOTALICMSST + (@V_VRENCAICMSSTIT * @V_VRFATOCONV), 2))),1,1) WHEN '.' THEN '0' + LTRIM(CONVERT(DECIMAL(20,2), ROUND(@V_VRTOTALICMSST + (@V_VRENCAICMSSTIT * @V_VRFATOCONV), 2))) ELSE LTRIM(CONVERT(DECIMAL(20,2), ROUND(@V_VRTOTALICMSST + (@V_VRENCAICMSSTIT * @V_VRFATOCONV), 2))) END
                                WHERE CDFILIAL   = @P_FILIAL
                                  AND NRLANCTONF = @P_LANCTONF
                                  AND DSDADOADIC LIKE 'ICMS ST: R$%';
                           END;
                        END;
                     END;
                  END;
               END;
            END;
         END;
         IF (@V_IDGERIPIDESPA = 'S') BEGIN
            SELECT @V_CDENCARGOOD = MAX(CDENCARGO)
              FROM ENCARGO
             WHERE CDENCARGONFE = '04';

            IF @V_CDENCARGOOD IS NOT NULL BEGIN
               SELECT @V_IDALTERADO_ENCA = ISNULL(MAX(IDALTERADO), 'N')
                 FROM ITEMENCARGO
                WHERE CDFILIAL   = @P_FILIAL
                  AND NRLANCTONF = @P_LANCTONF
                  AND CDENCARGO  = @V_CDENCARGOOD;
               IF @V_IDALTERADO_ENCA = 'N' BEGIN
                  IF (@V_VRTOTALIPI > 0) BEGIN
                     UPDATE ITEMENCARGO
                        SET VRITEMENCA = ROUND(VRITEMENCA + @V_VRTOTALIPI, 2)
                      WHERE CDFILIAL   = @P_FILIAL
                        AND NRLANCTONF = @P_LANCTONF
                        AND CDENCARGO  = @V_CDENCARGOOD;

                     SELECT @V_EXISTDSDADOSADIC = COUNT(*)
                       FROM DADOSADIC
                      WHERE CDFILIAL   = @P_FILIAL
                        AND NRLANCTONF = @P_LANCTONF
                        AND DSDADOADIC LIKE 'Valor de IPI: R$%';

                     IF (@V_EXISTDSDADOSADIC = 0) BEGIN

                        INSERT INTO DADOSADIC(CDFILIAL, NRLANCTONF, NRDADOADIC, DSDADOADIC)
                                       VALUES(@P_FILIAL, @P_LANCTONF, @V_DADOADIC, 'Valor de IPI: R$ ' + CASE SUBSTRING(LTRIM(CONVERT(DECIMAL(20,2), ROUND(@V_VRTOTALIPI, 2))),1,1) WHEN '.' THEN '0' + LTRIM(CONVERT(DECIMAL(20,2), ROUND(@V_VRTOTALIPI, 2))) ELSE LTRIM(CONVERT(DECIMAL(20,2), ROUND(@V_VRTOTALIPI, 2))) END);

                        SET @V_DADOADIC = RIGHT(REPLICATE('0',3) + RTRIM(CONVERT(VARCHAR, CONVERT(NUMERIC, @V_DADOADIC) + 1)),3);
                     END
                     ELSE BEGIN
                        UPDATE DADOSADIC
                           SET DSDADOADIC  = 'Valor de IPI: R$ ' + CASE SUBSTRING(LTRIM(CONVERT(DECIMAL(20,2), ROUND(@V_VRTOTALIPI, 2))),1,1) WHEN '.' THEN '0' + LTRIM(CONVERT(DECIMAL(20,2), ROUND(@V_VRTOTALIPI, 2))) ELSE LTRIM(CONVERT(DECIMAL(20,2), ROUND(@V_VRTOTALIPI, 2))) END
                          WHERE CDFILIAL   = @P_FILIAL
                            AND NRLANCTONF = @P_LANCTONF
                            AND DSDADOADIC LIKE 'Valor de IPI: R$%';
                     END;
                  END;
               END;
            END;
         END;
      END;

      --RATEIO DOS ENCARGOS
      DECLARE C_ITEMENCARGO CURSOR FOR
      SELECT IE.CDENCARGO AS CDENCARGO, VRITEMENCA, IDENCARGO,
             EN.CDCTBLENTREN, EN.CDCTBLSAIDEN
      FROM ITEMENCARGO IE, ENCARGO EN
      WHERE (IE.CDFILIAL   = @P_FILIAL)     AND
            (IE.NRLANCTONF = @P_LANCTONF)   AND
            (IE.VRITEMENCA > 0)            AND
            (EN.CDENCARGO  = IE.CDENCARGO);

      OPEN C_ITEMENCARGO;

      FETCH NEXT FROM C_ITEMENCARGO INTO @V_ITEMENC_CDENCARGO, @V_ITEMENC_VRITEMENCA,
                                         @V_ITEMENC_IDENCARGO, @V_ITEMENC_CDCTBLENTREN,
                                         @V_ITEMENC_CDCTBLSAIDEN;

      WHILE (@@FETCH_STATUS = 0) BEGIN

         SET @V_TOTAPRODENCA = 0;

         DECLARE C_VRLIQRATEIO CURSOR FOR
         SELECT DISTINCT(IP.NRSEQITPROD) AS NRSEQITPROD, (VRTOTAITEM - VRDESCITEM) AS VRLIQUIDO
         FROM ITEMPRODUTO IP, ITEMPROIMPOS II
         WHERE (IP.CDFILIAL    = @P_FILIAL)      AND
               (IP.NRLANCTONF  = @P_LANCTONF)    AND
               (II.CDFILIAL    = IP.CDFILIAL)    AND
               (II.NRLANCTONF  = IP.NRLANCTONF)  AND
               (II.NRSEQITPROD = IP.NRSEQITPROD) AND
               (II.NRITPROIMPOS = '1')           AND
               (II.CDIMPOSTO IN (SELECT MIN(BC.CDIMPOSTO)
                                 FROM BASECALC BC
                                 WHERE (BC.CDENCARGO = @V_ITEMENC_CDENCARGO)));

         OPEN C_VRLIQRATEIO;

         FETCH NEXT FROM C_VRLIQRATEIO INTO @V_VRLIQ_NRSEQITPROD, @V_VRLIQ_VRLIQUIDO;

         WHILE (@@FETCH_STATUS = 0) BEGIN
            IF NOT (@V_VRLIQ_VRLIQUIDO IS NULL) BEGIN
               SET @V_TOTAPRODENCA = @V_TOTAPRODENCA + @V_VRLIQ_VRLIQUIDO;
            END;

            FETCH NEXT FROM C_VRLIQRATEIO INTO @V_VRLIQ_NRSEQITPROD, @V_VRLIQ_VRLIQUIDO;
         END; /*WHILE DO CURSOR C_VRLIQRATEIO*/

         CLOSE C_VRLIQRATEIO;
         DEALLOCATE C_VRLIQRATEIO;

         IF (@V_TOTAPRODENCA = 0) BEGIN
            SELECT @V_TOTAPRODENCA = SUM(VRTOTAITEM - VRDESCITEM)
            FROM ITEMPRODUTO IP
            WHERE (IP.CDFILIAL   = @P_FILIAL)   AND
                  (IP.NRLANCTONF = @P_LANCTONF);

            IF NOT @V_TOTAPRODENCA IS NULL BEGIN

               DECLARE C_ATUAVRCONT CURSOR FOR
               SELECT IP.NRSEQITPROD, (VRTOTAITEM - VRDESCITEM) AS VRLIQUIDO
               FROM ITEMPRODUTO IP
               WHERE (IP.CDFILIAL    = @P_FILIAL) AND
                     (IP.NRLANCTONF  = @P_LANCTONF);

               OPEN C_ATUAVRCONT;

               FETCH NEXT FROM C_ATUAVRCONT INTO @V_ATUAVR_NRSEQITPROD, @V_ATUAVR_VRLIQUIDO;

               WHILE (@@FETCH_STATUS = 0) BEGIN

                  IF (@V_ITEMENC_IDENCARGO = 'A') BEGIN
                     SET @V_VRBRUTO  = (@V_ITEMENC_VRITEMENCA/@V_TOTAPRODENCA);
                  END
                  ELSE IF (@V_ITEMENC_IDENCARGO = 'D') BEGIN
                     SET @V_VRBRUTO  = - (@V_ITEMENC_VRITEMENCA/@V_TOTAPRODENCA);
                  END
                  ELSE BEGIN
                     SET @V_VRBRUTO = 0;
                  END;

                  IF (@V_ITEMENC_CDCTBLENTREN IS NULL) BEGIN
                     SET @V_VRCONTAB = @V_VRBRUTO;
                  END
                  ELSE BEGIN
                     SET @V_VRCONTAB = 0;
                  END;

                  UPDATE ITEMPRODUTO
                  SET VRBRUTITEM = VRBRUTITEM + (@V_VRBRUTO  * (VRTOTAITEM - VRDESCITEM)),
                      VRCONTITEM = VRCONTITEM + (@V_VRCONTAB * (VRTOTAITEM - VRDESCITEM))
                  WHERE CDFILIAL    = @P_FILIAL   AND
                        NRLANCTONF  = @P_LANCTONF AND
                        NRSEQITPROD = @V_ATUAVR_NRSEQITPROD;


                  FETCH NEXT FROM C_ATUAVRCONT INTO @V_ATUAVR_NRSEQITPROD, @V_ATUAVR_VRLIQUIDO;
               END; /*WHILE DO CURSOR C_ATUAVRCONT*/

               CLOSE C_ATUAVRCONT;
               DEALLOCATE C_ATUAVRCONT;
            END;
         END
         ELSE BEGIN

            DECLARE C_ATUAVRCONT CURSOR FOR
            SELECT DISTINCT(IP.NRSEQITPROD) AS NRSEQITPROD, (VRTOTAITEM - VRDESCITEM) AS VRLIQUIDO,
                   NRITPROIMPOS
            FROM ITEMPRODUTO IP, ITEMPROIMPOS II
            WHERE (IP.CDFILIAL     = @P_FILIAL)      AND
                  (IP.NRLANCTONF   = @P_LANCTONF)    AND
                  (II.CDFILIAL     = IP.CDFILIAL)    AND
                  (II.NRLANCTONF   = IP.NRLANCTONF)  AND
                  (II.NRSEQITPROD  = IP.NRSEQITPROD) AND
                  (II.NRITPROIMPOS = '1')            AND
                  (II.CDIMPOSTO IN (SELECT MIN(BC.CDIMPOSTO)
                                    FROM BASECALC BC
                                    WHERE (BC.CDENCARGO = @V_ITEMENC_CDENCARGO)));
            OPEN C_ATUAVRCONT;

            FETCH NEXT FROM C_ATUAVRCONT INTO @V_ATUAVR_NRSEQITPROD, @V_ATUAVR_VRLIQUIDO, @V_ATUAVR_NRITPROIMPOS;

            WHILE (@@FETCH_STATUS = 0) BEGIN

               IF (@V_ITEMENC_IDENCARGO = 'A') BEGIN
                  SET @V_VRBRUTO = (@V_ITEMENC_VRITEMENCA/@V_TOTAPRODENCA);
               END
               ELSE IF (@V_ITEMENC_IDENCARGO = 'D') BEGIN
                  SET @V_VRBRUTO = - (@V_ITEMENC_VRITEMENCA/@V_TOTAPRODENCA);
               END
               ELSE BEGIN
                  SET @V_VRBRUTO = 0;
               END;

               IF (@V_ITEMENC_CDCTBLENTREN IS NULL) BEGIN
                  SET @V_VRCONTAB = @V_VRBRUTO;
               END
               ELSE BEGIN
                  SET @V_VRCONTAB = 0;
               END;

               UPDATE ITEMPRODUTO
               SET VRBRUTITEM = ROUND(VRBRUTITEM + (@V_VRBRUTO  * (VRTOTAITEM - VRDESCITEM)),2),
                   VRCONTITEM = ROUND(VRCONTITEM + (@V_VRCONTAB * (VRTOTAITEM - VRDESCITEM)),2)
               WHERE CDFILIAL    = @P_FILIAL   AND
                     NRLANCTONF  = @P_LANCTONF AND
                     NRSEQITPROD = @V_ATUAVR_NRSEQITPROD;

               FETCH NEXT FROM C_ATUAVRCONT INTO @V_ATUAVR_NRSEQITPROD, @V_ATUAVR_VRLIQUIDO, @V_ATUAVR_NRITPROIMPOS;
            END; /*WHILE DO CURSOR C_ATUAVRCONT*/


            CLOSE C_ATUAVRCONT;
            DEALLOCATE C_ATUAVRCONT;

            DECLARE C_ITEMPROIMPOS CURSOR FOR
            SELECT II.NRSEQITPROD, II.NRITPROIMPOS, II.CDIMPOSTO, II.VRPERREDBCIT,
                   II.VRALIQITEM, II.VRPARDEDIT, II.IDTRIMPSTII, (VRTOTAITEM - VRDESCITEM) AS VRLIQUIDO
            FROM ITEMPROIMPOS II, ITEMPRODUTO IP, BASECALC BC
            WHERE (II.CDFILIAL     = @P_FILIAL)
              AND (II.NRLANCTONF   = @P_LANCTONF)
              AND (IP.CDFILIAL     = @P_FILIAL)
              AND (IP.NRLANCTONF   = @P_LANCTONF)
              AND (IP.NRSEQITPROD  = II.NRSEQITPROD)
              --AND (CHARINDEX(II.CDIMPOSTO+'_', @V_CDIMPOSRECALC) > 0)
              AND (BC.CDIMPOSTO    = II.CDIMPOSTO)
              AND (BC.CDENCARGO    = @V_ITEMENC_CDENCARGO)
            ORDER BY 1, 2, 3;

            OPEN C_ITEMPROIMPOS;

            FETCH NEXT FROM C_ITEMPROIMPOS INTO @V_ITEMPROI_NRSEQITPROD, @V_ITEMPROI_NRITPROIMPOS, @V_ITEMPROI_CDIMPOSTO, @V_ITEMPROI_VRPERREDBCIT,
                                                @V_ITEMPROI_VRALIQITEM,  @V_ITEMPROI_VRPARDEDIT, @V_ITEMPROI_IDTRIMPSTII, @V_ITEMPROI_VRLIQUIDO;

            WHILE (@@FETCH_STATUS = 0) BEGIN

               SELECT @V_TOTAPRENIMPO = SUM(VRTOTAITEM - VRDESCITEM)
               FROM ITEMPRODUTO IP
               WHERE (IP.CDFILIAL     = @P_FILIAL)      AND
                     (IP.NRLANCTONF   = @P_LANCTONF);

               IF (@V_ITEMENC_IDENCARGO = 'A') BEGIN
                  SET @V_PRODUENCARGO = +(@V_ITEMENC_VRITEMENCA/@V_TOTAPRENIMPO)*@V_ITEMPROI_VRLIQUIDO;
               END
               ELSE IF (@V_ITEMENC_IDENCARGO = 'D') BEGIN
                  SET @V_PRODUENCARGO = -(@V_ITEMENC_VRITEMENCA/@V_TOTAPRENIMPO)*@V_ITEMPROI_VRLIQUIDO;
               END
               ELSE BEGIN
                  SET @V_PRODUENCARGO = 0;
               END;

               SET @V_CDIMPOSTRIB  = NULL;
               SET @V_IDVRIMPSTRIB = NULL;

               DECLARE C_ICMSST CURSOR FOR
                  SELECT CDIMPOSTO
                    FROM IMPOSTO
                   WHERE CDIMPOSTRIB = @V_ITEMPROI_CDIMPOSTO;

               OPEN C_ICMSST;
               FETCH NEXT FROM C_ICMSST INTO @V_ICMSST_CDIMPOSTRIB;

               WHILE (@@FETCH_STATUS = 0) BEGIN

                  SET @V_CDIMPOSTRIB = ISNULL(@V_CDIMPOSTRIB,'')+@V_ICMSST_CDIMPOSTRIB+'_';
                  FETCH NEXT FROM C_ICMSST INTO @V_ICMSST_CDIMPOSTRIB;
               END;
               CLOSE C_ICMSST;
               DEALLOCATE C_ICMSST;

               SET @V_VRIMPOSTOST = 0;
               SET @V_TAXAALIQUOTA = (@V_ITEMPROI_VRALIQITEM/100);

               IF @V_CDIMPOSTRIB IS NULL BEGIN
                  SET @V_TAXABASECALC = (100 - @V_ITEMPROI_VRPERREDBCIT)/100;
               END
               ELSE BEGIN
                  SET @V_TAXABASECALC = 1 + (@V_ITEMPROI_VRPERREDBCIT)/100;

                  SELECT @V_IDVRIMPSTRIB = ISNULL(MAX(IDVRIMPSTRIB), 'N')
                    FROM ITEMPROIMPOS I, IMPOSTO II
                   WHERE (CDFILIAL  = @P_FILIAL)
                     AND (NRLANCTONF = @P_LANCTONF)
                     AND (NRSEQITPROD  = @V_ITEMPROI_NRSEQITPROD)
                     AND (CHARINDEX(II.CDIMPOSTO+'_', @V_CDIMPOSTRIB) > 0)
                     AND (I.CDIMPOSTO = II.CDIMPOSTO);

                  IF (@V_ITEMPROI_IDTRIMPSTII = '1') OR (ISNULL(@V_ITEMPROI_IDTRIMPSTII,'N') = 'N') BEGIN
                     SET @V_VRIMPOSTOST = 0;
                  END
                  ELSE BEGIN
                     SELECT @V_VRIMPOSTOST = ISNULL(MAX(VRIMPOSTOIT),0)
                     FROM ITEMPROIMPOS I
                     WHERE (CDFILIAL  = @P_FILIAL)
                       AND (NRLANCTONF = @P_LANCTONF)
                       AND (CHARINDEX(CDIMPOSTO+'_', @V_CDIMPOSTRIB) > 0)
                       AND (NRITPROIMPOS = @V_ITEMPROI_NRITPROIMPOS);
                  END;
               END;

               SET @V_IMPOSTOIT = ((@V_PRODUENCARGO * @V_TAXABASECALC) * @V_TAXAALIQUOTA);
               SET @V_IMPOSTOIT = @V_IMPOSTOIT - ((@V_VRIMPOSTOST * @V_TAXABASECALC) * @V_TAXAALIQUOTA);

               SELECT @V_IDPERVISIMPSCRE = ISNULL(MAX(IDPERVISIMPSCRE), 'S')
                 FROM PARAMGERAL;

               UPDATE ITEMPROIMPOS
               SET VRBASECALCIT = ISNULL(VRBASECALCIT + (@V_PRODUENCARGO * @V_TAXABASECALC),0),
                   VRIMPOSTOIT  = VRIMPOSTOIT  + @V_IMPOSTOIT,
                   VRIMPOSTOVISUIT = CASE @V_IDPERVISIMPSCRE WHEN 'S' THEN VRIMPOSTOIT  + @V_IMPOSTOIT ELSE CASE CDFISCALIT WHEN '1' THEN VRIMPOSTOIT  + @V_IMPOSTOIT ELSE 0 END END
               WHERE (NRLANCTONF   = @P_LANCTONF) AND
                     (CDFILIAL     = @P_FILIAL)   AND
                     (NRSEQITPROD  = @V_ITEMPROI_NRSEQITPROD) AND
                     (CDIMPOSTO    = @V_ITEMPROI_CDIMPOSTO)   AND
                     (NRITPROIMPOS = @V_ITEMPROI_NRITPROIMPOS);

               /* ROTINA PARA RECALCULAR O DIFERIMENTO DO IMPOSTO */
               SET @V_VRIMPOSTOOPERAIT = 0;
               SET @V_VRPERDIFEREIT    = 0;

               SELECT @V_VRIMPOSTOOPERAIT = MAX(VRIMPOSTOOPERAIT),
                      @V_VRPERDIFEREIT = MAX(VRPERDIFEREIT)
                 FROM ITEMPROIMPOS
                WHERE (CDFILIAL     = @P_FILIAL)                AND
                      (NRLANCTONF   = @P_LANCTONF)              AND
                      (NRSEQITPROD  = @V_ITEMPROI_NRSEQITPROD)  AND
                      (CDIMPOSTO    = @V_ITEMPROI_CDIMPOSTO)    AND
                      (NRITPROIMPOS = @V_ITEMPROI_NRITPROIMPOS) AND
                      (VRPERDIFEREIT <> 0);

               IF @V_VRPERDIFEREIT <> 0 BEGIN
                  SET @V_VRIMPOSTOOPERAIT = ROUND((@V_VRIMPOSTOOPERAIT + @V_IMPOSTOIT),2);
                  SET @V_VRIMPOSTODIFERIT = ROUND((@V_VRIMPOSTOOPERAIT * @V_VRPERDIFEREIT/100), 2);

                  UPDATE ITEMPROIMPOS
                     SET VRIMPOSTOOPERAIT = @V_VRIMPOSTOOPERAIT,
                         VRIMPOSTODIFERIT = @V_VRIMPOSTODIFERIT,
                         VRIMPOSTOIT = (@V_VRIMPOSTOOPERAIT - @V_VRIMPOSTODIFERIT),
                         VRIMPOSTOVISUIT = (@V_VRIMPOSTOOPERAIT - @V_VRIMPOSTODIFERIT)
                   WHERE (CDFILIAL     = @P_FILIAL)                AND
                         (NRLANCTONF   = @P_LANCTONF)              AND
                         (NRSEQITPROD  = @V_ITEMPROI_NRSEQITPROD)  AND
                         (CDIMPOSTO    = @V_ITEMPROI_CDIMPOSTO)    AND
                         (NRITPROIMPOS = @V_ITEMPROI_NRITPROIMPOS) AND
                         (VRPERDIFEREIT <> 0);
               END;

               FETCH NEXT FROM C_ITEMPROIMPOS INTO @V_ITEMPROI_NRSEQITPROD, @V_ITEMPROI_NRITPROIMPOS, @V_ITEMPROI_CDIMPOSTO, @V_ITEMPROI_VRPERREDBCIT,
                                                @V_ITEMPROI_VRALIQITEM,  @V_ITEMPROI_VRPARDEDIT, @V_ITEMPROI_IDTRIMPSTII, @V_ITEMPROI_VRLIQUIDO;
            END; /*WHILE DO CURSOR C_ITEMPROIMPOS*/

            CLOSE C_ITEMPROIMPOS;
            DEALLOCATE C_ITEMPROIMPOS;
         END;

         FETCH NEXT FROM C_ITEMENCARGO INTO @V_ITEMENC_CDENCARGO, @V_ITEMENC_VRITEMENCA,
                                            @V_ITEMENC_IDENCARGO, @V_ITEMENC_CDCTBLENTREN,
                                            @V_ITEMENC_CDCTBLSAIDEN;
      END; /*WHILE DO CURSOR C_ITEMENCARGO*/

      CLOSE C_ITEMENCARGO;
      DEALLOCATE C_ITEMENCARGO;

      --CLCULO DO VALOR DOS IMPOSTOS QUE CONTM OUTROS IMPOSTOS NA SUA BASE DE CLCULO
      DECLARE C_PRODUTO CURSOR FOR
         SELECT IP.NRSEQITPROD AS NRSEQITPROD, II.CDIMPOSTO, VRPERREDBCIT,
                VRALIQITEM, VRPARDEDIT, CDFISCALIT, VRIMPOSTOIT, IDTRATIMPO,
                IM.IDIMPORECUP, IM.CDCCTBLPASS, IM.CDCCTBLATIV, NRITPROIMPOS,
                II.IDTRIMPSTII, IM.IDTIPCONTAB, II.VRBASECALCIT
         FROM ITEMPRODUTO IP, ITEMPROIMPOS II, IMPOSTO IM
         WHERE (IP.CDFILIAL     = @P_FILIAL)     AND
               (IP.NRLANCTONF   = @P_LANCTONF)   AND
               (II.CDFILIAL     = IP.CDFILIAL)   AND
               (II.NRLANCTONF   = IP.NRLANCTONF) AND
               (IM.CDIMPOSTO    = II.CDIMPOSTO)  AND
               --(CHARINDEX(II.CDIMPOSTO+'_', @V_CDIMPOSRECALC) > 0) AND
               (II.NRITPROIMPOS = '1')           AND
               (II.NRSEQITPROD  = IP.NRSEQITPROD)
         ORDER BY IP.NRSEQITPROD, II.CDIMPOSTO;
      OPEN C_PRODUTO;
      FETCH NEXT FROM C_PRODUTO INTO @V_PRODUTO_NRSEQITPROD , @V_PRODUTO_CDIMPOSTO,
                                     @V_PRODUTO_VRPERREDBCIT, @V_PRODUTO_VRALIQITEM,
                                     @V_PRODUTO_VRPARDEDIT  , @V_PRODUTO_CDFISCALIT,
                                     @V_PRODUTO_VRIMPOSTOIT , @V_PRODUTO_IDTRATIMPO,
                                     @V_PRODUTO_IDIMPORECUP , @V_PRODUTO_CDCCTBLPASS,
                                     @V_PRODUTO_CDCCTBLATIV , @V_PRODUTO_NRITPROIMPOS,
                                     @V_IDTRIMPSTII         , @V_PRODUTO_IDTIPCONTAB,
                                     @V_PRODUTO_VRBASECALCIT;

      WHILE (@@FETCH_STATUS = 0) BEGIN
         SET @V_IDIMPOBCALTPOP = NULL;

         SELECT @V_IDIMPOBCALTPOP = MAX('S') , @V_TOTAIMPBCALC = ISNULL(SUM(VRIMPOSTOIT),0)
         FROM ITEMPRODUTO IP, ITEMPROIMPOS II, BASECALCTPOPER BC , IMPOSTO I
         WHERE (BC.CDIMPOSTO    = @V_PRODUTO_CDIMPOSTO)    AND
               (IP.CDFILIAL     = @P_FILIAL)               AND
               (IP.NRLANCTONF   = @P_LANCTONF)             AND
               (II.NRLANCTONF   = IP.NRLANCTONF)          AND
               (II.CDFILIAL     = IP.CDFILIAL)            AND
               (IP.NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD)  AND
               (II.NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD)  AND
               (II.NRITPROIMPOS = @V_PRODUTO_NRITPROIMPOS) AND
               ((SUBSTRING(IP.CDSITUTRIBPR,2,2) = BC.CDCSTIMPOTPOP)  OR (BC.CDCSTIMPOTPOP  IS NULL)) AND
               ((SUBSTRING(IP.CDFISOPEITEM,2,4) = BC.CDCFOPIMPOTPOP) OR (BC.CDCFOPIMPOTPOP IS NULL)) AND
               ((@V_PRODUTO_CDFISCALIT        = BC.CDFISCIMPOTPOP) OR (BC.CDFISCIMPOTPOP IS NULL)) AND
               (BC.IDENTRSAIDOP = 'S')             AND
               (BC.CDTIPOOPER = @P_TIPOOPER)               AND
               (II.CDIMPOSTO = BC.CDIMPOBCALC)            AND
               (BC.CDIMPOBCALC = I.CDIMPOSTO)             AND
               (ISNULL(BC.IDTRATIMPOBCTPOP, I.IDTRATIMPO) <> 'D');

         IF @V_IDIMPOBCALTPOP IS NULL BEGIN
            SELECT @V_TOTAIMPBCALC = ISNULL(SUM(VRIMPOSTOIT),0)
              FROM ITEMPRODUTO IP, ITEMPROIMPOS II, BASECALC BC, IMPOSTO I
             WHERE (BC.CDIMPOSTO    = @V_PRODUTO_CDIMPOSTO)    AND
                   (IP.CDFILIAL     = @P_FILIAL)               AND
                   (IP.NRLANCTONF   = @P_LANCTONF)             AND
                   (II.NRLANCTONF   = IP.NRLANCTONF)           AND
                   (II.CDFILIAL     = IP.CDFILIAL)             AND
                   (IP.NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD)  AND
                   (II.NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD)  AND
                   (II.NRITPROIMPOS = @V_PRODUTO_NRITPROIMPOS) AND
                   ((SUBSTRING(IP.CDSITUTRIBPR,2,2) = BC.CDCSTIMPO)  OR (BC.CDCSTIMPO  IS NULL)) AND
                   ((SUBSTRING(IP.CDFISOPEITEM,2,4) = BC.CDCFOPIMPO) OR (BC.CDCFOPIMPO IS NULL)) AND
                   ((@V_PRODUTO_CDFISCALIT          = BC.CDFISCIMPO) OR (BC.CDFISCIMPO IS NULL)) AND
                   (II.CDIMPOSTO     = BC.CDIMPOBCALC) AND
                   (BC.IDTIPOBCALC   = 'I') AND
                   (BC.CDIMPOBCALC = I.CDIMPOSTO)  AND
                   (ISNULL(BC.IDTRATIMPOBC, I.IDTRATIMPO) <> 'D');
         END;

         SET @V_IDIMBCALTPOPDE = NULL;

         SELECT @V_IDIMBCALTPOPDE = MAX('S'), @V_TOTAIMPBCDES = (ISNULL(SUM(VRIMPOSTOIT),0)*-1)
           FROM ITEMPRODUTO IP, ITEMPROIMPOS II, BASECALCTPOPER BC, IMPOSTO I
          WHERE (BC.CDIMPOSTO    = @V_PRODUTO_CDIMPOSTO)    AND
                (IP.CDFILIAL     = @P_FILIAL)               AND
                (IP.NRLANCTONF   = @P_LANCTONF)             AND
                (II.NRLANCTONF   = IP.NRLANCTONF)          AND
                (II.CDFILIAL     = IP.CDFILIAL)            AND
                (IP.NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD)  AND
                (II.NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD)  AND
                (II.NRITPROIMPOS = @V_PRODUTO_NRITPROIMPOS) AND
                ((SUBSTRING(IP.CDSITUTRIBPR,2,2) = BC.CDCSTIMPOTPOP)  OR (BC.CDCSTIMPOTPOP  IS NULL)) AND
                ((SUBSTRING(IP.CDFISOPEITEM,2,4) = BC.CDCFOPIMPOTPOP) OR (BC.CDCFOPIMPOTPOP IS NULL)) AND
                ((@V_PRODUTO_CDFISCALIT        = BC.CDFISCIMPOTPOP) OR (BC.CDFISCIMPOTPOP IS NULL)) AND
                (BC.IDENTRSAIDOP = 'S')  AND
                (BC.CDTIPOOPER = @P_TIPOOPER)    AND
                (II.CDIMPOSTO = BC.CDIMPOBCALC) AND
                (BC.CDIMPOBCALC = I.CDIMPOSTO)  AND
                (ISNULL(BC.IDTRATIMPOBCTPOP, I.IDTRATIMPO) = 'D');

         IF @V_IDIMBCALTPOPDE IS NULL BEGIN
            SELECT @V_TOTAIMPBCDES = (ISNULL(SUM(VRIMPOSTOIT),0)*-1)
              FROM ITEMPRODUTO IP, ITEMPROIMPOS II, BASECALC BC, IMPOSTO I
             WHERE (BC.CDIMPOSTO    = @V_PRODUTO_CDIMPOSTO)    AND
                   (IP.CDFILIAL     = @P_FILIAL)               AND
                   (IP.NRLANCTONF   = @P_LANCTONF)             AND
                   (II.NRLANCTONF   = IP.NRLANCTONF)           AND
                   (II.CDFILIAL     = IP.CDFILIAL)             AND
                   (IP.NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD)  AND
                   (II.NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD)  AND
                   (II.NRITPROIMPOS = @V_PRODUTO_NRITPROIMPOS) AND
                   ((SUBSTRING(IP.CDSITUTRIBPR,2,2) = BC.CDCSTIMPO)  OR (BC.CDCSTIMPO  IS NULL)) AND
                   ((SUBSTRING(IP.CDFISOPEITEM,2,4) = BC.CDCFOPIMPO) OR (BC.CDCFOPIMPO IS NULL)) AND
                   ((@V_PRODUTO_CDFISCALIT          = BC.CDFISCIMPO) OR (BC.CDFISCIMPO IS NULL)) AND
                   (II.CDIMPOSTO     = BC.CDIMPOBCALC) AND
                   (BC.IDTIPOBCALC   = 'I') AND
                   (BC.CDIMPOBCALC = I.CDIMPOSTO)  AND
                   (ISNULL(BC.IDTRATIMPOBC, I.IDTRATIMPO) = 'D');
         END;

         SET @V_VRIMPOSTO = @V_PRODUTO_VRIMPOSTOIT;

         SET @V_CDIMPOSTRIB  = NULL;
         SET @V_IDVRIMPSTRIB = NULL;

         DECLARE C_ICMSST CURSOR FOR
           SELECT CDIMPOSTO
             FROM IMPOSTO
            WHERE CDIMPOSTRIB = @V_PRODUTO_CDIMPOSTO;

         OPEN C_ICMSST;
         FETCH NEXT FROM C_ICMSST INTO @V_ICMSST_CDIMPOSTRIB;

         WHILE (@@FETCH_STATUS = 0) BEGIN

            SET @V_CDIMPOSTRIB = ISNULL(@V_CDIMPOSTRIB,'')+@V_ICMSST_CDIMPOSTRIB+'_';
            FETCH NEXT FROM C_ICMSST INTO @V_ICMSST_CDIMPOSTRIB;
         END;
         CLOSE C_ICMSST;
         DEALLOCATE C_ICMSST;

         SET @V_VRIMPOSTOST = 0;

         /*S ir fazer o clculo de outro imposto compondo a base de clculo,
           se o valor do mesmo no estiver zerado OU
           se for o imposto de st, pois o icms pode ter sido recalculado(por ter alguem compondo sua bc)
           e o imposto st precisa retirar o valor final do st*/
         IF (NOT(@V_TOTAIMPBCALC IS NULL) AND (@V_TOTAIMPBCALC <> 0)) OR
            (NOT(@V_TOTAIMPBCDES IS NULL) AND (@V_TOTAIMPBCDES <> 0)) OR
            (@V_CDIMPOSTRIB IS NOT NULL) BEGIN

            SELECT @V_IDPERVISIMPSCRE = ISNULL(MAX(IDPERVISIMPSCRE), 'S')
              FROM PARAMGERAL;

            IF @V_CDIMPOSTRIB IS NULL BEGIN
               SET @V_TAXABASECALC = (100 - @V_PRODUTO_VRPERREDBCIT)/100;
               SET @V_TAXAALIQUOTA = (@V_PRODUTO_VRALIQITEM/100);
               SET @V_VRIMPOSTO    = @V_VRIMPOSTO + (((@V_TOTAIMPBCALC+@V_TOTAIMPBCDES) * @V_TAXABASECALC) * @V_TAXAALIQUOTA);

               UPDATE ITEMPROIMPOS
                  SET VRBASECALCIT = VRBASECALCIT + ((@V_TOTAIMPBCALC+@V_TOTAIMPBCDES) * @V_TAXABASECALC),
                      VRIMPOSTOIT  = (VRIMPOSTOIT  + (((@V_TOTAIMPBCALC+@V_TOTAIMPBCDES) * @V_TAXABASECALC) * @V_TAXAALIQUOTA)),
                      VRIMPOSTOVISUIT = CASE @V_IDPERVISIMPSCRE WHEN 'S' THEN (VRIMPOSTOIT  + (((@V_TOTAIMPBCALC+@V_TOTAIMPBCDES) * @V_TAXABASECALC) * @V_TAXAALIQUOTA)) ELSE CASE CDFISCALIT WHEN '1' THEN (VRIMPOSTOIT  + (((@V_TOTAIMPBCALC+@V_TOTAIMPBCDES) * @V_TAXABASECALC) * @V_TAXAALIQUOTA)) ELSE 0 END END
                WHERE (CDFILIAL     = @P_FILIAL)              AND
                      (NRLANCTONF   = @P_LANCTONF)            AND
                      (NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD) AND
                      (CDIMPOSTO    = @V_PRODUTO_CDIMPOSTO)   AND
                     (NRITPROIMPOS = @V_PRODUTO_NRITPROIMPOS);
               /* ROTINA PARA RECALCULAR O DIFERIMENTO DO IMPOSTO */
               SET @V_VRIMPOSTOOPERAIT = 0;
               SET @V_VRPERDIFEREIT    = 0;

               SELECT @V_VRIMPOSTOOPERAIT = MAX(VRIMPOSTOOPERAIT),
                      @V_VRPERDIFEREIT = MAX(VRPERDIFEREIT)
                 FROM ITEMPROIMPOS
                WHERE (CDFILIAL     = @P_FILIAL)               AND
                      (NRLANCTONF   = @P_LANCTONF)             AND
                      (NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD)  AND
                      (CDIMPOSTO    = @V_PRODUTO_CDIMPOSTO)    AND
                      (NRITPROIMPOS = @V_PRODUTO_NRITPROIMPOS) AND
                      (VRPERDIFEREIT <> 0);

               IF @V_VRPERDIFEREIT <> 0 BEGIN
                  SET @V_VRIMPOSTOOPERAIT = ROUND((@V_VRIMPOSTOOPERAIT + ((ROUND((@V_TOTAIMPBCALC+@V_TOTAIMPBCDES), 2) * @V_TAXABASECALC) * @V_TAXAALIQUOTA)),2);
                  SET @V_VRIMPOSTODIFERIT = ROUND((@V_VRIMPOSTOOPERAIT * @V_VRPERDIFEREIT/100), 2);

                  UPDATE ITEMPROIMPOS
                     SET VRIMPOSTOOPERAIT = @V_VRIMPOSTOOPERAIT,
                         VRIMPOSTODIFERIT = @V_VRIMPOSTODIFERIT,
                         VRIMPOSTOIT = (@V_VRIMPOSTOOPERAIT - @V_VRIMPOSTODIFERIT),
                         VRIMPOSTOVISUIT = (@V_VRIMPOSTOOPERAIT - @V_VRIMPOSTODIFERIT)
                   WHERE (CDFILIAL     = @P_FILIAL)               AND
                         (NRLANCTONF   = @P_LANCTONF)             AND
                         (NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD)  AND
                         (CDIMPOSTO    = @V_PRODUTO_CDIMPOSTO)    AND
                         (NRITPROIMPOS = @V_PRODUTO_NRITPROIMPOS) AND
                         (VRPERDIFEREIT <> 0);
               END;
            END
            ELSE BEGIN
               SET @V_VRIMPOSST   = 0;
               SET @V_VRIMPOSTOST = 0;

               DECLARE C_SUBSTRIB CURSOR FOR
                  SELECT ISNULL(IDVRIMPSTRIB, 'N') IDVRIMPSTRIB, I.CDIMPOSTO
                    FROM ITEMPROIMPOS I, IMPOSTO II
                   WHERE (CDFILIAL     = @P_FILIAL)
                     AND (NRLANCTONF   = @P_LANCTONF)
                     AND (NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD)
                     AND (NRITPROIMPOS = '1')
                     AND (CHARINDEX(II.CDIMPOSTO+'_', @V_CDIMPOSTRIB) > 0)
                     AND (I.CDIMPOSTO = II.CDIMPOSTO);

               OPEN C_SUBSTRIB;
               FETCH NEXT FROM C_SUBSTRIB INTO @V_SUBSTRIB_IDVRIMPSTRIB, @V_SUBSTRIB_CDIMPOSTO;
               WHILE (@@FETCH_STATUS = 0) BEGIN

                  IF (@V_SUBSTRIB_IDVRIMPSTRIB = 'S') BEGIN
                        SELECT @V_VRIMPOSST = ISNULL(ROUND(MAX(VRIMPOSTOIT), 2),0)
                        FROM ITEMPROIMPOS I
                        WHERE (CDFILIAL     = @P_FILIAL)                     AND
                              (NRLANCTONF   = @P_LANCTONF)                   AND
                              (NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD)     AND
                              (CDIMPOSTO    = @V_SUBSTRIB_CDIMPOSTO)         AND
                              (CHARINDEX(CDIMPOSTO+'_', @V_CDIMPOSTRIB) > 0) AND
                              (NRITPROIMPOS = '1');
                  END
                  ELSE BEGIN
                     SET @V_VRIMPOSST = 0;
                  END;
                  SET @V_VRIMPOSTOST = @V_VRIMPOSTOST + @V_VRIMPOSST;

                  FETCH NEXT FROM C_SUBSTRIB INTO @V_SUBSTRIB_IDVRIMPSTRIB, @V_SUBSTRIB_CDIMPOSTO;
               END;
               CLOSE C_SUBSTRIB;
               DEALLOCATE C_SUBSTRIB;

               SET @V_TAXABASECALC = 1 + (@V_PRODUTO_VRPERREDBCIT)/100;
               SET @V_TAXAALIQUOTA = (@V_PRODUTO_VRALIQITEM/100);
               SET @V_VRIMPOSTO    = ((@V_PRODUTO_VRBASECALCIT+ ((@V_TOTAIMPBCALC+@V_TOTAIMPBCDES) * @V_TAXABASECALC)) * @V_TAXAALIQUOTA);


               IF @V_VRIMPOSTOST > @V_VRIMPOSTO BEGIN
                  UPDATE ITEMPROIMPOS
                  SET VRBASECALCIT = VRBASECALCIT + ((@V_TOTAIMPBCALC+@V_TOTAIMPBCDES) * @V_TAXABASECALC),
                      VRIMPOSTOIT  = 0,
                      VRIMPOSTOVISUIT = 0
                WHERE (CDFILIAL     = @P_FILIAL)              AND
                      (NRLANCTONF   = @P_LANCTONF)            AND
                      (NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD) AND
                      (CDIMPOSTO    = @V_PRODUTO_CDIMPOSTO)   AND
                      (NRITPROIMPOS = @V_PRODUTO_NRITPROIMPOS);

                  SET @V_VRIMPOSTO  = 0;
               END
               ELSE BEGIN
                  UPDATE ITEMPROIMPOS
                     SET VRBASECALCIT = VRBASECALCIT + ((@V_TOTAIMPBCALC+@V_TOTAIMPBCDES) * @V_TAXABASECALC),
                         VRIMPOSTOIT  = @V_VRIMPOSTO - @V_VRIMPOSTOST,
                         VRIMPOSTOVISUIT = CASE @V_IDPERVISIMPSCRE WHEN 'S' THEN @V_VRIMPOSTO - @V_VRIMPOSTOST ELSE CASE CDFISCALIT WHEN '1' THEN @V_VRIMPOSTO - @V_VRIMPOSTOST ELSE 0 END END
                   WHERE (CDFILIAL     = @P_FILIAL)              AND
                         (NRLANCTONF   = @P_LANCTONF)            AND
                         (NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD) AND
                         (CDIMPOSTO    = @V_PRODUTO_CDIMPOSTO)   AND
                         (NRITPROIMPOS = @V_PRODUTO_NRITPROIMPOS);

                  SET  @V_VRIMPOSTO = @V_VRIMPOSTO - @V_VRIMPOSTOST;
               END;
--               SET @V_VRIMPOSTO    = ((@V_VRIMPOSTO + (((@V_TOTAIMPBCALC+@V_TOTAIMPBCDES) * @V_TAXABASECALC) * @V_TAXAALIQUOTA)) - ((@V_VRIMPOSTOST * @V_TAXABASECALC) * @V_TAXAALIQUOTA));
            END;
         END;
         FETCH NEXT FROM C_PRODUTO INTO @V_PRODUTO_NRSEQITPROD , @V_PRODUTO_CDIMPOSTO,
                                        @V_PRODUTO_VRPERREDBCIT, @V_PRODUTO_VRALIQITEM,
                                        @V_PRODUTO_VRPARDEDIT  , @V_PRODUTO_CDFISCALIT,
                                        @V_PRODUTO_VRIMPOSTOIT , @V_PRODUTO_IDTRATIMPO,
                                        @V_PRODUTO_IDIMPORECUP , @V_PRODUTO_CDCCTBLPASS,
                                        @V_PRODUTO_CDCCTBLATIV , @V_PRODUTO_NRITPROIMPOS,
                                        @V_IDTRIMPSTII         , @V_PRODUTO_IDTIPCONTAB,
                                        @V_PRODUTO_VRBASECALCIT;
      END;
      CLOSE C_PRODUTO;
      DEALLOCATE C_PRODUTO;
      DECLARE C_PRODUTO CURSOR FOR
      SELECT IP.NRSEQITPROD AS NRSEQITPROD, II.CDIMPOSTO, VRPERREDBCIT,
             VRALIQITEM, VRPARDEDIT, CDFISCALIT, VRIMPOSTOIT, IDTRATIMPO,
             IM.IDIMPORECUP, IM.CDCCTBLPASS, IM.CDCCTBLATIV, NRITPROIMPOS,
             II.IDTRIMPSTII, IM.IDTIPCONTAB
      FROM ITEMPRODUTO IP, ITEMPROIMPOS II, IMPOSTO IM
      WHERE (IP.CDFILIAL     = @P_FILIAL)     AND
            (IP.NRLANCTONF   = @P_LANCTONF)   AND
            (II.CDFILIAL     = IP.CDFILIAL)   AND
            (II.NRLANCTONF   = IP.NRLANCTONF) AND
            (IM.CDIMPOSTO    = II.CDIMPOSTO)  AND
            (II.NRITPROIMPOS = '1')           AND
            (II.NRSEQITPROD  = IP.NRSEQITPROD);
      OPEN C_PRODUTO;
      FETCH NEXT FROM C_PRODUTO INTO @V_PRODUTO_NRSEQITPROD , @V_PRODUTO_CDIMPOSTO,
                                     @V_PRODUTO_VRPERREDBCIT, @V_PRODUTO_VRALIQITEM,
                                     @V_PRODUTO_VRPARDEDIT  , @V_PRODUTO_CDFISCALIT,
                                     @V_PRODUTO_VRIMPOSTOIT , @V_PRODUTO_IDTRATIMPO,
                                     @V_PRODUTO_IDIMPORECUP , @V_PRODUTO_CDCCTBLPASS,
                                     @V_PRODUTO_CDCCTBLATIV , @V_PRODUTO_NRITPROIMPOS,
                                     @V_IDTRIMPSTII         , @V_PRODUTO_IDTIPCONTAB;

      WHILE (@@FETCH_STATUS = 0) BEGIN

         SET @V_VRIMPOSTO = @V_PRODUTO_VRIMPOSTOIT;
         SET @V_VRIMPOSTOST = 0;

         SET @V_CDIMPOSTRIB  = NULL;
         SET @V_IDVRIMPSTRIB = NULL;

         DECLARE C_ICMSST CURSOR FOR
            SELECT CDIMPOSTO
              FROM IMPOSTO
             WHERE CDIMPOSTRIB = @V_PRODUTO_CDIMPOSTO;

         OPEN C_ICMSST;
         FETCH NEXT FROM C_ICMSST INTO @V_ICMSST_CDIMPOSTRIB;

         WHILE (@@FETCH_STATUS = 0) BEGIN

            SET @V_CDIMPOSTRIB = ISNULL(@V_CDIMPOSTRIB,'')+@V_ICMSST_CDIMPOSTRIB+'_';
            FETCH NEXT FROM C_ICMSST INTO @V_ICMSST_CDIMPOSTRIB;
         END;
         CLOSE C_ICMSST;
         DEALLOCATE C_ICMSST;

         IF NOT (@V_TOTAIMPBCALC IS NULL) BEGIN
            IF @V_CDIMPOSTRIB IS NULL BEGIN
               SET @V_TAXABASECALC = (100 - @V_PRODUTO_VRPERREDBCIT)/100;
               SET @V_TAXAALIQUOTA = (@V_PRODUTO_VRALIQITEM/100);
               SET @V_VRIMPOSTO    = @V_VRIMPOSTO + ((@V_TOTAIMPBCALC * @V_TAXABASECALC) * @V_TAXAALIQUOTA);
            END
            ELSE BEGIN
               SELECT V_IDVRIMPSTRIB = ISNULL(MAX(IDVRIMPSTRIB), 'N')
                FROM ITEMPROIMPOS I, IMPOSTO II
               WHERE (CDFILIAL     = @P_FILIAL)
                 AND (NRLANCTONF   = @P_LANCTONF)
                 AND (NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD)
                 AND (CHARINDEX(II.CDIMPOSTO+'_', @V_CDIMPOSTRIB) > 0)
                 AND (I.CDIMPOSTO = II.CDIMPOSTO);

               IF (@V_IDTRIMPSTII = '1') OR (ISNULL(@V_IDVRIMPSTRIB,'N') = 'N') BEGIN
                  SET @V_VRIMPOSTOST = 0;
               END
               ELSE BEGIN

                  SELECT @V_VRIMPOSTOST = ISNULL(MAX(VRIMPOSTOIT),0)
                    FROM ITEMPROIMPOS I
                   WHERE (CDFILIAL     = @P_FILIAL)               AND
                         (NRLANCTONF   = @P_LANCTONF)             AND
                         (NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD)  AND
                         (CHARINDEX(CDIMPOSTO+'_', @V_CDIMPOSTRIB) > 0) AND
                         (NRITPROIMPOS = '1');

                  SET @V_TAXABASECALC = 1 + (@V_PRODUTO_VRPERREDBCIT)/100;
                  SET @V_TAXAALIQUOTA = (@V_PRODUTO_VRALIQITEM/100);
                  SET @V_VRIMPOSTO    = @V_VRIMPOSTO + (((@V_TOTAIMPBCALC - @V_VRIMPOSTOST) * @V_TAXABASECALC) * @V_TAXAALIQUOTA);
               END;
            END;
            SELECT @V_IDPERVISIMPSCRE = ISNULL(MAX(IDPERVISIMPSCRE),'S')
              FROM PARAMGERAL;

            IF (@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV') BEGIN
               UPDATE ITEMPROIMPOS
               SET VRBASECALCIT = ROUND((VRBASECALCIT + (@V_TOTAIMPBCALC * @V_TAXABASECALC)),2,2),
                   VRIMPOSTOIT  = ROUND((VRIMPOSTOIT  + (((@V_TOTAIMPBCALC - @V_VRIMPOSTOST) * @V_TAXABASECALC) * @V_TAXAALIQUOTA)),2,2),
                   VRIMPOSTOVISUIT = CASE @V_IDPERVISIMPSCRE WHEN 'S' THEN ROUND((VRIMPOSTOIT  + (((@V_TOTAIMPBCALC - @V_VRIMPOSTOST) * @V_TAXABASECALC) * @V_TAXAALIQUOTA)),2,2) ELSE CASE CDFISCALIT WHEN '1' THEN ROUND((VRIMPOSTOIT  + (((@V_TOTAIMPBCALC - @V_VRIMPOSTOST) * @V_TAXABASECALC) * @V_TAXAALIQUOTA)),2,2) ELSE 0 END END
               WHERE (CDFILIAL     = @P_FILIAL)              AND
                     (NRLANCTONF   = @P_LANCTONF)            AND
                     (NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD) AND
                     (CDIMPOSTO    = @V_PRODUTO_CDIMPOSTO)   AND
                     (NRITPROIMPOS = @V_PRODUTO_NRITPROIMPOS);
            END
            ELSE BEGIN
               UPDATE ITEMPROIMPOS
               SET VRBASECALCIT = ROUND(VRBASECALCIT + (@V_TOTAIMPBCALC * @V_TAXABASECALC),2),
                   VRIMPOSTOIT  = ROUND(VRIMPOSTOIT  + (((@V_TOTAIMPBCALC - @V_VRIMPOSTOST) * @V_TAXABASECALC) * @V_TAXAALIQUOTA),2),
                   VRIMPOSTOVISUIT = CASE @V_IDPERVISIMPSCRE WHEN 'S' THEN ROUND(VRIMPOSTOIT  + (((@V_TOTAIMPBCALC - @V_VRIMPOSTOST) * @V_TAXABASECALC) * @V_TAXAALIQUOTA),2) ELSE CASE CDFISCALIT WHEN '1' THEN ROUND(VRIMPOSTOIT  + (((@V_TOTAIMPBCALC - @V_VRIMPOSTOST) * @V_TAXABASECALC) * @V_TAXAALIQUOTA),2) ELSE 0 END END
               WHERE (CDFILIAL     = @P_FILIAL)              AND
                     (NRLANCTONF   = @P_LANCTONF)            AND
                     (NRSEQITPROD  = @V_PRODUTO_NRSEQITPROD) AND
                     (CDIMPOSTO    = @V_PRODUTO_CDIMPOSTO)   AND
                     (NRITPROIMPOS = @V_PRODUTO_NRITPROIMPOS);
            END;
         END;

         SET @V_IMPOCONTAB = 0;

         IF (@V_PRODUTO_IDTRATIMPO = 'A') BEGIN
            IF ((@V_PRODUTO_IDIMPORECUP = 'S')  AND (@V_PRODUTO_CDFISCALIT = '1')) OR
               ((@V_PRODUTO_IDIMPORECUP <> 'S') AND (@V_PRODUTO_CDCCTBLPASS IS NOT NULL)) AND
               (@V_CDIMPOSTRIB IS NULL) AND (@V_PRODUTO_IDTIPCONTAB = 'D') BEGIN

               IF (@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV') BEGIN
                  UPDATE ITEMPRODUTO
                  SET VRBRUTITEM = ROUND((VRBRUTITEM + @V_VRIMPOSTO),2,2)
                  WHERE CDFILIAL    = @P_FILIAL   AND
                        NRLANCTONF  = @P_LANCTONF AND
                        NRSEQITPROD = @V_PRODUTO_NRSEQITPROD;
               END
               ELSE BEGIN
                  UPDATE ITEMPRODUTO
                  SET VRBRUTITEM = ROUND(VRBRUTITEM + @V_VRIMPOSTO,2)
                  WHERE CDFILIAL    = @P_FILIAL   AND
                        NRLANCTONF  = @P_LANCTONF AND
                        NRSEQITPROD = @V_PRODUTO_NRSEQITPROD;
               END;
            END
            ELSE BEGIN
               IF ((@V_CDIMPOSTRIB IS NOT NULL) AND (@V_IDTRIMPSTII = '0')) OR
                   (@V_CDIMPOSTRIB IS NULL) BEGIN
                  IF (@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV') BEGIN
                     UPDATE ITEMPRODUTO
                     SET VRBRUTITEM = ROUND((VRBRUTITEM + @V_VRIMPOSTO),2,2),
                         VRCONTITEM = ROUND((VRCONTITEM + @V_VRIMPOSTO),2,2)
                     WHERE CDFILIAL    = @P_FILIAL   AND
                           NRLANCTONF  = @P_LANCTONF AND
                           NRSEQITPROD = @V_PRODUTO_NRSEQITPROD;
                  END
                  ELSE BEGIN
                     UPDATE ITEMPRODUTO
                     SET VRBRUTITEM = ROUND(VRBRUTITEM + @V_VRIMPOSTO,2),
                         VRCONTITEM = ROUND(VRCONTITEM + @V_VRIMPOSTO,2)
                     WHERE CDFILIAL    = @P_FILIAL   AND
                           NRLANCTONF  = @P_LANCTONF AND
                           NRSEQITPROD = @V_PRODUTO_NRSEQITPROD;
                  END;
               END;
            END;
         END
         ELSE IF (@V_PRODUTO_IDTRATIMPO = 'D') BEGIN
            IF ((@V_PRODUTO_IDIMPORECUP = 'S') AND (@V_PRODUTO_CDFISCALIT = '1')) OR
               ((@V_PRODUTO_IDIMPORECUP <> 'S') AND (@V_PRODUTO_CDCCTBLATIV IS NOT NULL)) AND
               (@V_PRODUTO_IDTIPCONTAB = 'D') BEGIN
               IF (@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV') BEGIN
                  UPDATE ITEMPRODUTO
                  SET VRBRUTITEM = ROUND((VRBRUTITEM - @V_VRIMPOSTO),2,2)
                  WHERE CDFILIAL    = @P_FILIAL   AND
                        NRLANCTONF  = @P_LANCTONF AND
                        NRSEQITPROD = @V_PRODUTO_NRSEQITPROD;
               END
               ELSE BEGIN
                  UPDATE ITEMPRODUTO
                  SET VRBRUTITEM = ROUND(VRBRUTITEM - @V_VRIMPOSTO,2)
                  WHERE CDFILIAL    = @P_FILIAL   AND
                        NRLANCTONF  = @P_LANCTONF AND
                        NRSEQITPROD = @V_PRODUTO_NRSEQITPROD;
               END;
            END
            ELSE BEGIN
               IF (@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV') BEGIN
                  UPDATE ITEMPRODUTO
                  SET VRBRUTITEM = ROUND((VRBRUTITEM - @V_VRIMPOSTO),2,2),
                      VRCONTITEM = ROUND((VRCONTITEM - @V_VRIMPOSTO),2,2)
                  WHERE CDFILIAL    = @P_FILIAL   AND
                        NRLANCTONF  = @P_LANCTONF AND
                        NRSEQITPROD = @V_PRODUTO_NRSEQITPROD;
               END
               ELSE BEGIN
                  UPDATE ITEMPRODUTO
                  SET VRBRUTITEM = ROUND(VRBRUTITEM - @V_VRIMPOSTO,2),
                      VRCONTITEM = ROUND(VRCONTITEM - @V_VRIMPOSTO,2)
                  WHERE CDFILIAL    = @P_FILIAL   AND
                        NRLANCTONF  = @P_LANCTONF AND
                        NRSEQITPROD = @V_PRODUTO_NRSEQITPROD;
               END;
            END;
         END
         ELSE IF (@V_PRODUTO_IDTRATIMPO = 'R') BEGIN
            IF (@V_PRODUTO_IDIMPORECUP = 'S') BEGIN
               IF (@V_PRODUTO_CDCCTBLATIV IS NULL) OR
                  (@V_PRODUTO_CDFISCALIT <> '1') BEGIN
                  SET @V_IMPOCONTAB = - @V_VRIMPOSTO;
               END;
            END
            ELSE BEGIN
               IF (@V_PRODUTO_CDCCTBLATIV IS NULL) BEGIN
                  SET @V_IMPOCONTAB = - @V_VRIMPOSTO;
               END;
            END;

            IF (@V_PRODUTO_IDTIPCONTAB = 'D') BEGIN
               IF (@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV') BEGIN
                  UPDATE ITEMPRODUTO
                  SET VRCONTITEM = ROUND((VRCONTITEM + @V_IMPOCONTAB),2,2)
                  WHERE CDFILIAL    = @P_FILIAL   AND
                        NRLANCTONF  = @P_LANCTONF AND
                        NRSEQITPROD = @V_PRODUTO_NRSEQITPROD;
               END
               ELSE BEGIN
                  UPDATE ITEMPRODUTO
                  SET VRCONTITEM = ROUND(VRCONTITEM + @V_IMPOCONTAB,2)
                  WHERE CDFILIAL    = @P_FILIAL   AND
                        NRLANCTONF  = @P_LANCTONF AND
                        NRSEQITPROD = @V_PRODUTO_NRSEQITPROD;
               END;
            END;

         END
         ELSE IF (@V_PRODUTO_IDTRATIMPO = 'V') BEGIN
            IF (@V_PRODUTO_IDIMPORECUP = 'S')  BEGIN
               IF (@V_PRODUTO_CDCCTBLPASS IS NOT NULL) AND
                  (@V_PRODUTO_CDFISCALIT = '1') BEGIN

                  SET @V_IMPOCONTAB = - @V_VRIMPOSTO;
               END;
            END;

            IF (@V_PRODUTO_IDTIPCONTAB = 'D') BEGIN
               IF (@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV') BEGIN
                  UPDATE ITEMPRODUTO
                  SET VRCONTITEM = ROUND((VRCONTITEM + @V_IMPOCONTAB),2,2)
                  WHERE CDFILIAL    = @P_FILIAL   AND
                        NRLANCTONF  = @P_LANCTONF AND
                        NRSEQITPROD = @V_PRODUTO_NRSEQITPROD;
               END
               ELSE BEGIN
                  UPDATE ITEMPRODUTO
                  SET VRCONTITEM = ROUND(VRCONTITEM + @V_IMPOCONTAB,2)
                  WHERE CDFILIAL    = @P_FILIAL   AND
                        NRLANCTONF  = @P_LANCTONF AND
                        NRSEQITPROD = @V_PRODUTO_NRSEQITPROD;
               END;
            END;
         END;

         FETCH NEXT FROM C_PRODUTO INTO @V_PRODUTO_NRSEQITPROD , @V_PRODUTO_CDIMPOSTO,
                                        @V_PRODUTO_VRPERREDBCIT, @V_PRODUTO_VRALIQITEM,
                                        @V_PRODUTO_VRPARDEDIT  , @V_PRODUTO_CDFISCALIT,
                                        @V_PRODUTO_VRIMPOSTOIT , @V_PRODUTO_IDTRATIMPO,
                                        @V_PRODUTO_IDIMPORECUP , @V_PRODUTO_CDCCTBLPASS,
                                        @V_PRODUTO_CDCCTBLATIV , @V_PRODUTO_NRITPROIMPOS,
                                        @V_IDTRIMPSTII         , @V_PRODUTO_IDTIPCONTAB;
      END;
      CLOSE C_PRODUTO;
      DEALLOCATE C_PRODUTO;

      IF @V_IDOPERDEVONF = 'S' BEGIN
         SET @V_SEQUIMPOSTNF = '01';

         DELETE FROM ITEMPRODUTO
         WHERE (CDFILIAL   = @P_FILIAL)   AND
               (NRLANCTONF = @P_LANCTONF) AND
               (QTITEMPROD = 0);

         DELETE FROM IMPOSNFTOT
         WHERE (CDFILIAL = @P_FILIAL) AND
               (NRLANCTONF = @P_LANCTONF);

         DECLARE C_IMPOSNFTOT CURSOR FOR
            SELECT IT.CDIMPOSTO
            FROM ITEMPROIMPOS IT
            WHERE (IT.CDFILIAL   = @P_FILIAL) AND
                  (IT.NRLANCTONF = @P_LANCTONF)
            GROUP BY IT.CDIMPOSTO;
         OPEN C_IMPOSNFTOT;
         FETCH NEXT FROM C_IMPOSNFTOT INTO @V_IMPOSNFTOT_CDIMPOSTO;
         WHILE (@@FETCH_STATUS = 0) BEGIN

            SET @V_IMPOSTOIT  = 0;
            SET @V_BASECALCIT = 0;

            SELECT @V_IMPOSTOIT = ISNULL(SUM(IT.VRIMPOSTOIT),0),
                   @V_BASECALCIT = ISNULL(SUM(IT.VRBASECALCIT),0)
            FROM ITEMPROIMPOS IT, IMPOSTO I
            WHERE (IT.CDFILIAL   = @P_FILIAL)               AND
                  (IT.NRLANCTONF = @P_LANCTONF)             AND
                  (IT.CDIMPOSTO  = @V_IMPOSNFTOT_CDIMPOSTO) AND
                  (IT.CDIMPOSTO  = I.CDIMPOSTO);

               SET @V_ICMS = NULL;
               DECLARE C_ICMS CURSOR FOR
                  SELECT CDIMPOSTO
                    FROM IMPOSTONFE N, IMPOSTO I
                   WHERE N.CDIMPOSTONFE = I.CDIMPOSTONFE
                     AND N.CDIMPOSTONFE = '00'
                     AND I.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
               OPEN C_ICMS;
               FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
               WHILE (@@FETCH_STATUS = 0) BEGIN
                  SET @V_ICMS = 'S';
                  FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
               END;
               CLOSE C_ICMS;
               DEALLOCATE C_ICMS;

            IF ((@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV')) AND (@V_ICMS = 'S') BEGIN
               INSERT INTO IMPOSNFTOT(CDFILIAL, NRLANCTONF, CDIMPOSTO, VRTOTIMPONF, VRTOTBCALCNF)
               VALUES (@P_FILIAL, @P_LANCTONF, @V_IMPOSNFTOT_CDIMPOSTO, ROUND(@V_IMPOSTOIT,@V_NRDECITOTANF,2), ROUND(@V_BASECALCIT,@V_NRDECITOTANF,2));
            END
            ELSE BEGIN
               INSERT INTO IMPOSNFTOT(CDFILIAL, NRLANCTONF, CDIMPOSTO, VRTOTIMPONF, VRTOTBCALCNF)
               VALUES (@P_FILIAL, @P_LANCTONF, @V_IMPOSNFTOT_CDIMPOSTO, ROUND(@V_IMPOSTOIT,@V_NRDECITOTANF), ROUND(@V_BASECALCIT,@V_NRDECITOTANF));
            END;

            FETCH NEXT FROM C_IMPOSNFTOT INTO @V_IMPOSNFTOT_CDIMPOSTO;
         END;
         CLOSE C_IMPOSNFTOT;
         DEALLOCATE C_IMPOSNFTOT;

         DELETE FROM IMPOSTONF
         WHERE (CDFILIAL   = @P_FILIAL) AND
               (NRLANCTONF = @P_LANCTONF);

         DECLARE C_ITEMNOTAFISC CURSOR FOR
            SELECT CDFILIALIT, NRLANCTONFIT
            FROM ITEMNOTAFISC
            WHERE CDFILIAL   = @P_FILIAL AND
                  NRLANCTONF = @P_LANCTONF;
         OPEN C_ITEMNOTAFISC;
         FETCH NEXT FROM C_ITEMNOTAFISC INTO @V_CDFILIALIT, @V_NRLANCTONFIT;
         WHILE (@@FETCH_STATUS = 0) BEGIN

            SELECT @V_VRLIQUORIG = SUM(VRTOTAITEM - VRDESCITEM)
            FROM ITEMPRODUTO I
            WHERE CDFILIAL    = @V_CDFILIALIT AND
                  NRLANCTONF  = @V_NRLANCTONFIT;

            IF @V_VRLIQUORIG = 0 BEGIN
               SET @V_VRFATOCONV = 0;
            END ELSE BEGIN
               SET @V_VRFATOCONV = @V_LIQUIDO / @V_VRLIQUORIG;
            END;

            DECLARE C_IMPOSNFTOT CURSOR FOR
               SELECT IT.CDIMPOSTO, IT.VRTOTIMPONF, IT.VRTOTBCALCNF
               FROM IMPOSNFTOT IT, IMPOSTO IP
               WHERE IT.CDFILIAL   = @V_CDFILIALIT AND
                     IT.NRLANCTONF = @V_NRLANCTONFIT AND
                     IT.CDIMPOSTO  = IP.CDIMPOSTO AND
                     IP.IDPRODNOTA = 'C';

            OPEN C_IMPOSNFTOT;
            FETCH NEXT FROM C_IMPOSNFTOT INTO @V_IMPOSNFTOT_CDIMPOSTO, @V_IMPOSNFTOT_VRTOTIMPONF, @V_IMPOSNFTOT_VRTOTBCALCNF;
            WHILE (@@FETCH_STATUS = 0) BEGIN
               SELECT @V_IDUTMUNIORIG = ISNULL(MAX(IDUTMUNIORIG),'N')
                 FROM IMPOSTO
                WHERE CDIMPOSTO = @V_IMPOSNFTOT_CDIMPOSTO;

               IF ((@V_IDUTMUNIORIG = 'O') OR (@V_IDUTMUNIORIG = 'N')) BEGIN
                  EXEC CONSULTA_ALIQUOTA @V_IMPOSNFTOT_CDIMPOSTO, 'S', @P_EMPRESA, null, @P_INSCESTA, @V_PAISORIG,
                                         @V_ESTAORIG, @V_PAISDEST, @V_ESTADEST, @V_MUNIORIG, @V_LIQUIITEM, @P_INIVALID, @P_FILIAL, @P_LANCTONF, @V_CDGRUPOFISC, @P_TIPOOPER;
               END
               ELSE BEGIN
                  EXEC CONSULTA_ALIQUOTA @V_IMPOSNFTOT_CDIMPOSTO, 'S', @P_EMPRESA, null, @P_INSCESTA, @V_PAISORIG,
                                         @V_ESTAORIG, @V_PAISDEST, @V_ESTADEST, @V_MUNIDEST, @V_LIQUIITEM, @P_INIVALID, @P_FILIAL, @P_LANCTONF, @V_CDGRUPOFISC, @P_TIPOOPER;
               END;

               SELECT @V_NRALIQTEMP = MAX(NRALIQTEMP),
                      @V_PARDEDTMP = MAX(VRPARDEDTMP),
                      @V_PREDBCTMP = MAX(VRPREDBCTMP),
                      @V_ALIQUTMP = MAX(VRALIQUTMP),
                      @V_TRATIMPST = ISNULL(MAX(IDTRIMPSTTMP), '0'),
                      @V_CDTIPOOPER = MAX(CDTIPOOPERTMP)
                 FROM ALIQTEMP
                WHERE (NRALIQTEMP = @V_ALIQTEMP);

               IF ((@V_NRALIQTEMP IS NOT NULL) AND (@V_CDTIPOOPER IS NOT NULL) AND (@V_ESTORNOCANC <> 'S')) BEGIN
                  IF (@V_ALIQUTMP IS NULL) BEGIN
                     SET @V_ALIQUTMP = 0;
                  END;
                  SET @V_PRODUENCARGO = 0;

                  SELECT @V_SOMAITEM = SUM(VRITEMENCA)
                    FROM ITEMENCARGO IE, ENCARGO EN, BASECALC BC
                   WHERE (IE.CDFILIAL   = @P_FILIAL)
                     AND (IE.NRLANCTONF = @P_LANCTONF)
                     AND (EN.CDENCARGO  = IE.CDENCARGO)
                     AND (BC.CDENCARGO  = IE.CDENCARGO)
                     AND (BC.CDIMPOSTO  = @V_IMPOSNFTOT_CDIMPOSTO)
                     AND (EN.IDENCARGO  = 'A');

                  SELECT @V_DESCITEM = SUM(VRITEMENCA)
                    FROM ITEMENCARGO IE, ENCARGO EN, BASECALC BC
                   WHERE (IE.CDFILIAL   = @P_FILIAL)
                     AND (IE.NRLANCTONF = @P_LANCTONF)
                     AND (EN.CDENCARGO  = IE.CDENCARGO)
                     AND (BC.CDENCARGO  = IE.CDENCARGO)
                     AND (BC.CDIMPOSTO  = @V_IMPOSNFTOT_CDIMPOSTO)
                     AND (EN.IDENCARGO  = 'D');

                  IF @V_SOMAITEM IS NULL BEGIN
                     SET @V_SOMAITEM = 0;
                  END;

                  IF @V_DESCITEM IS NULL BEGIN
                     SET @V_DESCITEM = 0;
                  END;

                  IF (@V_ALIQUTMP IS NULL) BEGIN
                     SET @V_ALIQUTMP = 0;
                  END;

                  IF (@V_PREDBCTMP IS NULL) BEGIN
                     SET @V_PREDBCTMP = 0;
                  END;

                  IF (@V_PARDEDTMP IS NULL) BEGIN
                     SET @V_PARDEDTMP = 0;
                  END;

                  SET @V_PRODUENCARGO = @V_SOMAITEM - @V_DESCITEM;

                  SET @V_TAXABASECALC = (100 - @V_PREDBCTMP)/100;
                  SET @V_TAXAALIQUOTA = (@V_ALIQUTMP/100);
                  SET @V_BASECALCIT   = (@V_LIQUIDO + @V_PRODUENCARGO) * @V_TAXABASECALC;

                  SET @V_CONTIMPO     = @V_BASECALCIT;
                  SET @V_IMPOSTOIT    = (@V_BASECALCIT * @V_TAXAALIQUOTA) - @V_PARDEDTMP;

                  IF @V_BASECALCIT < 0 BEGIN
                     SET @V_BASECALCIT = 0;
                  END;

                  SET @V_CONTABCALC = (@V_LIQUIDO + @V_PRODUENCARGO) - ((@V_LIQUIDO + @V_PRODUENCARGO) * @V_TAXABASECALC);
                  SET @V_PERDBCALC  = 100 - @V_PREDBCTMP;

                  IF @V_IMPOSTOIT < 0 BEGIN
                     SET @V_IMPOSTOIT = 0;
                  END;

                  SET @V_ICMS = NULL;
                  DECLARE C_ICMS CURSOR FOR
                     SELECT CDIMPOSTO
                       FROM IMPOSTONFE N, IMPOSTO I
                      WHERE N.CDIMPOSTONFE = I.CDIMPOSTONFE
                        AND N.CDIMPOSTONFE = '00'
                        AND I.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
                  OPEN C_ICMS;
                  FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
                  WHILE (@@FETCH_STATUS = 0) BEGIN
                     SET @V_ICMS = 'S';
                     FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
                  END;
                  CLOSE C_ICMS;
                  DEALLOCATE C_ICMS;

                  IF ((@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV')) AND (@V_ICMS = 'S') BEGIN
                     INSERT INTO IMPOSNFTOT(CDFILIAL, NRLANCTONF, CDIMPOSTO, VRTOTIMPONF, VRTOTBCALCNF)
                                       VALUES (@P_FILIAL, @P_LANCTONF, @V_IMPOSNFTOT_CDIMPOSTO, ROUND(@V_IMPOSTOIT ,@V_NRDECITOTANF,2), ROUND(@V_BASECALCIT,@V_NRDECITOTANF,2));
                  END
                  ELSE BEGIN
                     INSERT INTO IMPOSNFTOT(CDFILIAL, NRLANCTONF, CDIMPOSTO, VRTOTIMPONF, VRTOTBCALCNF)
                                       VALUES (@P_FILIAL, @P_LANCTONF, @V_IMPOSNFTOT_CDIMPOSTO, ROUND(@V_IMPOSTOIT ,@V_NRDECITOTANF), ROUND(@V_BASECALCIT,@V_NRDECITOTANF));
                  END;
               END
               ELSE BEGIN
                  SET @V_IMPOSTOIT = (@V_IMPOSNFTOT_VRTOTIMPONF * @V_VRFATOCONV);
                  SET @V_BASECALCIT = (@V_IMPOSNFTOT_VRTOTBCALCNF * @V_VRFATOCONV);

                  SET @V_ICMS = NULL;
                  DECLARE C_ICMS CURSOR FOR
                     SELECT CDIMPOSTO
                       FROM IMPOSTONFE N, IMPOSTO I
                      WHERE N.CDIMPOSTONFE = I.CDIMPOSTONFE
                        AND N.CDIMPOSTONFE = '00'
                        AND I.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
                  OPEN C_ICMS;
                  FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
                  WHILE (@@FETCH_STATUS = 0) BEGIN
                     SET @V_ICMS = 'S';
                     FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
                  END;
                  CLOSE C_ICMS;
                  DEALLOCATE C_ICMS;

                  IF ((@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV')) AND (@V_ICMS = 'S') BEGIN
                     INSERT INTO IMPOSNFTOT(CDFILIAL, NRLANCTONF, CDIMPOSTO, VRTOTIMPONF, VRTOTBCALCNF)
                        VALUES (@P_FILIAL, @P_LANCTONF, @V_IMPOSNFTOT_CDIMPOSTO, ROUND(@V_IMPOSTOIT ,@V_NRDECITOTANF,2), ROUND(@V_BASECALCIT,@V_NRDECITOTANF,2));
                  END
                  ELSE BEGIN
                     INSERT INTO IMPOSNFTOT(CDFILIAL, NRLANCTONF, CDIMPOSTO, VRTOTIMPONF, VRTOTBCALCNF)
                        VALUES (@P_FILIAL, @P_LANCTONF, @V_IMPOSNFTOT_CDIMPOSTO, ROUND(@V_IMPOSTOIT ,@V_NRDECITOTANF), ROUND(@V_BASECALCIT,@V_NRDECITOTANF));
                  END;

               END;

               DELETE ALIQTEMP
               WHERE NRALIQTEMP = @V_ALIQTEMP;

               FETCH NEXT FROM C_IMPOSNFTOT INTO @V_IMPOSNFTOT_CDIMPOSTO, @V_IMPOSNFTOT_VRTOTIMPONF, @V_IMPOSNFTOT_VRTOTBCALCNF;


            END;
            CLOSE C_IMPOSNFTOT;
            DEALLOCATE C_IMPOSNFTOT;

            DECLARE C_IMPOSTONF CURSOR FOR
               SELECT IT.CDIMPOSTO, IT.NRIMPOSNF, IT.VRCONTABILNF, IT.VRPERREDBCNF, IT.VRBASECALCNF,
                      IT.VRALIQNF, IT.VRPARDEDNF, IT.VRIMPOSTONF, IT.CDFISCALNF, IT.CDSITUTRIBNF,
                      IT.CDFISCOPERNF, IT.CDSUFXCFOPNF, IDTRIMPOSTNF, IT.CDSITUTRIBIMNFE, IP.IDIMPORECUP,
					  IT.CDTPCREDPICONF, IT.CDNATUBCALPCNF, IT.IDMOTDESONERANF
               FROM IMPOSTONF IT, IMPOSTO IP
               WHERE IT.CDFILIAL   = @V_CDFILIALIT AND
                     IT.NRLANCTONF = @V_NRLANCTONFIT AND
                     IT.CDIMPOSTO  = IP.CDIMPOSTO AND
                     IP.IDPRODNOTA = 'C';

            OPEN C_IMPOSTONF;


            FETCH NEXT FROM C_IMPOSTONF INTO @V_IMPOSTONF_CDIMPOSTO, @V_IMPOSTONF_NRIMPOSNF,
                                             @V_IMPOSTONF_VRCONTABILNF, @V_IMPOSTONF_VRPERREDBCNF,
                                             @V_IMPOSTONF_VRBASECALCNF, @V_IMPOSTONF_VRALIQNF,
                                             @V_IMPOSTONF_VRPARDEDNF, @V_IMPOSTONF_VRIMPOSTONF,
                                             @V_IMPOSTONF_CDFISCALNF, @V_IMPOSTONF_CDSITUTRIBNF,
                                             @V_IMPOSTONF_CDFISCOPERNF, @V_IMPOSTONF_CDSUFXCFOPNF,
                                             @V_IMPOSTONF_IDTRIMPOSTNF, @V_IMPOSTONF_CDSITUTRIBIMNFE,
                                             @V_IMPOSTONF_IDIMPORECUP, @V_IMPOSTONF_CDTPCREDPICONF,
                                             @V_IMPOSTONF_CDNATUBCALPCNF, @V_IMPOSTONF_IDMOTDESONERANF;

            WHILE (@@FETCH_STATUS = 0) BEGIN

               /*VERIFICA CST POR IMPOSTO*/
               SET @V_IMPOICMS = NULL;
               SET @V_CDGRUPOFISCAUX = NULL;

               SELECT @V_CDGRUPOFISCAUX = MAX(G.CDGRUPOFISC)
                 FROM GRUPOFISCIMPFIL G,
                      (SELECT CDFILIEMIT AS CDFILIAL
                         FROM NOTAFISCAL
                        WHERE CDFILIAL = @P_FILIAL
                          AND NRLANCTONF = @P_LANCTONF) F
                WHERE G.CDFILIAL = F.CDFILIAL
                  AND NOT G.CDGRUPOFISC IS NULL
                  AND G.CDIMPOSTO = @V_IMPOSTONF_CDIMPOSTO;

               IF @V_IDORIGDESTNF = 'C' BEGIN
                  SELECT @V_CDGRUPOFISCAUX = ISNULL(MAX(G.CDGRUPOFISC), @V_CDGRUPOFISCAUX)
                    FROM GRFISIMPIECLIE G,
                         (SELECT CDCLIENTE
                            FROM NOTAFISCAL
                           WHERE CDFILIAL = @P_FILIAL
                             AND NRLANCTONF = @P_LANCTONF) N
                   WHERE G.CDCLIENTE = N.CDCLIENTE
                     AND G.CDEMPRESA = @P_EMPRESA
                     AND G.CDINSCESTA = @P_INSCESTA
                     AND NOT G.CDGRUPOFISC IS NULL
                     AND G.CDIMPOSTO = @V_IMPOSTONF_CDIMPOSTO;
               END
               ELSE BEGIN
                  SELECT @V_CDGRUPOFISCAUX = ISNULL(MAX(G.CDGRUPOFISC), @V_CDGRUPOFISCAUX)
                    FROM GRFISIMPIEFORN G,
                        (SELECT CDFORNECED
                           FROM NOTAFISCAL
                          WHERE CDFILIAL = @P_FILIAL
                            AND NRLANCTONF = @P_LANCTONF) N
                   WHERE G.CDFORNECED = N.CDFORNECED
                     AND G.CDEMPRESA = @P_EMPRESA
                     AND G.CDINSCESTA = @P_INSCESTA
                     AND NOT G.CDGRUPOFISC IS NULL
                     AND G.CDIMPOSTO = @V_IMPOSTONF_CDIMPOSTO;
               END;

               IF @V_CDGRUPOFISCAUX IS NULL BEGIN
                  EXEC CONSULTA_CST_NFE 'S', @P_EMPRESA, '', @P_INSCESTA, @P_TIPOOPER, @V_CDGRUPOFISC, @V_IMPOSTONF_CDIMPOSTO, @V_IDINTEREST, @V_IDINTERNA, @P_FILIAL, @P_LANCTONF, '', @P_CDSITTRIBTMP = @V_CDSITTRIBTMP OUTPUT, @P_IDMODBCNFE = @V_IDMODBCNFE OUTPUT, @P_IDMODBCSTNFE = @V_IDMODBCSTNFE OUTPUT, @P_CDTPCRPICOSTNFE = @V_CDTPCRPICOSTNFE OUTPUT, @P_CDNATUBCPCSTNFE = @V_CDNATUBCPCSTNFE OUTPUT, @P_IDMOTIDESSTNFE = @V_IDMOTIDESSTNFE OUTPUT;
               END
               ELSE BEGIN
                  EXEC CONSULTA_CST_NFE 'S', @P_EMPRESA, '', @P_INSCESTA, @P_TIPOOPER, @V_CDGRUPOFISCAUX, @V_IMPOSTONF_CDIMPOSTO, @V_IDINTEREST, @V_IDINTERNA, @P_FILIAL, @P_LANCTONF, '', @P_CDSITTRIBTMP = @V_CDSITTRIBTMP OUTPUT, @P_IDMODBCNFE = @V_IDMODBCNFE OUTPUT, @P_IDMODBCSTNFE = @V_IDMODBCSTNFE OUTPUT, @P_CDTPCRPICOSTNFE = @V_CDTPCRPICOSTNFE OUTPUT, @P_CDNATUBCPCSTNFE = @V_CDNATUBCPCSTNFE OUTPUT, @P_IDMOTIDESSTNFE = @V_IDMOTIDESSTNFE OUTPUT;
               END;

               IF (@V_IMPOSTONF_CDSITUTRIBIMNFE IS NULL) BEGIN
                  SET @V_CDSITUTRIBNFE = @V_CDSITTRIBTMP;
               END
               ELSE BEGIN
                  SET @V_CDSITUTRIBNFE = @V_IMPOSTONF_CDSITUTRIBIMNFE;
               END;

               IF (@V_IMPOSTONF_CDTPCREDPICONF IS NULL) BEGIN
                  SET @V_CDTPCRPICOSTNFEIT = @V_CDTPCRPICOSTNFE;
               END
               ELSE BEGIN
                  SET @V_CDTPCRPICOSTNFEIT = @V_IMPOSTONF_CDTPCREDPICONF;
               END;

               IF (@V_IMPOSTONF_CDNATUBCALPCNF IS NULL) BEGIN
                  SET @V_CDNATUBCPCSTNFEIT = @V_CDNATUBCPCSTNFE;
               END
               ELSE BEGIN
                  SET @V_CDNATUBCPCSTNFEIT = @V_IMPOSTONF_CDNATUBCALPCNF;
               END;

               IF (@V_IMPOSTONF_IDMOTDESONERANF IS NULL) BEGIN
                  SET @V_IDMOTIDESSTNFE = @V_IDMOTIDESSTNFE;
               END
               ELSE BEGIN
                  SET @V_IDMOTIDESSTNFE = @V_IMPOSTONF_IDMOTDESONERANF;
               END;

               SELECT @V_IDUTMUNIORIG = ISNULL(MAX(IDUTMUNIORIG),'N')
                 FROM IMPOSTO
                WHERE CDIMPOSTO = @V_IMPOSTONF_CDIMPOSTO;

               IF ((@V_IDUTMUNIORIG = 'O') OR (@V_IDUTMUNIORIG = 'N')) BEGIN
                  EXEC CONSULTA_ALIQUOTA @V_IMPOSTONF_CDIMPOSTO, 'S', @P_EMPRESA, null, @P_INSCESTA, @V_PAISORIG,
                                         @V_ESTAORIG, @V_PAISDEST, @V_ESTADEST, @V_MUNIORIG, @V_LIQUIITEM, @P_INIVALID, @P_FILIAL, @P_LANCTONF, @V_CDGRUPOFISC, @P_TIPOOPER;
               END
               ELSE BEGIN
                  EXEC CONSULTA_ALIQUOTA @V_IMPOSTONF_CDIMPOSTO, 'S', @P_EMPRESA, null, @P_INSCESTA, @V_PAISORIG,
                                         @V_ESTAORIG, @V_PAISDEST, @V_ESTADEST, @V_MUNIDEST, @V_LIQUIITEM, @P_INIVALID, @P_FILIAL, @P_LANCTONF, @V_CDGRUPOFISC, @P_TIPOOPER;
               END;

               SELECT @V_NRALIQTEMP = MAX(NRALIQTEMP),
                      @V_PARDEDTMP = MAX(VRPARDEDTMP),
                      @V_PREDBCTMP = MAX(VRPREDBCTMP),
                      @V_ALIQUTMP = MAX(VRALIQUTMP),
                      @V_TRATIMPST = ISNULL(MAX(IDTRIMPSTTMP), '0'),
                      @V_CDTIPOOPER = MAX(CDTIPOOPERTMP)
                 FROM ALIQTEMP
                WHERE (NRALIQTEMP = @V_ALIQTEMP);

               IF ((@V_NRALIQTEMP IS NOT NULL) AND (@V_CDTIPOOPER IS NOT NULL) AND (@V_ESTORNOCANC <> 'S')) BEGIN
                  IF (@V_ALIQUTMP IS NULL) BEGIN
                     SET @V_ALIQUTMP = 0;
                  END;
                  SET @V_PRODUENCARGO = 0;

                  SELECT @V_SOMAITEM = SUM(VRITEMENCA)
                    FROM ITEMENCARGO IE, ENCARGO EN, BASECALC BC
                   WHERE (IE.CDFILIAL   = @P_FILIAL)
                     AND (IE.NRLANCTONF = @P_LANCTONF)
                     AND (EN.CDENCARGO  = IE.CDENCARGO)
                     AND (BC.CDENCARGO  = IE.CDENCARGO)
                     AND (BC.CDIMPOSTO  = @V_IMPOSTONF_CDIMPOSTO)
                     AND (EN.IDENCARGO  = 'A');

                  SELECT @V_DESCITEM = SUM(VRITEMENCA)
                    FROM ITEMENCARGO IE, ENCARGO EN, BASECALC BC
                   WHERE (IE.CDFILIAL   = @P_FILIAL)
                     AND (IE.NRLANCTONF = @P_LANCTONF)
                     AND (EN.CDENCARGO  = IE.CDENCARGO)
                     AND (BC.CDENCARGO  = IE.CDENCARGO)
                     AND (BC.CDIMPOSTO  = @V_IMPOSTONF_CDIMPOSTO)
                     AND (EN.IDENCARGO  = 'D');

                  IF @V_SOMAITEM IS NULL BEGIN
                     SET @V_SOMAITEM = 0;
                  END;

                  IF @V_DESCITEM IS NULL BEGIN
                     SET @V_DESCITEM = 0;
                  END;

                  IF (@V_ALIQUTMP IS NULL) BEGIN
                     SET @V_ALIQUTMP = 0;
                  END;

                  IF (@V_PREDBCTMP IS NULL) BEGIN
                     SET @V_PREDBCTMP = 0;
                  END;

                  IF (@V_PARDEDTMP IS NULL) BEGIN
                     SET @V_PARDEDTMP = 0;
                  END;

                  SET @V_PRODUENCARGO = @V_SOMAITEM - @V_DESCITEM;

                  SET @V_TAXABASECALC = (100 - @V_PREDBCTMP)/100;
                  SET @V_TAXAALIQUOTA = (@V_ALIQUTMP/100);
                  SET @V_BASECALCIT   = (@V_LIQUIDO + @V_PRODUENCARGO) * @V_TAXABASECALC;

                  SET @V_CONTIMPO     = @V_BASECALCIT;
                  SET @V_IMPOSTOIT    = (@V_BASECALCIT * @V_TAXAALIQUOTA) - @V_PARDEDTMP;

                  IF @V_BASECALCIT < 0 BEGIN
                     SET @V_BASECALCIT = 0;
                  END;

                  SET @V_CONTABCALC = (@V_LIQUIDO + @V_PRODUENCARGO) - ((@V_LIQUIDO + @V_PRODUENCARGO) * @V_TAXABASECALC);
                  SET @V_PERDBCALC  = 100 - @V_PREDBCTMP;

                  IF @V_IMPOSTOIT < 0 BEGIN
                     SET @V_IMPOSTOIT = 0;
                  END;

                  IF (@V_IMPOSTONF_IDIMPORECUP = 'S') OR (@V_IMPOSTONF_IDIMPORECUP <> 'S' AND @V_ALIQUTMP <> 0) BEGIN
                     IF ((@V_IMPOSTONF_IDIMPORECUP = 'S') AND (@V_IMPOSTONF_CDFISCALNF <> '1')) BEGIN
                        SET @V_BASECALCIT = 0;
                        SET @V_ALIQUTMP   = 0;
                        SET @V_IMPOSTOIT  = 0;
                        SET @V_PREDBCTMP  = 0;
                        SET @V_PARDEDTMP  = 0;
                     END;

                     SET @V_ICMS = NULL;
                     DECLARE C_ICMS CURSOR FOR
                        SELECT CDIMPOSTO
                          FROM IMPOSTONFE N, IMPOSTO I
                         WHERE N.CDIMPOSTONFE = I.CDIMPOSTONFE
                           AND N.CDIMPOSTONFE = '00'
                           AND I.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
                     OPEN C_ICMS;
                     FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
                     WHILE (@@FETCH_STATUS = 0) BEGIN
                        SET @V_ICMS = 'S';
                        FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
                     END;
                     CLOSE C_ICMS;
                     DEALLOCATE C_ICMS;

                     IF ((@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV')) AND (@V_ICMS = 'S') BEGIN
                        INSERT INTO IMPOSTONF(
                           CDFILIAL, NRLANCTONF, CDIMPOSTO, NRIMPOSNF, VRCONTABILNF, VRPERREDBCNF, VRBASECALCNF,
                           VRALIQNF, VRPARDEDNF, VRIMPOSTONF, CDFISCALNF, IDTRIMPOSTNF, CDSITUTRIBIMNFE, CDTPCREDPICONF, CDNATUBCALPCNF, IDMOTDESONERANF)
                        VALUES(
                           @P_FILIAL, @P_LANCTONF, @V_IMPOSTONF_CDIMPOSTO, @V_IMPOSTONF_NRIMPOSNF, ROUND(@V_CONTIMPO,2,2), @V_PREDBCTMP,
                           ROUND(@V_BASECALCIT,2,2), @V_ALIQUTMP, ROUND(@V_PARDEDTMP,2,2), ROUND(@V_IMPOSTOIT,2,2), @V_IMPOSTONF_CDSUFXCFOPNF, @V_IMPOSTONF_IDTRIMPOSTNF, @V_CDSITTRIBTMP, @V_CDTPCRPICOSTNFEIT, @V_CDNATUBCPCSTNFEIT, @V_IDMOTIDESSTNFE);
                     END
                     ELSE BEGIN
                        INSERT INTO IMPOSTONF(
                           CDFILIAL, NRLANCTONF, CDIMPOSTO, NRIMPOSNF, VRCONTABILNF, VRPERREDBCNF, VRBASECALCNF,
                           VRALIQNF, VRPARDEDNF, VRIMPOSTONF, CDFISCALNF, IDTRIMPOSTNF, CDSITUTRIBIMNFE, CDTPCREDPICONF, CDNATUBCALPCNF, IDMOTDESONERANF)
                        VALUES(
                           @P_FILIAL, @P_LANCTONF, @V_IMPOSTONF_CDIMPOSTO, @V_IMPOSTONF_NRIMPOSNF, @V_CONTIMPO, @V_PREDBCTMP,
                           @V_BASECALCIT, @V_ALIQUTMP, @V_PARDEDTMP, @V_IMPOSTOIT, @V_IMPOSTONF_CDSUFXCFOPNF, @V_IMPOSTONF_IDTRIMPOSTNF, @V_CDSITTRIBTMP, @V_CDTPCRPICOSTNFEIT, @V_CDNATUBCPCSTNFEIT, @V_IDMOTIDESSTNFE);
                     END;

                     IF ((@V_IMPOSTONF_IDIMPORECUP = 'S') AND (@V_PREDBCTMP > 0) AND (@V_IMPOSTONF_CDFISCALNF = '1')) BEGIN
                        INSERT INTO IMPOSTONF(
                           CDFILIAL, NRLANCTONF, CDIMPOSTO, NRIMPOSNF, VRCONTABILNF, VRPERREDBCNF, VRBASECALCNF,
                           VRALIQNF, VRPARDEDNF, VRIMPOSTONF, CDFISCALNF, CDSITUTRIBIMNFE, CDTPCREDPICONF, CDNATUBCALPCNF, IDMOTDESONERANF)
                        VALUES(
                           @P_FILIAL, @P_LANCTONF, @V_IMPOSTONF_CDIMPOSTO, @V_IMPOSTONF_NRIMPOSNF, @V_CONTABCALC, @V_PERDBCALC,
                           0, 0, @V_PARDEDTMP, 0, '2', @V_CDSITTRIBTMP, @V_CDTPCRPICOSTNFEIT, @V_CDNATUBCPCSTNFEIT, @V_IDMOTIDESSTNFE);
                     END;
                  END;

                  DELETE ALIQTEMP
                  WHERE NRALIQTEMP = @V_ALIQTEMP;
               END
               ELSE BEGIN

                  SET @V_ICMS = NULL;
                  DECLARE C_ICMS CURSOR FOR
                     SELECT CDIMPOSTO
                       FROM IMPOSTONFE N, IMPOSTO I
                      WHERE N.CDIMPOSTONFE = I.CDIMPOSTONFE
                        AND N.CDIMPOSTONFE = '00'
                        AND I.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
                  OPEN C_ICMS;
                  FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
                  WHILE (@@FETCH_STATUS = 0) BEGIN
                     SET @V_ICMS = 'S';
                     FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
                  END;
                  CLOSE C_ICMS;
                  DEALLOCATE C_ICMS;

                  IF ((@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV')) AND (@V_ICMS = 'S') BEGIN
                     INSERT INTO IMPOSTONF(
                        CDFILIAL, NRLANCTONF, CDIMPOSTO, NRIMPOSNF, VRCONTABILNF, VRPERREDBCNF, VRBASECALCNF,
                        VRALIQNF, VRPARDEDNF, VRIMPOSTONF, CDFISCALNF, CDSITUTRIBNF, CDFISCOPERNF, CDSUFXCFOPNF,
                        IDTRIMPOSTNF, CDSITUTRIBIMNFE, CDTPCREDPICONF, CDNATUBCALPCNF, IDMOTDESONERANF)
                     VALUES(@P_FILIAL, @P_LANCTONF, @V_IMPOSTONF_CDIMPOSTO, @V_IMPOSTONF_NRIMPOSNF,
                            ROUND((@V_IMPOSTONF_VRCONTABILNF * @V_VRFATOCONV),2,2), @V_IMPOSTONF_VRPERREDBCNF, ROUND((@V_IMPOSTONF_VRBASECALCNF * @V_VRFATOCONV),2,2),
                            @V_IMPOSTONF_VRALIQNF, ROUND((@V_IMPOSTONF_VRPARDEDNF * @V_VRFATOCONV),2,2), ROUND((@V_IMPOSTONF_VRIMPOSTONF * @V_VRFATOCONV),2,2), @V_IMPOSTONF_CDFISCALNF,
                            @V_IMPOSTONF_CDSITUTRIBNF, @V_IMPOSTONF_CDFISCOPERNF, @V_IMPOSTONF_CDSUFXCFOPNF,
                            @V_IMPOSTONF_IDTRIMPOSTNF, @V_CDSITTRIBTMP, @V_CDTPCRPICOSTNFEIT, @V_CDNATUBCPCSTNFEIT, @V_IDMOTIDESSTNFE);
                  END
                  ELSE BEGIN
                     INSERT INTO IMPOSTONF(
                        CDFILIAL, NRLANCTONF, CDIMPOSTO, NRIMPOSNF, VRCONTABILNF, VRPERREDBCNF, VRBASECALCNF,
                        VRALIQNF, VRPARDEDNF, VRIMPOSTONF, CDFISCALNF, CDSITUTRIBNF, CDFISCOPERNF, CDSUFXCFOPNF,
                        IDTRIMPOSTNF, CDSITUTRIBIMNFE, CDTPCREDPICONF, CDNATUBCALPCNF, IDMOTDESONERANF)
                     VALUES(@P_FILIAL, @P_LANCTONF, @V_IMPOSTONF_CDIMPOSTO, @V_IMPOSTONF_NRIMPOSNF,
                            (@V_IMPOSTONF_VRCONTABILNF * @V_VRFATOCONV), @V_IMPOSTONF_VRPERREDBCNF, (@V_IMPOSTONF_VRBASECALCNF * @V_VRFATOCONV),
                            @V_IMPOSTONF_VRALIQNF, (@V_IMPOSTONF_VRPARDEDNF * @V_VRFATOCONV), (@V_IMPOSTONF_VRIMPOSTONF * @V_VRFATOCONV), @V_IMPOSTONF_CDFISCALNF,
                            @V_IMPOSTONF_CDSITUTRIBNF, @V_IMPOSTONF_CDFISCOPERNF, @V_IMPOSTONF_CDSUFXCFOPNF,
                            @V_IMPOSTONF_IDTRIMPOSTNF, @V_CDSITTRIBTMP, @V_CDTPCRPICOSTNFEIT, @V_CDNATUBCPCSTNFEIT, @V_IDMOTIDESSTNFE);
                  END;

                  SET @V_SEQUIMPOSTNF = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR,CONVERT(NUMERIC,@V_SEQUIMPOSTNF) + 1)),2);
               END;

               FETCH NEXT FROM C_IMPOSTONF INTO @V_IMPOSTONF_CDIMPOSTO, @V_IMPOSTONF_NRIMPOSNF,
                                                @V_IMPOSTONF_VRCONTABILNF, @V_IMPOSTONF_VRPERREDBCNF,
                                                @V_IMPOSTONF_VRBASECALCNF, @V_IMPOSTONF_VRALIQNF,
                                                @V_IMPOSTONF_VRPARDEDNF, @V_IMPOSTONF_VRIMPOSTONF,
                                                @V_IMPOSTONF_CDFISCALNF, @V_IMPOSTONF_CDSITUTRIBNF,
                                                @V_IMPOSTONF_CDFISCOPERNF, @V_IMPOSTONF_CDSUFXCFOPNF,
                                                @V_IMPOSTONF_IDTRIMPOSTNF, @V_IMPOSTONF_CDSITUTRIBIMNFE,
                                                @V_IMPOSTONF_IDIMPORECUP, @V_IMPOSTONF_CDTPCREDPICONF,
                                                @V_IMPOSTONF_CDNATUBCALPCNF;

            END;
            CLOSE C_IMPOSTONF;
            DEALLOCATE C_IMPOSTONF;

            FETCH NEXT FROM C_ITEMNOTAFISC INTO @V_CDFILIALIT, @V_NRLANCTONFIT;
         END;
         CLOSE C_ITEMNOTAFISC;
         DEALLOCATE C_ITEMNOTAFISC;
      END;
   END
   ELSE IF (@P_TIPOOPER = '03') BEGIN /*NOTA DE COMPLEMENTO*/
      DECLARE C_IMPOSITEMCOM CURSOR FOR SELECT II.NRSEQITPROD,  II.CDIMPOSTO,    II.NRITPROIMPOS, II.VRCONTITIMP,
                                               II.VRPERREDBCIT, II.VRBASECALCIT, II.VRALIQITEM,   II.VRPARDEDIT,
                                               II.VRIMPOSTOIT,  II.CDFISCALIT,   I.IDUTVLRQTDEIMPO,
                                               II.CDSITUTRIBIT ,II.CDFISCOPERIT, II.VRPERMAJBCIT, P.CDARVPROD,
                                               II.CDENQLEGALIPI, II.CDCEST
                                           FROM ITEMPROIMPOS II, IMPOSTO I, ITEMPRODUTO IT, PRODUTO P
                                          WHERE (II.CDFILIAL   = @P_FILIAL)
                                            AND (II.NRLANCTONF = @P_LANCTONF)
                                            AND (II.NRITPROIMPOS = '1')
                                            AND (II.CDIMPOSTO = I.CDIMPOSTO)
                                            AND (P.CDPRODUTO  = IT.CDPRODUTO)
                                            AND (II.CDFILIAL = IT.CDFILIAL)
                                            AND (II.NRLANCTONF = IT.NRLANCTONF)
                                            AND (II.NRSEQITPROD = IT.NRSEQITPROD)
                                         ORDER BY II.NRSEQITPROD, II.CDIMPOSTO, II.NRITPROIMPOS;
      OPEN C_IMPOSITEMCOM;
      FETCH NEXT FROM C_IMPOSITEMCOM INTO @V_IMPOSITEMCOM_NRSEQITPROD,   @V_IMPOSITEMCOM_CDIMPOSTO,    @V_IMPOSITEMCOM_NRITPROIMPOS,   @V_IMPOSITEMCOM_VRCONTITIMP,
                                          @V_IMPOSITEMCOM_VRPERREDBCIT,  @V_IMPOSITEMCOM_VRBASECALCIT, @V_IMPOSITEMCOM_VRALIQITEM,     @V_IMPOSITEMCOM_VRPARDEDIT,
                                          @V_IMPOSITEMCOM_VRIMPOSTOIT,   @V_IMPOSITEMCOM_CDFISCALIT,   @V_IMPOSITEMCOM_IDUTVLRQTEIMPO,
                                          @V_IMPOSITEMCOM_CDSITUTRIBIT,  @V_IMPOSITEMCOM_CDFISCOPERIT, @V_IMPOSITEMCOM_VRPERMAJBCIT, @V_IMPOSITEMCOM_CDARVPROD,
                                          @V_IMPOSITEMCOM_CDENQLEGALIPI, @V_IMPOSITEMCOM_CDCEST;
      WHILE (@@FETCH_STATUS = 0) BEGIN

         EXEC CONSULTA_CSOSN 'S', @P_EMPRESA, @V_IMPOSITEMCOM_CDARVPROD, @P_INSCESTA, @P_TIPOOPER,@P_FILIAL, @P_LANCTONF, @V_CDGRUPOFISC, @V_IDINTEREST, @P_CDFISCOPERSN = @V_CDFISCOPERSN OUTPUT;

         UPDATE ITEMPRODUTO
            SET CDFISCOPERSN = @V_CDFISCOPERSN
          WHERE CDFILIAL     = @P_FILIAL
            AND NRLANCTONF   = @P_LANCTONF
            AND NRSEQITPROD  = @V_IMPOSITEMCOM_NRSEQITPROD;

         IF (@V_IMPOSITEMCOM_VRIMPOSTOIT = 0)  BEGIN
            IF (@V_IMPOSITEMCOM_VRALIQITEM <> 0) BEGIN

               SET @V_TAXAALIQUOTA = (@V_IMPOSITEMCOM_VRALIQITEM/100);
               SET @V_TAXABASECALC = (100 - @V_IMPOSITEMCOM_VRPERREDBCIT)/100;
               SET @V_TAXABCSUBSTR = (100 + @V_IMPOSITEMCOM_VRPERMAJBCIT)/100;

               SELECT @V_VRTOTAITEM = MAX(VRTOTAITEM), @V_QTITEMPROD = MAX(QTITEMPROD), @V_CDPRODUTO = MAX(CDPRODUTO)
                 FROM ITEMPRODUTO
                WHERE CDFILIAL = @P_FILIAL
                  AND NRLANCTONF = @P_LANCTONF
                  AND NRSEQITPROD = @V_IMPOSITEMCOM_NRSEQITPROD;

               IF @V_IMPOSITEMCOM_VRBASECALCIT > 0 BEGIN
                  SET @V_BASECALCIT = @V_IMPOSITEMCOM_VRBASECALCIT;
               END
               ELSE BEGIN
                  SET @V_BASECALCIT = @V_VRTOTAITEM * @V_TAXABASECALC;
               END;

               SET @V_PERDBCALC = 100 - @V_IMPOSITEMCOM_VRPERREDBCIT;

               SET @V_CONTABCALC  = @V_VRTOTAITEM - (@V_VRTOTAITEM * @V_TAXABASECALC);

               IF @V_IMPOSITEMCOM_VRPERMAJBCIT > 0 BEGIN
                  SELECT @V_CDIMPOSTO = MAX(CDIMPOSTO)
                    FROM IMPOSTO
                   WHERE CDIMPOSTRIB = @V_IMPOSITEMCOM_CDIMPOSTO;

                  IF (@V_CDIMPOSTO IS NOT NULL) BEGIN
                     SET @V_BASECALCIT = (@V_BASECALCIT * @V_TAXABCSUBSTR);
                  END
                  ELSE BEGIN
                     UPDATE ITEMPROIMPOS
                     SET VRPERMAJBCIT = 0
                    WHERE CDFILIAL    = @P_FILIAL
                      AND NRLANCTONF  = @P_LANCTONF
                      AND NRSEQITPROD = @V_IMPOSITEMCOM_NRSEQITPROD
                      AND CDIMPOSTO   = @V_IMPOSITEMCOM_CDIMPOSTO;
                  END;
               END;

               /* ICMS-ST para nota fiscal de complento */
               SET @V_CDIMPOSTRIB  = null;
               SET @V_IDVRIMPSTRIB = null;
               SET @V_CDIMPOSTRIB  = null;

               DECLARE C_ICMSST CURSOR FOR
                  SELECT CDIMPOSTO
                    FROM IMPOSTO
                   WHERE CDIMPOSTRIB = @V_IMPOSITEMCOM_CDIMPOSTO;

               OPEN C_ICMSST;
               FETCH NEXT FROM C_ICMSST INTO @V_ICMSST_CDIMPOSTRIB;
               WHILE (@@FETCH_STATUS = 0) BEGIN

                  SET @V_CDIMPOSTRIB = ISNULL(@V_CDIMPOSTRIB,'')+@V_ICMSST_CDIMPOSTRIB+'_';
                  FETCH NEXT FROM C_ICMSST INTO @V_ICMSST_CDIMPOSTRIB;
               END;
               CLOSE C_ICMSST;
               DEALLOCATE C_ICMSST;

               IF @V_CDIMPOSTRIB IS NOT NULL BEGIN

                  SELECT @V_IDVRIMPSTRIB = ISNULL(MAX(IDVRIMPSTRIB), 'N')
                    FROM ITEMPROIMPOS I, IMPOSTO II
                   WHERE (CDFILIAL        = @P_FILIAL)
                     AND (NRLANCTONF      = @P_LANCTONF)
                     AND (NRSEQITPROD     = @V_IMPOSITEMCOM_NRSEQITPROD)
                     AND (CHARINDEX(II.CDIMPOSTO+'_', @V_CDIMPOSTRIB) > 0)
                     AND (I.CDIMPOSTO = II.CDIMPOSTO);

                  IF (@V_IDTRIMPSTII = '1') OR (ISNULL(@V_IDVRIMPSTRIB,'N') = 'N') BEGIN
                     SET @V_VRIMPOSTOST = 0;
                  END
                  ELSE BEGIN
                     SELECT @V_VRIMPOSTOST = ISNULL(MAX(VRIMPOSTOIT),0)
                       FROM ITEMPROIMPOS
                      WHERE (CDFILIAL        = @P_FILIAL)
                        AND (NRLANCTONF      = @P_LANCTONF)
                        AND (NRSEQITPROD     = @V_IMPOSITEMCOM_NRSEQITPROD)
                        AND (CHARINDEX(CDIMPOSTO+'_', @V_CDIMPOSTRIB) > 0)
                        AND (NRITPROIMPOS     = '1');
                  END;
               END;

               /* ICMS-ST para nota fiscal de complemento */

               IF (@V_IMPOSITEMCOM_IDUTVLRQTEIMPO = 'S') BEGIN
                  SELECT @V_VRFATOCONVES = ISNULL(MAX(VRFATOCONVES), 1)
                    FROM CONVPRODUTO
                   WHERE CDPRODUTO = @V_CDPRODUTO;

                  IF (ISNULL(@V_IDVRIMPSTRIB, 'N') = 'N') BEGIN
                     SET @V_BASECALCTO  = (@V_QTITEMPROD * @V_VRFATOCONVES);
                     SET @V_IMPOSTOIT   = ((@V_QTITEMPROD * @V_VRFATOCONVES) * @V_IMPOSITEMCOM_VRALIQITEM) - @V_IMPOSITEMCOM_VRPARDEDIT;
                  END
                  ELSE BEGIN
                     SET @V_BASECALCTO  = (@V_QTITEMPROD * @V_VRFATOCONVES);
                     SET @V_IMPOSTOIT   = ((@V_QTITEMPROD * @V_VRFATOCONVES) * @V_IMPOSITEMCOM_VRALIQITEM) - @V_IMPOSITEMCOM_VRPARDEDIT - @V_VRIMPOSTOST;
                     IF @V_IMPOSTOIT < 0 BEGIN
                        SET @V_IMPOSTOIT = 0;
                     END;
                  END;
               END
               ELSE BEGIN
                  IF (ISNULL(@V_IDVRIMPSTRIB, 'N') = 'N') BEGIN
                     SET @V_BASECALCTO  = @V_BASECALCIT;
                     SET @V_IMPOSTOIT   = (@V_BASECALCIT * @V_TAXAALIQUOTA) - @V_IMPOSITEMCOM_VRPARDEDIT;
                  END
                  ELSE BEGIN
                     SET @V_BASECALCTO  = @V_BASECALCIT;
                     SET @V_IMPOSTOIT   = (@V_BASECALCIT * @V_TAXAALIQUOTA) - @V_IMPOSITEMCOM_VRPARDEDIT - @V_VRIMPOSTOST;
                     IF @V_IMPOSTOIT < 0 BEGIN
                        SET @V_IMPOSTOIT = 0;
                     END;
                  END;
               END;

               SELECT @V_IDPERVISIMPSCRE = ISNULL(MAX(IDPERVISIMPSCRE), 'S')
                 FROM PARAMGERAL;

               IF @V_IDPERVISIMPSCRE = 'S' BEGIN
                  SET @V_VRIMPOSTOVISUIT = @V_IMPOSTOIT;
               END
               ELSE BEGIN
                  IF @V_IMPOSITEMCOM_CDFISCALIT = '1' BEGIN
                     SET @V_VRIMPOSTOVISUIT = @V_IMPOSTOIT;
                  END
                  ELSE BEGIN
                     SET @V_VRIMPOSTOVISUIT = 0;
                  END;
               END;

               IF ((@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV')) AND (@V_ICMS = 'S') BEGIN
                  UPDATE ITEMPROIMPOS
                     SET VRCONTITIMP = @V_BASECALCTO,
                         VRBASECALCIT = @V_BASECALCTO,
                         VRIMPOSTOIT = ROUND(@V_IMPOSTOIT,2,2),
                         VRIMPOSTOVISUIT = ROUND(@V_VRIMPOSTOVISUIT,2,2)
                    WHERE CDFILIAL = @P_FILIAL
                      AND NRLANCTONF = @P_LANCTONF
                      AND NRSEQITPROD = @V_IMPOSITEMCOM_NRSEQITPROD
                      AND CDIMPOSTO = @V_IMPOSITEMCOM_CDIMPOSTO
                      AND NRITPROIMPOS = '1';
               END
               ELSE BEGIN
                  UPDATE ITEMPROIMPOS
                     SET VRCONTITIMP = @V_BASECALCTO,
                         VRBASECALCIT = @V_BASECALCTO,
                         VRIMPOSTOIT = ROUND(@V_IMPOSTOIT,2),
                         VRIMPOSTOVISUIT = ROUND(@V_VRIMPOSTOVISUIT,2)
                    WHERE CDFILIAL = @P_FILIAL
                      AND NRLANCTONF = @P_LANCTONF
                      AND NRSEQITPROD = @V_IMPOSITEMCOM_NRSEQITPROD
                      AND CDIMPOSTO = @V_IMPOSITEMCOM_CDIMPOSTO
                      AND NRITPROIMPOS = '1';
               END;
               IF (@V_IMPOSITEMCOM_VRPERREDBCIT > 0) BEGIN
                  SELECT @V_CHAVE = MAX(CDFILIAL)
                    FROM ITEMPROIMPOS
                   WHERE CDFILIAL     = @P_FILIAL                 AND
                         NRLANCTONF   = @P_LANCTONF               AND
                         NRSEQITPROD  = @V_IMPOSITEMCOM_NRSEQITPROD  AND
                         CDIMPOSTO    = @V_IMPOSITEMCOM_CDIMPOSTO AND
                         NRITPROIMPOS = '2';

                  IF (@V_CHAVE IS NULL) BEGIN
                     INSERT INTO ITEMPROIMPOS(
                        CDFILIAL, NRLANCTONF, NRSEQITPROD, CDIMPOSTO, NRITPROIMPOS, CDFISCALIT,
                        VRALIQITEM, VRPERREDBCIT, VRCONTITIMP, VRBASECALCIT, VRIMPOSTOIT, VRPARDEDIT,
                        CDSITUTRIBIT, CDFISCOPERIT, VRIMPOSTOVISUIT, CDENQLEGALIPI,
                        CDCEST)
                     VALUES(
                        @P_FILIAL, @P_LANCTONF, @V_IMPOSITEMCOM_NRSEQITPROD, @V_IMPOSITEMCOM_CDIMPOSTO, '2', '2',
                        0, @V_PERDBCALC, @V_CONTABCALC, 0, 0, 0,
                        @V_IMPOSITEMCOM_CDSITUTRIBIT, @V_IMPOSITEMCOM_CDFISCOPERIT, 0, @V_IMPOSITEMCOM_CDENQLEGALIPI,
                        @V_IMPOSITEMCOM_CDCEST);
                  END
                  ELSE BEGIN
                     UPDATE ITEMPROIMPOS
                        SET VRCONTITIMP = @V_CONTABCALC,
                            VRBASECALCIT = 0,
                            VRIMPOSTOIT = 0,
                            VRPERREDBCIT = @V_PERDBCALC,
                            VRIMPOSTOVISUIT = 0
                    WHERE CDFILIAL = @P_FILIAL
                      AND NRLANCTONF = @P_LANCTONF
                      AND NRSEQITPROD = @V_IMPOSITEMCOM_NRSEQITPROD
                      AND CDIMPOSTO = @V_IMPOSITEMCOM_CDIMPOSTO
                      AND NRITPROIMPOS = '2';
                  END;
               END;

            END;
         END;
         FETCH NEXT FROM C_IMPOSITEMCOM INTO @V_IMPOSITEMCOM_NRSEQITPROD,   @V_IMPOSITEMCOM_CDIMPOSTO,    @V_IMPOSITEMCOM_NRITPROIMPOS,   @V_IMPOSITEMCOM_VRCONTITIMP,
                                             @V_IMPOSITEMCOM_VRPERREDBCIT,  @V_IMPOSITEMCOM_VRBASECALCIT, @V_IMPOSITEMCOM_VRALIQITEM,     @V_IMPOSITEMCOM_VRPARDEDIT,
                                             @V_IMPOSITEMCOM_VRIMPOSTOIT,   @V_IMPOSITEMCOM_CDFISCALIT,   @V_IMPOSITEMCOM_IDUTVLRQTEIMPO,
                                             @V_IMPOSITEMCOM_CDSITUTRIBIT,  @V_IMPOSITEMCOM_CDFISCOPERIT, @V_IMPOSITEMCOM_VRPERMAJBCIT, @V_IMPOSITEMCOM_CDARVPROD,
                                             @V_IMPOSITEMCOM_CDENQLEGALIPI, @V_IMPOSITEMCOM_CDCEST;
      END;
      CLOSE C_IMPOSITEMCOM;
      DEALLOCATE C_IMPOSITEMCOM;

      --TOTALIZAO DOS IMPOSTOS
      DECLARE C_IMPOSNFCOMP CURSOR FOR (SELECT IT.CDFILIAL, IT.NRLANCTONF, IT.CDIMPOSTO
                                          FROM IMPOSNFTOT IT, IMPOSTO I
                                         WHERE IT.CDIMPOSTO  = I.CDIMPOSTO AND
                                               I.IDPRODNOTA  <> 'C'        AND
                                               IT.CDFILIAL   = @P_FILIAL    AND
                                               IT.NRLANCTONF = @P_LANCTONF)
      OPEN C_IMPOSNFCOMP;
      FETCH NEXT FROM C_IMPOSNFCOMP INTO @V_IMPOSNFCOMP_CDFILIAL,
                                         @V_IMPOSNFCOMP_NRLANCTONF,
                                         @V_IMPOSNFCOMP_CDIMPOSTO;
      WHILE (@@FETCH_STATUS = 0) BEGIN

          DELETE IMPOSNFTOT
          WHERE (CDFILIAL   = @P_FILIAL) AND
                (NRLANCTONF = @P_LANCTONF) AND
                (CDIMPOSTO = @V_IMPOSNFCOMP_CDIMPOSTO);

          FETCH NEXT FROM C_IMPOSNFCOMP INTO @V_IMPOSNFCOMP_CDFILIAL,
                                             @V_IMPOSNFCOMP_NRLANCTONF,
                                             @V_IMPOSNFCOMP_CDIMPOSTO;

      END;
      CLOSE C_IMPOSNFCOMP;
      DEALLOCATE C_IMPOSNFCOMP;

      DELETE FROM IMPOSTONF
      WHERE (CDFILIAL = @P_FILIAL) AND
            (NRLANCTONF = @P_LANCTONF);

      DECLARE C_IMPOSNFTOT CURSOR FOR
      SELECT CDIMPOSTO, ISNULL(SUM(VRIMPOSTOIT),0) AS VRIMPOSTOIT, ISNULL(SUM(VRBASECALCIT),0) AS VRBASECALCIT
      FROM ITEMPROIMPOS
      WHERE (CDFILIAL   = @P_FILIAL)   AND
            (NRLANCTONF = @P_LANCTONF)
      GROUP BY CDIMPOSTO;
      OPEN C_IMPOSNFTOT;
      FETCH NEXT FROM C_IMPOSNFTOT INTO @V_IMPOSNFTOT_CDIMPOSTO,
                                        @V_IMPOSNFTOT_VRIMPOSTOIT,
                                        @V_IMPOSNFTOT_VRBASECALCIT;
      WHILE (@@FETCH_STATUS = 0) BEGIN
         SET @V_ICMS = NULL;
         DECLARE C_ICMS CURSOR FOR
            SELECT CDIMPOSTO
              FROM IMPOSTONFE N, IMPOSTO I
             WHERE N.CDIMPOSTONFE = I.CDIMPOSTONFE
               AND N.CDIMPOSTONFE = '00'
               AND I.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
         OPEN C_ICMS;
         FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
         WHILE (@@FETCH_STATUS = 0) BEGIN
            SET @V_ICMS = 'S';
            FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
         END;
         CLOSE C_ICMS;
         DEALLOCATE C_ICMS;

         IF ((@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV')) AND (@V_ICMS = 'S') BEGIN
            INSERT INTO IMPOSNFTOT(CDFILIAL, NRLANCTONF, CDIMPOSTO, VRTOTIMPONF, VRTOTBCALCNF)
            VALUES (@P_FILIAL, @P_LANCTONF, @V_IMPOSNFTOT_CDIMPOSTO, ROUND(@V_IMPOSNFTOT_VRIMPOSTOIT,@V_NRDECITOTANF,2), ROUND(@V_IMPOSNFTOT_VRBASECALCIT,@V_NRDECITOTANF,2));
            FETCH NEXT FROM C_IMPOSNFTOT INTO @V_IMPOSNFTOT_CDIMPOSTO,
                                              @V_IMPOSNFTOT_VRIMPOSTOIT,
                                              @V_IMPOSNFTOT_VRBASECALCIT;
         END
         ELSE BEGIN
            INSERT INTO IMPOSNFTOT(CDFILIAL, NRLANCTONF, CDIMPOSTO, VRTOTIMPONF, VRTOTBCALCNF)
            VALUES (@P_FILIAL, @P_LANCTONF, @V_IMPOSNFTOT_CDIMPOSTO, ROUND(@V_IMPOSNFTOT_VRIMPOSTOIT,@V_NRDECITOTANF), ROUND(@V_IMPOSNFTOT_VRBASECALCIT,@V_NRDECITOTANF));
            FETCH NEXT FROM C_IMPOSNFTOT INTO @V_IMPOSNFTOT_CDIMPOSTO,
                                              @V_IMPOSNFTOT_VRIMPOSTOIT,
                                              @V_IMPOSNFTOT_VRBASECALCIT;
         END;
      END;
      CLOSE C_IMPOSNFTOT;
      DEALLOCATE C_IMPOSNFTOT;

      UPDATE ITEMPROIMPOS
         SET IDMODBCITNFE = '3'
       WHERE CDFILIAL = @P_FILIAL
         AND NRLANCTONF = @P_LANCTONF;


   END
   ELSE IF (@P_TIPOOPER = '09') OR (@P_TIPOOPER = '12') BEGIN
      IF (@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV') BEGIN
         UPDATE ITEMPRODUTO
         SET VRBRUTITEM   = ROUND((VRTOTAITEM - VRDESCITEM),2,2),
             VRCONTITEM   = ROUND((VRTOTAITEM - VRDESCITEM),2,2)
         WHERE CDFILIAL   = @P_FILIAL   AND
               NRLANCTONF = @P_LANCTONF;
      END
      ELSE BEGIN
         UPDATE ITEMPRODUTO
         SET VRBRUTITEM   = ROUND((VRTOTAITEM - VRDESCITEM),2),
             VRCONTITEM   = ROUND((VRTOTAITEM - VRDESCITEM),2)
         WHERE CDFILIAL   = @P_FILIAL   AND
               NRLANCTONF = @P_LANCTONF;
      END;

      DECLARE C_ITPROD CURSOR FOR
      SELECT I.CDPRODUTO, CDCFOPINFUSU, CDSUFXINFUSU, CDCSTINFUSU, NRSEQITPROD, P.CDARVPROD, IDORIGEMPROD
      FROM ITEMPRODUTO I, PRODUTO P
      WHERE CDFILIAL   = @P_FILIAL AND
            NRLANCTONF = @P_LANCTONF AND
            I.CDPRODUTO = P.CDPRODUTO;
      OPEN C_ITPROD;
      FETCH NEXT FROM C_ITPROD INTO @V_ITPROD_CDPRODUTO, @V_ITPROD_CDCFOPINFUSU, @V_ITPROD_CDSUFXINFUSU, @V_ITPROD_CDCSTINFUSU, @V_ITPROD_NRSEQIT, @V_ITPROD_CDARVPROD, @V_ITPROD_IDORIGEMPROD;
      WHILE (@@FETCH_STATUS = 0) BEGIN

         EXEC CONSULTA_CST 'S', @P_EMPRESA, @V_ITPROD_CDARVPROD, @P_INSCESTA, @P_TIPOOPER, @P_FILIAL, @P_LANCTONF, @V_CDGRUPOFISC, @V_IDINTEREST, @V_IDINTERNA, NULL, @V_ITPROD_IDORIGEMPROD;

         DECLARE C_CSTTEMP CURSOR FOR
         SELECT DSMENSCSTTMP
         FROM CSTTEMP
         WHERE (NRCSTTEMP = @V_CSTTEMP) AND
               (NOT (DSMENSCSTTMP IS NULL)) AND
               (NOT EXISTS (SELECT DSDADOADIC
                              FROM DADOSADIC
                             WHERE (CDFILIAL = @P_FILIAL)     AND
                                   (NRLANCTONF = @P_LANCTONF) AND
                                   (DSDADOADIC LIKE CSTTEMP.DSMENSCSTTMP + '%')));
         OPEN C_CSTTEMP;
         FETCH NEXT FROM C_CSTTEMP INTO @V_CSTTMP_DSMENSCSTTMP;
         WHILE (@@FETCH_STATUS = 0) BEGIN
            IF NOT (@V_CSTTMP_DSMENSCSTTMP IS NULL) BEGIN
               INSERT INTO DADOSADIC(CDFILIAL, NRLANCTONF, NRDADOADIC, DSDADOADIC)
               VALUES(@P_FILIAL, @P_LANCTONF, @V_DADOADIC, @V_CSTTMP_DSMENSCSTTMP);
               SET @V_DADOADIC = RIGHT(REPLICATE('0',3) + RTRIM(CONVERT(VARCHAR, CONVERT(NUMERIC, @V_DADOADIC) + 1)),3);
            END;
			FETCH NEXT FROM C_CSTTEMP INTO @V_CSTTMP_DSMENSCSTTMP;
         END;
         CLOSE C_CSTTEMP;
         DEALLOCATE C_CSTTEMP;

         EXEC CONSULTA_CFOP 'S', @P_EMPRESA, @V_ITPROD_CDARVPROD, @P_INSCESTA, @P_TIPOOPER, @V_PAISORIG,
                            @V_ESTAORIG, @V_PAISCFOP, @V_ESTACFOP, @P_FILIAL, @P_LANCTONF, @V_CDGRUPOFISC,@P_INIVALID, @V_ITPROD_IDORIGEMPROD;

         DECLARE C_CFOPTEMP CURSOR FOR
         SELECT DSMENSCFOTMP
         FROM CFOPTEMP
         WHERE (NRCFOPTEMP = @V_CFOPTEMP) AND
               (NOT (DSMENSCFOTMP IS NULL)) AND
               (NOT EXISTS (SELECT DSDADOADIC
                              FROM DADOSADIC
                             WHERE (CDFILIAL = @P_FILIAL)     AND
                                   (NRLANCTONF = @P_LANCTONF) AND
                                   (DSDADOADIC LIKE CFOPTEMP.DSMENSCFOTMP + '%')));
         OPEN C_CFOPTEMP;
         FETCH NEXT FROM C_CFOPTEMP INTO @V_CFOPTMP_DSMENSCFOTMP;
         WHILE (@@FETCH_STATUS = 0) BEGIN
            IF NOT (@V_CFOPTMP_DSMENSCFOTMP IS NULL) BEGIN
               INSERT INTO DADOSADIC(CDFILIAL, NRLANCTONF, NRDADOADIC, DSDADOADIC)
               VALUES(@P_FILIAL, @P_LANCTONF, @V_DADOADIC, @V_CFOPTMP_DSMENSCFOTMP);
               SET @V_DADOADIC = RIGHT(REPLICATE('0',3) + RTRIM(CONVERT(VARCHAR, CONVERT(NUMERIC, @V_DADOADIC) + 1)),3);
            END;
			FETCH NEXT FROM C_CFOPTEMP INTO @V_CFOPTMP_DSMENSCFOTMP;
         END;
         CLOSE C_CFOPTEMP;
         DEALLOCATE C_CFOPTEMP;

         IF @V_ITPROD_CDCFOPINFUSU IS NULL BEGIN
            UPDATE NOTAFISCAL
            SET DSCDFISOPENF = (SELECT MAX(DSCFOPTMP)
                                 FROM CFOPTEMP
                                 WHERE NRCFOPTEMP = @V_CFOPTEMP)
            WHERE CDFILIAL   = @P_FILIAL AND
                  NRLANCTONF = @P_LANCTONF AND
                  DSCDFISOPENF IS NULL;

            SELECT @V_FISOPEITEM = MAX(CDFISOPETMP), @V_SUFXCFOPPR = MAX(CDSUFCFOPTMP), @V_DSCDFISOPEIT = MAX(DSCFOPTMP)
            FROM CFOPTEMP
            WHERE NRCFOPTEMP = @V_CFOPTEMP;

            SELECT @V_SITUTRIBPR = MAX(CDSITTRIBTMP)
            FROM CSTTEMP
            WHERE NRCSTTEMP = @V_CSTTEMP;
         END
         ELSE BEGIN
            SET @V_FISOPEITEM = @V_ITPROD_CDCFOPINFUSU;
            SET @V_SUFXCFOPPR = @V_ITPROD_CDSUFXINFUSU;
            SET @V_SITUTRIBPR = @V_ITPROD_CDCSTINFUSU;
         END;

         IF @V_IDDOCREPLIC IS NOT NULL BEGIN
            IF LEN(@V_SITUTRIBPR) = 3 BEGIN
               SET @V_SITUTRIBPR = SUBSTRING(@V_SITUTRIBPR,1,1) + '90';
            END
            ELSE BEGIN
               SET @V_SITUTRIBPR = '90';
            END;
         END;  --lucas

         EXEC CONSULTA_CSOSN 'S', @P_EMPRESA, @V_ITPROD_CDARVPROD, @P_INSCESTA, @P_TIPOOPER,@P_FILIAL, @P_LANCTONF, @V_CDGRUPOFISC, @V_IDINTEREST, @P_CDFISCOPERSN = @V_CDFISCOPERSN OUTPUT;

         UPDATE ITEMPRODUTO
         SET CDFISOPEITEM = @V_FISOPEITEM,
             CDSUFXCFOPPR = @V_SUFXCFOPPR,
             CDSITUTRIBPR = @V_SITUTRIBPR,
             DSCDFISOPEIT = @V_DSCDFISOPEIT,
             CDFISCOPERSN = @V_CDFISCOPERSN
         WHERE CDFILIAL    = @P_FILIAL AND
               NRLANCTONF  = @P_LANCTONF AND
               NRSEQITPROD = @V_ITPROD_NRSEQIT;

         DELETE FROM CFOPTEMP
         WHERE NRCFOPTEMP = @V_CFOPTEMP;

         DELETE FROM CSTTEMP
         WHERE NRCSTTEMP = @V_CSTTEMP;

         /*Consulta de nfe*/
         SET @V_CDSITTRIBTMP    = NULL;
         SET @V_IDMODBCNFE      = NULL;
         SET @V_IDMODBCSTNFE    = NULL;
         SET @V_CDTPCRPICOSTNFE = NULL;
         SET @V_CDNATUBCPCSTNFE = NULL;

         DECLARE C_ITPROI CURSOR FOR SELECT II.CDIMPOSTO, II.NRITPROIMPOS
                                       FROM ITEMPROIMPOS II, IMPOSTO I
                                      WHERE II.CDFILIAL   = @P_FILIAL
                                        AND II.NRLANCTONF = @P_LANCTONF
                                        AND II.NRSEQITPROD = @V_ITPROD_NRSEQIT
                                        AND II.CDIMPOSTO = I.CDIMPOSTO
                                        AND I.IDPRODNOTA = 'P'
                                     ORDER BY II.CDIMPOSTO;
         OPEN C_ITPROI;
         FETCH NEXT FROM C_ITPROI INTO @V_ITPROI_CDIMPOSTO, @V_ITPROI_NRITPROIMPOS;
         WHILE (@@FETCH_STATUS = 0) BEGIN

             SET @V_IMPOICMS = NULL;
             SET @V_CDGRUPOFISCAUX = NULL;

             SELECT @V_CDGRUPOFISCAUX = MAX(G.CDGRUPOFISC)
               FROM GRUPOFISCIMPFIL G,
                    (SELECT CDFILIEMIT AS CDFILIAL
                       FROM NOTAFISCAL
                      WHERE CDFILIAL = @P_FILIAL
                        AND NRLANCTONF = @P_LANCTONF) F
              WHERE G.CDFILIAL = F.CDFILIAL
                AND NOT G.CDGRUPOFISC IS NULL
                AND G.CDIMPOSTO = @V_ITPROI_CDIMPOSTO;

             IF @V_IDORIGDESTNF = 'C' BEGIN
                SELECT @V_CDGRUPOFISCAUX = ISNULL(MAX(G.CDGRUPOFISC), @V_CDGRUPOFISCAUX)
                  FROM GRFISIMPIECLIE G,
                       (SELECT CDCLIENTE
                          FROM NOTAFISCAL
                         WHERE CDFILIAL = @P_FILIAL
                           AND NRLANCTONF = @P_LANCTONF) N
                 WHERE G.CDCLIENTE = N.CDCLIENTE
                   AND G.CDEMPRESA = @P_EMPRESA
                   AND G.CDINSCESTA = @P_INSCESTA
                   AND NOT G.CDGRUPOFISC IS NULL
                   AND G.CDIMPOSTO = @V_ITPROI_CDIMPOSTO;
             END
             ELSE BEGIN
                SELECT @V_CDGRUPOFISCAUX = ISNULL(MAX(G.CDGRUPOFISC), @V_CDGRUPOFISCAUX)
                  FROM GRFISIMPIEFORN G,
                      (SELECT CDFORNECED
                         FROM NOTAFISCAL
                        WHERE CDFILIAL = @P_FILIAL
                          AND NRLANCTONF = @P_LANCTONF) N
                 WHERE G.CDFORNECED = N.CDFORNECED
                   AND G.CDEMPRESA = @P_EMPRESA
                   AND G.CDINSCESTA = @P_INSCESTA
                   AND NOT G.CDGRUPOFISC IS NULL
                   AND G.CDIMPOSTO = @V_ITPROI_CDIMPOSTO;
             END;

             IF @V_CDGRUPOFISCAUX IS NULL BEGIN
                EXEC CONSULTA_CST_NFE 'S', @P_EMPRESA, @V_ITPROD_CDARVPROD, @P_INSCESTA, @P_TIPOOPER, @V_CDGRUPOFISC, @V_ITPROI_CDIMPOSTO, @V_IDINTEREST, @V_IDINTERNA, @P_FILIAL, @P_LANCTONF, '', @V_ITPROD_IDORIGEMPROD, @P_CDSITTRIBTMP = @V_CDSITTRIBTMP OUTPUT, @P_IDMODBCNFE = @V_IDMODBCNFE OUTPUT, @P_IDMODBCSTNFE = @V_IDMODBCSTNFE OUTPUT, @P_CDTPCRPICOSTNFE = @V_CDTPCRPICOSTNFE OUTPUT, @P_CDNATUBCPCSTNFE = @V_CDNATUBCPCSTNFE OUTPUT, @P_IDMOTIDESSTNFE = @V_IDMOTIDESSTNFE OUTPUT;
             END
             ELSE BEGIN
                EXEC CONSULTA_CST_NFE 'S', @P_EMPRESA, @V_ITPROD_CDARVPROD, @P_INSCESTA, @P_TIPOOPER, @V_CDGRUPOFISCAUX, @V_ITPROI_CDIMPOSTO, @V_IDINTEREST, @V_IDINTERNA, @P_FILIAL, @P_LANCTONF, '', @V_ITPROD_IDORIGEMPROD, @P_CDSITTRIBTMP = @V_CDSITTRIBTMP OUTPUT, @P_IDMODBCNFE = @V_IDMODBCNFE OUTPUT, @P_IDMODBCSTNFE = @V_IDMODBCSTNFE OUTPUT, @P_CDTPCRPICOSTNFE = @V_CDTPCRPICOSTNFE OUTPUT, @P_CDNATUBCPCSTNFE = @V_CDNATUBCPCSTNFE OUTPUT, @P_IDMOTIDESSTNFE = @V_IDMOTIDESSTNFE OUTPUT;
             END;

             UPDATE ITEMPROIMPOS
               SET CDSITUTRIBITNFE = @V_CDSITTRIBTMP,
                   IDMODBCITNFE    = @V_IDMODBCNFE,
                   IDMODBCSTITNFE  = @V_IDMODBCSTNFE,
                   CDTPCREDPICOITE = @V_CDTPCRPICOSTNFE,
                   CDNATUBCALPCIT  = @V_CDNATUBCPCSTNFE
               WHERE (CDFILIAL     = @P_FILIAL)                   AND
                     (NRLANCTONF   = @P_LANCTONF)                 AND
                     (NRSEQITPROD  = @V_ITPROD_NRSEQIT) AND
                     (CDIMPOSTO    = @V_ITPROI_CDIMPOSTO)   AND
                     (NRITPROIMPOS = @V_ITPROI_NRITPROIMPOS);
             FETCH NEXT FROM C_ITPROI INTO @V_ITPROI_CDIMPOSTO, @V_ITPROI_NRITPROIMPOS;
         END;
         CLOSE C_ITPROI;
         DEALLOCATE C_ITPROI;

         FETCH NEXT FROM C_ITPROD INTO @V_ITPROD_CDPRODUTO, @V_ITPROD_CDCFOPINFUSU, @V_ITPROD_CDSUFXINFUSU, @V_ITPROD_CDCSTINFUSU, @V_ITPROD_NRSEQIT, @V_ITPROD_CDARVPROD, @V_ITPROD_IDORIGEMPROD;
      END;
      CLOSE C_ITPROD;
      DEALLOCATE C_ITPROD;
   END;

   DELETE FROM REGRANOTA
   WHERE CDFILIAL = @P_FILIAL
     AND NRLANCTONF = @P_LANCTONF;

   DECLARE C_IMPOSNOTA CURSOR FOR
      SELECT DISTINCT CDREGRAIT
        FROM ITEMPROIMPOS
       WHERE CDFILIAL = @P_FILIAL
         AND NRLANCTONF = @P_LANCTONF
         AND CDREGRAIT IS NOT NULL
      ORDER BY CDREGRAIT;
   OPEN C_IMPOSNOTA;
   FETCH NEXT FROM C_IMPOSNOTA INTO @V_IMPOSNOTA_CDREGRAIT;

   WHILE (@@FETCH_STATUS = 0) BEGIN

      DECLARE C_REGRAMSG CURSOR FOR
         SELECT CDREGRAFISC, DSMENSREGRAFISC
           FROM TEKNISA.MSG_REGRAFISCAL(@V_IMPOSNOTA_CDREGRAIT, @P_EMPRESA, 'S', @P_TIPOOPER, @P_INSCESTA) M
          WHERE NOT EXISTS(SELECT DSDADOADIC
                             FROM DADOSADIC
                            WHERE (CDFILIAL   = @P_FILIAL)
                              AND (NRLANCTONF = @P_LANCTONF)
                              AND (DSDADOADIC = M.DSMENSREGRAFISC)) ;
      OPEN C_REGRAMSG;
      FETCH NEXT FROM C_REGRAMSG INTO @V_REGRAMSG_CDREGRAFISC, @V_REGRAMSG_DSMENSREGRAFISC;

      WHILE (@@FETCH_STATUS = 0) BEGIN

         INSERT INTO DADOSADIC(CDFILIAL,  NRLANCTONF,  NRDADOADIC,  DSDADOADIC)
                        VALUES(@P_FILIAL, @P_LANCTONF, @V_DADOADIC, @V_REGRAMSG_DSMENSREGRAFISC);

         SET @V_DADOADIC = RIGHT(REPLICATE('0',3) + RTRIM(CONVERT(VARCHAR, CONVERT(NUMERIC, @V_DADOADIC) + 1)),3);

         FETCH NEXT FROM C_REGRAMSG INTO @V_REGRAMSG_CDREGRAFISC, @V_REGRAMSG_DSMENSREGRAFISC;
      END;                       
      CLOSE C_REGRAMSG;
      DEALLOCATE C_REGRAMSG;
      INSERT INTO REGRANOTA(CDFILIAL, NRLANCTONF, CDREGRAFISC)
                     VALUES(@P_FILIAL, @P_LANCTONF, @V_IMPOSNOTA_CDREGRAIT);

      FETCH NEXT FROM C_IMPOSNOTA INTO @V_IMPOSNOTA_CDREGRAIT;
   END;
   CLOSE C_IMPOSNOTA;
   DEALLOCATE C_IMPOSNOTA;

   SET @V_DIFERENCA = 0;
 /* RATEIO DOS ENCARGOS PARA OS PRODUTOS DA NOTA. ESTE RATEIO  NECESSRIO PARA A NOTA FISCAL ELETRNICA */
   DECLARE C_ITEMENCARGO CURSOR FOR (SELECT ENCARGO.CDENCARGONFE, SUM(ITEMENCARGO.VRITEMENCA) AS VRITEMENCA
                                       FROM ITEMENCARGO, ENCARGO
                                      WHERE ITEMENCARGO.CDENCARGO = ENCARGO.CDENCARGO
                                        AND ENCARGO.CDENCARGONFE IN ('01', '02', '03', '04', '05')
                                        AND ISNULL(ITEMENCARGO.VRITEMENCA, 0) >= 0
                                        AND CDFILIAL = @P_FILIAL
                                        AND NRLANCTONF = @P_LANCTONF
                                      GROUP BY ENCARGO.CDENCARGONFE);
   OPEN C_ITEMENCARGO;
   FETCH NEXT FROM C_ITEMENCARGO INTO @V_ITEMENCARGO_CDENCARGONFE, @V_ITEMENCARGO_VRITEMENCA;
   WHILE (@@FETCH_STATUS = 0) BEGIN
      /* ENCARGO FRETE */
      IF (@V_ITEMENCARGO_CDENCARGONFE = '01') BEGIN
         IF (@V_ITEMENCARGO_VRITEMENCA > 0) BEGIN
            DECLARE C_ITEMPRODUTO CURSOR FOR (SELECT NRSEQITPROD, VRTOTAITEM
                                                FROM ITEMPRODUTO
                                                WHERE CDFILIAL = @P_FILIAL
                                                  AND NRLANCTONF = @P_LANCTONF);
            OPEN C_ITEMPRODUTO;
            FETCH NEXT FROM C_ITEMPRODUTO INTO @V_ITEMPRODUTO_NRSEQITPROD, @V_ITEMPRODUTO_VRTOTAITEM;
            WHILE (@@FETCH_STATUS = 0) BEGIN

               SELECT @V_VRTOTAITEM = ITEMPRODUTO.VRTOTAITEM,
                      @V_SOMATOTAITEM = TOTAL.SOMATOTAITEM,
                      @V_PERCENTITEM = CASE TOTAL.SOMATOTAITEM WHEN 0 THEN 0 ELSE ((100 * ITEMPRODUTO.VRTOTAITEM) / TOTAL.SOMATOTAITEM) END
                 FROM ITEMPRODUTO, (SELECT CDFILIAL, NRLANCTONF, SUM(VRTOTAITEM) SOMATOTAITEM
                                      FROM ITEMPRODUTO
                                     WHERE CDFILIAL = @P_FILIAL
                                       AND NRLANCTONF = @P_LANCTONF
                                     GROUP BY CDFILIAL, NRLANCTONF) TOTAL
                WHERE ITEMPRODUTO.CDFILIAL = TOTAL.CDFILIAL
                  AND ITEMPRODUTO.NRLANCTONF = TOTAL.NRLANCTONF
                  AND ITEMPRODUTO.NRSEQITPROD = @V_ITEMPRODUTO_NRSEQITPROD;

               IF (@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV') BEGIN
                  UPDATE ITEMPRODUTO
                     SET VRFRETEITEM = ROUND(@V_ITEMENCARGO_VRITEMENCA * (@V_PERCENTITEM / 100), 2, 2)
                   WHERE CDFILIAL  = @P_FILIAL
                     AND NRLANCTONF = @P_LANCTONF
                     AND NRSEQITPROD = @V_ITEMPRODUTO_NRSEQITPROD;
               END ELSE BEGIN
                  UPDATE ITEMPRODUTO
                     SET VRFRETEITEM = ROUND(@V_ITEMENCARGO_VRITEMENCA * (@V_PERCENTITEM / 100), 2)
                   WHERE CDFILIAL  = @P_FILIAL
                     AND NRLANCTONF = @P_LANCTONF
                     AND NRSEQITPROD = @V_ITEMPRODUTO_NRSEQITPROD;
               END;
               FETCH NEXT FROM C_ITEMPRODUTO INTO @V_ITEMPRODUTO_NRSEQITPROD, @V_ITEMPRODUTO_VRTOTAITEM;
            END;
            CLOSE C_ITEMPRODUTO;
            DEALLOCATE C_ITEMPRODUTO;
            /*AJUSTE DE VALORES*/
            SELECT @V_VRFRETEITEM = SUM(VRFRETEITEM)
              FROM ITEMPRODUTO
             WHERE CDFILIAL = @P_FILIAL
               AND NRLANCTONF = @P_LANCTONF;

            SET @V_DIFERENCA = @V_ITEMENCARGO_VRITEMENCA - @V_VRFRETEITEM;

            IF @V_DIFERENCA <> 0 BEGIN
               UPDATE ITEMPRODUTO
                  SET VRFRETEITEM = VRFRETEITEM + @V_DIFERENCA
                WHERE CDFILIAL = @P_FILIAL
                  AND NRLANCTONF = @P_LANCTONF
                  AND NRSEQITPROD = (SELECT MAX(NRSEQITPROD)
                                      FROM ITEMPRODUTO
                                      WHERE CDFILIAL = @P_FILIAL
                                        AND NRLANCTONF = @P_LANCTONF
                                        AND VRTOTAITEM = (SELECT MAX(VRTOTAITEM)
                                                           FROM ITEMPRODUTO
                                                          WHERE CDFILIAL = @P_FILIAL
                                                            AND NRLANCTONF = @P_LANCTONF));

            END;
         END ELSE BEGIN
            UPDATE ITEMPRODUTO
               SET VRFRETEITEM = 0
             WHERE CDFILIAL  = @P_FILIAL
               AND NRLANCTONF = @P_LANCTONF;
         END;
      END;

      /* ENCARGO SEGURO */
      IF (@V_ITEMENCARGO_CDENCARGONFE = '02') BEGIN
         IF (@V_ITEMENCARGO_VRITEMENCA > 0) BEGIN
            DECLARE C_ITEMPRODUTO CURSOR FOR (SELECT NRSEQITPROD, VRTOTAITEM
                                                FROM ITEMPRODUTO
                                               WHERE CDFILIAL = @P_FILIAL
                                                 AND NRLANCTONF = @P_LANCTONF);

            OPEN C_ITEMPRODUTO;
            FETCH NEXT FROM C_ITEMPRODUTO INTO @V_ITEMPRODUTO_NRSEQITPROD, @V_ITEMPRODUTO_VRTOTAITEM;
            WHILE (@@FETCH_STATUS = 0) BEGIN

               SELECT @V_VRTOTAITEM = ITEMPRODUTO.VRTOTAITEM,
                      @V_SOMATOTAITEM = TOTAL.SOMATOTAITEM,
                      @V_PERCENTITEM = CASE TOTAL.SOMATOTAITEM WHEN 0 THEN 0 ELSE ((100 * ITEMPRODUTO.VRTOTAITEM) / TOTAL.SOMATOTAITEM) END
                 FROM ITEMPRODUTO, (SELECT CDFILIAL, NRLANCTONF, SUM(VRTOTAITEM) SOMATOTAITEM
                                      FROM ITEMPRODUTO
                                     WHERE CDFILIAL = @P_FILIAL
                                       AND NRLANCTONF = @P_LANCTONF
                                     GROUP BY CDFILIAL, NRLANCTONF) TOTAL
                WHERE ITEMPRODUTO.CDFILIAL = TOTAL.CDFILIAL
                  AND ITEMPRODUTO.NRLANCTONF = TOTAL.NRLANCTONF
                  AND ITEMPRODUTO.NRSEQITPROD = @V_ITEMPRODUTO_NRSEQITPROD;

               IF (@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV') BEGIN
                  UPDATE ITEMPRODUTO
                     SET VRSEGURITEM = ROUND(@V_ITEMENCARGO_VRITEMENCA * (@V_PERCENTITEM / 100), 2, 2)
                   WHERE CDFILIAL  = @P_FILIAL
                     AND NRLANCTONF = @P_LANCTONF
                     AND NRSEQITPROD = @V_ITEMPRODUTO_NRSEQITPROD;
               END ELSE BEGIN
                  UPDATE ITEMPRODUTO
                     SET VRSEGURITEM = ROUND(@V_ITEMENCARGO_VRITEMENCA * (@V_PERCENTITEM / 100), 2)
                   WHERE CDFILIAL  = @P_FILIAL
                     AND NRLANCTONF = @P_LANCTONF
                     AND NRSEQITPROD = @V_ITEMPRODUTO_NRSEQITPROD;
               END;
               FETCH NEXT FROM C_ITEMPRODUTO INTO @V_ITEMPRODUTO_NRSEQITPROD, @V_ITEMPRODUTO_VRTOTAITEM;
            END;
            CLOSE C_ITEMPRODUTO;
            DEALLOCATE C_ITEMPRODUTO;
            /*AJUSTE DE VALORES*/
            SELECT @V_VRSEGURITEM = SUM(VRSEGURITEM)
              FROM ITEMPRODUTO
             WHERE CDFILIAL = @P_FILIAL
               AND NRLANCTONF = @P_LANCTONF;

            SET @V_DIFERENCA = @V_ITEMENCARGO_VRITEMENCA - @V_VRSEGURITEM;

            IF @V_DIFERENCA <> 0 BEGIN
               UPDATE ITEMPRODUTO
                  SET VRSEGURITEM = VRSEGURITEM + @V_DIFERENCA
                WHERE CDFILIAL = @P_FILIAL
                  AND NRLANCTONF = @P_LANCTONF
                  AND NRSEQITPROD = (SELECT MAX(NRSEQITPROD)
                                      FROM ITEMPRODUTO
                                      WHERE CDFILIAL = @P_FILIAL
                                        AND NRLANCTONF = @P_LANCTONF
                                        AND VRTOTAITEM = (SELECT MAX(VRTOTAITEM)
                                                           FROM ITEMPRODUTO
                                                          WHERE CDFILIAL = @P_FILIAL
                                                            AND NRLANCTONF = @P_LANCTONF));

            END;
         END ELSE BEGIN
            UPDATE ITEMPRODUTO
               SET VRSEGURITEM = 0
             WHERE CDFILIAL  = @P_FILIAL
               AND NRLANCTONF = @P_LANCTONF;
         END;
      END;

      /* ENCARGO DESCONTO */
      IF (@V_ITEMENCARGO_CDENCARGONFE = '03') BEGIN
         IF (@V_ITEMENCARGO_VRITEMENCA > 0) BEGIN
            DECLARE C_ITEMPRODUTO CURSOR FOR (SELECT NRSEQITPROD, VRTOTAITEM
                                                FROM ITEMPRODUTO
                                               WHERE CDFILIAL = @P_FILIAL
                                                 AND NRLANCTONF = @P_LANCTONF);
            OPEN C_ITEMPRODUTO;
            FETCH NEXT FROM C_ITEMPRODUTO INTO @V_ITEMPRODUTO_NRSEQITPROD, @V_ITEMPRODUTO_VRTOTAITEM;
            WHILE (@@FETCH_STATUS = 0) BEGIN

               SELECT @V_VRTOTAITEM = ITEMPRODUTO.VRTOTAITEM,
                      @V_SOMATOTAITEM = TOTAL.SOMATOTAITEM,
                      @V_PERCENTITEM = CASE TOTAL.SOMATOTAITEM WHEN 0 THEN 0 ELSE ((100 * ITEMPRODUTO.VRTOTAITEM) / TOTAL.SOMATOTAITEM) END
                 FROM ITEMPRODUTO, (SELECT CDFILIAL, NRLANCTONF, SUM(VRTOTAITEM) SOMATOTAITEM
                                      FROM ITEMPRODUTO
                                     WHERE CDFILIAL = @P_FILIAL
                                       AND NRLANCTONF = @P_LANCTONF
                                     GROUP BY CDFILIAL, NRLANCTONF) TOTAL
                WHERE ITEMPRODUTO.CDFILIAL = TOTAL.CDFILIAL
                  AND ITEMPRODUTO.NRLANCTONF = TOTAL.NRLANCTONF
                  AND ITEMPRODUTO.NRSEQITPROD = @V_ITEMPRODUTO_NRSEQITPROD;

               IF (@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV') BEGIN
                  UPDATE ITEMPRODUTO
                     SET VRENCARGODESC = ROUND(VRDESCITEM + (@V_ITEMENCARGO_VRITEMENCA * (@V_PERCENTITEM / 100)), 2, 2)
                   WHERE CDFILIAL  = @P_FILIAL
                     AND NRLANCTONF = @P_LANCTONF
                     AND NRSEQITPROD = @V_ITEMPRODUTO_NRSEQITPROD;
               END ELSE BEGIN
                  UPDATE ITEMPRODUTO
                     SET VRENCARGODESC = ROUND(VRDESCITEM + (@V_ITEMENCARGO_VRITEMENCA * (@V_PERCENTITEM / 100)), 2)
                   WHERE CDFILIAL  = @P_FILIAL
                     AND NRLANCTONF = @P_LANCTONF
                     AND NRSEQITPROD = @V_ITEMPRODUTO_NRSEQITPROD;
               END;
               FETCH NEXT FROM C_ITEMPRODUTO INTO @V_ITEMPRODUTO_NRSEQITPROD, @V_ITEMPRODUTO_VRTOTAITEM;
            END;
            CLOSE C_ITEMPRODUTO;
            DEALLOCATE C_ITEMPRODUTO;
            /*AJUSTE DE VALORES*/
            SELECT @V_VRENCARGODESC = SUM(VRENCARGODESC)
              FROM ITEMPRODUTO
             WHERE CDFILIAL = @P_FILIAL
               AND NRLANCTONF = @P_LANCTONF;

            SELECT @V_SUMVRDESCITEM = SUM(VRDESCITEM)
              FROM ITEMPRODUTO
             WHERE CDFILIAL  = @P_FILIAL
               AND NRLANCTONF = @P_LANCTONF;

            SET @V_DIFERENCA = (@V_ITEMENCARGO_VRITEMENCA+@V_SUMVRDESCITEM) - @V_VRENCARGODESC;

            IF @V_DIFERENCA <> 0 BEGIN
               UPDATE ITEMPRODUTO
                  SET VRENCARGODESC = VRENCARGODESC + @V_DIFERENCA
                WHERE CDFILIAL = @P_FILIAL
                  AND NRLANCTONF = @P_LANCTONF
                  AND NRSEQITPROD = (SELECT MAX(NRSEQITPROD)
                                      FROM ITEMPRODUTO
                                      WHERE CDFILIAL = @P_FILIAL
                                        AND NRLANCTONF = @P_LANCTONF
                                        AND VRTOTAITEM = (SELECT MAX(VRTOTAITEM)
                                                           FROM ITEMPRODUTO
                                                          WHERE CDFILIAL = @P_FILIAL
                                                            AND NRLANCTONF = @P_LANCTONF));

            END;
         END ELSE BEGIN
            UPDATE ITEMPRODUTO
               SET VRENCARGODESC = VRDESCITEM + 0
             WHERE CDFILIAL   = @P_FILIAL
               AND NRLANCTONF = @P_LANCTONF;
         END;
      END;

      /*ENCARGO OUTRAS DESPESAS*/
      IF (@V_ITEMENCARGO_CDENCARGONFE = '04') BEGIN
         IF (@V_ITEMENCARGO_VRITEMENCA > 0) BEGIN
            DECLARE C_ITEMPRODUTO CURSOR FOR(SELECT NRSEQITPROD, VRTOTAITEM
                                               FROM ITEMPRODUTO
                                              WHERE CDFILIAL   = @P_FILIAL
                                                AND NRLANCTONF = @P_LANCTONF)
            OPEN C_ITEMPRODUTO;
            FETCH NEXT FROM C_ITEMPRODUTO INTO @V_ITEMPRODUTO_NRSEQITPROD, @V_ITEMPRODUTO_VRTOTAITEM;
            WHILE(@@FETCH_STATUS = 0) BEGIN
               SELECT @V_VRTOTAITEM   = ITEMPRODUTO.VRTOTAITEM,
                      @V_SOMATOTAITEM = TOTAL.SOMATOTAITEM,
                      @V_PERCENTITEM  = CASE TOTAL.SOMATOTAITEM WHEN 0 THEN 0 ELSE ((100 * ITEMPRODUTO.VRTOTAITEM) / TOTAL.SOMATOTAITEM) END
                 FROM ITEMPRODUTO, (SELECT CDFILIAL, NRLANCTONF, SUM(VRTOTAITEM) SOMATOTAITEM
                                      FROM ITEMPRODUTO
                                     WHERE CDFILIAL = @P_FILIAL
                                       AND NRLANCTONF = @P_LANCTONF
                                     GROUP BY CDFILIAL, NRLANCTONF) TOTAL
                WHERE ITEMPRODUTO.CDFILIAL    = TOTAL.CDFILIAL
                  AND ITEMPRODUTO.NRLANCTONF  = TOTAL.NRLANCTONF
                  AND ITEMPRODUTO.NRSEQITPROD = @V_ITEMPRODUTO_NRSEQITPROD;

               IF (@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV') BEGIN
                  UPDATE ITEMPRODUTO
                     SET VROUTRASDESPITEM = ROUND(@V_ITEMENCARGO_VRITEMENCA * (@V_PERCENTITEM / 100), 2, 2)
                   WHERE CDFILIAL    = @P_FILIAL
                     AND NRLANCTONF  = @P_LANCTONF
                     AND NRSEQITPROD = @V_ITEMPRODUTO_NRSEQITPROD;
               END ELSE BEGIN
                  UPDATE ITEMPRODUTO
                     SET VROUTRASDESPITEM = ROUND(@V_ITEMENCARGO_VRITEMENCA * (@V_PERCENTITEM / 100), 2)
                   WHERE CDFILIAL    = @P_FILIAL
                     AND NRLANCTONF  = @P_LANCTONF
                     AND NRSEQITPROD = @V_ITEMPRODUTO_NRSEQITPROD;
               END;
               FETCH NEXT FROM C_ITEMPRODUTO INTO @V_ITEMPRODUTO_NRSEQITPROD, @V_ITEMPRODUTO_VRTOTAITEM;
            END;
            CLOSE C_ITEMPRODUTO;
            DEALLOCATE C_ITEMPRODUTO;
            /*AJUSTE DE VALORES*/
            SELECT @V_VROUTRASDESPITEM = SUM(VROUTRASDESPITEM)
              FROM ITEMPRODUTO
             WHERE CDFILIAL   = @P_FILIAL
               AND NRLANCTONF = @P_LANCTONF;


            SET @V_DIFERENCA = @V_ITEMENCARGO_VRITEMENCA - @V_VROUTRASDESPITEM;

            IF @V_DIFERENCA <> 0 BEGIN
               UPDATE ITEMPRODUTO
                  SET VROUTRASDESPITEM = VROUTRASDESPITEM + @V_DIFERENCA
                WHERE CDFILIAL    = @P_FILIAL
                  AND NRLANCTONF  = @P_LANCTONF
                  AND NRSEQITPROD = (SELECT MAX(NRSEQITPROD)
                                      FROM ITEMPRODUTO
                                      WHERE CDFILIAL   = @P_FILIAL
                                        AND NRLANCTONF = @P_LANCTONF
                                        AND VRTOTAITEM = (SELECT MAX(VRTOTAITEM)
                                                           FROM ITEMPRODUTO
                                                          WHERE CDFILIAL   = @P_FILIAL
                                                            AND NRLANCTONF = @P_LANCTONF));

            END;
         END;
         ELSE BEGIN
            UPDATE ITEMPRODUTO
               SET VROUTRASDESPITEM = 0
             WHERE CDFILIAL   = @P_FILIAL
               AND NRLANCTONF = @P_LANCTONF;
         END
      END;

      /*ENCARGO DESPESAS ADUANEIRAS*/
      IF (@V_ITEMENCARGO_CDENCARGONFE = '05') BEGIN
         /*REFAZ O RATEIO DO ENCARGO VERIFICANDO A INCIDENCIA DO IMPOSTO DE IMPORTACAO*/
         UPDATE ITEMPRODUTO
            SET VRDESPADUANEIRA = 0
          WHERE CDFILIAL   = @P_FILIAL
            AND NRLANCTONF = @P_LANCTONF;
         IF (@V_ITEMENCARGO_VRITEMENCA > 0) BEGIN
            DECLARE C_ITEMPRODUTO CURSOR FOR (SELECT DISTINCT(I.NRSEQITPROD)
                                    FROM ITEMPROIMPOS I, IMPOSTO II
                                   WHERE I.NRLANCTONF    = @P_LANCTONF
                                     AND I.CDFILIAL      = @P_FILIAL
                                     AND I.CDIMPOSTO     = II.CDIMPOSTO
                                     AND II.CDIMPOSTONFE = '20')
            OPEN C_ITEMPRODUTO;
            FETCH NEXT FROM C_ITEMPRODUTO INTO @V_ITEMPRODUTO_NRSEQITPROD;
            WHILE(@@FETCH_STATUS = 0) BEGIN
               SELECT @V_VRTOTAITEM   = ITEMPRODUTO.VRTOTAITEM,
                      @V_SOMATOTAITEM = TOTAL.SOMATOTAITEM,
                      @V_PERCENTITEM  = CASE TOTAL.SOMATOTAITEM WHEN 0 THEN 0 ELSE ((100 * ITEMPRODUTO.VRTOTAITEM) / TOTAL.SOMATOTAITEM) END
                 FROM ITEMPRODUTO, (SELECT CDFILIAL, NRLANCTONF, SUM(VRTOTAITEM) SOMATOTAITEM
                                      FROM ITEMPRODUTO
                                     WHERE CDFILIAL   = @P_FILIAL
                                       AND NRLANCTONF = @P_LANCTONF
                                     GROUP BY CDFILIAL, NRLANCTONF) TOTAL
                WHERE ITEMPRODUTO.CDFILIAL    = TOTAL.CDFILIAL
                  AND ITEMPRODUTO.NRLANCTONF  = TOTAL.NRLANCTONF
                  AND ITEMPRODUTO.NRSEQITPROD = @V_ITEMPRODUTO_NRSEQITPROD;

               IF (@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV') BEGIN
                  UPDATE ITEMPRODUTO
                     SET VRDESPADUANEIRA = ROUND(@V_ITEMENCARGO_VRITEMENCA * (@V_PERCENTITEM / 100), 2, 2)
                   WHERE CDFILIAL    = @P_FILIAL
                     AND NRLANCTONF  = @P_LANCTONF
                     AND NRSEQITPROD = @V_ITEMPRODUTO_NRSEQITPROD;
               END
               ELSE BEGIN
                  UPDATE ITEMPRODUTO
                     SET VRDESPADUANEIRA = ROUND(@V_ITEMENCARGO_VRITEMENCA * (@V_PERCENTITEM / 100), 2)
                   WHERE CDFILIAL    = @P_FILIAL
                     AND NRLANCTONF  = @P_LANCTONF
                     AND NRSEQITPROD = @V_ITEMPRODUTO_NRSEQITPROD;
               END;
               FETCH NEXT FROM C_ITEMPRODUTO INTO @V_ITEMPRODUTO_NRSEQITPROD;
            END;
            /*AJUSTE DE VALORES*/
            SELECT @V_VRDESPADUANEIRA = SUM(VRDESPADUANEIRA)
              FROM ITEMPRODUTO
             WHERE CDFILIAL   = @P_FILIAL
               AND NRLANCTONF = @P_LANCTONF;

            SET @V_DIFERENCA = @V_ITEMENCARGO_VRITEMENCA - @V_VRDESPADUANEIRA;

            IF @V_DIFERENCA <> 0 BEGIN
               UPDATE ITEMPRODUTO
                  SET VRDESPADUANEIRA = VRDESPADUANEIRA + @V_DIFERENCA
                WHERE CDFILIAL    = @P_FILIAL
                  AND NRLANCTONF  = @P_LANCTONF
                  AND NRSEQITPROD = (SELECT MAX(II.NRSEQITPROD)
                                       FROM ITEMPRODUTO I, ITEMPROIMPOS II, IMPOSTO S
                                      WHERE I.CDFILIAL     = @P_FILIAL
                                        AND I.NRLANCTONF   = @P_LANCTONF
                                        AND I.CDFILIAL     = II.CDFILIAL
                                        AND I.NRLANCTONF   = II.NRLANCTONF
                                        AND I.NRSEQITPROD  = II.NRSEQITPROD
                                        AND II.CDIMPOSTO   = S.CDIMPOSTO
                                        AND S.CDIMPOSTONFE = '20'
                                        AND VRTOTAITEM = (SELECT MAX(VRTOTAITEM)
                                                            FROM ITEMPRODUTO I, ITEMPROIMPOS II, IMPOSTO S
                                                           WHERE I.CDFILIAL     = @P_FILIAL
                                                             AND I.NRLANCTONF   = @P_LANCTONF
                                                             AND I.CDFILIAL     = II.CDFILIAL
                                                             AND I.NRLANCTONF   = II.NRLANCTONF
                                                             AND I.NRSEQITPROD  = II.NRSEQITPROD
                                                             AND II.CDIMPOSTO   = S.CDIMPOSTO
                                                             AND S.CDIMPOSTONFE = '20'));
            END;
         END
         ELSE BEGIN
            UPDATE ITEMPRODUTO
               SET VRDESPADUANEIRA = 0
             WHERE CDFILIAL   = @P_FILIAL
               AND NRLANCTONF = @P_LANCTONF;
         END;
      END;
      FETCH NEXT FROM C_ITEMENCARGO INTO @V_ITEMENCARGO_CDENCARGONFE, @V_ITEMENCARGO_VRITEMENCA;
   END;
   CLOSE C_ITEMENCARGO;
   DEALLOCATE C_ITEMENCARGO;

   --CLCULO DO VALOR TOTAL DA NOTA FISCAL
   SELECT @V_SOMAENCA = SUM(VRITEMENCA)
   FROM ITEMENCARGO IE, ENCARGO EN
   WHERE IE.CDFILIAL   = @P_FILIAL    AND
         IE.NRLANCTONF = @P_LANCTONF  AND
         IE.CDENCARGO  = EN.CDENCARGO AND
         IDENCARGO     = 'A';

   SELECT @V_MENOENCA = SUM(VRITEMENCA)
   FROM ITEMENCARGO IE, ENCARGO EN
   WHERE IE.CDFILIAL   = @P_FILIAL AND
         IE.NRLANCTONF = @P_LANCTONF AND
         IE.CDENCARGO  = EN.CDENCARGO AND
         IDENCARGO = 'D';

   IF @V_IDOPERDEVONF = 'S' BEGIN
      SELECT @V_SOMAIMPO = SUM(VRTOTIMPONF)
      FROM IMPOSNFTOT, IMPOSTO
      WHERE IMPOSNFTOT.CDFILIAL   = @P_FILIAL          AND
            IMPOSNFTOT.NRLANCTONF = @P_LANCTONF        AND
            IMPOSNFTOT.CDIMPOSTO  = IMPOSTO.CDIMPOSTO AND
            IDTRATIMPO            = 'A'               AND
            ISNULL(IDACRPRODENTRNF, 'N') = 'N' AND
            NOT EXISTS(SELECT CDIMPOSTO
                       FROM IMPOSTO
                       WHERE IMPOSTO.CDIMPOSTRIB = IMPOSNFTOT.CDIMPOSTO);
   END
   ELSE BEGIN
      SELECT @V_SOMAIMPO = SUM(VRTOTIMPONF)
      FROM IMPOSNFTOT, IMPOSTO
      WHERE IMPOSNFTOT.CDFILIAL   = @P_FILIAL         AND
            IMPOSNFTOT.NRLANCTONF = @P_LANCTONF       AND
            IMPOSNFTOT.CDIMPOSTO  = IMPOSTO.CDIMPOSTO AND
            IDTRATIMPO            = 'A'               AND
            NOT EXISTS(SELECT CDIMPOSTO
                       FROM IMPOSTO
                       WHERE IMPOSTO.CDIMPOSTRIB = IMPOSNFTOT.CDIMPOSTO);
   END;

   SELECT @V_MENOIMPO = SUM(VRTOTIMPONF)
   FROM IMPOSNFTOT, IMPOSTO
   WHERE IMPOSNFTOT.CDFILIAL   = @P_FILIAL AND
         IMPOSNFTOT.NRLANCTONF = @P_LANCTONF AND
         IMPOSNFTOT.CDIMPOSTO  = IMPOSTO.CDIMPOSTO AND
         IDTRATIMPO = 'D';

   IF NOT (@V_LIQUIDO IS NULL) AND (@P_TIPOOPER <> '12') BEGIN
      SET @V_TOTALNOTA = @V_LIQUIDO;
   END;

   IF NOT (@V_SOMAIMPO IS NULL) BEGIN
      SET @V_TOTALNOTA = @V_TOTALNOTA + @V_SOMAIMPO;
   END;

   IF NOT (@V_MENOIMPO IS NULL) BEGIN
      SET @V_TOTALNOTA = @V_TOTALNOTA - @V_MENOIMPO;
   END;

   IF NOT (@V_SOMAENCA IS NULL) BEGIN
      SET @V_TOTALNOTA = @V_TOTALNOTA + @V_SOMAENCA;
   END;

   IF NOT (@V_MENOENCA IS NULL) BEGIN
      SET @V_TOTALNOTA = @V_TOTALNOTA - @V_MENOENCA;
   END;

   --VALOR SUBSTITUIO TRIBUTRIA COM IDENTIFICAO PARA ACRESCER AO TOTAL DA NF
   IF @V_IDOPERDEVONF = 'S' BEGIN
      SELECT @V_SOMAIMPO = ISNULL(ROUND(SUM(VRIMPOSTOIT), @V_NRDECITOTANF),0)
      FROM ITEMPROIMPOS IT, IMPOSTO I
      WHERE CDFILIAL     = @P_FILIAL   AND
            NRLANCTONF   = @P_LANCTONF AND
            IT.CDIMPOSTO = I.CDIMPOSTO AND
            ISNULL(I.IDACRPRODENTRNF, 'N') = 'N' AND
            ISNULL(IT.IDTRIMPSTII, (CASE WHEN I.CDIMPOSTO = (SELECT CDIMPOSTRIB FROM IMPOSTO WHERE CDIMPOSTONFE = '00') THEN '0' ELSE IT.IDTRIMPSTII END)) = '0' AND
            EXISTS(SELECT CDIMPOSTO
                   FROM IMPOSTO
                   WHERE CDIMPOSTRIB = IT.CDIMPOSTO);
   END
   ELSE BEGIN
      SELECT @V_SOMAIMPO = ISNULL(ROUND(SUM(IT.VRIMPOSTOIT), @V_NRDECITOTANF),0)
      FROM ITEMPROIMPOS IT, IMPOSTO I
      WHERE IT.CDFILIAL   = @P_FILIAL   AND
            IT.NRLANCTONF = @P_LANCTONF AND
            IT.CDIMPOSTO  = I.CDIMPOSTO AND
            ISNULL(IT.IDTRIMPSTII, (CASE WHEN I.CDIMPOSTO = (SELECT CDIMPOSTRIB FROM IMPOSTO WHERE CDIMPOSTONFE = '00') THEN '0' ELSE IT.IDTRIMPSTII END)) = '0' AND
            EXISTS(SELECT CDIMPOSTO
                   FROM IMPOSTO
                   WHERE CDIMPOSTRIB = IT.CDIMPOSTO);
   END;

   IF NOT (@V_SOMAIMPO IS NULL) BEGIN
      SET @V_TOTALNOTA = @V_TOTALNOTA + @V_SOMAIMPO;
   END;

   IF @P_TIPOOPER = '12' BEGIN

      DECLARE C_NOTABEBICRED CURSOR FOR
         SELECT I.CDPRODUTO, VRTOTAITEM, IDITEMISSAO, IDTPNFCREDEB
         FROM   ITEMPRODUTO I, ITEMISSAO T
         WHERE  I.CDFILIAL   = @P_FILIAL      AND
                I.NRLANCTONF = @P_LANCTONF    AND
                I.CDPRODUTO  = T.CDPRODUTO
         ORDER BY IDITEMISSAO;

      OPEN C_NOTABEBICRED;
      FETCH NEXT FROM C_NOTABEBICRED INTO @V_NOTABEBICRED_CDPRODUTO,   @V_NOTABEBICRED_VRTOTAITEM,
                                          @V_NOTABEBICRED_IDITEMISSAO, @V_NOTABEBICRED_IDTPNFCREDEB;

      WHILE (@@FETCH_STATUS = 0) BEGIN

         SELECT @V_IDITEMISSAO = IDITEMISSAO
         FROM ITEMISSAO
         WHERE CDPRODUTO = @V_NOTABEBICRED_CDPRODUTO;

         IF (@V_IDITEMISSAO = 'D') BEGIN
            UPDATE ITEMPRODUTO
            SET IDTPNFCREDEB = '2'
            WHERE CDFILIAL   = @P_FILIAL   AND
                  NRLANCTONF = @P_LANCTONF AND
                  CDPRODUTO  = @V_NOTABEBICRED_CDPRODUTO;

            SET @V_TOTALNOTA = @V_TOTALNOTA + @V_NOTABEBICRED_VRTOTAITEM;
         END
         ELSE BEGIN
            IF (@V_IDITEMISSAO = 'C')  BEGIN
               UPDATE ITEMPRODUTO
               SET IDTPNFCREDEB = '1'
               WHERE CDFILIAL   = @P_FILIAL   AND
                     NRLANCTONF = @P_LANCTONF AND
                     CDPRODUTO  = @V_NOTABEBICRED_CDPRODUTO;
            SET @V_TOTALNOTA = @V_TOTALNOTA - @V_NOTABEBICRED_VRTOTAITEM;
            END
            ELSE BEGIN
               UPDATE ITEMPRODUTO
               SET IDTPNFCREDEB = '3'
               WHERE CDFILIAL   = @P_FILIAL   AND
                     NRLANCTONF = @P_LANCTONF AND
                     CDPRODUTO  = @V_NOTABEBICRED_CDPRODUTO;

               SET @V_TOTALNOTA = @V_TOTALNOTA - @V_NOTABEBICRED_VRTOTAITEM;
            END;
         END;

         SELECT @V_CDFILIAPFATU = CDFILIAPFATU, @V_NRAPFATUTNF = NRAPFATUTNF
         FROM NOTAFISCAL
         WHERE CDFILIAL   = @P_FILIAL   AND
               NRLANCTONF = @P_LANCTONF;
         IF NOT(@V_CDFILIAPFATU IS NULL) AND NOT(@V_NRAPFATUTNF IS NULL) BEGIN

            IF ((@V_NOTABEBICRED_IDITEMISSAO = 'D') OR (@V_NOTABEBICRED_IDITEMISSAO = 'O')) AND
               (@V_NOTABEBICRED_IDTPNFCREDEB IS NULL)  BEGIN
               SET @V_TOTALNOTA = @V_TOTALNOTA + @V_NOTABEBICRED_VRTOTAITEM;
            END
            ELSE BEGIN
               IF (@V_NOTABEBICRED_IDITEMISSAO = 'C')  BEGIN
                  SET @V_TOTALNOTA = @V_TOTALNOTA - @V_NOTABEBICRED_VRTOTAITEM;
               END
               ELSE BEGIN
                  SET @V_TOTALNOTA = @V_TOTALNOTA + @V_NOTABEBICRED_VRTOTAITEM;
               END;
            END;
        END;
        FETCH NEXT FROM C_NOTABEBICRED INTO @V_NOTABEBICRED_CDPRODUTO,   @V_NOTABEBICRED_VRTOTAITEM,
                                            @V_NOTABEBICRED_IDITEMISSAO, @V_NOTABEBICRED_IDTPNFCREDEB;
      END;
      CLOSE C_NOTABEBICRED;
      DEALLOCATE C_NOTABEBICRED;
   END;

   /* AJUSTANDO O VALOR DO DIFERIMENTO CASO OCORRA ALGUMA DIFERENA DEVIDO AOS ARREDONDAMENTOS */
   DECLARE C_AJUSTA_DIFERIMENTO CURSOR FOR SELECT IT.NRSEQITPROD, IT.VRIMPOSTOIT, IT.VRIMPOSTOOPERAIT, IT.VRIMPOSTODIFERIT, 
                                                  IT.VRPERDIFEREIT
                                             FROM ITEMPROIMPOS IT JOIN IMPOSTO IM ON (IT.CDIMPOSTO = IM.CDIMPOSTO)
                                            WHERE (IT.VRIMPOSTOIT <> (IT.VRIMPOSTOOPERAIT - IT.VRIMPOSTODIFERIT))
                                              AND (IT.VRPERDIFEREIT IS NOT NULL)
                                              AND (IM.CDIMPOSTONFE = '00')
                                              AND (IT.NRITPROIMPOS = '1')
                                              AND (IT.CDFILIAL = @P_FILIAL)
                                              AND (IT.NRLANCTONF = @P_LANCTONF)
                                            ORDER BY IT.NRSEQITPROD;
   OPEN C_AJUSTA_DIFERIMENTO;
   FETCH NEXT FROM C_AJUSTA_DIFERIMENTO INTO @C_AJUSTA_DIFERIMENTO_NRSEQITPROD, @C_AJUSTA_DIFERIMENTO_VRIMPOSTOIT, @C_AJUSTA_DIFERIMENTO_VRIMPOSTOOPERAIT, @C_AJUSTA_DIFERIMENTO_VRIMPOSTODIFERIT,
                                             @C_AJUSTA_DIFERIMENTO_VRPERDIFEREIT;
   WHILE (@@FETCH_STATUS = 0) BEGIN
      UPDATE ITEMPROIMPOS
         SET VRIMPOSTODIFERIT = VRIMPOSTODIFERIT + (@C_AJUSTA_DIFERIMENTO_VRIMPOSTOOPERAIT - @C_AJUSTA_DIFERIMENTO_VRIMPOSTOIT - @C_AJUSTA_DIFERIMENTO_VRIMPOSTODIFERIT)
       WHERE CDFILIAL = @P_FILIAL
         AND NRLANCTONF = @P_LANCTONF
         AND NRSEQITPROD = @C_AJUSTA_DIFERIMENTO_NRSEQITPROD;
      FETCH NEXT FROM C_AJUSTA_DIFERIMENTO INTO @C_AJUSTA_DIFERIMENTO_NRSEQITPROD, @C_AJUSTA_DIFERIMENTO_VRIMPOSTOIT, @C_AJUSTA_DIFERIMENTO_VRIMPOSTOOPERAIT, @C_AJUSTA_DIFERIMENTO_VRIMPOSTODIFERIT,
                                                @C_AJUSTA_DIFERIMENTO_VRPERDIFEREIT;
   END;
   CLOSE C_AJUSTA_DIFERIMENTO;
   DEALLOCATE C_AJUSTA_DIFERIMENTO;

   EXEC CONSULTA_DESONERACAO @P_FILIAL, @P_LANCTONF, @P_VRDESONERA = @V_IMPOSDESONERA OUTPUT;
   SET @V_TOTALNOTA = @V_TOTALNOTA - @V_IMPOSDESONERA;


   SET @V_TOTALNOTA = ROUND(@V_TOTALNOTA, @V_NRDECITOTANF);

   SELECT @V_DIFEVRBRUTO = ISNULL(@V_TOTALNOTA,0) - SUM(ROUND(ISNULL(VRBRUTITEM,0), 2))
     FROM ITEMPRODUTO
    WHERE CDFILIAL   = @P_FILIAL
      AND NRLANCTONF = @P_LANCTONF;

   IF @V_DIFEVRBRUTO <> 0 BEGIN
      UPDATE ITEMPRODUTO
         SET VRBRUTITEM = VRBRUTITEM + @V_DIFEVRBRUTO
       WHERE CDFILIAL    = @P_FILIAL
         AND NRLANCTONF  = @P_LANCTONF
         AND NRSEQITPROD = (SELECT MAX(I.NRSEQITPROD)
                              FROM ITEMPRODUTO I
                             WHERE I.CDFILIAL     = @P_FILIAL
                               AND I.NRLANCTONF   = @P_LANCTONF
                               AND VRTOTAITEM = (SELECT MAX(VRTOTAITEM)
                                                   FROM ITEMPRODUTO I
                                                  WHERE I.CDFILIAL     = @P_FILIAL
                                                    AND I.NRLANCTONF   = @P_LANCTONF));

   END;


   -- RECALCULO DO VALOR CONTABIL DO ITEM
   DECLARE C_ITEM CURSOR FOR SELECT II.CDIMPOSTO, I.VRBRUTITEM, I.NRSEQITPROD, I.VRCONTITEM
                             FROM ITEMPRODUTO I, ITEMPROIMPOS II
                             WHERE I.CDFILIAL    = @P_FILIAL      AND
                                   I.NRLANCTONF  = @P_LANCTONF    AND
                                   I.CDFILIAL    = II.CDFILIAL    AND
                                   I.NRLANCTONF  = II.NRLANCTONF  AND
                                   I.NRSEQITPROD = II.NRSEQITPROD;
   OPEN C_ITEM;
   FETCH NEXT FROM C_ITEM INTO @C_ITEM_CDIMPOSTO, @C_ITEM_VRBRUTITEM, @C_ITEM_NRSEQITPROD, @C_ITEM_VRCONTITEM;

   WHILE (@@FETCH_STATUS = 0) BEGIN
      SET @V_ICMS = NULL;
      DECLARE C_ICMS CURSOR FOR
         SELECT CDIMPOSTO
           FROM IMPOSTONFE N, IMPOSTO I
          WHERE N.CDIMPOSTONFE = I.CDIMPOSTONFE
            AND N.CDIMPOSTONFE = '00'
            AND I.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
      OPEN C_ICMS;
      FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
      WHILE (@@FETCH_STATUS = 0) BEGIN
         SET @V_ICMS = 'S';
         FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
      END;
      CLOSE C_ICMS;
      DEALLOCATE C_ICMS;

      IF ((@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV')) AND (@V_ICMS = 'S') BEGIN
         UPDATE ITEMPROIMPOS
         SET VRCONTITIMP = ROUND(VRCONTITIMP,2,2)
         WHERE (NRLANCTONF   = @P_LANCTONF)         AND
               (CDFILIAL     = @P_FILIAL)           AND
               (NRSEQITPROD  = @C_ITEM_NRSEQITPROD) AND
               (CDIMPOSTO    = @C_ITEM_CDIMPOSTO)   AND
               (NRITPROIMPOS = '2');
      END
      ELSE BEGIN
         UPDATE ITEMPROIMPOS
         SET VRCONTITIMP = ROUND(VRCONTITIMP,2)
         WHERE (NRLANCTONF   = @P_LANCTONF)         AND
               (CDFILIAL     = @P_FILIAL)           AND
               (NRSEQITPROD  = @C_ITEM_NRSEQITPROD) AND
               (CDIMPOSTO    = @C_ITEM_CDIMPOSTO)   AND
               (NRITPROIMPOS = '2');
      END;

      SELECT @V_VRREDUCAO = MAX(ISNULL(VRCONTITIMP,0))
      FROM ITEMPROIMPOS
      WHERE (NRLANCTONF   = @P_LANCTONF) AND
            (CDFILIAL     = @P_FILIAL)   AND
            (NRSEQITPROD  = @C_ITEM_NRSEQITPROD) AND
            (CDIMPOSTO    = @C_ITEM_CDIMPOSTO)   AND
            (NRITPROIMPOS = '2');

      IF @V_VRREDUCAO IS NULL BEGIN
         SET @V_VRREDUCAO = 0;
      END;

      SET @V_ICMS = NULL;
      DECLARE C_ICMS CURSOR FOR
         SELECT CDIMPOSTO
           FROM IMPOSTONFE N, IMPOSTO I
          WHERE N.CDIMPOSTONFE = I.CDIMPOSTONFE
            AND N.CDIMPOSTONFE = '00'
            AND I.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
      OPEN C_ICMS;
      FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
      WHILE (@@FETCH_STATUS = 0) BEGIN
         SET @V_ICMS = 'S';
         FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
      END;
      CLOSE C_ICMS;
      DEALLOCATE C_ICMS;

      IF (ISNULL(@V_IDUTDESCICMS, 'N') <> 'S') BEGIN
         IF ((@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV')) AND (@V_ICMS = 'S') BEGIN
            UPDATE ITEMPROIMPOS
            SET VRCONTITIMP = ROUND((@C_ITEM_VRBRUTITEM - @V_VRREDUCAO),2,2)
            WHERE (NRLANCTONF   = @P_LANCTONF)         AND
                  (CDFILIAL     = @P_FILIAL)           AND
                  (NRSEQITPROD  = @C_ITEM_NRSEQITPROD) AND
                  (CDIMPOSTO    = @C_ITEM_CDIMPOSTO)   AND
                  (NRITPROIMPOS = '1')                 AND
                  (NOT EXISTS(SELECT CDIMPOSTO
                              FROM IMPOSTO
                              WHERE CDIMPOSTRIB = ITEMPROIMPOS.CDIMPOSTO));
         END
         ELSE BEGIN
            UPDATE ITEMPROIMPOS
            SET VRCONTITIMP = ROUND((@C_ITEM_VRBRUTITEM - @V_VRREDUCAO),2)
            WHERE (NRLANCTONF   = @P_LANCTONF)         AND
                  (CDFILIAL     = @P_FILIAL)           AND
                  (NRSEQITPROD  = @C_ITEM_NRSEQITPROD) AND
                  (CDIMPOSTO    = @C_ITEM_CDIMPOSTO)   AND
                  (NRITPROIMPOS = '1')                 AND
                  (NOT EXISTS(SELECT CDIMPOSTO
                              FROM IMPOSTO
                              WHERE CDIMPOSTRIB = ITEMPROIMPOS.CDIMPOSTO));
         END;
      END
      ELSE BEGIN
         IF ((@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV')) AND (@V_ICMS = 'S') BEGIN
            UPDATE ITEMPROIMPOS
            SET VRCONTITIMP = ROUND((@C_ITEM_VRCONTITEM - @V_VRREDUCAO),2,2)
            WHERE (NRLANCTONF   = @P_LANCTONF)         AND
                  (CDFILIAL     = @P_FILIAL)           AND
                  (NRSEQITPROD  = @C_ITEM_NRSEQITPROD) AND
                  (CDIMPOSTO    = @C_ITEM_CDIMPOSTO)   AND
                  (NRITPROIMPOS = '1')                 AND
                  (NOT EXISTS(SELECT CDIMPOSTO
                              FROM IMPOSTO
                              WHERE CDIMPOSTRIB = ITEMPROIMPOS.CDIMPOSTO));
         END
         ELSE BEGIN
            UPDATE ITEMPROIMPOS
            SET VRCONTITIMP = ROUND((@C_ITEM_VRCONTITEM - @V_VRREDUCAO),2)
            WHERE (NRLANCTONF   = @P_LANCTONF)         AND
                  (CDFILIAL     = @P_FILIAL)           AND
                  (NRSEQITPROD  = @C_ITEM_NRSEQITPROD) AND
                  (CDIMPOSTO    = @C_ITEM_CDIMPOSTO)   AND
                  (NRITPROIMPOS = '1')                 AND
                  (NOT EXISTS(SELECT CDIMPOSTO
                              FROM IMPOSTO
                              WHERE CDIMPOSTRIB = ITEMPROIMPOS.CDIMPOSTO));
         END;
      END;

      IF ((@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV')) AND (@V_ICMS = 'S') BEGIN
         UPDATE ITEMPROIMPOS
            SET VRCONTITIMP = ROUND(@C_ITEM_VRBRUTITEM,2,2)
          WHERE (NRLANCTONF   = @P_LANCTONF)
            AND (CDFILIAL     = @P_FILIAL)
            AND (NRSEQITPROD  = @C_ITEM_NRSEQITPROD)
            AND (CDIMPOSTO    = @C_ITEM_CDIMPOSTO)
            AND (NRITPROIMPOS = '1')
            AND (EXISTS(SELECT CDIMPOSTO
                          FROM IMPOSTO
                         WHERE CDIMPOSTRIB = ITEMPROIMPOS.CDIMPOSTO));
      END
      ELSE BEGIN
         UPDATE ITEMPROIMPOS
            SET VRCONTITIMP = ROUND(@C_ITEM_VRBRUTITEM,2)
          WHERE (NRLANCTONF   = @P_LANCTONF)
            AND (CDFILIAL     = @P_FILIAL)
            AND (NRSEQITPROD  = @C_ITEM_NRSEQITPROD)
            AND (CDIMPOSTO    = @C_ITEM_CDIMPOSTO)
            AND (NRITPROIMPOS = '1')
            AND (EXISTS(SELECT CDIMPOSTO
                          FROM IMPOSTO
                         WHERE CDIMPOSTRIB = ITEMPROIMPOS.CDIMPOSTO));
      END;

      FETCH NEXT FROM C_ITEM INTO @C_ITEM_CDIMPOSTO, @C_ITEM_VRBRUTITEM, @C_ITEM_NRSEQITPROD, @C_ITEM_VRCONTITEM;
   END;
   CLOSE C_ITEM;
   DEALLOCATE C_ITEM;

   EXEC ARREDONDA_BASECALC 'S', @P_FILIAL, @P_LANCTONF;

   SET @V_SEQUIMPOSTNF = '01';

   UPDATE ITEMPROIMPOS
      SET CDFISCALIT = '2',
          VRBASECALCIT = 0	      
    WHERE CDFILIAL = @P_FILIAL
      AND NRLANCTONF = @P_LANCTONF
      AND VRPERREDBCIT > 0.00
      AND NRITPROIMPOS = '2';

   /* ESTE UPDATE ESTA SENDO REALIZADO PARA EVITAR QUE EXISTAM LANCAMENTOS COM BASE DE CLCULO E SEM IMPOSTO E SEM ALIQUOTA */
   UPDATE ITEMPROIMPOS
      SET VRBASECALCIT = 0
    WHERE CDFILIAL     = @P_FILIAL
      AND NRLANCTONF   = @P_LANCTONF
      AND NRITPROIMPOS = '1'
      AND CDFISCALIT   = '1'
      AND VRALIQITEM   = 0.00
      AND VRIMPOSTOIT  = 0.00;

   IF @V_IDOPERDEVONF = 'S' BEGIN
      DECLARE C_IMPOSTONF CURSOR FOR
         SELECT IT.CDIMPOSTO, VRALIQITEM, VRPERREDBCIT, VRPARDEDIT, CDFISCALIT,
                CDSITUTRIBIT, CDFISCOPERIT, CDSUFXCFOPIT, IDTRIMPSTII, SUM(VRCONTITIMP) AS VRCONTITIMP,
                SUM(VRBASECALCIT) AS VRBASECALCIT, SUM(VRIMPOSTOIT) AS VRIMPOSTOIT,
                MAX(NRITPROIMPOS) AS NRITPROIMPOS,
                SUM(VRBCICMSSTRETIDO) VRBCICMSSTRETIDO, SUM(VRICMSSTRETIDO) VRICMSSTRETIDO,
                ISNULL(IDDIFALIQCUSPRI, 'N') AS IDDIFALIQCUSPRI
         FROM ITEMPROIMPOS IT, IMPOSTO I
         WHERE (CDFILIAL     = @P_FILIAL)    AND
               (NRLANCTONF   = @P_LANCTONF)  AND
               (IT.CDIMPOSTO = I.CDIMPOSTO)  AND
               (((CDFISCALIT  = '1')  AND (IDIMPORECUP = 'S')) OR
                ((IDIMPORECUP <> 'S') AND (VRALIQITEM <> 0)))
         GROUP BY IT.CDIMPOSTO, VRALIQITEM, VRPERREDBCIT, VRPARDEDIT, CDFISCALIT,
                  CDSITUTRIBIT, CDFISCOPERIT, CDSUFXCFOPIT, IDTRIMPSTII, IDDIFALIQCUSPRI
         UNION
         SELECT IT.CDIMPOSTO, CONVERT(FLOAT, 0) AS VRALIQITEM, CONVERT(FLOAT, 0) AS VRPERREDBCIT, CONVERT(FLOAT, 0) AS VRPARDEDIT, CDFISCALIT,
                CDSITUTRIBIT, CDFISCOPERIT, CDSUFXCFOPIT, IDTRIMPSTII, SUM(VRCONTITIMP) AS VRCONTITIMP,
                CONVERT(FLOAT, 0) AS VRBASECALCIT, CONVERT(FLOAT, 0) AS VRIMPOSTOIT,
                MAX(NRITPROIMPOS) AS NRITPROIMPOS,
                SUM(VRBCICMSSTRETIDO) VRBCICMSSTRETIDO, SUM(VRICMSSTRETIDO) VRICMSSTRETIDO,
                ISNULL(IDDIFALIQCUSPRI, 'N') AS IDDIFALIQCUSPRI
         FROM ITEMPROIMPOS IT, IMPOSTO I
         WHERE (CDFILIAL     = @P_FILIAL)    AND
               (NRLANCTONF   = @P_LANCTONF)  AND
               (IT.CDIMPOSTO = I.CDIMPOSTO)  AND
               (NRITPROIMPOS <> '3')         AND
               (((CDFISCALIT  <> '1') AND (IDIMPORECUP = 'S')) OR
               ((IDIMPORECUP  <> 'S') AND (VRALIQITEM = 0)))
         GROUP BY IT.CDIMPOSTO, CDFISCALIT, CDSITUTRIBIT,
                  CDFISCOPERIT, CDSUFXCFOPIT, IDTRIMPSTII, IDDIFALIQCUSPRI
         UNION
         SELECT IT.CDIMPOSTO, VRALIQITEM, VRPERREDBCIT, VRPARDEDIT, CDFISCALIT,
                CDSITUTRIBIT, CDFISCOPERIT, CDSUFXCFOPIT, IDTRIMPSTII, SUM(VRCONTITIMP) AS VRCONTITIMP,
                SUM(VRBASECALCIT) AS VRBASECALCIT, SUM(VRIMPOSTOIT) AS VRIMPOSTOIT,
                MAX(NRITPROIMPOS) AS NRITPROIMPOS,
                SUM(VRBCICMSSTRETIDO) VRBCICMSSTRETIDO, SUM(VRICMSSTRETIDO) VRICMSSTRETIDO,
                ISNULL(IDDIFALIQCUSPRI, 'N') AS IDDIFALIQCUSPRI
         FROM ITEMPROIMPOS IT, IMPOSTO I
         WHERE (CDFILIAL     = @P_FILIAL)    AND
               (NRLANCTONF   = @P_LANCTONF)  AND
               (IT.CDIMPOSTO = I.CDIMPOSTO)  AND
               (NRITPROIMPOS = '3')
         GROUP BY IT.CDIMPOSTO, VRALIQITEM, VRPERREDBCIT, VRPARDEDIT, CDFISCALIT,
                  CDSITUTRIBIT, CDFISCOPERIT, CDSUFXCFOPIT, IDTRIMPSTII, IDDIFALIQCUSPRI;

      OPEN C_IMPOSTONF;
      FETCH NEXT FROM C_IMPOSTONF INTO @V_IMPOSTONF_CDIMPOSTO,    @V_IMPOSTONF_VRALIQITEM,       @V_IMPOSTONF_VRPERREDBCIT,
                                       @V_IMPOSTONF_VRPARDEDIT,   @V_IMPOSTONF_CDFISCALIT,       @V_IMPOSTONF_CDSITUTRIBIT,
                                       @V_IMPOSTONF_CDFISCOPERIT, @V_IMPOSTONF_CDSUFXCFOPIT,     @V_IMPOSTONF_IDTRIMPSTII,
                                       @V_IMPOSTONF_VRCONTITIMP,  @V_IMPOSTONF_VRBASECALCIT,     @V_IMPOSTONF_VRIMPOSTOIT,
                                       @V_IMPOSTONF_NRITPROIMPOS, @V_IMPOSTONF_VRBCICMSSTRETIDO, @V_IMPOSTONF_VRICMSSTRETIDO,
                                       @V_IMPOSTONF_IDDIFALIQCUSPRI;

      WHILE (@@FETCH_STATUS = 0) BEGIN
         SET @V_ICMS = NULL;
         DECLARE C_ICMS CURSOR FOR
            SELECT CDIMPOSTO
              FROM IMPOSTONFE N, IMPOSTO I
             WHERE N.CDIMPOSTONFE = I.CDIMPOSTONFE
               AND N.CDIMPOSTONFE = '00'
               AND I.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
         OPEN C_ICMS;
         FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
         WHILE (@@FETCH_STATUS = 0) BEGIN
            SET @V_ICMS = 'S';
            FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
         END;
         CLOSE C_ICMS;
         DEALLOCATE C_ICMS;

         IF ((@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV')) AND (@V_ICMS = 'S') BEGIN
            INSERT INTO IMPOSTONF(
               CDFILIAL, NRLANCTONF, CDIMPOSTO, NRIMPOSNF, VRCONTABILNF, VRPERREDBCNF,
               VRBASECALCNF, VRALIQNF, VRPARDEDNF, VRIMPOSTONF, CDFISCALNF, CDSITUTRIBNF,
               CDFISCOPERNF, CDSUFXCFOPNF, IDIMPOSTONF, VRBCICMSSTRETIDO, VRICMSSTRETIDO,
               IDTRIMPOSTNF)
            VALUES(
               @P_FILIAL, @P_LANCTONF, @V_IMPOSTONF_CDIMPOSTO, @V_SEQUIMPOSTNF, ROUND(@V_IMPOSTONF_VRCONTITIMP,2,2),@V_IMPOSTONF_VRPERREDBCIT,
               ROUND(@V_IMPOSTONF_VRBASECALCIT,2,2), @V_IMPOSTONF_VRALIQITEM, ROUND(@V_IMPOSTONF_VRPARDEDIT,2,2), ROUND(@V_IMPOSTONF_VRIMPOSTOIT,2,2), @V_IMPOSTONF_CDFISCALIT, @V_IMPOSTONF_CDSITUTRIBIT,
               @V_IMPOSTONF_CDFISCOPERIT, @V_IMPOSTONF_CDSUFXCFOPIT, @V_IMPOSTONF_NRITPROIMPOS, ROUND(@V_IMPOSTONF_VRBCICMSSTRETIDO,2,2), ROUND(@V_IMPOSTONF_VRICMSSTRETIDO,2,2),
               @V_IMPOSTONF_IDTRIMPSTII);
         END
         ELSE BEGIN
            INSERT INTO IMPOSTONF(
               CDFILIAL, NRLANCTONF, CDIMPOSTO, NRIMPOSNF, VRCONTABILNF, VRPERREDBCNF,
               VRBASECALCNF, VRALIQNF, VRPARDEDNF, VRIMPOSTONF, CDFISCALNF, CDSITUTRIBNF,
               CDFISCOPERNF, CDSUFXCFOPNF, IDIMPOSTONF, VRBCICMSSTRETIDO, VRICMSSTRETIDO,
               IDTRIMPOSTNF)
            VALUES(
               @P_FILIAL, @P_LANCTONF, @V_IMPOSTONF_CDIMPOSTO, @V_SEQUIMPOSTNF, ROUND(@V_IMPOSTONF_VRCONTITIMP,2), @V_IMPOSTONF_VRPERREDBCIT,
               @V_IMPOSTONF_VRBASECALCIT, @V_IMPOSTONF_VRALIQITEM, @V_IMPOSTONF_VRPARDEDIT, @V_IMPOSTONF_VRIMPOSTOIT, @V_IMPOSTONF_CDFISCALIT, @V_IMPOSTONF_CDSITUTRIBIT,
               @V_IMPOSTONF_CDFISCOPERIT, @V_IMPOSTONF_CDSUFXCFOPIT, @V_IMPOSTONF_NRITPROIMPOS, ROUND(@V_IMPOSTONF_VRBCICMSSTRETIDO,2), ROUND(@V_IMPOSTONF_VRICMSSTRETIDO,2),
               @V_IMPOSTONF_IDTRIMPSTII);
         END;


         SET @V_SEQUIMPOSTNF = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(NUMERIC, @V_SEQUIMPOSTNF) + 1)),2);


         FETCH NEXT FROM C_IMPOSTONF INTO @V_IMPOSTONF_CDIMPOSTO,    @V_IMPOSTONF_VRALIQITEM,       @V_IMPOSTONF_VRPERREDBCIT,
                                          @V_IMPOSTONF_VRPARDEDIT,   @V_IMPOSTONF_CDFISCALIT,       @V_IMPOSTONF_CDSITUTRIBIT,
                                          @V_IMPOSTONF_CDFISCOPERIT, @V_IMPOSTONF_CDSUFXCFOPIT,     @V_IMPOSTONF_IDTRIMPSTII,
                                          @V_IMPOSTONF_VRCONTITIMP,  @V_IMPOSTONF_VRBASECALCIT,     @V_IMPOSTONF_VRIMPOSTOIT,
                                          @V_IMPOSTONF_NRITPROIMPOS, @V_IMPOSTONF_VRBCICMSSTRETIDO, @V_IMPOSTONF_VRICMSSTRETIDO,
                                          @V_IMPOSTONF_IDDIFALIQCUSPRI;
      END;
      CLOSE C_IMPOSTONF;
      DEALLOCATE C_IMPOSTONF;
   END
   ELSE BEGIN
      DECLARE C_IMPOSTONF CURSOR FOR
         SELECT IT.CDIMPOSTO, VRALIQITEM, VRPERREDBCIT, VRPARDEDIT, CDFISCALIT,
                CDSITUTRIBIT, CDFISCOPERIT, CDSUFXCFOPIT, IDTRIMPSTII, SUM(ROUND(VRCONTITIMP,2)) AS VRCONTITIMP,
                SUM(VRBASECALCIT) AS VRBASECALCIT, SUM(VRIMPOSTOIT) AS VRIMPOSTOIT, NRITPROIMPOS,
                SUM(VRBCICMSSTRETIDO) VRBCICMSSTRETIDO, SUM(VRICMSSTRETIDO) VRICMSSTRETIDO
         FROM ITEMPROIMPOS IT, IMPOSTO I
         WHERE (CDFILIAL     = @P_FILIAL)    AND
               (NRLANCTONF   = @P_LANCTONF)  AND
               (IT.CDIMPOSTO = I.CDIMPOSTO)  AND
               (((CDFISCALIT  = '1') AND (IDIMPORECUP = 'S')) OR
                ((IDIMPORECUP <> 'S') AND (VRALIQITEM <> 0 )))
         GROUP BY IT.CDIMPOSTO, VRALIQITEM, VRPERREDBCIT, VRPARDEDIT, CDFISCALIT,
                  CDSITUTRIBIT, CDFISCOPERIT, CDSUFXCFOPIT, IDTRIMPSTII, NRITPROIMPOS
         UNION
         SELECT IT.CDIMPOSTO, CONVERT(FLOAT, 0) AS VRALIQITEM, CONVERT(FLOAT, 0) AS VRPERREDBCIT, CONVERT(FLOAT, 0) AS VRPARDEDIT, CDFISCALIT,
                CDSITUTRIBIT, CDFISCOPERIT, CDSUFXCFOPIT, IDTRIMPSTII, SUM(ROUND(VRCONTITIMP,2)) AS VRCONTITIMP,
                CONVERT(FLOAT, 0) AS VRBASECALCIT, CONVERT(FLOAT, 0) AS VRIMPOSTOIT, NRITPROIMPOS,
                SUM(VRBCICMSSTRETIDO) VRBCICMSSTRETIDO, SUM(VRICMSSTRETIDO) VRICMSSTRETIDO
         FROM ITEMPROIMPOS IT, IMPOSTO I
         WHERE (CDFILIAL      = @P_FILIAL)    AND
               (NRLANCTONF    = @P_LANCTONF)  AND
               (IT.CDIMPOSTO  = I.CDIMPOSTO)  AND
               (((IT.CDFISCALIT <> '1') AND (IDIMPORECUP = 'S')) OR
                ((I.IDIMPORECUP  <> 'S') AND (VRALIQITEM = 0) ))
         GROUP BY IT.CDIMPOSTO, CDFISCALIT, CDSITUTRIBIT,
                  CDFISCOPERIT, CDSUFXCFOPIT, IDTRIMPSTII, NRITPROIMPOS;

      OPEN C_IMPOSTONF;
      FETCH NEXT FROM C_IMPOSTONF INTO @V_IMPOSTONF_CDIMPOSTO,    @V_IMPOSTONF_VRALIQITEM,       @V_IMPOSTONF_VRPERREDBCIT,
                                       @V_IMPOSTONF_VRPARDEDIT,   @V_IMPOSTONF_CDFISCALIT,       @V_IMPOSTONF_CDSITUTRIBIT,
                                       @V_IMPOSTONF_CDFISCOPERIT, @V_IMPOSTONF_CDSUFXCFOPIT,     @V_IMPOSTONF_IDTRIMPSTII,
                                       @V_IMPOSTONF_VRCONTITIMP,  @V_IMPOSTONF_VRBASECALCIT,     @V_IMPOSTONF_VRIMPOSTOIT,
                                       @V_IMPOSTONF_NRITPROIMPOS, @V_IMPOSTONF_VRBCICMSSTRETIDO, @V_IMPOSTONF_VRICMSSTRETIDO;

      WHILE (@@FETCH_STATUS = 0) BEGIN
         SET @V_ICMS = NULL;
         DECLARE C_ICMS CURSOR FOR
            SELECT CDIMPOSTO
              FROM IMPOSTONFE N, IMPOSTO I
             WHERE N.CDIMPOSTONFE = I.CDIMPOSTONFE
               AND N.CDIMPOSTONFE = '00'
               AND I.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
         OPEN C_ICMS;
         FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
         WHILE (@@FETCH_STATUS = 0) BEGIN
            SET @V_ICMS = 'S';
            FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
         END;
         CLOSE C_ICMS;
         DEALLOCATE C_ICMS;

         IF ((@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV')) AND (@V_ICMS = 'S') BEGIN
            INSERT INTO IMPOSTONF(
               CDFILIAL, NRLANCTONF, CDIMPOSTO, NRIMPOSNF, VRCONTABILNF, VRPERREDBCNF,
               VRBASECALCNF, VRALIQNF, VRPARDEDNF, VRIMPOSTONF, CDFISCALNF, CDSITUTRIBNF,
               CDFISCOPERNF, CDSUFXCFOPNF, IDIMPOSTONF, VRBCICMSSTRETIDO, VRICMSSTRETIDO,
               IDTRIMPOSTNF)
            VALUES(
               @P_FILIAL, @P_LANCTONF, @V_IMPOSTONF_CDIMPOSTO, @V_SEQUIMPOSTNF, ROUND(@V_IMPOSTONF_VRCONTITIMP,2,2), @V_IMPOSTONF_VRPERREDBCIT,
               ROUND(@V_IMPOSTONF_VRBASECALCIT,2,2), @V_IMPOSTONF_VRALIQITEM, ROUND(@V_IMPOSTONF_VRPARDEDIT,2,2), ROUND(@V_IMPOSTONF_VRIMPOSTOIT,2,2), @V_IMPOSTONF_CDFISCALIT, @V_IMPOSTONF_CDSITUTRIBIT,
               @V_IMPOSTONF_CDFISCOPERIT, @V_IMPOSTONF_CDSUFXCFOPIT, @V_IMPOSTONF_NRITPROIMPOS, ROUND(@V_IMPOSTONF_VRBCICMSSTRETIDO,2,2), ROUND(@V_IMPOSTONF_VRICMSSTRETIDO,2,2),
               @V_IMPOSTONF_IDTRIMPSTII);
         END
         ELSE BEGIN
            INSERT INTO IMPOSTONF(
               CDFILIAL, NRLANCTONF, CDIMPOSTO, NRIMPOSNF, VRCONTABILNF, VRPERREDBCNF,
               VRBASECALCNF, VRALIQNF, VRPARDEDNF, VRIMPOSTONF, CDFISCALNF, CDSITUTRIBNF,
               CDFISCOPERNF, CDSUFXCFOPNF, IDIMPOSTONF, VRBCICMSSTRETIDO, VRICMSSTRETIDO,
               IDTRIMPOSTNF)
            VALUES(
               @P_FILIAL, @P_LANCTONF, @V_IMPOSTONF_CDIMPOSTO, @V_SEQUIMPOSTNF, ROUND(@V_IMPOSTONF_VRCONTITIMP,2), @V_IMPOSTONF_VRPERREDBCIT,
               @V_IMPOSTONF_VRBASECALCIT, @V_IMPOSTONF_VRALIQITEM,  @V_IMPOSTONF_VRPARDEDIT, @V_IMPOSTONF_VRIMPOSTOIT, @V_IMPOSTONF_CDFISCALIT, @V_IMPOSTONF_CDSITUTRIBIT,
               @V_IMPOSTONF_CDFISCOPERIT, @V_IMPOSTONF_CDSUFXCFOPIT, @V_IMPOSTONF_NRITPROIMPOS, ROUND(@V_IMPOSTONF_VRBCICMSSTRETIDO,2), ROUND(@V_IMPOSTONF_VRICMSSTRETIDO,2),
               @V_IMPOSTONF_IDTRIMPSTII);
         END;

         SET @V_SEQUIMPOSTNF = RIGHT(REPLICATE('0',2) + RTRIM(CONVERT(VARCHAR, CONVERT(NUMERIC, @V_SEQUIMPOSTNF) + 1)),2);

         FETCH NEXT FROM C_IMPOSTONF INTO @V_IMPOSTONF_CDIMPOSTO,    @V_IMPOSTONF_VRALIQITEM,       @V_IMPOSTONF_VRPERREDBCIT,
                                          @V_IMPOSTONF_VRPARDEDIT,   @V_IMPOSTONF_CDFISCALIT,       @V_IMPOSTONF_CDSITUTRIBIT,
                                          @V_IMPOSTONF_CDFISCOPERIT, @V_IMPOSTONF_CDSUFXCFOPIT,     @V_IMPOSTONF_IDTRIMPSTII,
                                          @V_IMPOSTONF_VRCONTITIMP,  @V_IMPOSTONF_VRBASECALCIT,     @V_IMPOSTONF_VRIMPOSTOIT,
                                          @V_IMPOSTONF_NRITPROIMPOS, @V_IMPOSTONF_VRBCICMSSTRETIDO, @V_IMPOSTONF_VRICMSSTRETIDO;
      END;
      CLOSE C_IMPOSTONF;
      DEALLOCATE C_IMPOSTONF;
   END;

   DECLARE C_CARGA CURSOR FOR SELECT DISTINCT CDIMPOSTO
                                FROM IMPOSTONF
                               WHERE CDFILIAL = @P_FILIAL
                                 AND NRLANCTONF = @P_LANCTONF;
   OPEN C_CARGA;
   FETCH NEXT FROM C_CARGA INTO @V_CARGA_CDIMPOSTO;

   WHILE (@@FETCH_STATUS = 0) BEGIN

      SET @V_CARGA = TEKNISA.VALOR_CARGA_TRIBUTARIA(@V_CARGA_CDIMPOSTO, @P_FILIAL, @P_LANCTONF);
      IF (@V_CARGA > 0) BEGIN
         UPDATE IMPOSTONF
            SET VRIMPCARGATRIBI = @V_CARGA
           WHERE CDFILIAL = @P_FILIAL
             AND NRLANCTONF = @P_LANCTONF
             AND CDIMPOSTO = @V_CARGA_CDIMPOSTO
             AND NRIMPOSNF = (SELECT MAX(NRIMPOSNF)
                                      FROM IMPOSTONF
                                      WHERE CDFILIAL = @P_FILIAL
                                        AND NRLANCTONF = @P_LANCTONF
                                        AND CDIMPOSTO = @V_CARGA_CDIMPOSTO);

      END;
      FETCH NEXT FROM C_CARGA INTO @V_CARGA_CDIMPOSTO;
   END;
   CLOSE C_CARGA;
   DEALLOCATE C_CARGA;

   DECLARE C_IMPOSTORETI CURSOR FOR
      SELECT N.CDEMPRESA, IP.CDIMPOSTO, N.IDTPIJURNF, N.NRINSJURNF, N.DTENTRSAID
      FROM IMPOSTO I, NOTAFISCAL N, IMPOSTONF IP
      WHERE N.CDFILIAL   = @P_FILIAL     AND
            N.NRLANCTONF = @P_LANCTONF   AND
            N.CDFILIAL   = IP.CDFILIAL   AND
            N.NRLANCTONF = IP.NRLANCTONF AND
            IP.CDIMPOSTO = I.CDIMPOSTO   AND
            I.IDTRATIMPO   = 'R'        AND
            I.IDUTVRMENSBC = 'S';

   OPEN C_IMPOSTORETI;
   FETCH NEXT FROM C_IMPOSTORETI INTO @V_IMPRETI_CDEMPRESA, @V_IMPRETI_CDIMPOSTO,  @V_IMPRETI_IDTPIJURNF,
                                      @V_IMPRETI_NRINSJURNF, @V_IMPRETI_DTENTRSAID;

   WHILE (@@FETCH_STATUS = 0) BEGIN

      EXEC BASECALC_RETIDO 'S', @P_FILIAL, @P_LANCTONF, @V_IMPRETI_IDTPIJURNF, @V_IMPRETI_NRINSJURNF,
                                @V_IMPRETI_DTENTRSAID, @V_IMPRETI_CDIMPOSTO, 'S', @V_IMPRETI_CDEMPRESA,
                                @P_INSCESTA, @V_PAISORIG, @V_ESTAORIG, @V_PAISDEST, @V_ESTADEST, @V_CDGRUPOFISC, @V_CDGRPFISCSV, @P_TIPOOPER

      --OPEN C_IMPOSTORETI;
      FETCH NEXT FROM C_IMPOSTORETI INTO @V_IMPRETI_CDEMPRESA, @V_IMPRETI_CDIMPOSTO,  @V_IMPRETI_IDTPIJURNF, @V_IMPRETI_NRINSJURNF, @V_IMPRETI_DTENTRSAID;
   END;
   CLOSE C_IMPOSTORETI;
   DEALLOCATE C_IMPOSTORETI;

/* SE O IPI COMPOR A BASE DE CALCULO DO ICMS E O ICMS TIVER O CODIGO FISCAL IGUAL A 1 SERA ATUALIZADO COM O IDENTIFICADOR 4 */
   DECLARE C_IMPFISC CURSOR FOR SELECT CDFILIAL, NRLANCTONF, CDIMPOSTO, CDSITUTRIBNF, CDFISCOPERNF, CDFISCALNF
                                  FROM IMPOSTONF IP
                                 WHERE IP.CDFILIAL = @P_FILIAL
                                   AND IP.NRLANCTONF = @P_LANCTONF
                                   AND IP.IDIMPOSTONF = '1'
                                   AND IP.CDFISCALNF = '1';
   OPEN C_IMPFISC;
   FETCH NEXT FROM C_IMPFISC INTO @V_IMPFISC_CDFILIAL, @V_IMPFISC_NRLANCTONF, @V_IMPFISC_CDIMPOSTO, @V_IMPFISC_CDSITUTRIBNF,
                                  @V_IMPFISC_CDFISCOPERNF, @V_IMPFISC_CDFISCALNF;

   WHILE (@@FETCH_STATUS = 0) BEGIN
      SELECT @V_CDIMPOBCALC = MAX(BC.CDIMPOBCALC)
        FROM BASECALCTPOPER BC
       WHERE (BC.IDENTRSAIDOP = 'S')
         AND (BC.CDTIPOOPER = @P_TIPOOPER)
         AND (BC.CDIMPOSTO = @V_IMPFISC_CDIMPOSTO)
         AND (BC.CDIMPOBCALC IS NOT NULL)
         AND ((SUBSTRING(@V_IMPFISC_CDSITUTRIBNF,2,2)  = BC.CDCSTIMPOTPOP)  OR (BC.CDCSTIMPOTPOP  IS NULL))
         AND ((SUBSTRING(@V_IMPFISC_CDFISCOPERNF,2,4) = BC.CDCFOPIMPOTPOP) OR (BC.CDCFOPIMPOTPOP IS NULL))
         AND (@V_IMPFISC_CDFISCALNF = BC.CDFISCIMPOTPOP) OR (BC.CDFISCIMPOTPOP IS NULL);

      IF @V_CDIMPOBCALC IS NULL BEGIN
         SELECT @V_CDIMPOBCALC = MAX(BC.CDIMPOBCALC)
           FROM BASECALC BC
          WHERE BC.CDIMPOSTO = @V_IMPFISC_CDIMPOSTO
            AND BC.CDIMPOBCALC IS NOT NULL
            AND ((SUBSTRING(@V_IMPFISC_CDSITUTRIBNF,2,2)  = BC.CDCSTIMPO)  OR (BC.CDCSTIMPO  IS NULL))
            AND ((SUBSTRING(@V_IMPFISC_CDFISCOPERNF,2,4) = BC.CDCFOPIMPO) OR (BC.CDCFOPIMPO IS NULL))
            AND (@V_IMPFISC_CDFISCALNF = BC.CDFISCIMPO) OR (BC.CDFISCIMPO IS NULL)
            AND BC.IDTIPOBCALC = 'I';

         IF NOT @V_CDIMPOBCALC IS NULL BEGIN
            UPDATE IMPOSTONF
               SET IDIMPOSTONF = '4'
             WHERE CDFILIAL   = @V_IMPFISC_CDFILIAL
               AND NRLANCTONF = @V_IMPFISC_NRLANCTONF
               AND CDIMPOSTO  = @V_CDIMPOBCALC;
         END;
      END
      ELSE BEGIN
         UPDATE IMPOSTONF
         SET IDIMPOSTONF = '4'
         WHERE CDFILIAL   = @V_IMPFISC_CDFILIAL   AND
               NRLANCTONF = @V_IMPFISC_NRLANCTONF AND
               CDIMPOSTO  = @V_CDIMPOBCALC;
      END;
      FETCH NEXT FROM C_IMPFISC INTO @V_IMPFISC_CDFILIAL, @V_IMPFISC_NRLANCTONF, @V_IMPFISC_CDIMPOSTO, @V_IMPFISC_CDSITUTRIBNF,
                                  @V_IMPFISC_CDFISCOPERNF, @V_IMPFISC_CDFISCALNF;
   END;
   CLOSE C_IMPFISC;
   DEALLOCATE C_IMPFISC;

   SET @V_TOTALNOTA = ROUND(@V_TOTALNOTA, @V_NRDECITOTANF);

   UPDATE NOTAFISCAL
   SET VRNOTAFISC = ISNULL(@V_TOTALNOTA,0),
       VRPRODUTOS = ISNULL(@V_LIQUIDO,0),
       VRDISPNFDEVO = ISNULL(@V_TOTALNOTA,0),
       IDERROS    = '000'
   WHERE CDFILIAL   = @P_FILIAL AND
         NRLANCTONF = @P_LANCTONF;

   DELETE 
     FROM INFOPAGANFE
    WHERE CDFILIAL = @P_FILIAL
      AND NRLANCTONF = @P_LANCTONF;

   SELECT @V_IMPOSRETI = ROUND(ISNULL(SUM(IT.VRTOTIMPONF),0), @V_NRDECITOTANF)
   FROM IMPOSNFTOT IT, IMPOSTO I
   WHERE I.CDIMPOSTO    = IT.CDIMPOSTO  AND
         IT.CDFILIAL    = @P_FILIAL     AND
         IT.NRLANCTONF  = @P_LANCTONF   AND
         I.IDDESCRFONTE <> 'A'          AND
         I.IDTRATIMPO   = 'R';

   SET @V_TOTALNOTA  = @V_TOTALNOTA - @V_IMPOSRETI;
   SET @P_VRNOTAFISC = @V_TOTALNOTA;

   SELECT @V_VRCONTAREC = ISNULL(SUM(VRORIGREC),0), @V_NRLANBOLREC = MAX(NRLANBOLREC)
   FROM CONTARECEBER
   WHERE CDFILIAL   = @P_FILIAL AND
         NRLANCTONF = @P_LANCTONF;

   IF (@V_VRCONTAREC <> @V_TOTALNOTA) AND (@V_IMPOSRETI > 0) AND
      (@V_IDDOCFINANC <> 'L') AND (@V_NRLANBOLREC IS NULL) BEGIN
      EXEC APURAC_VENC @P_FILIAL, @P_CLIENTE, @P_LANCTONF;
   END;

   UPDATE ITEMPRODUTO
   SET IDAVISOSITEM  = '00000'
   WHERE (CDFILIAL   = @P_FILIAL) AND
         (NRLANCTONF = @P_LANCTONF);

   UPDATE ITEMPROIMPOS
   SET IDAVISIMPIT   = '00000',
       IDERROSIMPIT  = '00000'
   WHERE (CDFILIAL   = @P_FILIAL) AND
         (NRLANCTONF = @P_LANCTONF);

   --IDENTIFICADOR DE ERROS E AVISOS
   IF NOT(@P_TIPOOPER IN ('09', '10', '12')) BEGIN /*VALE DE TRANSFERENCIA, SAIDA SEM NOTA, NOTA DE CREDITO/DEBITO*/
      SELECT @V_IDERROAVISO = MAX(IDERROAVISOFIL)
      FROM ERROAVISONFFIL
      WHERE CDERROAVISOFIL = 'AV09'
        AND CDFILIAL = @V_CDFILIEMIT;

      IF @V_IDERROAVISO IS NULL BEGIN
         SELECT @V_IDERROAVISO = MAX(IDERROAVISO)
         FROM ERROAVISONF
         WHERE CDERROAVISO = 'AV09';
      END;

      UPDATE ITEMPRODUTO
      SET IDAVISOSITEM = '1' + SUBSTRING(IDAVISOSITEM,2,4)
      WHERE (CDFILIAL   = @P_FILIAL)   AND
            (NRLANCTONF = @P_LANCTONF) AND
            ((CDSITUTRIBPR IS NULL) OR (LEN(LTRIM(RTRIM(CDSITUTRIBPR))) < 3)) AND
            (@V_IDERROAVISO <> 'N')    AND
            (@V_IDCONSPARFIS <> 'N');

      SELECT @V_IDERROAVISO = MAX(IDERROAVISOFIL)
      FROM ERROAVISONFFIL
      WHERE CDERROAVISOFIL = 'AV10'
        AND CDFILIAL = @V_CDFILIEMIT;

      IF @V_IDERROAVISO IS NULL BEGIN
         SELECT @V_IDERROAVISO = MAX(IDERROAVISO)
         FROM ERROAVISONF
         WHERE CDERROAVISO = 'AV10';
      END;

      UPDATE ITEMPRODUTO
      SET IDAVISOSITEM = SUBSTRING(IDAVISOSITEM,1,1) + '1' + SUBSTRING(IDAVISOSITEM,3,3)
      WHERE (CDFILIAL   = @P_FILIAL)   AND
            (NRLANCTONF = @P_LANCTONF) AND
            ((CDFISOPEITEM IS NULL) OR (LEN(CDFISOPEITEM) < 3)) AND
            (@V_IDERROAVISO <> 'N')    AND
            (@V_IDCONSPARFIS <> 'N');

      IF NOT(@P_TIPOOPER IN ('07', '12')) BEGIN
         /* (AVISO) IMPOSTO DO ITEM DA ENTRADA COM CDIGO FISCAL INVLIDO */
         SELECT @V_IDERROAVISO = MAX(IDERROAVISOFIL)
         FROM ERROAVISONFFIL
         WHERE CDERROAVISOFIL = 'AV04'
           AND CDFILIAL = @V_CDFILIEMIT;

         IF @V_IDERROAVISO IS NULL BEGIN
            SELECT @V_IDERROAVISO = MAX(IDERROAVISO)
            FROM ERROAVISONF
            WHERE CDERROAVISO = 'AV04';
         END;

         UPDATE ITEMPROIMPOS
         SET IDAVISIMPIT = SUBSTRING(IDAVISIMPIT,1,1) + '1' + SUBSTRING(IDAVISIMPIT,3,3)
         WHERE (CDFILIAL   = @P_FILIAL)   AND
               (NRLANCTONF = @P_LANCTONF) AND
               ((CDFISCALIT IS NULL) OR LEN(CDFISCALIT) <> 1) AND
               (@V_IDERROAVISO <> 'N');

         /* (AVISO) IMPOSTO DO ITEM COM SITUAO TRIBUTRIA(CST) INVLIDA */
         SELECT @V_IDERROAVISO = MAX(IDERROAVISOFIL)
         FROM ERROAVISONFFIL
         WHERE CDERROAVISOFIL = 'AV05'
           AND CDFILIAL = @V_CDFILIEMIT;

         IF @V_IDERROAVISO IS NULL BEGIN
            SELECT @V_IDERROAVISO = MAX(IDERROAVISO)
            FROM ERROAVISONF
            WHERE CDERROAVISO = 'AV05';
         END;

         UPDATE ITEMPROIMPOS
         SET IDAVISIMPIT = SUBSTRING(IDAVISIMPIT,1,2) + '1' + SUBSTRING(IDAVISIMPIT,4,2)
         WHERE (CDFILIAL   = @P_FILIAL)   AND
               (NRLANCTONF = @P_LANCTONF) AND
               ((CDSITUTRIBIT IS NULL) OR (LEN(CDSITUTRIBIT) < 2))AND
               (@V_IDERROAVISO <> 'N')    AND
               (@V_IDCONSPARFIS <> 'N');

         /* (AVISO) IMPOSTO DO ITEM COM CD. FISCAL OPERAO - CFOP INVLIDO */
         SELECT @V_IDERROAVISO = MAX(IDERROAVISOFIL)
         FROM ERROAVISONFFIL
         WHERE CDERROAVISOFIL = 'AV06'
           AND CDFILIAL = @V_CDFILIEMIT;

         IF @V_IDERROAVISO IS NULL BEGIN
            SELECT @V_IDERROAVISO = MAX(IDERROAVISO)
            FROM ERROAVISONF
            WHERE CDERROAVISO = 'AV06';
         END;

         UPDATE ITEMPROIMPOS
         SET IDAVISIMPIT = SUBSTRING(IDAVISIMPIT,1,3) + '1' + SUBSTRING(IDAVISIMPIT,5,1)
         WHERE (CDFILIAL   = @P_FILIAL)   AND
               (NRLANCTONF = @P_LANCTONF) AND
               ((CDFISCOPERIT IS NULL) OR (LEN(CDFISCOPERIT) < 3)) AND
               (@V_IDERROAVISO <> 'N')    AND
               (@V_IDCONSPARFIS <> 'N');
      END;
   END;

   SELECT @V_ERROAVISO = MAX(CONVERT(NUMERIC,IDAVISOSITEM))
   FROM ITEMPRODUTO
   WHERE (CDFILIAL   = @P_FILIAL) AND
         (NRLANCTONF = @P_LANCTONF);

   IF (@V_ERROAVISO > 0) BEGIN
      UPDATE NOTAFISCAL
      SET IDAVISOS = '1'
      WHERE (CDFILIAL   = @P_FILIAL) AND
            (NRLANCTONF = @P_LANCTONF);
   END
   ELSE BEGIN
      SELECT @V_ERROAVISO = MAX(CONVERT(NUMERIC, IDAVISIMPIT))
      FROM ITEMPROIMPOS
      WHERE (CDFILIAL   = @P_FILIAL) AND
            (NRLANCTONF = @P_LANCTONF);

      IF (@V_ERROAVISO > 0) BEGIN
         UPDATE NOTAFISCAL
         SET IDAVISOS = '1'
         WHERE (CDFILIAL   = @P_FILIAL) AND
               (NRLANCTONF = @P_LANCTONF);
      END
      ELSE BEGIN
         UPDATE NOTAFISCAL
         SET IDAVISOS = '0'
         WHERE (CDFILIAL   = @P_FILIAL) AND
               (NRLANCTONF = @P_LANCTONF);
      END;
   END;

   /*(ERRO) ITEM COM VALOR UNITARIO IGUAL A ZERO*/
   SELECT @V_IDERROAVISO = MAX(IDERROAVISOFIL)
   FROM ERROAVISONFFIL
   WHERE CDERROAVISOFIL = 'ER04'
     AND CDFILIAL = @V_CDFILIEMIT;

   IF @V_IDERROAVISO IS NULL BEGIN
      SELECT @V_IDERROAVISO = MAX(IDERROAVISO)
      FROM ERROAVISONF
      WHERE CDERROAVISO = 'ER04';
   END;

   IF @P_TIPOOPER <> '03' BEGIN
      UPDATE NOTAFISCAL
      SET IDERROS = '101'
      WHERE CDFILIAL   =  @P_FILIAL    AND
            NRLANCTONF =  @P_LANCTONF  AND
            @V_IDERROAVISO <> 'N'      AND
            NRLANCTONF = (SELECT MAX(NRLANCTONF)
                          FROM ITEMPRODUTO
                          WHERE CDFILIAL   =  @P_FILIAL   AND
                                NRLANCTONF =  @P_LANCTONF AND
                                VRUNITITEM = 0            AND
                                QTITEMPROD > 0);
   END;

   IF @P_TIPOOPER = '11' BEGIN
      SELECT @V_IDERROAVISO = MAX(IDERROAVISOFIL)
      FROM ERROAVISONFFIL
      WHERE CDERROAVISOFIL = 'ER06'
        AND CDFILIAL = @V_CDFILIEMIT;

      IF @V_IDERROAVISO IS NULL BEGIN
         SELECT @V_IDERROAVISO = MAX(IDERROAVISO)
         FROM ERROAVISONF
         WHERE CDERROAVISO = 'ER06';
      END;

      /* (ERRO) SOMA DAS SADAS SEM NOTA FISCAL DIFERE DO VALOR TOTAL DA NOTA */
      UPDATE NOTAFISCAL
      SET IDERROS = '1'+SUBSTRING(IDERROS,2,2)
      WHERE CDFILIAL   =  @P_FILIAL    AND
            NRLANCTONF =  @P_LANCTONF  AND
            @V_IDERROAVISO <> 'N'      AND
            @V_FAIXATOLER < (SELECT ABS(SUM(N.VRNOTAFISC) - NOTAFISCAL.VRNOTAFISC)
                            FROM ITEMNOTAFISC I, NOTAFISCAL N
                            WHERE I.CDFILIAL   = @P_FILIAL      AND
                                  I.NRLANCTONF = @P_LANCTONF    AND
                                  N.CDFILIAL   = I.CDFILIALIT   AND
                                  N.NRLANCTONF = I.NRLANCTONFIT);
   END;

   -- CALCULANDO PESO BRUTO DOS PRODUTOS DA NOTA FISCAL
   SELECT @V_VRPESOBRUTO = VRPBRUTOVOLU
   FROM NOTAFISCAL
   WHERE CDFILIAL   = @P_FILIAL AND
         NRLANCTONF = @P_LANCTONF;

   IF (@V_VRPESOBRUTO IS NULL) OR (@V_VRPESOBRUTO = 0) BEGIN

      SELECT @V_VRPESOBRUTO = SUM(QTITEMPROD * PR.VRPESOBRUTPR)
        FROM ITEMPRODUTO I, PRODUTO PR
       WHERE I.CDFILIAL    = @P_FILIAL
         AND I.NRLANCTONF  = @P_LANCTONF
         AND PR.CDPRODUTO  = I.CDPRODUTO;

      IF (@V_VRPESOBRUTO IS NULL) OR (@V_VRPESOBRUTO = 0) BEGIN

         SELECT @V_VRPESOBRUTO = SUM(QTITEMPROD * PA.VRPESOUNID * PR.VRFATOCONV)
         FROM ITEMPRODUTO I, PRODUTO PR, PRODUTO PA
         WHERE I.CDFILIAL    = @P_FILIAL     AND
               I.NRLANCTONF  = @P_LANCTONF   AND
               PR.CDPRODUTO  = I.CDPRODUTO   AND
               PR.CDPRODESTO = PA.CDPRODUTO;

         IF (@V_VRPESOBRUTO <> 0) BEGIN

            UPDATE NOTAFISCAL
            SET VRPBRUTOVOLU = @V_VRPESOBRUTO
            WHERE (CDFILIAL   = @P_FILIAL)   AND
                  (NRLANCTONF = @P_LANCTONF);

         END;

      END ELSE BEGIN

         UPDATE NOTAFISCAL
            SET VRPBRUTOVOLU = @V_VRPESOBRUTO
          WHERE CDFILIAL   = @P_FILIAL
            AND NRLANCTONF = @P_LANCTONF;

      END;

   END;

   -- CALCULANDO PESO LQUIDO DOS PRODUTOS DA NOTA FISCAL
   SELECT @V_VRLIQUORIG = VRPLIQUVOLU
   FROM NOTAFISCAL
   WHERE CDFILIAL   = @P_FILIAL   AND
         NRLANCTONF = @P_LANCTONF;

   IF (@V_VRLIQUORIG IS NULL) OR (@V_VRLIQUORIG = 0) BEGIN
 
     SELECT @V_IDCALCPESONF = ISNULL(IDCALCPESONF,'N')
      FROM PARAMGERAL;

      IF(@V_IDCALCPESONF = 'S') BEGIN

         SELECT @V_VRLIQUORIG = SUM(I.QTITEMPROD * ISNULL(P.VRPESOLIQUPR, 0))
           FROM ITEMPRODUTO I, PRODUTO P
          WHERE I.CDPRODUTO   = P.CDPRODUTO
            AND I.CDFILIAL    = @P_FILIAL
            AND I.NRLANCTONF  = @P_LANCTONF;

         IF (@V_VRLIQUORIG IS NOT NULL) AND (@V_VRLIQUORIG <> 0) BEGIN

            UPDATE NOTAFISCAL
               SET VRPLIQUVOLU = @V_VRLIQUORIG
             WHERE CDFILIAL   = @P_FILIAL
               AND NRLANCTONF = @P_LANCTONF;

         END;

      END;

   END;

   --ATUALIZAO DO CDIGO FISCAL DA OPERAO NA TABELA DE NOTA FISCAL
   SELECT @V_COUNT = COUNT(DISTINCT CDFISOPEITEM), @V_CDFISOPENTF = MAX(CDFISOPEITEM)
   FROM ITEMPRODUTO
   WHERE (CDFILIAL   = @P_FILIAL) AND
         (NRLANCTONF = @P_LANCTONF);

   IF (@V_COUNT > 1) BEGIN
      UPDATE NOTAFISCAL
      SET CDFISOPENTF = '***'
      WHERE CDFILIAL   = @P_FILIAL AND
            NRLANCTONF = @P_LANCTONF AND
            CDFISOPENTF IS NULL;
   END
   ELSE BEGIN
      IF (@V_COUNT = 1) BEGIN

         SELECT @V_CDFISOPENTF = MAX(CDFISOPENTF)
         FROM NOTAFISCAL
         WHERE CDFILIAL   = @P_FILIAL AND
               NRLANCTONF = @P_LANCTONF;

         IF (@V_CDFISOPENTF IS NULL) OR (@V_CDFISOPENTF = '***') BEGIN
            UPDATE NOTAFISCAL
            SET CDFISOPENTF = (SELECT MAX(CDFISOPEITEM) AS CDFISOPEITEM
                               FROM ITEMPRODUTO
                               WHERE (CDFILIAL   = @P_FILIAL) AND
                                     (NRLANCTONF = @P_LANCTONF))
            WHERE (CDFILIAL   = @P_FILIAL)   AND
                  (NRLANCTONF = @P_LANCTONF) AND
                  (ISNULL(CDFISOPENTF, '***') = '***');
         END
         ELSE BEGIN
            UPDATE ITEMPRODUTO
            SET CDFISOPEITEM = @V_CDFISOPENTF
            WHERE CDFILIAL   = @P_FILIAL   AND
                  NRLANCTONF = @P_LANCTONF;

            UPDATE ITEMPROIMPOS
            SET CDFISCOPERIT = @V_CDFISOPENTF
            WHERE CDFILIAL   = @P_FILIAL   AND
                  NRLANCTONF = @P_LANCTONF;

            UPDATE IMPOSTONF
            SET CDFISCOPERNF = @V_CDFISOPENTF
            WHERE CDFILIAL   = @P_FILIAL   AND
                  NRLANCTONF = @P_LANCTONF;
         END;
      END;
   END;

   IF NOT @V_CDINTEGRACAO IS NULL BEGIN
      --INCLUSO DOS ENCARGOS DA NF EM CASO DE IMPORTAO
      INSERT INTO ITEMENCARGO
      (CDFILIAL, NRLANCTONF, CDENCARGO, VRITEMENCA)
      (SELECT @P_FILIAL, @P_LANCTONF, CDENCARGO, CONVERT(NUMERIC, 0) AS VRITEMENCA
       FROM ENCARGO
       WHERE
       NOT EXISTS
       (SELECT CDFILIAL, NRLANCTONF, CDENCARGO, CONVERT(NUMERIC, 0) AS VRITEMENCA
        FROM ITEMENCARGO
        WHERE CDFILIAL   = @P_FILIAL AND
              NRLANCTONF = @P_LANCTONF));

      SELECT @V_IDERROAVISO = MAX(IDERROAVISO)
      FROM ERROAVISONF
      WHERE CDERROAVISO = 'ER03';

      UPDATE NOTAFISCAL
      SET IDERROS = '11'+SUBSTRING(IDERROS, 3, 1)
      WHERE CDFILIAL   =  @P_FILIAL   AND
            NRLANCTONF =  @P_LANCTONF AND
            @V_IDERROAVISO <> 'N'     AND
            @V_FAIXATOLER < (SELECT ISNULL(ABS(ISNULL(SUM(C.VRORIGREC), (NOTAFISCAL.VRNOTAFISC - MAX(I.VRIMPOSRETI))) - (NOTAFISCAL.VRNOTAFISC - MAX(I.VRIMPOSRETI))), @V_FAIXATOLER)
                            FROM CONTARECEBER C,
                                 (SELECT ISNULL(SUM(IT.VRTOTIMPONF),0) AS VRIMPOSRETI
                                  FROM IMPOSNFTOT IT, IMPOSTO I
                                  WHERE I.CDIMPOSTO    = IT.CDIMPOSTO AND
                                        IT.CDFILIAL    = @P_FILIAL    AND
                                        IT.NRLANCTONF  = @P_LANCTONF  AND
                                        I.IDDESCRFONTE <> 'A'         AND
                                        I.IDTRATIMPO   = 'R') I
                            WHERE C.CDFILIAL   = @P_FILIAL AND
                                  C.NRLANCTONF = @P_LANCTONF);
   END;

   /* ESTA ROTINA ABAIXO SERVE PARA ATUALIZAR O VALOR CONTBIL E BRUTO DOS PRODUTOS COM A DIFERENA
      DE CENTAVOS ENTRE O VALOR DOS IMPOSTOS POR TEM E A SUA RESPECTIVA TOTALIZAO. ESTA DIFERENA
       IGNORADA NO FECHAMENTO DA NF CASO O CLIENTE TRABALHE COM UM NMERO MENOR DE CASAS DECIMAIS E
      PROVOCA ERROS NA CONTABILIZAO*/

   IF (@V_NRDECITOTANF <> 2) AND (@V_IDOPERDEVONF <> 'S') BEGIN
      DECLARE C_ATUAVRCONT CURSOR FOR
         SELECT T.CDIMPOSTO, SUM(T.VRIMPOSTOIT) AS VRIMPOSTOIT, T.CDFISCALIT,
                I.IDIMPORECUP, I.CDCCTBLATIV, I.CDCCTBLPASS, I.IDTRATIMPO, I.IDTIPCONTAB
         FROM ITEMPROIMPOS T, IMPOSTO I
         WHERE T.CDFILIAL     = @P_FILIAL   AND
               T.NRLANCTONF   = @P_LANCTONF AND
               T.NRITPROIMPOS = '1'         AND
               T.CDIMPOSTO    = I.CDIMPOSTO
         GROUP BY T.CDIMPOSTO, T.CDFISCALIT, I.IDIMPORECUP,
                  I.CDCCTBLATIV, I.CDCCTBLPASS, I.IDTRATIMPO, I.IDTIPCONTAB;
      OPEN C_ATUAVRCONT;
      FETCH NEXT FROM C_ATUAVRCONT INTO @V_ATUAVR_CDIMPOSTO,   @V_ATUAVR_VRIMPOSTOIT, @V_ATUAVR_CDFISCALIT,
                                        @V_ATUAVR_IDIMPORECUP, @V_ATUAVR_CDCCTBLATIV, @V_ATUAVR_CDCCTBLPASS,
                                        @V_ATUAVR_IDTRATIMPO,  @V_ATUAVR_IDTIPCONTAB;

      WHILE (@@FETCH_STATUS = 0) BEGIN

         SELECT @V_VRDIFERENCA = SUM(VRTOTIMPONF) - @V_ATUAVR_VRIMPOSTOIT
         FROM IMPOSNFTOT
         WHERE CDFILIAL   = @P_FILIAL   AND
               NRLANCTONF = @P_LANCTONF AND
               CDIMPOSTO  = @V_ATUAVR_CDIMPOSTO;

         SELECT @V_VRBRUTO = SUM(VRBRUTITEM), @V_VRCONTAB = SUM(VRCONTITEM)
         FROM ITEMPRODUTO I, ITEMPROIMPOS T
         WHERE T.CDFILIAL     = I.CDFILIAL    AND
               T.NRLANCTONF   = I.NRLANCTONF  AND
               T.NRSEQITPROD  = I.NRSEQITPROD AND
               T.CDFILIAL     = @P_FILIAL     AND
               T.NRLANCTONF   = @P_LANCTONF   AND
               T.NRITPROIMPOS = '1'           AND
               T.CDIMPOSTO    = @V_ATUAVR_CDIMPOSTO;

         IF @V_VRDIFERENCA <> 0 BEGIN
            IF (@V_ATUAVR_IDTRATIMPO = 'A') BEGIN
               IF ((@V_ATUAVR_IDIMPORECUP = 'S')  AND (@V_ATUAVR_CDFISCALIT = '1')) OR
                  ((@V_ATUAVR_IDIMPORECUP <> 'S') AND (NOT @V_ATUAVR_CDCCTBLPASS IS NULL)) AND
                  (@V_ATUAVR_IDTIPCONTAB = 'D') BEGIN

               SET @V_ICMS = NULL;
               DECLARE C_ICMS CURSOR FOR
                  SELECT CDIMPOSTO
                    FROM IMPOSTONFE N, IMPOSTO I
                   WHERE N.CDIMPOSTONFE = I.CDIMPOSTONFE
                     AND N.CDIMPOSTONFE = '00'
                     AND I.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
               OPEN C_ICMS;
               FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
               WHILE (@@FETCH_STATUS = 0) BEGIN
                  SET @V_ICMS = 'S';
                  FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
               END;
               CLOSE C_ICMS;
               DEALLOCATE C_ICMS;

               IF ((@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV')) AND (@V_ICMS = 'S') BEGIN
                     UPDATE ITEMPRODUTO
                     SET VRBRUTITEM = ROUND(VRBRUTITEM + ((@V_VRDIFERENCA / @V_VRBRUTO)  * VRBRUTITEM),2,2)
                     WHERE EXISTS(SELECT CDFILIAL, NRLANCTONF, NRSEQITPROD
                                  FROM ITEMPROIMPOS T
                                  WHERE T.CDFILIAL    = @P_FILIAL               AND
                                        T.NRLANCTONF  = @P_LANCTONF             AND
                                        T.NRSEQITPROD = ITEMPRODUTO.NRSEQITPROD AND
                                        T.CDIMPOSTO   = @V_ATUAVR_CDIMPOSTO);
                  END
                  ELSE BEGIN
                     UPDATE ITEMPRODUTO
                     SET VRBRUTITEM = ROUND(VRBRUTITEM + ((@V_VRDIFERENCA / @V_VRBRUTO)  * VRBRUTITEM),2)
                     WHERE EXISTS(SELECT CDFILIAL, NRLANCTONF, NRSEQITPROD
                                  FROM ITEMPROIMPOS T
                                  WHERE T.CDFILIAL    = @P_FILIAL               AND
                                        T.NRLANCTONF  = @P_LANCTONF             AND
                                        T.NRSEQITPROD = ITEMPRODUTO.NRSEQITPROD AND
                                        T.CDIMPOSTO   = @V_ATUAVR_CDIMPOSTO);
                  END;
               END
               ELSE BEGIN
                  SET @V_ICMS = NULL;
                  DECLARE C_ICMS CURSOR FOR
                     SELECT CDIMPOSTO
                       FROM IMPOSTONFE N, IMPOSTO I
                      WHERE N.CDIMPOSTONFE = I.CDIMPOSTONFE
                        AND N.CDIMPOSTONFE = '00'
                        AND I.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
                  OPEN C_ICMS;
                  FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
                  WHILE (@@FETCH_STATUS = 0) BEGIN
                     SET @V_ICMS = 'S';
                     FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
                  END;
                  CLOSE C_ICMS;
                  DEALLOCATE C_ICMS;

                  IF ((@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV')) AND (@V_ICMS = 'S') BEGIN
                     UPDATE ITEMPRODUTO
                     SET VRBRUTITEM = ROUND(VRBRUTITEM + ((@V_VRDIFERENCA / @V_VRBRUTO)  * VRBRUTITEM),2,2),
                         VRCONTITEM = ROUND(VRCONTITEM + ((@V_VRDIFERENCA / @V_VRCONTAB) * VRCONTITEM),2,2)
                     WHERE EXISTS(SELECT CDFILIAL, NRLANCTONF, NRSEQITPROD
                                  FROM ITEMPROIMPOS T
                                  WHERE T.CDFILIAL    = @P_FILIAL               AND
                                        T.NRLANCTONF  = @P_LANCTONF             AND
                                        T.NRSEQITPROD = ITEMPRODUTO.NRSEQITPROD AND
                                        T.CDIMPOSTO   = @V_ATUAVR_CDIMPOSTO);
                  END
                  ELSE BEGIN
                     UPDATE ITEMPRODUTO
                     SET VRBRUTITEM = ROUND(VRBRUTITEM + ((@V_VRDIFERENCA / @V_VRBRUTO)  * VRBRUTITEM),2),
                         VRCONTITEM = ROUND(VRCONTITEM + ((@V_VRDIFERENCA / @V_VRCONTAB) * VRCONTITEM),2)
                     WHERE EXISTS(SELECT CDFILIAL, NRLANCTONF, NRSEQITPROD
                                  FROM ITEMPROIMPOS T
                                  WHERE T.CDFILIAL    = @P_FILIAL               AND
                                        T.NRLANCTONF  = @P_LANCTONF             AND
                                        T.NRSEQITPROD = ITEMPRODUTO.NRSEQITPROD AND
                                        T.CDIMPOSTO   = @V_ATUAVR_CDIMPOSTO);
                  END;
               END;
            END
            ELSE IF (@V_ATUAVR_IDTRATIMPO = 'D') BEGIN
               IF ((@V_ATUAVR_IDIMPORECUP = 'S') AND (@V_ATUAVR_CDFISCALIT = '1'))  OR
                  ((@V_ATUAVR_IDIMPORECUP <> 'S') AND (@V_ATUAVR_CDCCTBLATIV IS NOT NULL)) AND
                  (@V_ATUAVR_IDTIPCONTAB = 'D') BEGIN

                  SET @V_ICMS = NULL;
                  DECLARE C_ICMS CURSOR FOR
                     SELECT CDIMPOSTO
                       FROM IMPOSTONFE N, IMPOSTO I
                      WHERE N.CDIMPOSTONFE = I.CDIMPOSTONFE
                        AND N.CDIMPOSTONFE = '00'
                        AND I.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
                  OPEN C_ICMS;
                  FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
                  WHILE (@@FETCH_STATUS = 0) BEGIN
                     SET @V_ICMS = 'S';
                     FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
                  END;
                  CLOSE C_ICMS;
                  DEALLOCATE C_ICMS;

                  IF ((@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV')) AND (@V_ICMS = 'S') BEGIN
                     UPDATE ITEMPRODUTO
                     SET VRBRUTITEM = ROUND(VRBRUTITEM - ((@V_VRDIFERENCA / @V_VRBRUTO)  * VRBRUTITEM),2,2)
                     WHERE EXISTS(SELECT CDFILIAL, NRLANCTONF, NRSEQITPROD
                                  FROM ITEMPROIMPOS T
                                  WHERE T.CDFILIAL    = @P_FILIAL               AND
                                        T.NRLANCTONF  = @P_LANCTONF             AND
                                        T.NRSEQITPROD = ITEMPRODUTO.NRSEQITPROD AND
                                        T.CDIMPOSTO   = @V_ATUAVR_CDIMPOSTO);
                  END
                  ELSE BEGIN
                     UPDATE ITEMPRODUTO
                     SET VRBRUTITEM = ROUND(VRBRUTITEM - ((@V_VRDIFERENCA / @V_VRBRUTO)  * VRBRUTITEM),2)
                     WHERE EXISTS(SELECT CDFILIAL, NRLANCTONF, NRSEQITPROD
                                  FROM ITEMPROIMPOS T
                                  WHERE T.CDFILIAL    = @P_FILIAL               AND
                                        T.NRLANCTONF  = @P_LANCTONF             AND
                                        T.NRSEQITPROD = ITEMPRODUTO.NRSEQITPROD AND
                                        T.CDIMPOSTO   = @V_ATUAVR_CDIMPOSTO);
                  END;
               END
               ELSE BEGIN
                  SET @V_ICMS = NULL;
                  DECLARE C_ICMS CURSOR FOR
                     SELECT CDIMPOSTO
                       FROM IMPOSTONFE N, IMPOSTO I
                      WHERE N.CDIMPOSTONFE = I.CDIMPOSTONFE
                        AND N.CDIMPOSTONFE = '00'
                        AND I.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
                  OPEN C_ICMS;
                  FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
                  WHILE (@@FETCH_STATUS = 0) BEGIN
                     SET @V_ICMS = 'S';
                     FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
                  END;
                  CLOSE C_ICMS;
                  DEALLOCATE C_ICMS;

                  IF ((@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV')) AND (@V_ICMS = 'S') BEGIN
                     UPDATE ITEMPRODUTO
                     SET VRBRUTITEM = ROUND(VRBRUTITEM - ((@V_VRDIFERENCA / @V_VRBRUTO)  * VRBRUTITEM),2,2),
                         VRCONTITEM = ROUND(VRCONTITEM - ((@V_VRDIFERENCA / @V_VRCONTAB) * VRCONTITEM),2,2)
                     WHERE EXISTS(SELECT CDFILIAL, NRLANCTONF, NRSEQITPROD
                                  FROM ITEMPROIMPOS T
                                  WHERE T.CDFILIAL    = @P_FILIAL               AND
                                        T.NRLANCTONF  = @P_LANCTONF             AND
                                        T.NRSEQITPROD = ITEMPRODUTO.NRSEQITPROD AND
                                        T.CDIMPOSTO   = @V_ATUAVR_CDIMPOSTO);
                  END
                  ELSE BEGIN
                     UPDATE ITEMPRODUTO
                     SET VRBRUTITEM = ROUND(VRBRUTITEM - ((@V_VRDIFERENCA / @V_VRBRUTO)  * VRBRUTITEM),2),
                         VRCONTITEM = ROUND(VRCONTITEM - ((@V_VRDIFERENCA / @V_VRCONTAB) * VRCONTITEM),2)
                     WHERE EXISTS(SELECT CDFILIAL, NRLANCTONF, NRSEQITPROD
                                  FROM ITEMPROIMPOS T
                                  WHERE T.CDFILIAL    = @P_FILIAL               AND
                                        T.NRLANCTONF  = @P_LANCTONF             AND
                                        T.NRSEQITPROD = ITEMPRODUTO.NRSEQITPROD AND
                                        T.CDIMPOSTO   = @V_ATUAVR_CDIMPOSTO);
                  END;
               END;
            END
            ELSE IF (@V_ATUAVR_IDTRATIMPO = 'R') BEGIN
               IF (@V_ATUAVR_IDIMPORECUP = 'S') BEGIN
                  IF (@V_ATUAVR_CDCCTBLATIV IS NULL) OR
                     (@V_ATUAVR_CDFISCALIT <> '1') BEGIN

                     SET @V_IMPOCONTAB = - @V_VRIMPOSTO;
                  END;
               END
               ELSE BEGIN
                  IF (@V_ATUAVR_CDCCTBLATIV IS NULL) BEGIN
                     SET @V_IMPOCONTAB = - @V_VRIMPOSTO;
                  END;
               END;

               IF (@V_ATUAVR_IDTIPCONTAB = 'D') BEGIN
                  SET @V_ICMS = NULL;
                  DECLARE C_ICMS CURSOR FOR
                     SELECT CDIMPOSTO
                       FROM IMPOSTONFE N, IMPOSTO I
                      WHERE N.CDIMPOSTONFE = I.CDIMPOSTONFE
                        AND N.CDIMPOSTONFE = '00'
                        AND I.CDIMPOSTO = @V_INCIDEN_CDIMPOTEMP;
                  OPEN C_ICMS;
                  FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
                  WHILE (@@FETCH_STATUS = 0) BEGIN
                     SET @V_ICMS = 'S';
                     FETCH NEXT FROM C_ICMS INTO @V_IMPOSTOTMP;
                  END;
                  CLOSE C_ICMS;
                  DEALLOCATE C_ICMS;

                  IF ((@V_IDSISTEMA = 'VND') OR (@V_IDSISTEMA = 'PDV')) AND (@V_ICMS = 'S') BEGIN
                     UPDATE ITEMPRODUTO
                     SET VRCONTITEM = ROUND(VRCONTITEM + ((@V_VRDIFERENCA / @V_VRCONTAB) * VRCONTITEM),2,2)
                     WHERE EXISTS(SELECT CDFILIAL, NRLANCTONF, NRSEQITPROD
                                  FROM ITEMPROIMPOS T
                                  WHERE T.CDFILIAL    = @P_FILIAL               AND
                                        T.NRLANCTONF  = @P_LANCTONF             AND
                                        T.NRSEQITPROD = ITEMPRODUTO.NRSEQITPROD AND
                                        T.CDIMPOSTO   = @V_ATUAVR_CDIMPOSTO);
                  END
                  ELSE BEGIN
                     UPDATE ITEMPRODUTO
                     SET VRCONTITEM = ROUND(VRCONTITEM + ((@V_VRDIFERENCA / @V_VRCONTAB) * VRCONTITEM),2)
                     WHERE EXISTS(SELECT CDFILIAL, NRLANCTONF, NRSEQITPROD
                                  FROM ITEMPROIMPOS T
                                  WHERE T.CDFILIAL    = @P_FILIAL               AND
                                        T.NRLANCTONF  = @P_LANCTONF             AND
                                        T.NRSEQITPROD = ITEMPRODUTO.NRSEQITPROD AND
                                        T.CDIMPOSTO   = @V_ATUAVR_CDIMPOSTO);
                  END;
               END;
            END;
         END;
         FETCH NEXT FROM C_ATUAVRCONT INTO @V_ATUAVR_CDIMPOSTO,   @V_ATUAVR_VRIMPOSTOIT, @V_ATUAVR_CDFISCALIT,
                                           @V_ATUAVR_IDIMPORECUP, @V_ATUAVR_CDCCTBLATIV, @V_ATUAVR_CDCCTBLPASS,
                                           @V_ATUAVR_IDTRATIMPO,  @V_ATUAVR_IDTIPCONTAB;
      END;
      CLOSE C_ATUAVRCONT;
      DEALLOCATE C_ATUAVRCONT;
   END;
   SELECT TOP 1
          @V_CDFILIALPED = CDFILIALPED,
          @V_NRPEDIDO = NRPEDIDO
     FROM ITEMPRODUTO
    WHERE CDFILIAL = @P_FILIAL
      AND NRLANCTONF = @P_LANCTONF;
   
   IF (@V_CDFILIALPED IS NOT NULL) AND (@V_NRPEDIDO IS NOT NULL) BEGIN
      SELECT @V_DADOSADICENDPED = DADOSADICENDPED
        FROM (SELECT ('DADO PARA ENTREGA - CLIENTE: '+C.NRINSJURCLIE+' '+C.NMRAZSOCCLIE+
                      ' - ENDEREO: '+ D.DSENDEPED+
                      ' - BAIRRO: '+D.NMBAIRROPED+
                      ' - MUNICIPIO: '+D.NMMUNIPED+
                      ' - ESTADO: '+D.SGESTADOPED+
                      ' - CEP: '+NRCEPPED) AS DADOSADICENDPED
                FROM DADOSENDPED D, CLIENTE C
               WHERE D.CDCLIENTE = C.CDCLIENTE
                 AND C.IDENDEMISCLI <> D.IDTPENDECLIE
                 AND D.CDFILIAL = @V_CDFILIALPED
                 AND NRPEDIDO = @V_NRPEDIDO) DEP
       WHERE NOT EXISTS(SELECT DSDADOADIC
                          FROM DADOSADIC                                     
                         WHERE CDFILIAL   = @P_FILIAL
                           AND NRLANCTONF = @P_LANCTONF
                           AND DSDADOADIC = DEP.DADOSADICENDPED);

      IF @V_DADOSADICENDPED IS NOT NULL BEGIN
         INSERT INTO DADOSADIC
            (CDFILIAL, NRLANCTONF, NRDADOADIC, DSDADOADIC)
         VALUES
            (@P_FILIAL, @P_LANCTONF, @V_DADOADIC, SUBSTRING(@V_DADOSADICENDPED, 1, 250));

         SET @V_DADOADIC = RIGHT(REPLICATE('0',3) + RTRIM(CONVERT(VARCHAR, CONVERT(NUMERIC, @V_DADOADIC) + 1)),3);
      END;
   END ELSE BEGIN
      DECLARE C_ENDDADOSADIC CURSOR FOR
                             SELECT DSDADOADIC FROM (
                             SELECT '' AS NRDADOADIC,'999' AS CDMENSAGEM,('DESTINO - FILIAL: '+F.NRINSJURFILI+' '+F.NMFILIAL+' -  ENDEREO: '+
                                    E.DSENDEFILI+' - BAIRRO: '+E.NMBAIRFILI+' - MUNICIPIO: '+M.NMMUNICIPIO+' - ESTADO: '+M.SGESTADO) AS DSDADOADIC
                               FROM NOTAFISCAL N INNER JOIN ENDEFILI E ON (CASE WHEN N.IDENTRSAIDOP = 'S' THEN N.CDFILIRECE ELSE N.CDFILIEMIT END) = E.CDFILIAL
                                                 INNER JOIN FILIAL F   ON E.CDFILIAL   = F.CDFILIAL
                                                 INNER JOIN MUNICIPIO M ON E.CDMUNICIPIO = M.CDMUNICIPIO
                                                                       AND E.CDPAIS      = M.CDPAIS
                                                                       AND E.SGESTADO    = M.SGESTADO
                              WHERE N.CDFILIAL     = @P_FILIAL
                                AND N.NRLANCTONF   = @P_LANCTONF
                                AND N.IDORIGDESTNF = 'L'
                                AND E.IDTPENDEFILI = 'T'
                             UNION ALL
                             SELECT '' AS NRDADOADIC, '999' AS CDMENSAGEM,('DESTINO - CLIENTE: '+C.NRINSJURCLIE+' '+C.NMRAZSOCCLIE+' -  ENDEREO: '+
                                    E.DSENDECLIE+' - BAIRRO: '+E.NMBAIRCLIE+' - MUNICIPIO: '+M.NMMUNICIPIO+' - ESTADO: '+M.SGESTADO) AS DSDADOADIC
                               FROM NOTAFISCAL N INNER JOIN ENDECLIE E ON N.CDCLIENTE = E.CDCLIENTE
                                                 INNER JOIN CLIENTE  C ON E.CDCLIENTE = C.CDCLIENTE
                                                 INNER JOIN MUNICIPIO M ON E.CDMUNICIPIO = M.CDMUNICIPIO
                                                                       AND E.CDPAIS      = M.CDPAIS
                                                                       AND E.SGESTADO    = M.SGESTADO
                              WHERE N.CDFILIAL     = @P_FILIAL
                                AND N.NRLANCTONF   = @P_LANCTONF
                                AND E.IDTPENDECLIE = 'T'
                             UNION ALL
                             SELECT '' AS NRDADOADIC, '999' AS CDMENSAGEM,('DESTINO - FORNECEDOR: '+F.NRINSJURFORN+' '+F.NMRAZSOCFORN+' -  ENDEREO: '+
                                    E.DSENDEFORN+' - BAIRRO: '+E.NMBAIRFORN+' - MUNICIPIO: '+M.NMMUNICIPIO+' - ESTADO: '+M.SGESTADO) AS DSDADOADIC
                               FROM NOTAFISCAL N INNER JOIN ENDEFORN E   ON N.CDFORNECED = E.CDFORNECED
                                                 INNER JOIN FORNECEDOR F ON E.CDFORNECED = F.CDFORNECED
                                                 INNER JOIN MUNICIPIO M  ON E.CDMUNICIPIO = M.CDMUNICIPIO
                                                                        AND E.CDPAIS      = M.CDPAIS
                                                                        AND E.SGESTADO    = M.SGESTADO
                              WHERE N.CDFILIAL     = @P_FILIAL
                                AND N.NRLANCTONF   = @P_LANCTONF
                                AND E.IDTPENDEFORN = 'T') I
                              WHERE NOT EXISTS(SELECT DSDADOADIC
                                                 FROM DADOSADIC
                                                WHERE (CDFILIAL   = @P_FILIAL)
                                                  AND (NRLANCTONF = @P_LANCTONF)
                                                  AND (DSDADOADIC = I.DSDADOADIC))
      OPEN C_ENDDADOSADIC;
      FETCH NEXT FROM C_ENDDADOSADIC INTO @V_DSDADOADIC;

      WHILE (@@FETCH_STATUS = 0) BEGIN      
         INSERT INTO DADOSADIC(CDFILIAL, NRLANCTONF, NRDADOADIC, CDMENSAGEM, DSDADOADIC)
                        VALUES(@P_FILIAL, @P_LANCTONF, @V_DADOADIC, @V_MENSINSC_CDMENSAGEM, SUBSTRING(@V_DSDADOADIC,1,250));

          SET @V_DADOADIC = RIGHT(REPLICATE('0',3) + RTRIM(CONVERT(VARCHAR, CONVERT(NUMERIC, @V_DADOADIC) + 1)),3);
          FETCH NEXT FROM C_ENDDADOSADIC INTO @V_DSDADOADIC;   
      END;
      CLOSE C_ENDDADOSADIC;
      DEALLOCATE C_ENDDADOSADIC;
   END;

   /*PREENCHENDO A TABELA DADOSADIC DE ACORDO COM OS VALORES DO ADICIONAL DE ALQUOTA DO FECP*/
   DELETE 
     FROM DADOSADIC
    WHERE CDFILIAL = @P_FILIAL
      AND NRLANCTONF = @P_LANCTONF
      AND UPPER(DSDADOADIC) LIKE 'ADICIONAL DE ALQUOTA DO IMPOSTO % DE % (FUNDO ESTADUAL DE COMBATE A POBREZA):%';

   SET @V_STRVRADICALIQFECP = NULL;
   SET @V_STRVRADICFECP = NULL;
   
   DECLARE C_VRADICALIQFECP CURSOR FOR SELECT CASE P.CDIMPOSTONFE WHEN '00' THEN 'ICMS' WHEN '80' THEN 'ICMS-ST' END AS CDIMPOSTONFE, 
                                              I.VRADICALIQFECP, 
                                              SUM(ISNULL(I.VRADICFECP, 0)) AS VRADICFECP
                                         FROM ITEMPROIMPOS I JOIN IMPOSTO P ON (I.CDIMPOSTO = P.CDIMPOSTO)
                                        WHERE I.CDFILIAL = @P_FILIAL
                                          AND I.NRLANCTONF = @P_LANCTONF
                                          AND I.VRADICALIQFECP IS NOT NULL
                                        GROUP BY P.CDIMPOSTONFE, 
                                              I.VRADICALIQFECP
   OPEN C_VRADICALIQFECP;
   FETCH NEXT FROM C_VRADICALIQFECP INTO @V_VRADICALIQFECP_VRADICALIQFECP, 
                                         @V_VRADICALIQFECP_VRADICFECP,
                                         @V_VRADICALIQFECP_CDIMPOSTONFE;
   WHILE (@@FETCH_STATUS = 0) BEGIN
      SELECT @V_STRVRADICALIQFECP = CASE SUBSTRING(LTRIM(CONVERT(DECIMAL(13,2), @V_VRADICALIQFECP_VRADICALIQFECP)),1,1) WHEN '.' THEN '0' + LTRIM(CONVERT(DECIMAL(13,2), @V_VRADICALIQFECP_VRADICALIQFECP)) ELSE LTRIM(CONVERT(DECIMAL(13,2), @V_VRADICALIQFECP_VRADICALIQFECP)) END,
             @V_STRVRADICFECP = CASE SUBSTRING(LTRIM(CONVERT(DECIMAL(13,2), @V_VRADICALIQFECP_VRADICFECP)),1,1) WHEN '.' THEN '0' + LTRIM(CONVERT(DECIMAL(13,2), @V_VRADICALIQFECP_VRADICFECP)) ELSE LTRIM(CONVERT(DECIMAL(13,2), @V_VRADICALIQFECP_VRADICFECP)) END;
      INSERT INTO DADOSADIC
         (CDFILIAL, 
          NRLANCTONF, 
          NRDADOADIC, 
          DSDADOADIC)
      VALUES
         (@P_FILIAL, 
          @P_LANCTONF, 
          @V_DADOADIC,
          'Adicional de alquota do imposto '+@V_VRADICALIQFECP_CDIMPOSTONFE+' de '+@V_STRVRADICALIQFECP+'% (Fundo Estadual de Combate a Pobreza): R$ '+@V_STRVRADICFECP);

      SET @V_DADOADIC = RIGHT(REPLICATE('0',3) + RTRIM(CONVERT(VARCHAR, CONVERT(NUMERIC, @V_DADOADIC) + 1)),3);
      FETCH NEXT FROM C_VRADICALIQFECP INTO @V_VRADICALIQFECP_VRADICALIQFECP, 
                                            @V_VRADICALIQFECP_VRADICFECP,
                                            @V_VRADICALIQFECP_CDIMPOSTONFE;
   END;
   CLOSE C_VRADICALIQFECP;
   DEALLOCATE C_VRADICALIQFECP;

   IF NOT(@P_LANCESTQ IS NULL) AND (@V_IDCTRLESTQ <> 'N') BEGIN
      /* INSERIDO POR LUCIANA CORREA PARA O SISTEMA DE PDV */
      IF (@V_IDSISTEMA <> 'VMN') BEGIN
         SELECT NRCTRLMOVEST = @V_NRCTRLMOVEST,
                CDFILIALENTR = @V_CDFILIALENTR,
                NRLANESTENTR = @V_NRLANESTENTR
           FROM CTRLMOVIESTQ
          WHERE CDFILIALSAID = @P_FILIAL
            AND NRLANESTSAID = @P_LANCESTQ;
         
         IF @V_NRCTRLMOVEST IS NOT NULL BEGIN
            DELETE 
              FROM CTRLMOVIESTQ
             WHERE CDFILIAL = @V_CDFILIEMIT
               AND NRCTRLMOVEST = @V_NRCTRLMOVEST;
            
            DELETE 
              FROM ITLANCTOEST
             WHERE CDFILIAL = @V_CDFILIALENTR
               AND NRLANCESTQ = @V_NRLANESTENTR;

            DELETE 
              FROM LANCTOESTOQ
             WHERE CDFILIAL = @V_CDFILIALENTR
               AND NRLANCESTQ = @V_NRLANESTENTR;

         END;

         DELETE FROM ITLANCTOEST
         WHERE CDFILIAL   = @P_FILIAL AND
               NRLANCESTQ = @P_LANCESTQ;

         DELETE FROM LANCTOESTOQ
         WHERE CDFILIAL   = @P_FILIAL AND
               NRLANCESTQ = @P_LANCESTQ;

         DELETE FROM LANCTOESTOQ
         WHERE CDFILIAL   = @P_FILIAL AND
               NRLANCTONF = @P_LANCTONF;
      END
      ELSE BEGIN
         UPDATE LANCTOESTOQ
         SET DTLANCESTQ = @P_INIVALID
         WHERE CDFILIAL   = @P_FILIAL AND
               NRLANCESTQ = @P_LANCESTQ;
      END;

      SELECT @V_NMTIPOOPER = MAX(T.NMTIPOOPER), @V_NMFILIRECE = MAX(F.NMFILIAL)
      FROM TIPOOPERAC T,
           NOTAFISCAL N LEFT JOIN FILIAL F ON (N.CDFILIRECE = F.CDFILIAL)
      WHERE
         (N.CDFILIAL     = @P_FILIAL)      AND
         (N.NRLANCTONF   = @P_LANCTONF)    AND
         (N.CDTIPOOPER   = T.CDTIPOOPER)   AND
         (N.IDENTRSAIDOP = T.IDENTRSAIDOP);

      IF @V_IDORIGDESTNF = 'L' BEGIN
         SET @V_DESCLANC = 'NF: '+@P_LANCTONF+' - '+SUBSTRING(@V_NMTIPOOPER,1,25)+' - '+SUBSTRING(@V_NMFILIRECE,1,15);
      END
      ELSE BEGIN
         SET @V_DESCLANC = 'LANC. ORIGEM: '+@V_NRINSJURNF+' N'+@P_LANCTONF+' SERIE '+@V_SERIE;
      END;

      SELECT @V_COUNT = COUNT(*)
      FROM LANCTOESTOQ
      WHERE CDFILIAL   = @P_FILIAL AND
            NRLANCESTQ = @P_LANCESTQ;

      IF @V_COUNT = 0 BEGIN
         INSERT INTO LANCTOESTOQ
            (CDFILIAL,NRLANCESTQ,NRLANCTONF,DSLANCESTQ,IDTPLANCTO,DTLANCESTQ,CDOPERADOR, CDFILIMOVI)
         VALUES
            (@P_FILIAL, @P_LANCESTQ, @P_LANCTONF, @V_DESCLANC, 'S', @P_INIVALID, @P_CDOPERADOR, @V_CDFILIEMIT);
      END;

      IF (@V_IDOPERDEVONF = 'S') BEGIN
         SET @V_TIPOMOVI = '5';
      END
      ELSE BEGIN
         SET @V_TIPOMOVI = '4';
      END;

      IF (@V_IDSISTEMA = 'EXP') BEGIN
         SELECT @V_IDRETPROEXP = ISNULL(MAX(IDRETPROEXP),1)
           FROM PAREXPEDICAO
          WHERE CDFILIAL = @V_CDFILIEMIT;
      END;

      IF (@V_IDSISTEMA = 'VND') BEGIN
         SELECT @V_CDFILIMOVI = CDFILIMOVI
         FROM LANCTOESTOQ
         WHERE CDFILIAL   = @P_FILIAL AND
               NRLANCTONF = @P_LANCTONF;

         SELECT @V_IDATUEST = ISNULL(MAX(IDATUEST),1)
         FROM PARAVEND
         WHERE CDFILIAL = @V_CDFILIMOVI;
      END;

      IF ((@V_IDSISTEMA = 'EXP') AND (@V_IDRETPROEXP = '2')) OR ((@V_IDSISTEMA = 'VND') AND (@V_IDATUEST = '1')) BEGIN
         DECLARE C_ITLANCTOEST CURSOR FOR
            SELECT NRSEQITPROD,
                   IP.CDPRODUTO,
                   VRUNITITEM,
                   VRTOTAITEM,
                   ISNULL(CDFILIMOVI, CDFILIEMIT) AS CDFILIMOVI,
                   QTITEMPROD,
                   CDPRODESTO,
                   VRBRUTITEM,
                   VRDESCITEM,
                   VRCONTITEM,
                   ISNULL(IP.CDALMOXARIFE,' ') AS CDALMOXARIFE,
                   ISNULL(IP.CDLOCALESTOQ,' ') AS CDLOCALESTOQ,
                   ISNULL(NRLOTEESTQ,' ') AS NRLOTEESTQ,
                   ISNULL(NRSUBLOTE,' ') AS NRSUBLOTE, IDCNTRESTOQ,
                   IP.NRPEDIDO,
                   IP.NRITEMPED,
                   CDARVPROD,
                   NMPRODUTO
            FROM ITEMPRODUTO IP, PRODUTO P, PRODFILI PF, NOTAFISCAL N
            WHERE IP.CDFILIAL    = @P_FILIAL     AND
                  IP.NRLANCTONF  = @P_LANCTONF   AND
                  IP.NRLANCTONF  = N.NRLANCTONF  AND
                  IP.CDFILIAL    = N.CDFILIAL    AND
                  P.CDPRODUTO    = IP.CDPRODUTO  AND
                  PF.CDFILIAL    = @V_CDFILIEMIT AND
                  PF.CDPRODUTO   = P.CDPRODESTO  ;

         OPEN C_ITLANCTOEST;
         FETCH NEXT FROM C_ITLANCTOEST INTO @V_ITLANCT_NRSEQITPROD, @V_ITLANCT_CDPRODUTO, @V_ITLANCT_VRUNITITEM,
                         @V_ITLANCT_VRTOTAITEM,   @V_ITLANCT_CDFILIMOVI, @V_ITLANCT_QTITEMPROD, @V_ITLANCT_CDPRODESTO,
                         @V_ITLANCT_VRBRUTITEM,   @V_ITLANCT_VRDESCITEM, @V_ITLANCT_VRCONTITEM,
                         @V_ITLANCT_CDALMOXARIFE, @V_ITLANCT_CDLOCALESTOQ, @V_ITLANCT_NRLOTEESTQ,
                         @V_ITLANCT_NRSUBLOTE,    @V_IDCNTRESTOQ, @V_ITLANCT_NRPEDIDO, @V_ITLANCT_NRITEMPED;

         WHILE (@@FETCH_STATUS = 0) BEGIN
            IF (@V_IDCNTRESTOQ = 'S') BEGIN
               UPDATE ITEMPRODUTO
               SET CDPRODMOVI = @V_ITLANCT_CDPRODESTO
               WHERE (CDFILIAL    = @P_FILIAL)    AND
                     (NRLANCTONF  = @P_LANCTONF ) AND
                     (NRSEQITPROD = @V_ITLANCT_NRSEQITPROD);
            END;

            IF (@V_IDUTILALMOX <> 'S' AND  @V_IDUTILLCESTQ <> 'S' AND @V_IDUTILLOTE <> 'S') BEGIN
               UPDATE ITEMPRODUTO
               SET CDALMOXARIFE  = ' ',
                   CDLOCALESTOQ  = ' ',
                   NRLOTEESTQ    = ' ',
                   NRSUBLOTE     = ' '
               WHERE (CDFILIAL     = @P_FILIAL)    AND
                     (NRLANCTONF   = @P_LANCTONF ) AND
                     (NRSEQITPROD  = @V_ITLANCT_NRSEQITPROD)  AND
                     ((CDALMOXARIFE IS NULL)       OR
                      (CDLOCALESTOQ IS NULL)       OR
                      (NRLOTEESTQ   IS NULL)       OR
                      (NRSUBLOTE    IS NULL));
            END;

            IF (@V_IDSISTEMA = 'EXP') BEGIN
               SELECT @V_IDTPCOMPPROD = ISNULL(IDTPCOMPPROD,'F')
                 FROM PARAMPEDIDO
                WHERE
                  CDFILIAL  = @P_FILIAL;

                IF @V_IDTPCOMPPROD IS NULL BEGIN
                   SET @V_IDTPCOMPPROD = 'F';
                END;
            END
            ELSE BEGIN
               SET @V_IDTPCOMPPROD = 'F';
            END;



            SELECT @V_EXISTE_ROT = COUNT(*)
            FROM   ROTFABLOCAL
            WHERE  CDFILIAL  = @V_ITLANCT_CDFILIMOVI AND
                   CDPRODUTO = @V_ITLANCT_CDPRODUTO;

            IF (@V_EXISTE_ROT > 0)AND( @V_IDTPCOMPPROD = 'F' ) BEGIN
               SET @V_EXISTE_ROT = @V_EXISTE_ROT;

               EXEC INSERE_SUBPRODMAN @P_FILIAL, @P_LANCESTQ, @P_TIPOOPER, @V_ITLANCT_CDPRODUTO,
                                         @V_ITLANCT_QTITEMPROD,
                                         @V_ITLANCT_VRTOTAITEM, @V_ITLANCT_VRDESCITEM,
                                         @V_ITLANCT_VRBRUTITEM, @V_ITLANCT_VRCONTITEM,
                                         @V_VRTOTALANCTO, @V_QTDELANCTO, @V_TIPOMOVI, @P_INIVALID,
                                         @V_ITLANCT_CDPRODESTO,
                                         @V_ITLANCT_NRPEDIDO,
                                         @V_ITLANCT_NRITEMPED,
                                         @V_IDTPCOMPPROD,
                                         @V_ITLANCT_CDALMOXARIFE,
                                         @V_ITLANCT_CDLOCALESTOQ;
            END
            ELSE BEGIN

               SELECT @V_EXISTE_ROT = COUNT(*)
               FROM   ROTFABRICA
               WHERE  CDPRODUTO = @V_ITLANCT_CDPRODUTO;
               IF (@V_EXISTE_ROT > 0)AND( @V_IDTPCOMPPROD = 'F' )BEGIN
                  SET @V_EXISTE_ROT = @V_EXISTE_ROT;

                  EXEC INSERE_SUBPRODMAN @P_FILIAL, @P_LANCESTQ, @P_TIPOOPER, @V_ITLANCT_CDPRODUTO,
                                         @V_ITLANCT_QTITEMPROD,
                                         @V_ITLANCT_VRTOTAITEM, @V_ITLANCT_VRDESCITEM,
                                         @V_ITLANCT_VRBRUTITEM, @V_ITLANCT_VRCONTITEM,
                                         @V_VRTOTALANCTO, @V_QTDELANCTO, @V_TIPOMOVI, @P_INIVALID,
                                         @V_ITLANCT_CDPRODESTO,
                                         @V_ITLANCT_NRPEDIDO,
                                         @V_ITLANCT_NRITEMPED,
                                         @V_IDTPCOMPPROD,
                                         @V_ITLANCT_CDALMOXARIFE,
                                         @V_ITLANCT_CDLOCALESTOQ;
               END
               ELSE BEGIN
                  SELECT @V_EXISTE_ROT = COUNT(*)
                  FROM COMPITEMPED
                  WHERE
                     CDFILIAL  = @V_ITLANCT_CDFILIMOVI  AND
                     NRPEDIDO  = @V_ITLANCT_NRPEDIDO    AND
                     NRITEMPED = @V_ITLANCT_NRITEMPED   AND
                     CDPRODUTO = @V_ITLANCT_CDPRODUTO;

                  IF (@V_EXISTE_ROT > 0)AND(@V_IDTPCOMPPROD = 'V')  BEGIN

                     EXEC INSERE_SUBPRODMAN @P_FILIAL, @P_LANCESTQ, @P_TIPOOPER, @V_ITLANCT_CDPRODUTO,
                                         @V_ITLANCT_QTITEMPROD,
                                         @V_ITLANCT_VRTOTAITEM, @V_ITLANCT_VRDESCITEM,
                                         @V_ITLANCT_VRBRUTITEM, @V_ITLANCT_VRCONTITEM,
                                         @V_VRTOTALANCTO, @V_QTDELANCTO, @V_TIPOMOVI, @P_INIVALID,
                                         @V_ITLANCT_CDPRODESTO,
                                         @V_ITLANCT_NRPEDIDO,
                                         @V_ITLANCT_NRITEMPED,
                                         @V_IDTPCOMPPROD,
                                         @V_ITLANCT_CDALMOXARIFE,
                                         @V_ITLANCT_CDLOCALESTOQ;
                  END
                  ELSE BEGIN

                     IF (@V_IDCNTRESTOQ = 'S') BEGIN
                        SELECT @V_FATOCONV = MAX(VRFATOCONV)
                        FROM   PRODUTO
                        WHERE  CDPRODUTO = @V_ITLANCT_CDPRODUTO;

                        IF (@V_FATOCONV IS NULL) OR (@V_FATOCONV = 0) BEGIN
                           SET @V_FATOCONV = 1;
                        END;

                        SET @V_QTDELANCTO   = @V_ITLANCT_QTITEMPROD;
                        SET @V_VRTOTALANCTO = @V_ITLANCT_VRTOTAITEM - @V_ITLANCT_VRDESCITEM;

                        IF NOT(@V_QTDELANCTO = 0) BEGIN
                           SET @V_VRUNITLANCTO = @V_VRTOTALANCTO/@V_QTDELANCTO;
                        END
                        ELSE BEGIN
                           SET @V_VRUNITLANCTO = @V_VRTOTALANCTO;
                        END;

                        IF (@V_IDOPERDEVONF = 'S') BEGIN
                           IF (@V_QTDELANCTO <> 0) BEGIN
                              SET @V_TOTABRUT   = (@V_ITLANCT_VRBRUTITEM/@V_QTDELANCTO)/@V_FATOCONV;
                              SET @V_TOTACONTAB = (@V_ITLANCT_VRCONTITEM/@V_QTDELANCTO)/@V_FATOCONV;
                           END
                           ELSE BEGIN
                              SET @V_TOTABRUT   = @V_ITLANCT_VRBRUTITEM/@V_FATOCONV;
                              SET @V_TOTACONTAB = @V_ITLANCT_VRCONTITEM/@V_FATOCONV;
                           END;
                        END
                        ELSE BEGIN
                           SET @V_TOTABRUT   = 0;
                           SET @V_TOTACONTAB = 0;
                        END;

                        IF (@V_IDOPERDEVONF <> 'S') OR
                           ((@V_IDOPERDEVONF = 'S') AND (@V_QTDELANCTO <> 0)) BEGIN

                           SELECT @V_NRSEQITPROD = ISNULL(MAX(NRSEQUITEM),0) + 1
                           FROM   ITLANCTOEST
                           WHERE  CDFILIAL   = @P_FILIAL AND
                                  NRLANCESTQ = @P_LANCESTQ;

                           INSERT INTO ITLANCTOEST
                              (CDFILIAL,NRLANCESTQ,NRSEQUITEM,CDPRODUTO,QTTOTLANCTO,VRUNILANCTO,VRTOTLANCTO,
                               IDTIPOMOVI,DTLANCMOVI,IDORDEMCLC,CDPRODMOVI,QTLANCTOEST,VRLANCTOBRUT, VRLANCTOEST,
                               CDFILIMOVI,CDALMOXARIFE,CDLOCALESTOQ,NRLOTEESTQ,NRSUBLOTE,NRLANCORIGRP)
                           VALUES
                              (@P_FILIAL, @P_LANCESTQ, RIGHT(REPLICATE('0',4) + @V_NRSEQITPROD,4), @V_ITLANCT_CDPRODUTO,
                               @V_QTDELANCTO, @V_VRUNITLANCTO, @V_VRTOTALANCTO,
                               @V_TIPOMOVI, @P_INIVALID, '8', @V_ITLANCT_CDPRODESTO,
                               (@V_QTDELANCTO * @V_FATOCONV), @V_TOTABRUT, @V_TOTACONTAB,
                               @V_CDFILIEMIT, @V_ITLANCT_CDALMOXARIFE, @V_ITLANCT_CDLOCALESTOQ, @V_ITLANCT_NRLOTEESTQ,
                               @V_ITLANCT_NRSUBLOTE, @V_IDDOCESTOQ);
                        END;
                     END;
                  END;
               END;   /* FIM DO IF DO SISTEMA */
            END;
            FETCH NEXT FROM C_ITLANCTOEST INTO @V_ITLANCT_NRSEQITPROD, @V_ITLANCT_CDPRODUTO, @V_ITLANCT_VRUNITITEM,
                         @V_ITLANCT_VRTOTAITEM,   @V_ITLANCT_CDFILIMOVI, @V_ITLANCT_QTITEMPROD, @V_ITLANCT_CDPRODESTO,
                         @V_ITLANCT_VRBRUTITEM,   @V_ITLANCT_VRDESCITEM, @V_ITLANCT_VRCONTITEM,
                         @V_ITLANCT_CDALMOXARIFE, @V_ITLANCT_CDLOCALESTOQ, @V_ITLANCT_NRLOTEESTQ,
                         @V_ITLANCT_NRSUBLOTE,    @V_IDCNTRESTOQ, @V_ITLANCT_NRPEDIDO, @V_ITLANCT_NRITEMPED;
         END;
         CLOSE C_ITLANCTOEST;
         DEALLOCATE C_ITLANCTOEST;
      END
      ELSE BEGIN /* DEMAIS SISTEMAS QUE NO SEJAM EXPEDICAO NEM GESTO DE VENDAS */

         SELECT @V_CDFILIORIG = MAX(CDFILIAL)
           FROM ITEMNOTAFISC
          WHERE CDFILIALIT   = @P_FILIAL
            AND NRLANCTONFIT = @P_LANCTONF;

         DECLARE C_ITLANCTOEST CURSOR FOR
            SELECT NRSEQITPROD,
                   IP.CDPRODUTO,
                   VRUNITITEM,
                   VRTOTAITEM,
                   QTITEMPROD,
                   CDPRODESTO,
                   VRBRUTITEM,
                   VRDESCITEM,
                   VRCONTITEM,
                   ISNULL(IP.CDALMOXARIFE,' ') AS CDALMOXARIFE,
                   ISNULL(IP.CDLOCALESTOQ,' ') AS CDLOCALESTOQ,
                   ISNULL(NRLOTEESTQ,' ') AS NRLOTEESTQ,
                   ISNULL(NRSUBLOTE,' ') AS NRSUBLOTE,
                   ISNULL(VRCONTITEMORIG, 0) VRCONTITEMORIG,
                   ISNULL(VRBRUTITEMORIG, 0) VRBRUTITEMORIG,
                   CDARVPROD, NMPRODUTO, IP.IDORIGEMPROD
            FROM ITEMPRODUTO IP, PRODUTO P, PRODFILI PF
            WHERE IP.CDFILIAL    = @P_FILIAL     AND
                  IP.NRLANCTONF  = @P_LANCTONF   AND
                  P.CDPRODUTO    = IP.CDPRODUTO  AND
                  PF.CDFILIAL    = @V_CDFILIEMIT AND
                  PF.CDPRODUTO   = P.CDPRODESTO  AND
                  ISNULL(IDCNTRESTOQ, 'S') <> 'N';
         OPEN C_ITLANCTOEST;
         FETCH NEXT FROM C_ITLANCTOEST INTO @V_ITLANCT_NRSEQITPROD,
                                            @V_ITLANCT_CDPRODUTO,
                                            @V_ITLANCT_VRUNITITEM,
                                            @V_ITLANCT_VRTOTAITEM,
                                            @V_ITLANCT_QTITEMPROD,
                                            @V_ITLANCT_CDPRODESTO,
                                            @V_ITLANCT_VRBRUTITEM,
                                            @V_ITLANCT_VRDESCITEM,
                                            @V_ITLANCT_VRCONTITEM,
                                            @V_ITLANCT_CDALMOXARIFE,
                                            @V_ITLANCT_CDLOCALESTOQ,
                                            @V_ITLANCT_NRLOTEESTQ,
                                            @V_ITLANCT_NRSUBLOTE,
                                            @V_ITLANCT_VRCONTITEMORIG,
                                            @V_ITLANCT_VRBRUTITEMORIG,
                                            @V_ITLANCT_CDARVPROD,
                                            @V_ITLANCT_NMPRODUTO,
                                            @V_ITLANCT_IDORIGEMPROD;
         WHILE (@@FETCH_STATUS = 0) BEGIN

            UPDATE ITEMPRODUTO
            SET CDPRODMOVI = @V_ITLANCT_CDPRODESTO
            WHERE (CDFILIAL    = @P_FILIAL)    AND
                  (NRLANCTONF  = @P_LANCTONF ) AND
                  (NRSEQITPROD = @V_ITLANCT_NRSEQITPROD);

            SELECT @V_IDATUESTTPOP = ISNULL(IDATUESTTPOP, 'S'), 
                   @V_IDREMESSAINDU = ISNULL(IDREMESSAINDU, 'N')
              FROM TIPOOPERAC
             WHERE IDENTRSAIDOP = 'S'
               AND CDTIPOOPER = @P_TIPOOPER;

            IF (@V_IDUTILALMOX <> 'S' AND  @V_IDUTILLCESTQ <> 'S' AND @V_IDUTILLOTE <> 'S') BEGIN
               UPDATE ITEMPRODUTO
               SET CDALMOXARIFE  = ' ',
                   CDLOCALESTOQ  = ' ',
                   NRLOTEESTQ    = ' ',
                   NRSUBLOTE     = ' '
               WHERE (CDFILIAL     = @P_FILIAL)    AND
                     (NRLANCTONF   = @P_LANCTONF ) AND
                     (NRSEQITPROD  = @V_ITLANCT_NRSEQITPROD)  AND
                     ((CDALMOXARIFE IS NULL)       OR
                      (CDLOCALESTOQ IS NULL)       OR
                      (NRLOTEESTQ   IS NULL)       OR
                      (NRSUBLOTE    IS NULL));
            END;

            SELECT @V_FATOCONV = MAX(VRFATOCONV)
            FROM PRODUTO P, ITEMPRODUTO IP
            WHERE P.CDPRODUTO    = IP.CDPRODUTO  AND
                  IP.CDFILIAL    = @P_FILIAL     AND
                  IP.NRLANCTONF  = @P_LANCTONF   AND
                  IP.NRSEQITPROD = @V_ITLANCT_NRSEQITPROD;

            IF (@V_FATOCONV IS NULL) OR (@V_FATOCONV = 0) BEGIN
               SET @V_FATOCONV = 1;
            END;

            SET @V_QTDELANCTO   = @V_ITLANCT_QTITEMPROD;
            SET @V_VRTOTALANCTO = @V_ITLANCT_VRTOTAITEM - @V_ITLANCT_VRDESCITEM;

            IF NOT(@V_QTDELANCTO = 0) BEGIN
               SET @V_VRUNITLANCTO = @V_VRTOTALANCTO/@V_QTDELANCTO;
            END
            ELSE BEGIN
               SET @V_VRUNITLANCTO = @V_VRTOTALANCTO;
            END;

            IF (@V_IDOPERDEVONF = 'S') OR (@V_IDREMESSAINDU = 'S') BEGIN
               IF (@V_QTDELANCTO <> 0) BEGIN
                  SET @V_TOTABRUT   = (@V_ITLANCT_VRBRUTITEM/@V_QTDELANCTO)/@V_FATOCONV;
                  SET @V_TOTACONTAB = (@V_ITLANCT_VRCONTITEM/@V_QTDELANCTO)/@V_FATOCONV;
                  IF @V_ITLANCT_VRBRUTITEMORIG <> 0 BEGIN
                     SET @V_TOTABRUT = (@V_ITLANCT_VRBRUTITEMORIG/@V_QTDELANCTO)/@V_FATOCONV;
                  END;
                  IF @V_ITLANCT_VRCONTITEMORIG <> 0 BEGIN
                     SET @V_TOTACONTAB = (@V_ITLANCT_VRCONTITEMORIG/@V_QTDELANCTO)/@V_FATOCONV;
                  END;
               END
               ELSE BEGIN
                  SET @V_TOTABRUT   = @V_ITLANCT_VRBRUTITEM/@V_FATOCONV;
                  SET @V_TOTACONTAB = @V_ITLANCT_VRCONTITEM/@V_FATOCONV;
               END;
            END
            ELSE BEGIN
               SET @V_TOTABRUT   = 0;
               SET @V_TOTACONTAB = 0;
            END;

            IF (@V_IDOPERDEVONF <> 'S') OR ((@V_IDOPERDEVONF = 'S') AND (@V_QTDELANCTO <> 0)) BEGIN

               INSERT INTO ITLANCTOEST
                  (CDFILIAL,NRLANCESTQ,NRSEQUITEM,CDPRODUTO,QTTOTLANCTO,VRUNILANCTO,VRTOTLANCTO,
                   IDTIPOMOVI,DTLANCMOVI,IDORDEMCLC,CDPRODMOVI,QTLANCTOEST,VRLANCTOBRUT, VRLANCTOEST,
                   CDFILIMOVI,CDALMOXARIFE,CDLOCALESTOQ,NRLOTEESTQ,NRSUBLOTE,NRLANCORIGRP, IDORIGEMPROD)
               VALUES
                  (@P_FILIAL, @P_LANCESTQ, @V_ITLANCT_NRSEQITPROD,@V_ITLANCT_CDPRODUTO,
                   @V_QTDELANCTO, @V_VRUNITLANCTO, @V_VRTOTALANCTO,
                   @V_TIPOMOVI, @P_INIVALID,'8', @V_ITLANCT_CDPRODESTO,
                   (@V_QTDELANCTO * @V_FATOCONV), @V_TOTABRUT, @V_TOTACONTAB,
                   @V_CDFILIEMIT, @V_ITLANCT_CDALMOXARIFE, @V_ITLANCT_CDLOCALESTOQ, @V_ITLANCT_NRLOTEESTQ,
                   @V_ITLANCT_NRSUBLOTE, @V_IDDOCESTOQ, @V_ITLANCT_IDORIGEMPROD);
            END;

            /* Se NF Remessa para Industrializao e Operao Atualiza Estoque */
            IF (@V_IDREMESSAINDU = 'S') AND (@V_IDATUESTTPOP = 'S') BEGIN
               IF @V_IDORIGDESTNF = 'C' BEGIN
                  SELECT @V_CDALMOXINFO = ISNULL(CDALMOXINFOCLI, ' '),
                         @V_CDLOCALINFO = ISNULL(CDLOCALINFOCLI, ' ')
                    FROM AGENTETERCECLI
                   WHERE CDFILIAL = @V_CDFILIEMIT
                     AND CDCLIENTE = @P_CLIENTE;
               END;
               IF @V_IDORIGDESTNF = 'F' BEGIN
                  SELECT @V_CDALMOXINFO = ISNULL(CDALMOXINFOFOR, ' '),
                         @V_CDLOCALINFO = ISNULL(CDLOCALINFOFOR, ' ')
                    FROM AGENTETERCEFOR
                   WHERE CDFILIAL = @V_CDFILIEMIT
                     AND CDFORNECED = @P_CLIENTE;
                  SET @V_CDFILIAGENT = NULL;

                  SELECT @V_CDFILIAGENT = CDFILIAL
                    FROM FILIAL
                   WHERE CDFORNAGETERC = @P_CLIENTE;

                  IF NOT @V_CDFILIAGENT IS NULL BEGIN
                     SET @V_CDALMOXARIFEAG = ' ';
                     SET @V_CDLOCALESTOQAG = ' ';
                     SET @V_IDUTILLOTEAG   = 'N';

                     SELECT @V_CDALMOXARIFEAG = ISNULL(ISNULL(P.CDALMOXARIFE, F.CDALMOXARIFE), ' '),
                            @V_CDLOCALESTOQAG = ISNULL(ISNULL(P.CDLOCALESTOQ, F.CDLOCALESTOQ), ' '),
                            @V_IDUTILLOTEAG = ISNULL(F.IDUTILLOTE, 'N')
                       FROM PARAMFILIAL F, PRODFILI P
                      WHERE F.CDFILIAL  = @V_CDFILIAGENT
                        AND P.CDFILIAL  = @V_CDFILIAGENT
                        AND P.CDPRODUTO = @V_ITLANCT_CDPRODESTO;

                     SET @V_CDEMPRESAAG  = NULL;
                     SET @V_CDINSCESTAAG = NULL;
                     SET @V_CDINSCMUNIAG = NULL;

                     SELECT @V_CDEMPRESAAG = CDEMPRESA, @V_CDINSCESTAAG = CDINSCESTA, @V_CDINSCMUNIAG = CDINSCMUNI
                       FROM FILIAL
                      WHERE CDFILIAL  = @V_CDFILIAGENT;

                     IF @V_IDUTILLOTEAG = 'S' BEGIN
                        IF (@V_NRLOTEESTQAG IS NULL) OR (@V_NRLOTEESTQAG = ' ') BEGIN
                           EXEC PRXLOTEPRODEST @V_CDFILIAGENT, @P_INIVALID, @V_ITLANCT_CDPRODESTO, @V_NRLOTEESTQAG;
                           SET @V_NRSUBLOTEAG = ' ';
                        END;
                     END
                     ELSE BEGIN
                        SET @V_NRLOTEESTQAG = ' ';
                        SET @V_NRSUBLOTEAG  = ' ';
                     END;
                  END;
               END;
               IF (@V_CDALMOXINFO IS NOT NULL) AND (@V_CDALMOXINFO <> ' ') AND (@V_CDFILIAGENT IS NULL)  BEGIN
                  
                  IF @V_BOLANESTENTR = 1 BEGIN
                     --GERANDO O REGISTRO NA TABELA LANCTOESTOQ PARA A ENTRADA NO ALMOXAXARIFADO 
                     IF (@V_NRLANESTENTR IS NULL) OR (@V_NRLANESTENTR = '') BEGIN
                        BEGIN TRANSACTION NOVO_CODIGO_SC
                        SET @V_TEXT = 'LANCTOEST' + @P_FILIAL;
                        EXEC NOVO_CODIGO_SC @V_TEXT, @P_SEQUENCIAL = @V_NRLANESTENTR OUTPUT;
                        SET @V_NRLANESTENTR = SUBSTRING(@V_NRLANESTENTR, 11, 10);
                        COMMIT TRANSACTION NOVO_CODIGO_SC
                     END;
                  
                     INSERT INTO LANCTOESTOQ
                        (CDFILIAL,
                         NRLANCESTQ,
                         IDTPLANCTO,
                         DTLANCESTQ,
                         DSLANCESTQ,
                         CDFILIMOVI,
                         CDOPERADOR)
                     VALUES
                        (@P_FILIAL,
                         @V_NRLANESTENTR,
                         '2',
                         @P_INIVALID,
                         'Transferncia de Estoque ' + @V_NRLANESTENTR,
                         @V_CDFILIEMIT,
                         @P_CDOPERADOR);

                     --GERANDO O REGISTRO NA TABELA CTRLMOVIESTQ
                     IF (@V_NRCTRLMOVEST IS NULL) OR (@V_NRCTRLMOVEST = '') BEGIN
                        BEGIN TRANSACTION NOVO_CODIGO_SC
                        SET @V_TEXT = 'NRTRANSESTQ' + @V_CDFILIEMIT;
                        EXEC NOVO_CODIGO_SC @V_TEXT, @P_SEQUENCIAL = @V_NRCTRLMOVEST;
                        SET @V_NRCTRLMOVEST = SUBSTRING(@V_NRCTRLMOVEST, 11, 10);
                        COMMIT TRANSACTION NOVO_CODIGO_SC
                     END;
                  
                     INSERT INTO CTRLMOVIESTQ
                        (CDFILIAL,
                         NRCTRLMOVEST,
                         CDFILIALENTR,
                         NRLANESTENTR,
                         CDFILIALSAID,
                         NRLANESTSAID,
                         CDALMOXENTR,
                         CDALMOXSAID,
                         CDLCESTENTR,
                         CDLCESTSAID,
                         DTMOVIESTQ,
                         NRREQUESTO)
                     VALUES
                        (@V_CDFILIEMIT,
                         @V_NRCTRLMOVEST,
                         @P_FILIAL,
                         @V_NRLANESTENTR,
                         @P_FILIAL,
                         @P_LANCESTQ,
                         @V_CDALMOXINFO,
                         @V_ITLANCT_CDALMOXARIFE,
                         @V_CDLOCALINFO,
                         @V_ITLANCT_CDLOCALESTOQ,
                         @P_INIVALID,
                         '');
                     
                     SET @V_BOLANESTENTR = 0;
                  END;

                  --GERANDO O REGISTRO NA TABELA ITLANCTOEST
                  INSERT INTO ITLANCTOEST
                     (CDFILIAL,
                      NRLANCESTQ,
                      NRSEQUITEM,
                      CDPRODUTO,
                      DSLANCESTIT,
                      CDALMOXARIFE,
                      CDLOCALESTOQ,
                      NRLOTEESTQ,
                      NRSUBLOTE,
                      CDFILIMOVI,
                      CDPRODMOVI,
                      IDORDEMCLC,
                      DTLANCMOVI,
                      IDEVOLESTOQ,
                      QTTOTLANCTO,
                      IDTIPOMOVI,
                      QTLANCTOEST,
                      VRUNILANCTO,
                      VRTOTLANCTO,
                      VRLANCTOEST,
                      VRLANCTOBRUT,
                      IDORIGEMPROD)
                  VALUES
                     (@P_FILIAL,
                     @V_NRLANESTENTR,
                     @V_ITLANCT_NRSEQITPROD,
                     @V_ITLANCT_CDPRODUTO,
                     '',
                     @V_CDALMOXINFO,
                     @V_CDLOCALINFO,
                     @V_ITLANCT_NRLOTEESTQ,
                     @V_ITLANCT_NRSUBLOTE,
                     @V_CDFILIEMIT,
                     @V_ITLANCT_CDPRODESTO,
                     '2',
                     @P_INIVALID,
                     'S',
                     @V_QTDELANCTO,
                     '2',
                     @V_QTDELANCTO * @V_FATOCONV,
                     @V_VRUNITLANCTO,
                     @V_VRTOTALANCTO,
                     @V_TOTACONTAB,
                     @V_TOTABRUT,
                     @V_ITLANCT_IDORIGEMPROD);
               END
               ELSE BEGIN
                  /* Se o fornecedor da nota fiscal for agente de terceirizao */
                  IF NOT @V_CDFILIAGENT IS NULL BEGIN
                     IF @V_CDFILIORIG IS NULL BEGIN
                        IF @V_BOLANESTENTRAG = 1 BEGIN
                           /* Gerando o registro na tabela LANCTOESTOQ para a entrada na filial relacionada ao agente de terceirizao */
                           SET @V_NOVO_CODIGO_NT = 'LANCNF/FILIAL' + @V_CDFILIAGENT;
                           EXEC NOVO_CODIGO_SC @V_NOVO_CODIGO, @P_SEQUENCIAL = @V_NRLANCTONFAG OUTPUT, @P_QTDE = 1;
                           SET @V_NRLANCTONFAG = SUBSTRING(@V_NRLANCTONFAG, 11, 10);

                           SET @V_NOVO_CODIGO_NT = 'LANCTOEST' + @V_CDFILIAGENT;
                           EXEC NOVO_CODIGO_SC @V_NOVO_CODIGO_NT, @P_SEQUENCIAL = @V_NRLANESTENTRAG OUTPUT, @P_QTDE = 1;
                           SET @V_NRLANESTENTRAG = SUBSTRING(@V_NRLANESTENTRAG, 11, 10);

                           SET @V_TPOPERRETORNO = NULL;

                           SELECT @V_TPOPERRETORNO = CDTPOOPRETORNO
                             FROM PARAMGERAL
                            WHERE CDPARGERAL = '0001';


                           IF (@V_TPOPERRETORNO  IS NULL) BEGIN
                              RAISERROR('Tipo de operao para gerao de lanamento de estoque deve ser informado - (Parmetros para Documentos Fiscais de Sada - Operador Logstico)', 16,1);
                           END;

                           INSERT INTO NOTAFISCAL
                              (CDFILIAL, NRLANCTONF, CDFILIRECE, CDEMPRESA, CDINSCESTA, CDSERIE, CDINSCMUNI,
                               IDTPIJURNF, NRINSJURNF, CDFORNECED, IDBLOQUEADO, IDDOCFISCAL, IDDOCFINANC,
                               NRNOTAFISC, DTEMISSAO, DTENTRSAID, VRPRODUTOS, VRNOTAFISC, IDENTRSAIDOP,
                               CDTIPOOPER, CDSERIEENTR, CDCLIENTE, CDFILIEMIT, IDORIGDESTNF)
                           VALUES
                              (@V_CDFILIAGENT, @V_NRLANCTONFAG, @V_CDFILIAGENT, @V_CDEMPRESAAG, @V_CDINSCESTAAG, NULL, @V_CDINSCMUNIAG,
                               @V_IDTPIJURNF, @V_NRINSJURNF, @P_CLIENTE, 'N', 'N', 'S',
                               NULL, @P_INIVALID, @P_INIVALID, ISNULL(@V_LIQUIDO,0), ISNULL(@V_TOTALNOTA,0), 'E',
                               @V_TPOPERRETORNO, NULL, NULL, NULL, @V_IDORIGDESTNF);

                           INSERT INTO ITEMNOTAFISC
                              (CDFILIAL, NRLANCTONF, NRSEQUITNOTA, CDFILIALIT, NRLANCTONFIT)
                           VALUES
                              (@V_CDFILIAGENT, @V_NRLANCTONFAG, '001', @P_FILIAL, @P_LANCTONF);

                           INSERT INTO LANCTOESTOQ
                              (CDFILIAL,
                               NRLANCESTQ,
                               NRLANCTONF,
                               IDTPLANCTO,
                               DTLANCESTQ,
                               DSLANCESTQ,
                               CDFILIMOVI,
                               CDOPERADOR)
                           VALUES
                              (@V_CDFILIAGENT,
                               @V_NRLANESTENTRAG,
                               @V_NRLANCTONFAG,
                               'E',
                               @P_INIVALID,
                               'NF Remessa Armazenagem - lan. ' + @V_CDFILIEMIT + ' ' + @P_LANCTONF,
                               @V_CDFILIAGENT,
                               @P_CDOPERADOR);

                           SET @V_BOLANESTENTRAG = 0;
                        END;

                        INSERT INTO ITEMPRODUTO
                           (CDFILIAL, NRLANCTONF, NRSEQITPROD, CDPRODUTO,
                            CDPRODEMIS, DSPRODEMIS, IDATUVRESTOQ, QTITEMPROD,
                            VRUNITITEM, VRDESCITEM, VRTOTAITEM, VRCONTITEM,
                            VRBRUTITEM, IDCONFORITEM, CDFILIMOVI,
                            CDALMOXARIFE, CDLOCALESTOQ, NRLOTEESTQ, NRSUBLOTE,
                            CDPRODMOVI)
                        VALUES
                           (@V_CDFILIAGENT, @V_NRLANCTONFAG, @V_ITLANCT_NRSEQITPROD, @V_ITLANCT_CDPRODUTO,
                            @V_ITLANCT_CDARVPROD,@V_ITLANCT_NMPRODUTO, 'S', @V_QTDELANCTO,
                            @V_VRUNITLANCTO, @V_ITLANCT_VRDESCITEM, @V_VRTOTALANCTO, @V_VRTOTALANCTO,
                            @V_VRTOTALANCTO, 'S', @V_CDFILIAGENT,
                            @V_CDALMOXARIFEAG, @V_CDLOCALESTOQAG, @V_NRLOTEESTQAG, @V_NRSUBLOTEAG,
                            @V_ITLANCT_CDPRODESTO);

                        INSERT INTO ITLANCTOEST
                           (CDFILIAL,
                            NRLANCESTQ,
                            NRSEQUITEM,
                            CDPRODUTO,
                            DSLANCESTIT,
                            CDALMOXARIFE,
                            CDLOCALESTOQ,
                            NRLOTEESTQ,
                            NRSUBLOTE,
                            CDFILIMOVI,
                            CDPRODMOVI,
                            IDORDEMCLC,
                            DTLANCMOVI,
                            IDEVOLESTOQ,
                            QTTOTLANCTO,
                            IDTIPOMOVI,
                            QTLANCTOEST,
                            VRUNILANCTO,
                            VRTOTLANCTO,
                            VRLANCTOEST,
                            VRLANCTOBRUT,
                            IDORIGEMPROD)
                        VALUES
                           (@V_CDFILIAGENT,
                            @V_NRLANESTENTRAG,
                            @V_ITLANCT_NRSEQITPROD,
                            @V_ITLANCT_CDPRODUTO,
                            '',
                            @V_CDALMOXARIFEAG,
                            @V_CDLOCALESTOQAG,
                            @V_NRLOTEESTQAG,
                            @V_NRSUBLOTEAG,
                            @V_CDFILIAGENT,
                            @V_ITLANCT_CDPRODESTO,
                            '2',
                            @P_INIVALID,
                            'S',
                            @V_QTDELANCTO,
                            '2',
                            @V_QTDELANCTO * @V_FATOCONV,
                            @V_VRUNITLANCTO,
                            @V_VRTOTALANCTO,
                            @V_TOTACONTAB,
                            @V_TOTABRUT,
                            @V_ITLANCT_IDORIGEMPROD);
                     END;
                  END;
               END;
            END;

            FETCH NEXT FROM C_ITLANCTOEST INTO @V_ITLANCT_NRSEQITPROD,
                                               @V_ITLANCT_CDPRODUTO,
                                               @V_ITLANCT_VRUNITITEM,
                                               @V_ITLANCT_VRTOTAITEM,
                                               @V_ITLANCT_QTITEMPROD,
                                               @V_ITLANCT_CDPRODESTO,
                                               @V_ITLANCT_VRBRUTITEM,
                                               @V_ITLANCT_VRDESCITEM,
                                               @V_ITLANCT_VRCONTITEM,
                                               @V_ITLANCT_CDALMOXARIFE,
                                               @V_ITLANCT_CDLOCALESTOQ,
                                               @V_ITLANCT_NRLOTEESTQ,
                                               @V_ITLANCT_NRSUBLOTE,
                                               @V_ITLANCT_VRCONTITEMORIG,
                                               @V_ITLANCT_VRBRUTITEMORIG,
                                               @V_ITLANCT_CDARVPROD,
                                               @V_ITLANCT_NMPRODUTO,
                                               @V_ITLANCT_IDORIGEMPROD;
         END;
         CLOSE C_ITLANCTOEST;
         DEALLOCATE C_ITLANCTOEST;
      END;
   END;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'IMPOSTO_SAIDA','6.25.xxx';
GO
